### Changelog

All notable changes to this project will be documented in this file. Dates are displayed in UTC.

#### [v10.0.26.dev1](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/10.0.25...v10.0.26.dev1)

- Refactored a core log entry from info to debug [`f7feab5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f7feab5c1ddd23d11ec411f75c90a307262db544)

#### [10.0.25](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/10.0.24...10.0.25)

> 3 August 2021

- Fixed ValueError sickrage.core.searchers.backlog_searcher in _get_wanted [`1633328`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1633328e43dede0070c144748f5b2dafa10eeffd)

#### [10.0.24](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/10.0.23...10.0.24)

> 2 August 2021

#### [10.0.23](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/10.0.22...10.0.23)

> 1 August 2021

- Refactored web handlers to return data and call tornado finish on resp from run_async method [`a7bffda`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a7bffda58098baab6b9392bef05ff92fbe43690c)
- Refactored web handlers to return data and call tornado finish on resp from run_async method [`7635d83`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7635d83894ecdaa8b72f5f3e3918e24eff8aa37e)
- Refactored web handlers to return data and call tornado finish on resp from run_async method [`98396dc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/98396dc7f97b2b355fee8e9271b418a65a74f370)

#### [10.0.22](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/10.0.21...10.0.22)

> 1 August 2021

- Moved websocket queue check function to webserver class [`18042f3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/18042f35c632962689f8854d24c09422ceaf666c)

#### [10.0.21](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/10.0.20...10.0.21)

> 1 August 2021

#### [10.0.20](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/10.0.19...10.0.20)

> 31 July 2021

#### [10.0.19](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/10.0.18...10.0.19)

> 30 July 2021

#### [10.0.18](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/10.0.17...10.0.18)

> 29 July 2021

#### [10.0.17](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/10.0.16...10.0.17)

> 29 July 2021

#### [10.0.16](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/10.0.15...10.0.16)

> 29 July 2021

#### [10.0.15](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/10.0.14...10.0.15)

> 28 July 2021

#### [10.0.14](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/10.0.13...10.0.14)

> 28 July 2021

- Refactored app updating for source [`9d7a3f8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9d7a3f8bf832152bdfed6eb10f71c7d18d5f7c10)

#### [10.0.13](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/10.0.12...10.0.13)

> 28 July 2021

#### [10.0.12](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/10.0.11...10.0.12)

> 28 July 2021

- Refactored episode slug to sXXeXX [`993479f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/993479fd84e3c97cc172efaf5dd5cfa395dbce3a)
- Misc fixes for series api v2 [`a86cc48`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a86cc485efd6072954a658f9741bdbfff90414c8)
- Refactored multi-project pipeline strategy to depend for CI script [`776e1f6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/776e1f6e7c5dec268956e8da162982185c60e807)
- Fixed `bad substitution` error in gitlab CI script [`bd8c393`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bd8c3932237246fef5007687fc4158ded90b840e)
- Refactored gitlab CI script [`6df07cc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6df07ccfd97c99da3746509c705a67471a327d13)
- Fixed git origin URL [`5d50c4f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5d50c4fa53a2e639190e8df358c8a5780b237c56)

#### [10.0.11](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/10.0.10...10.0.11)

> 11 March 2021

- Fixed issue with show refresh tasks getting stuck due to missing dependant task being cleared prematurely [`4ddbd58`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4ddbd581468c98eed8157c4fdd23fe33a9f50b4b)
- Refactred "Malformed air date" warnings to debug messages during loading data from series providers for episodes [`cb5551d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cb5551dc037d330b3dd796babb025dcc9691bc3d)

#### [10.0.10](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/10.0.9...10.0.10)

> 21 February 2021

- Fixed issues with mass episode status editing [`3e21025`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3e21025960645f480f6b366f9fd6d6603c874e44)
- Fixed issues with mass editing show search format and default episode status [`34e22ae`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/34e22ae4b3738a45eec384df72936e740bd55fcf)

#### [10.0.9](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/10.0.8...10.0.9)

> 8 February 2021

- Performed webpack [`03897ba`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/03897baf59f8bbf2f73449905b5c1de93be821d7)
- Fixed "Multiple rows were found for one_or_none()" exception when getting json object of episode object [`5761806`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5761806f6896148c6250c236faa489ba847258fc)
- Fixed issue with deploy of PyPi image [`18c3cbf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/18c3cbf43db10e234c3d544c0854abf614dd3ef2)
- Updated CI to use python 3.9 [`58ab668`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/58ab668fb584cc95a7534c83f3faa33be1e2308a)

#### [10.0.8](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/10.0.7...10.0.8)

> 26 January 2021

- Removed ability to set web host from settings in UI, constrained to only setting from cli. [`c17dc55`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c17dc551de4d6df4f4b20b96fb3d94bba086966e)
- Removed IRC from main layout [`87a989d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/87a989dc9f05308ea9fd6c23aad53d0249219624)
- Fixed issue with provider options not appearing in settings [`256e1df`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/256e1df2636a8810cfa85120ce323f5967a7e4da)
- Replaced get_lan_ip with get_internal_ip [`fa55c2c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fa55c2c97f156755ece800e46632bb7feb36977b)
- Fixed `invalid literal for int() with base 10` when attempting to mass edit default episode statuses [`a7dd0d7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a7dd0d7d8999ca6554a33dc5d4b3a3b0c4ca2033)

#### [10.0.7](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/10.0.6...10.0.7)

> 15 January 2021

#### [10.0.6](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/10.0.5...10.0.6)

> 14 January 2021

- Fixed issue with launching browser after app starts up via scheduler [`f554180`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f5541800645d5b78fb4723a9a194269fde283378)

#### [10.0.5](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/10.0.4...10.0.5)

> 14 January 2021

- Minor changes to CI script [`b9dd99c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b9dd99c21200368d4a1a11eb663cd1de5beeb044)

#### [10.0.4](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/10.0.3...10.0.4)

> 14 January 2021

- Fixed issue with searching for new shows [`4d571f8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4d571f8636feb1269705fc829721ac1fc7ef5860)
- Implemented abstract class in web base handler [`e9812be`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e9812be71593a35b0987e30ec7135f51b98afcae)
- Fixed issues with cascade database deletions [`4e8421c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4e8421c376baedd4c2e751b435916e1e71fa85de)
- Decreased noise of saving config during auth methods [`5322d50`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5322d507dd26c57d7ccb701241ec7380d56adcc0)
- Refactored CI script to update changelog in separate stage [`18f98b0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/18f98b04ac7ca43867752c5c6b1a2ccce72c783d)
- Fixed CI script and merge issues between develop and master branches [`149d52e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/149d52ee513080b794396b5e065db71ad17dff90)
- Moved changelog creation to happen in release branch [`506bac0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/506bac022497ac9c0d1c28f24dea5df2796931b4)
- Fixed unterminated string in CI script [`4ab3dbd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4ab3dbd401afe04015c95eb27eae503b892dd9b1)

#### [10.0.3](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/10.0.2...10.0.3)

> 12 January 2021

- Database code for migrating py2 codernitydb files is now depreciated and removed [`88b4cdf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/88b4cdff8eb95937bcbd013bc182245e9b3445ad)
- Further work done to subtitle refiners [`a25c7df`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a25c7df114ba831972aae9d5d9d58aa91dd3d258)
- When updating sub_id, mark config database dirty before saving [`db592df`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/db592df88a08ec26eeb1242190928ae5647d729d)
- Misc cleanup [`b162bac`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b162bac49b5a12a99fbdfd4ae28d280dfadf81d1)
- Removed left over code from testing [`619a0b2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/619a0b2e60101c818e7e69a2debcdc9ed229a94f)
- During config file migration to config database, initial user is granted superuser permissions now [`c484e5e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c484e5e387cf77c288c56525084c2aa564f1ed5e)

#### [10.0.2](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/10.0.1...10.0.2)

> 11 January 2021

- Fixed issue with multi-episode naming [`dad674a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dad674ace8c9b04bffa042ea2ef289c37c10f1b3)
- Fixed issue with failed snatched episodes [`f5f44bc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f5f44bc47fd6105ed28f07a99322b3da1d00a207)
- Fixed issue with sorting poster view by name [`6c5adf0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6c5adf0d402ce514df99c012536241730806f5c1)

#### [10.0.1](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/10.0.0...10.0.1)

> 11 January 2021

- Fixed issue with database upgrades, refactored database initialization to happen after migrations and upgrades are performed [`bcd24c3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bcd24c38683de82c3fbf733c3a99ce3761a28cff)

### [10.0.0](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.223...10.0.0)

> 11 January 2021

- Config settings are now stored and encrypted into a sqlite database [`acd1757`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/acd175780cb5d948eb3fba7ceb6092e9c8c8b33a)
- Refactored config and how it handles database sessions [`574f983`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/574f983270aae904224d550e22145c3bd4f26c8e)
- Fixed issue with migration of config.ini to config.db [`3b56918`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3b56918a61555212757a10b91573e3934f4e7b38)
- Refactored to re-initialize database after alembic upgrades [`a314767`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a31476725d342adb03c1a0d9e469a8c6ec5a7b80)
- Fixed issue with setting default quality options for new/existing shows [`439c6f9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/439c6f94c4d1f2eed57f1bcdd55faa65374b4a6f)
- Fixed issue with migration of config.ini to config.db [`f05bd79`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f05bd79b921e1fcbde971822cadb81c400d2e8fd)
- Fixed issue with default auth method being chosen during config migration [`fedbe48`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fedbe48c2880aedd89d6c9d91c94e29ca1864061)
- Fixed issue with configuration migration [`5780cfa`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5780cfa0b59bfd7269e6b01b55817ec709818a24)
- Refactored task action_id property to action [`c51340c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c51340c69b6b3c878b729f02bcb22c86fbb2c314)
- Refactored web server write_error function to log issues using error handler [`4edc0d8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4edc0d8364e6c2218a3045029387f0426796b815)
- Refactored web handler for getting manual search statuses [`4f211c0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4f211c0875a3cba76ec7bba9cf996916cc34ae5a)
- Refactored requirements to be installed one-by-one during version updates [`4c33752`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4c3375252f088c40e7053434b006c4fe7918f5a7)
- Reverted previous changes [`f423954`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f423954f9e008864ef234b21ecffccc6c2e08df2)
- Fixed issue with quicksearch and episodes [`770cddb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/770cddb5d03d7cfc2100166f431cf3bfe05514ec)
- Fixed issue with testing torrent and nzb search clients [`ae57c6d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ae57c6d9e8f92d8ef355ba7c6866f4d51cd4cfe2)
- Fixed issue with episode status manage view [`9922419`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/992241900c499c5c30a20623399f6a225e3a90c2)
- Fixed stage names for CI script [`b416eaa`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b416eaa15d7914c5c05cfba8b86e4f90f0d1fc9c)
- Fixed issue with CI script [`7822c90`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7822c90d6ad6d89d07c05a0de707c205a8dcf657)
- Fixed issue with provider cache and series provider id enum's [`063405b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/063405bde90ba81435a29da297b9fac1bc932d44)
- Fixed issues with mapped series provider id's to series id's [`1c3481f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1c3481ff31dede64a8b1d542bc245d368d0eb7ac)
- Fixed issue with adding new show using custom quality settings [`d206d05`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d206d05746c2a60de77c3d3f9df6cc5650fc684a)
- Fixed issue with switching home page layout [`0303d22`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0303d22c3c47949765d6f550c4d3b19fbd0654e6)
- Fixed issue with schedule view and sorting [`81493a9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/81493a9f21d296f0e92f8071dc134c5b4e174d8e)
- Fixed issue with manage backlog overview page and overview classes [`73f1042`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/73f1042db9e5d083e61945625c245241973d161e)
- Fixed issues with adding shows from IMDb [`b3215de`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b3215debb23a1789f340a2613e7c6c486b91e2ac)
- Fixed issues with switch-over from sqlalchemy-migrate to alembic migration engine [`f7ad701`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f7ad70160e47e0a9e2a70a50920533066828d44f)
- Fixed issues with incorrect separator being used for subtitle services enabled and subtitle extra scripts [`a5350d0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a5350d0fee90c58ef4c7b594c27f9f86e2b4dc5d)
- Fixed issue with specials not being retrieved from series providers [`7b3ae92`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7b3ae9233630ab11d5d12d99bc8c2528d8b2b113)
- Fixed issue with main home view and not selecting a layout choice after looking at layout choices causing a redirect to undefined [`b656661`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b65666128645106afc41e122ef5e273f42c3c093)
- Fixed issue with migration of config.ini to config.db [`471da17`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/471da170f18995c7fb3d0affc98cf91cafd28c5a)
- Fixed incorrect passed startup command for web host setting [`2922632`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/292263287e5024faed12a1dd9957e3a67213081b)
- Fixed issue with indexer caching [`992f519`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/992f51990a88f6c1764ca1b959da815e68999fc6)
- Commented out the removal of sub_id for this present moment till further code corrections are made [`4d14a72`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4d14a72e392e0989194e2858f39cdaf1103be24a)
- Performed webpack [`ac6cce3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ac6cce38cd0d6cb40b8e228b1d4899d4555021f5)
- Prevent null value when adding last_xem_refresh via alembic [`e738401`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e73840191a6ac0b770284da204371817eeb047ad)
- Fixed issue with being able to view debug logs [`474763e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/474763eb624ca164c94cdfb3478c2c4173d2bf3a)
- Fixed issue with searching series providers for series id by term during name parsing [`b84a57f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b84a57f1b58031503216c3bf631b6d28bd2d82b4)
- Major version bump to v10.0.0 [`3131c33`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3131c33aa2067f4af610b796ff33ef5db17a7ba6)
- Fixed issue with updating commit tag [`835d447`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/835d4473f62dbd95ab2670e34cbe159c87b8e72d)
- Fixed issue with forcing backlog for specific shows and passing of the series provider ID [`5f4ad57`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5f4ad5752d4192d2ddc6bcca70e179fd6c21ebfb)
- Bumped version in setup.cfg to 10.0.0.dev1 [`f4dc007`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f4dc0078adddbff6d97e5e54cd32a27b894c0a83)
- Fixed issue #525 - removal of shows not taking due to database commit not being executed [`d615ca6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d615ca6cfa27353c8d0c99037cfcc452a85b4fa1)
- Bumped version is package.json to 10.0.0.dev1 [`606c40b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/606c40b3a5fb0dcf0388ac900ab60fc80232d393)
- Fixed "has no property 'showi'" [`d0c9652`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d0c9652a6e2ca40a4661801c9b7e8a5ea348dda8)
- Updated requirements.txt [`143d3b2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/143d3b27e86c0a4ca981a221084f4b285e8a0b3e)
- Fixed issues with installation of requirements.txt during version updates [`cb0e3ee`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cb0e3ee825ddaea5fa3f230899d2363d1d5e2d04)

#### [9.4.223](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.222...9.4.223)

> 7 September 2020

#### [9.4.222](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.221...9.4.222)

> 31 August 2020

- Fixed issue with scene_season being non-integer [`eb54e81`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/eb54e81cd1b2c3c3a715ec9d20ee4d07e50892c7)
- Updated requirements.txt [`735f900`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/735f9005bcf3fe90c342e53f7ac55cd124aa4b8f)

#### [9.4.221](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.220...9.4.221)

> 19 August 2020

- Fixed issue shutting down scheduler causing an exception which broke restart sequence [`afc00d1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/afc00d10f9641ecd158b9be1ae8b05a6e26628ea)

#### [9.4.220](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.219...9.4.220)

> 19 August 2020

- Fixed issue with duplicate scene absolute numbering, old code removed. [`0c0c07d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0c0c07d3b1bad4977201aa6fe07adb008c19e479)
- Fixed issue with provider cookie verifications [`78f9f15`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/78f9f158f01345a189962e496c8a76aa67a3ea4b)
- Fixed issues with provider results containing both an airdate and season/episode in them being matched as standard to be matched as scene_date_format instead [`2d2906e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2d2906efb5be13b8c3f1cdfaa794262c28807142)

#### [9.4.219](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.218...9.4.219)

> 12 August 2020

- Commented out automatic requirements installation at app startup, needs more work. [`fa085ad`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fa085ad180c6aa5486389fa89b42bb947e1e61bd)
- Refactored requirements.txt to be conditional on python version [`4658183`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/46581833a7611e398c8fae326b0bf18ebdd471c4)
- Downgraded feedparser to v5.2.1 in requirements.txt [`35029d3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/35029d32c2c7965157ad6caaf84aa5ea08219abd)
- Refactored requirements install to use --no-deps, all depends are located in requirements.txt [`69276c9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/69276c9c13aaacef3aa6dbf1078dffda5fa0302c)
- Refactored database restores to use bulk inserts for data, performance fix. [`46496c6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/46496c6e35b617bd91eede4de163e82ee110d0d4)
- Misc cleanup of gitlab ci/cd script [`90b3a67`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/90b3a6721ba7147075b93ea576ca3f2197310e60)

#### [9.4.218](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.217...9.4.218)

> 9 August 2020

- Fixed issue with v16 database migration using multiple where clauses [`135dea3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/135dea3c4cb176fefb891a8d5023731753c6810a)

#### [9.4.217](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.216...9.4.217)

> 9 August 2020

- Fixed typo in database migration script [`b821ed0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b821ed0df6f59c1cf978a0a7fdd5e829620d3c5d)

#### [9.4.216](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.215...9.4.216)

> 9 August 2020

- Refactored database backup/restore code [`96cdca4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/96cdca42ae73a78ad4274918cd935b93e1995e36)
- Misc code improvements for Plex notifier [`6c346a8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6c346a8cbedbe44e0985e3b83b7f25d30d570661)
- Misc code improvements for Plex notifier [`09466b1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/09466b1abe83cae8e45d0652194808684cff3845)
- Misc corrections [`28e7ba8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/28e7ba8264e898c59ae5e4ec6ece17c5608231ea)

#### [9.4.215](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.214...9.4.215)

> 2 August 2020

#### [9.4.214](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.213...9.4.214)

> 1 August 2020

- Fixed issues with md5 checksum hasher to be compatible with python 3.5+ [`dca0752`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dca075283e27b836146de68a5da5f91d0664a421)
- Fixed issue with episodes being prematurely saved to database [`230e4a1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/230e4a11b46145fc881186a3ed574b2437d67350)
- Fixed path issue with cleanup function for startup [`64456b5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/64456b54aaa6ab4afca20a9448586545e1f0af7d)
- Refactored Dockerfile [`d546ce0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d546ce01a9b7509bfe381f5a3adc29f3d9008fe8)
- Fixed issue when episode location is null and attempting to load from .nfo file [`a37348c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a37348c6abe356742f1e50a647ed90ae1fcdca93)
- Fixed issue with removal of unwanted files and pathlib [`ce4fe00`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ce4fe0087ee88d752b3362950fc5b62f2630fe0c)
- Disabled cleanup *temp* [`083c97d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/083c97d2b7ff22344f62ea9136191b2e86195f2e)

#### [9.4.213](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.212...9.4.213)

> 29 July 2020

- Refactored server status to show task status value string [`3d28569`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3d2856923182324aee438ddeb164f56e40976dd6)

#### [9.4.212](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.211...9.4.212)

> 28 July 2020

- Fixed #484 - Mass Update Error caused by incorrectly handling show search formats as a checkbox value when it should be a integer [`#484`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/484)
- Refreshed package.json [`933467a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/933467a2eeb1a2dab6979884e2a83faedf7fb16d)
- Refactored exception handling for search providers [`0ab3a37`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0ab3a3777c4210ebba5c2e10baabcbc4caf89015)
- Refactored web handlers to run in executor in the background, this will improve performance of UI tasks that may be blocking [`6e639c3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6e639c3b07bc3a50703364a87d4aab5434f1e7ce)
- Refactored mako templates to be looked up and stored into template dict attached to tornado app settings [`60ac65d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/60ac65d283639628a9a2ebb45f246ee4b78e3f97)
- Refactored queue system and how it handles tasks [`4c39a2d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4c39a2d4baa6cf2577e9c1387f87ee182d9661b0)
- Refactored add_episodes_to_trakt_watch_list method [`1b9ce09`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1b9ce09f3aead661c1503712836518d21f0e0f45)
- Wrapped all apscheduler tasks in try/finally clause to control running state correctly [`fccfa0e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fccfa0ef96269fab2c94a586018b5dee53854b17)
- Refactored web server to run on a separate thread instead of the main thread [`502207a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/502207ad80a332f7a98aef894c91c40b924239d6)
- Refactored fifo list to collections deque in search queue class [`c237843`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c2378437376729f0d96accc9ee80d4ec0e659827)
- Refactored scheduled jobs to be async and execute on ioloop in their own thread [`64ecdbe`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/64ecdbeb0e988d7a6aae6a17ad539d0a8181cae8)
- Refactored usage of IOLoop by removing const io_loop from core and using IOLoop.current() calls instead [`6046334`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6046334370568652a611ef7b62cbfb8820b632b3)
- Delete item after queue worker function finishes [`5174141`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/51741412824d200b0a40944eaeefcdc565a87743)
- Fixed multi-thread issue with quicksearch [`a34c39d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a34c39d3eff469e3b29ed0a868c368f305ca523d)
- Misc exception handling fixes for indexers [`971e8e2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/971e8e28a6ce41bc12622af0be05dd17bcce8aa4)
- Feature added to view logs in realtime from log view [`0865b23`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0865b2326717524730f3c9ebec145684c019f7b0)
- Chore - Upgraded javascript modules for building core web functions [`9869925`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9869925269cf8f09830f89dd4b99e21e02dc40e5)
- Refactored queue system to process one queue item at a time [`2a47a79`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2a47a795a371afb3b120b20fcfa74645086b1cc3)
- Refactored `settings-&gt;general-&gt;advanced-&gt;git settings` buttons [`af28199`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/af28199b61d4e59f4ec216386f13242d0f633061)
- Pinned rarfile lib to v3.1 and refactored code for testing unrar compatibility [`1809d6b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1809d6b8872fa4002c8905e0730fd4b1ea8c4508)
- Refactored deluge and transmission web session handling [`71cc101`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/71cc1012434f475c89bf021341c24f09607d5093)
- Refactored how requirements.txt is installed/upgraded, added code to upgrade PIP [`3d65769`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3d657699824b79c86d303951b4f76b38c9cf8d4c)
- Refactored app_id to server_id [`a928edb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a928edb06b436ca9495f75ae65a467aeb10f3624)
- Optimized config.py imports [`6b08659`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6b08659cae1a43f2e1c85b7e0364be4df36d9308)
- Refactored web server to start right after config is loaded [`dff5d2f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dff5d2ff8a302a6f20d13afe699ac787c9289759)
- Refactored queue system to use while loop instead of apscheduler [`3173352`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/31733525322481ef3dd04adae0566e1e0cb6511b)
- Reverted changes to gitlab ci/cd script [`abfc264`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/abfc264e75bd010231604d7d07fc802ad161b82c)
- Refactored qbittorrent client web session handling [`db74410`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/db7441024f16979bd5f04efc6a53c38479c49715)
- Refactored gitlab ci/cd script [`438808f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/438808f40c0ca3f7f8bc080ff47602ffa73fc248)
- Fixed issue with linking/unlinking sickrage account to sickrage api [`f62ed72`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f62ed7227db3bf5673e4856e0280a8b93154aaf1)
- Refactored link/unlink sickrage account to sickrage api button to hide/show based on sickrage api enable/disable toggle [`5cc3a68`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5cc3a68987096468deadfeb9912171812b963c40)
- Fixed issue with post-processing [`8758c4a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8758c4a4cb150c2b53255f4956bfd8e52caef3fb)
- Refactored putio client web session handling [`2f5c9d5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2f5c9d560fd7953ca16a8344328ecaec67e83195)
- Refactored rss cache updater to fire task in ioloop executor [`5c616de`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5c616de51cf41f10667f5b7ee8e32c6068a4ac73)
- Refactored how testing auth for clients is handled [`1fc9071`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1fc907129e282b50ef9db5514708b17c27ad88e4)
- Fixed issues with app shutdown and restarts [`1325174`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1325174caa77fcc0443b24cec7223301029dd128)
- Fixed issue with task priorities and enum [`e49df65`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e49df65d510814533b83e886f2365beaf35dd1f3)
- Fixed issue `Cannot read property 'addEventListener' of null` [`1463221`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1463221f811de8e991f27865be96bf7e7b652e8a)
- Refactored check to see if sickrage account is linked to sickrage api [`458b9f8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/458b9f8019829aa4d7fad9b8d3d05891a27b126f)
- Refactored how recent shows are stored [`1dd1b7f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1dd1b7f6edf7f46395fcdf79b922140e2fee9cd2)
- Updated requirements.txt [`2e62168`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2e6216825cc0e9e3b332ba02a5bd8f8ebf64ea96)
- Refactored mvgroup regex to enforce `series` needing to proceed after show name and before season number [`0a7e81a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0a7e81ad6ed66bef0c3a964357b5e8b758602b37)
- Refactored download station client web session handling [`1c5c3aa`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1c5c3aa2ba9f0c4cc3c0dc1af3964645ce7e6df6)
- Fixed issue with search clients and urls [`d31d933`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d31d933766868119a6dfca5000b1ff81dc72fe2b)
- Refactored web username and password to be required to save settings when enabling local auth [`2275ec6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2275ec6e49af3442952eaab08725ded67e446f76)
- Refactored how scheduled jobs are forced to run [`fbcb4b0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fbcb4b0a8ad145d4b409a964dc240154f93fdd69)
- Misc fixes [`ab3323b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ab3323b4e1b7c2b12a6e28b99e5bcbffefac2b22)
- Fixed issue with retrieving scene exception names [`dd24e5a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dd24e5a126ccaed30a5d96b6acf728f3e539e9f0)
- Refactored mlnet client web session handling [`afd84ce`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/afd84cea45231e53f43414897a91b7afe5828ca3)
- Refactored popup window only for when enabling sickrage api and not when disabling it [`90ea945`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/90ea9457e7444706d5958a52f8fdcb0afd1cccfc)
- Refactored error logging of failed queue tasks to include task name instead of just queue name [`509aeae`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/509aeaee86ad8fd59022f6801e8319dfa6f3405c)
- Fixed multi-thread issue with quicksearch [`148e067`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/148e0671a11a7b422155bbfa924d939eb25779ca)
- Refactored how web session class performs retries on connection errors [`c1352ac`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c1352ac639de15067e482e141ea07fef367c398f)
- Refactored gitlab ci/cd to push only annotated tags with commits [`c5737a5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c5737a557dab2aadc6843194fefef4d28a397008)
- Refactored sickrage account &lt;&gt; sickrage api handler to logout existing auth tokens before creating new ones [`939eeb1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/939eeb16f620bf11e7eaa879ee17112300459afc)
- Misc formatting fix for backlog searches [`210e722`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/210e7227ee61b5198c9d20218fac3788aa7c0e52)
- Refactored show season poster and banner image download functions to be more descriptive when failing to find a download [`2f47c45`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2f47c458e4cfd0986f9a246cdf70a9e882b4d81d)
- Fixed comparisons in scan_subtitle_languages [`32723c5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/32723c58c843b91c0acd99a636e31ac8307bca60)
- Refactored display show view, merged right and left legend columns into one column [`18b7d47`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/18b7d471d3c05961f0df9a8a5e3a83949dc78677)
- Refactored queue system shutdown method [`fe042f9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fe042f9b11272ddfb39879b0a59de59503bed3d8)
- Fixed error message from hachoir package on import [`b8c55a6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b8c55a645136b2cd295d770364ccb637a313598c)
- Fixed a few typos in template_name's [`7fd4431`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7fd4431e80e657be897252449b2da2cd6636d149)
- Fixed `Unsupported header value None` when attempting to link sickrage account to sickrage api [`4e9d343`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4e9d3435d14257151bce3287b4f25641a0d6a848)
- Fixed reference to scheduler from core [`f9e6b25`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f9e6b255eae95d5be54b110c3a6512305ec06dc4)
- Refactored `settings-&gt;general-&gt;interface-&gt;api` generate button [`d473f39`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d473f39a1d86efc645dcf660dad66184ee3acf7e)
- Refactored ip whitelist helper [`1a87117`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1a8711755744893e4b7c61afe8c2c53f7a2c19ae)
- Replaced variable in gitlab-cicd script [`8f31e82`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8f31e82ac3f0b1f320ee5764c2523717aca04fe0)
- Fixed shutdown sequence [`016f7e8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/016f7e883558f3e259aa3f0e8ba45f9e932e03a0)
- Misc import cleanup [`a6eb943`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a6eb94382e641ed34b1e7aba750a92a6ff96ce3b)
- Removed debug logging from current_user web base method [`9e2f78c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9e2f78cfc41155d140d1cd4719f555b40a4fe341)
- Fixed error handling for when a queued task fails [`9a9019c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9a9019cd50e8a76a5553e76b5b9a867dcceb3141)
- Refactored search formats collection string [`aa0e659`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/aa0e65962a4537009fa9753239b4b0d950537d68)
- Fixed issue with shutting down post-processor queue during updates. [`13ddc68`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/13ddc68cf9ff14583c5769108064720444c3c981)
- Fixed typo that was preventing scene exception lookups [`5104e13`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5104e1382c4e6bf59c9786786ba4b7345ff8fd5b)
- Fixed issue with adding shows off IMDb [`617e12d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/617e12d17c17ab0287043277d808185fab3dcb91)
- Placed a 30s timeout on sickrage api and sickrage auth health checks [`f3e6f42`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f3e6f42c08108f4d4c644c1b1c95db1a9985e735)
- Refactored base render function to use write instead of finish, resolves a performance issue [`fafc42a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fafc42aa13ea71e31831e68a71391e66eed1995d)
- Refactored name of function in auto_postprocessor.py from run to task [`6ef74b1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6ef74b10569dd25046d57f18827e4a33671b5a80)
- Refactored mvgroup regex to be stricter [`3db8944`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3db8944c4de3c48a64532b1e52ff7d7209464f9d)
- Refactored ip whitelist helper and subnet checking [`741587f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/741587fb1c4bd7087afdf9c5ad76486e738e6aac)
- Fixed missing column headers for display show view [`21dd1f0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/21dd1f0e17bd28110cb2f7cd22c0755cd242d35b)
- Fixed issue with passing web root to Docker [`57444d9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/57444d96d9ae32b58fad872f2cb7dc6e0e72ad1c)
- Fixed issue #486 - scene_default reference removed from add existing shows code, added search_format_default to be passed when adding existing shows [`9b9e717`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9b9e717ec4d45a62bfdb9a16cf781ac204a10b71)
- Fixed issue with unregistering app_id when app_id is not set [`7a4d36b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7a4d36b0f29850711b88ff72befa5d36cb720294)
- Fixed issue with repeating debug message for whitelisted helper function [`484919d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/484919d7efe8288fa7f7f891761a93f05d19dca6)
- Refactored ip whitelist helper [`b29f00b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b29f00bcff0c3323f83af3affc9d492a02da16bf)
- Updated gktorrent provider URL [`d20520b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d20520bc71979f3e5b82aa6483ea66cbd3465ad1)
- Refactored auto-postprocessing task to be async [`f495891`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f49589158c79cb2ddbc30d7927e07d64dcb21dc4)
- Renabled mako template caching [`8430679`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/843067923593bc326328cda325c3060b198e7ed5)
- Fixed issue with displaying a show when no imdb info is available [`c8a763b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c8a763bfa2b6f0e2431ccdec488d95a2709ee52d)
- Fixed typo [`907f445`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/907f44547e6619f9a61541c96648d9c7187d2f1d)
- Fixed missing start of thread for queue class [`4350619`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4350619c6e64a56a8a6596cf910791b8215b6af5)
- Removed async from queue run function [`34e95c9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/34e95c93435cc466dfbcc8b493e9323ceebcf92d)
- Fixed passing of args to thread when creating thread for queue class task [`5ff5b1e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5ff5b1e91686fac3c3b5402ad2b1bd4af62710af)
- Fixed issue with enabling sickrage api when auth token exists [`5a82893`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5a828937d7bcbeb98ef42fabd4926bcce008e78a)

#### [9.4.211](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.210...9.4.211)

> 20 April 2020

- Refactored timezone updater to perform better when updating using bulk database transactions [`a8e4896`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a8e48962dec71914c03ea663de5b799ed58da7dd)
- Reverted small change [`e8f116e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e8f116ee99d2f67ddbe82f0ac96f9e370849c043)

#### [9.4.210](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.209...9.4.210)

> 20 April 2020

#### [9.4.209](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.208...9.4.209)

> 20 April 2020

- Fixed typo in nyaatorrents provider code [`2f710ba`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2f710baf844b9fa856e7db33afba620a16c0f28b)
- Fixed name 'ModuleNotFoundError' is not defined error for older Python 3 versions [`53746c7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/53746c73a1078e2b26760ef50c05d34858d5fd1a)
- Refactored gitlab-ci script to remove changelog create when building and deploying master branch [`5bd3790`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5bd3790e5c1130c88004ba73119c7df00a918352)

#### [9.4.208](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.207...9.4.208)

> 20 April 2020

- Removed old changelog.md [`71816be`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/71816be1cd6b7c7bead63eb3565e8b91b968cb09)
- Refactored changelog creation [`022e36d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/022e36d344ef0f0706acd7b363db1c634107a583)
- Replaced cfscrape with cloudcraper in requirements [`e4695af`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e4695affcedc66aabeeb0aabee2e53654db823e6)
- Fixed `Unknown format code 'd' for object of type 'str'` [`2eac392`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2eac39209671a37e47f83957184719cfa9ff8974)
- Refactored git-changelog to use a template [`2d6ce4b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2d6ce4b2679730aed40b8585d232296966529d8c)
- Refactored ErrorViewer and WarningViewer classes to use collections deque with a max size of 100 to prevent memory errors. [`ec25dfe`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ec25dfed73b8115375529793bd590f181d7c6b05)
- Refactored application startup to install requirements via pip if ModuleNotFound exception is thrown. [`3bddcc2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3bddcc22384ec23e3b22e4711af73a85c2adf440)
- Refactored npx command for generating changelog [`877f7f5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/877f7f57bbc3169f2217431487a67beb911a460b)
- Refactored code for adding new/existing shows, removed auto-detection of XEM scene numbering as it was falsely setting scene numbering to ON. [`caa7ddf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/caa7ddf76787f32e6f86b957636f120241397519)
- Refactored requirements install cmd to include `--no-cache-dir` flag when ModuleNotFound exception is thrown [`96e2baa`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/96e2baa026f1db19d761e2b1de8bdd1e7c7cfb04)
- Fixed path to requirements for startup install of missing modules [`0955612`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/09556122f82ebce44adcfbd4b2e6b1e83ed40b67)
- Refactored git-changelog template, removed version info. [`eeffca0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/eeffca07583e562dcc0729c0f25eb14e6b35cde0)
- Updated donation link URL [`31143a1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/31143a1557a4e06c6c605f68a9e65f80474e8537)

#### [9.4.207](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.206...9.4.207)

> 5 April 2020

- Removed bitsoup torrent provider [`7b2618d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7b2618d182cd9f41886656c81365b0b3c8402cb5)
- Refactored some startup events to fire via io_loop callbacks instead of scheduler, resolves timezone issues related to apscheduler. [`8abfa44`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8abfa4487353e1c988aa0ec77d4b8769d6ba7091)
- Fixed issue with daily searcher setting unaired episodes to wanted that do not have an airdate. [`ff440e4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ff440e4ab2145a4c0ebd3c10707f7e9c900a6098)
- Fixed missing namecache error for server status page [`b9e224f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b9e224ffa4ffce65ae15c593e751d5b2c264d951)

#### [9.4.206](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.205...9.4.206)

> 1 April 2020

#### [9.4.205](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.204...9.4.205)

> 30 March 2020

- Fixed issue with adding search result episodes to search snatch history for season search results. [`cfb0ceb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cfb0ceb41c9aa4c95d40ec4c7b228484d1f329ac)
- Fixed authentication issues with QBittorrent [`72ffe67`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/72ffe67ec9dd54c11d033a976a9e3902515bfbf5)
- Fixed issue with detailed/simple view and previous episode air dates. [`c3fc910`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c3fc91048121b747fb1692dd39d50379c60c7bb4)
- Removed encryption of versioned backup files, caused issues with backing up database files. [`6fe0adf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6fe0adf9a1bf84e6e0b1560a3b0ab5b9c338be85)
- Fixed regex pattern for search client URLs to allow for extra paths [`5ed88e9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5ed88e9df566bb48e83a9610d6947ca7b9f2329d)

#### [9.4.204](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.203...9.4.204)

> 13 March 2020

- Updated requirement dependencies [`c888386`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c888386521cafa46bba9c8b99cc87da878ec05e9)
- Resolved incorrect handling of indexer error for `_show_data` metadata class method. [`9004608`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9004608b8c17c9a12795bba8add3238413fb0698)
- Refactored core loading shows function to use query object from database to fill show details. [`0714833`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0714833119807efc275808ec04e458a9ee00dd34)

#### [9.4.203](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.202...9.4.203)

> 9 March 2020

- Fixed IndexError when deleting episode from show episode cache. [`69fda28`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/69fda28adf1088c8e7cd5e3bb944814bebbe5bfd)

#### [9.4.202](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.201...9.4.202)

> 8 March 2020

- Refactored nzb and torrent clients into separate folders. [`09d5fcc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/09d5fcc459b564c0508e4cc2bf507acf72f655de)
- Refactored home view to not display shows till fully loaded from initial show load, allows all other aspects of web-ui to work. [`b49e766`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b49e766ec09264b39cac3e1b14952636e4292716)
- Refactored more web handlers to be async [`bc7393a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bc7393aa3d6a66a7c2ac51a8125b313e66fcc125)
- Mako templates are now rendered on executor, resolves lockups for large renders. [`dc8df9f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dc8df9f7a4d04a5d1bbd6b9f36d2a7b0e8a67466)
- Refactored with statement for database session call to variable. [`da03a7b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/da03a7b0aa463a6ddb9ced2b6b1c8ce195d33efb)
- Fixed issue with getting result using search clients. [`d2145a1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d2145a164b680e2c55d614500486bfe5573c1213)
- Refactored shows cache to populate after database init. [`77cbb46`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/77cbb4678093e141d0e85f7962938fc37ceb710a)
- Created a scheduler just for queues. [`bbaf09a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bbaf09a5033ffc165367e940b30bad14f6a0e861)
- Bumped PNotify to v4.0.0 [`f3a0f0c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f3a0f0c6754af5e7f9766b75d9bb225becf4f55d)
- Fixed issue with home view simple taking forever to render. [`1fab208`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1fab20827a441fedf6b8a1e7172019e4feacb9dd)
- Fixed up more database session passing throughout application to help with 'database locked' exceptions [`e9cf48b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e9cf48b513cb762186f78d6338bb8b87d4558f66)
- Refactored queues to be watched via apscheduler 1s interval job. [`6c2ada5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6c2ada5a92f3e0635fa1609cc022813f81bb6947)
- Refactored RLock to be acquired/released using `with` statement inside safe_commit session method. [`80ea445`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/80ea4454a8d0e715f54d07353171ec6a0765750b)
- Misc refactor [`b102856`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b102856863fc60ef702296e11deb1bb857e054e8)
- Refactored clients get module function. [`c64e4f7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c64e4f793aecfd6c97e7bacac29e96c92dca8f0f)
- Increased max database commit attempts for "database is locked" exceptions to 50 with random sleep timer ranged 10 to 30 seconds each attempt. [`4a64aa4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4a64aa4a65839e168877fa4d4e3f75470031b11b)
- Removed left over session declares on cache and main table parent classes. [`b05bbee`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b05bbee5ff39f73c9c9312d78cf4a90aea71b741)
- Fixed issue where rollback on database transaction was not being called correctly on OperationalError exceptions. [`a7076e8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a7076e84cd6cfe947047cfe0172a947f2833892b)
- Refactored RLock to be acquired/released using `with` statement inside safe_commit session method. [`180bd6b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/180bd6b21e692f921b1608b6a3376652f27e4a10)
- Refactored `delete_episode` method to remove episode object from related show episode cache. [`97c5569`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/97c5569653dada1fec55ac173611eb643f598800)
- Fixed issue with progress bar not working. [`9b55c91`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9b55c9177c190386d6f0f4f7188036b9f781f8cd)
- Refactored lazy loading for relationships on database models to joined. [`f62514e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f62514eb8b30b9be5c096b648a6a4f0085796696)
- Populating data from indexers no longer returns false if show directory does not exist so to not raise a EpisodeNotFound exception. [`50f4c87`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/50f4c876ae54f9b2acbbffac2d51a0880f409216)
- Fixed type error in determine_release_name for post-processing. [`dafcedf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dafcedfce3677278d0d6d506f171e7771342fefd)
- Converted f-string literal to formatted string. [`4814986`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/481498627ba20417750ba545028fac2c76738d05)
- Refactored backup to not restore privatekey.pem file when choosing not to restore config. [`32e77cd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/32e77cdbb424b5b763da837f92b9c3718e5d3384)
- Fixed issue with saving shows during shutdown/restart of app. [`6917479`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/69174798e9be7a79f884c78022fb0a085c738eeb)

#### [9.4.201](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.200...9.4.201)

> 31 January 2020

- Fixed issue with retrieving images for cache [`7310f88`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7310f886a6e90eb3e124c1fb6747f372a19ae9b4)
- Fixed issue with image_type string being stripped improperly [`9763fa5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9763fa5b00588221f510ca729c372f445cf8a2ca)
- Fixed mislabeled banner image type for image cache [`d56b80e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d56b80ebf125ae65d011c4f262f0d00f6bd5d4bc)

#### [9.4.200](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.199...9.4.200)

> 31 January 2020

- Refactored `_retrieve_show_image` method to download images from fanart.tv if downloading images from indexer fails in anyway. [`92e1b2b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/92e1b2bd5695e4ed652b97f47ec3fe1efcbce9af)
- Refactored getting current user info from decoded token instead of userinfo endpoint [`a41b58f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a41b58f1358cd3945c609f12bc89ec28fe5f2881)
- Fixed issue with indexer error handling [`efb8215`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/efb8215fe556e00edf623b83fbd2f40bb6dd083f)
- Bumped guessit to v3.1.0 [`57dec5d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/57dec5d0a69d22ed344b336a6dca58c7254d632d)
- Bumped CacheControl to v0.12.6 [`ad5bf69`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ad5bf6961034ebdfcc553dff271957479cce3ebe)
- Increased default backlog search frequency to 1440 minutes (1 day) [`a6cbc19`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a6cbc1981ed2105da5d6304f68b7f4de139a7856)
- Reverted health check for providers, needs further work before considered beta. [`8a08741`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8a08741865edd668b1ad2228bebdb6b37a4e69e7)

#### [9.4.199](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.198...9.4.199)

> 17 January 2020

- Fixed issues with login cookies not storing in chrome or safari browsers causing failed login attempts. [`355e96e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/355e96e688491839394d90bd48534572ce809c5a)

#### [9.4.198](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.197...9.4.198)

> 12 January 2020

#### [9.4.197](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.196...9.4.197)

> 12 January 2020

- added .yarn-cache to .gitignore [`c5992b5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c5992b5e309c446f75ca2508e07f39a84ab9d6d6)
- Replaced npm with yarn in gitlab ci/cd script [`928a029`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/928a0292858ef5faba19c7c8e0d611d2eb52f88b)
- Refactored gitlab ci/cd script to clone to a depth of 10 [`aeff0eb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/aeff0eba3dcf5a6399530bce88540c9d241d5d7b)
- Removed all grunt related packages from package.json [`141db85`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/141db8547d4b55689e5cdfa2eb0a30f39b11d5d5)
- Push tags only after pushing commits was successful for gitlab ci/cd script [`5fe6a98`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5fe6a989a876566c2a0720d36a84dd75aa6600a3)
- Fixed scss import paths for fontawesome [`4ed31f0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4ed31f055a96347a932f82ea36ba6f6e94cd65d4)
- Updated nodejs to v12 for gitlab ci/cd script [`177d165`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/177d165df6c14981e26f493f3e6eca6f8d08dd9a)
- Refactored npm install command for gitlab ci/cd script [`38ac023`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/38ac02315ac6c1dd0b5886f8b3832e48797d8f95)
- Reverted git depth variable in gitlab ci/cd script [`5faa625`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5faa625df40abb661ecd8b702212c7d1bb53672b)

#### [9.4.196](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.195...9.4.196)

> 10 January 2020

- Refactored offline tokens to be revoked before being replaced, resolves issues with tokens piling up. [`92d0c0f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/92d0c0ffd8ef6c8e082d91e5dc6cd37ba7ed586b)

#### [9.4.195](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.194...9.4.195)

> 9 January 2020

- Reload database files after a restore, resolves issues with database scheme migrations. [`017b1a4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/017b1a4c94cfc5ff72857040012ce06d7fc6820e)

#### [9.4.194](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.193...9.4.194)

> 8 January 2020

- Removed footer from show cards in home view. [`5de63b9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5de63b9e276b4fa498f4745196436e4ee2c1d061)
- Refactored database `with_session` staticmethod to classmethod. [`61bd3e1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/61bd3e18f67161fb85b8823b2552744eebc83920)
- Refactored OperationalError to import from sqlalchemy.exc [`803b397`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/803b39775f077017474c473c96c87645d0e97938)
- Fixed issue with replacing oauth2 token on login if token already exists. [`2849e5c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2849e5c279eb6987c4ef08c9f03c4fc6c0e39dbd)
- Misc cleanup [`a929f0b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a929f0b2ef3eb8ade113a735622a7b4f47e776c1)

#### [9.4.193](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.192...9.4.193)

> 22 December 2019

#### [9.4.192](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.191...9.4.192)

> 20 December 2019

- Increased default quality sizes for 720p and up. [`0d2fd21`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0d2fd213afbef094f19eccfa06388736b9c0e42b)
- Re-enabled manual post-processing. [`e9c5c46`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e9c5c468001296f3b8cc5521d7d674c5bf988ad3)

#### [9.4.191](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.190...9.4.191)

> 19 December 2019

- Retired torrent9 provider in favour of gktorrent. [`daea33f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/daea33f084cde5d88c72ea03abbc443f560a8607)
- Increased sqlite timeout to 20 from 10 to help with `database is locked` errors during concurrency. [`f22c2df`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f22c2df7a54d3e39064d9968c0bdb674687c0378)
- Check if base url is present in download url before attempting to replace with custom url. [`339ca83`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/339ca834736594a740adf69a9e4e5cdd534b8ec0)

#### [9.4.190](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.189...9.4.190)

> 17 December 2019

#### [9.4.189](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.188...9.4.189)

> 16 December 2019

- Converting internal web calls to routines to direct calls, resolves issues with timeouts occurring. [`d3d413d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d3d413d59bb9b0c0fd081f21e53e058f863bb36b)
- Refactored default provider urls to bypass urls property when formatting urls on app startup. [`0cb3c8d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0cb3c8de2501f1b827f7ba28d2e3d8aa502f3e4f)
- Refactored naming of internal api error and external api error exception classes [`580f19e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/580f19ecc119c51d65ee6327f9c465c2aa8a9f2d)
- Refactored exception handling for `quality_from_file_meta` function. [`00d367c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/00d367c13abe7dc4a3f530c67002fd8cc65c129a)
- Fixes issue #432, outputs episode object as a dict when running episode cmd from app api. [`9cfcfa4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9cfcfa4c87fff080170a2889ec575782407f3905)
- Updated URL for YggtorrentProvider to `www2.yggtorrent.ws` [`00f2131`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/00f2131c924d455c3af6b2202db438ad5f4ad942)
- Increased sqlite pool size from 200 to 1000 [`28975f4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/28975f4931e92a7b643dace7768c69c716c2a8fa)

#### [9.4.188](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.187...9.4.188)

> 9 December 2019

- Fixed an issue with version updating related to checking for number of commits behind, manual update to this version commit may be required. [`37ea161`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/37ea161e35e38bc99b16ed95e59252dd87863654)

#### [9.4.187](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.186...9.4.187)

> 8 December 2019

- update RTorrent compatibility for 0.9.x [`#37`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/37)
- update rtorrent compatibility for 0.9.x [`568403a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/568403a2faccf353eb5194a0a975f12a565b5d93)
- Disabled review for CI script [`cdb11c1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cdb11c1a0c9abb4b4bdaa6fbca2a81cef2323662)
- Restricted CI/CD jobs to upstream. [`8e6c052`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8e6c052c1e7b19b5474d8dfe074bf5325cc4c144)
- Fixing issues with CI script and stages not being triggered on pushes. [`e30e8ea`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e30e8eac9987b01f7f53c3d650524981ca6ebffd)
- Fixing issues with CI script and stages not being triggered on pushes. [`c193f2f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c193f2f1ed541b27373c5b74fbd6a53d6f79da8c)
- Fixing issues with CI script and stages not being triggered on pushes. [`f99732f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f99732fa7482bc658094d2719a32a08d21be01e1)
- Disabled webpack stage for reviewing merge requests, webpack needs to be done manually before submitting a merge request online. [`d0c058b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d0c058bdf9d0b193acd0c97223f594905ffbedf8)
- Fixing issues with CI script and stages not being triggered on pushes. [`c10d945`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c10d94508971b4e354f6378a1b3dafb335a237f1)
- Disabled webpack stage for reviewing merge requests, webpack needs to be done manually before submitting a merge request online. [`c40e707`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c40e707797a2dc45fc26ddb68064632ae71be957)
- Re-enabled automatic build/release/deploy for develop branch [`ffe965b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ffe965b1a6c8425f4ecab0580d5331ef68507cc7)
- fix urllib import and usage [`6a7c4a5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6a7c4a5edf16c1b70bfc1988bfa23afe5a8e8301)
- permit scgi URIs for rtorrent [`38489fa`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/38489faf77124bd50e9ea810f4be2679af3dc0c1)
- Moved tagging of pre-release to happen after committing changes for CI script [`e4f45b2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e4f45b2de5c9932c3b6bbb9a563f38facbc8ec44)
- Fixing issues with CI script and stages not being triggered on pushes. [`03c886f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/03c886f7d55caeb2508984f542a5dd46eaacb9ed)
- add exception logging to rtorrent client auth test [`053ade3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/053ade3e148055d85024fbeecee95da7607d2f5c)
- Update sickrage/clients/rtorrent.py [`1332df2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1332df2c59375e2e3c923208e0fb0182d654b527)

#### [9.4.186](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.185...9.4.186)

> 28 November 2019

- Refactor CI review stage [`#28`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/28)
- Delete namespace when CI environment is stopped. [`#26`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/26)
- Fixes issue #425 - converting air-by-date to episode ID when multiple episodes... [`#25`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/25)
- Added CI/CD release stage to build app [`#24`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/24)
- Added regex for semantic versioning along with matching of each section of the... [`#20`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/20)
- Refactor gitlab cicd [`#19`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/19)
- Added ability to set webroot at startup from CLI. [`#17`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/17)
- Added ability to set webroot at startup from CLI. [`#17`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/17)
- Updated gitlab ci/cd script allowing reviews [`f31ae93`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f31ae93d97c6d67871f567668b8cffdfc02db4e6)
- Refactored websockets handler. [`ba3961e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ba3961e7291988c48344713b33acab024ec51889)
- Refactored bumpversion config to properly handle develop and master versioning schemes. [`4125ec2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4125ec22037cdf14f5bc54b6cf987506538a67f0)
- Refactoring release cycle for develop -&gt; master [`a50e87a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a50e87aedc650252d58cd958922555009f9774e2)
- Fixed issue with adding existing shows that have episode filenames that do not contain the show name. [`dc965ba`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dc965bade915fff67f494b3adef73420dba53713)
- Bumped version to 9.4.186.dev1 [`6438042`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6438042a2de979afc6a908a9c85e9ab347f82fce)
- Fixed issue with unlinking accounts and destroying token [`a73aa96`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a73aa968becb1c6eac71bd11b89d6956fdd92c21)
- Updated all CI jobs with proper requirements to build cryptography [`2ab5e3a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2ab5e3a011ce32aaf5e78895a50147c5f46d0f0c)
- Fixes issue #425 - converting air-by-date to episode ID when multiple episodes for show falls on same date. [`831fbb1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/831fbb180817e63e4a2deae3965508d008c06edc)
- Pre-Release v9.4.184.dev1 [`855fbd7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/855fbd738b66e1f5d36a61b6e49b78badd462941)
- Refactored gitlab ci/cd script [`d9c6d77`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d9c6d7732230f7f964df51124d65ac72baf30c56)

#### [9.4.185](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.183...9.4.185)

> 26 November 2019

- Merging Pre-Release v9.4.184.dev9 [`#29`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/29)
- Merge branch 'develop' into 'master' [`#425`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/425)

#### [9.4.183](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.182...9.4.183)

> 5 November 2019

- Revert "Refactored main shows page to load shows via web sockets." [`932c107`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/932c107abd9b64eacdffb6b18bd6c66564627a44)
- Revert "Refactored main shows page to load shows via web sockets." [`2afbbf6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2afbbf6fdb4d27d471b1d5ad1efb4ec6b94e06cf)
- Release v9.4.183 [`94f82ef`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/94f82ef67e5de5d493975d93efbb30ef0d51cbe7)
- Pre-Release v9.4.183.dev1 [`d517820`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d517820615086ffc83d91a85a6c430de3d192640)

#### [9.4.182](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.181...9.4.182)

> 4 November 2019

- Pre-Release v9.4.182.dev2 [`69602be`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/69602bec7c8ecae9269957edb7203f69e05ea2f4)
- Release v9.4.182 [`bb8c6e5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bb8c6e568d9c280eb77ba68c91cb352197c46e9c)
- Pre-Release v9.4.182.dev1 [`b7b2ac4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b7b2ac46bb3b508945e1e7baa2638d0517941a75)

#### [9.4.181](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.180...9.4.181)

> 3 November 2019

- Release v9.4.181 [`6bb50b2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6bb50b258ea32c57401262152a3fe6f3d4c133af)
- Pre-Release v9.4.181.dev1 [`fdc5c9d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fdc5c9d5b9b3f68e0dcdfd54883d7e7d68cd24ff)

#### [9.4.180](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.179...9.4.180)

> 3 November 2019

- Release v9.4.180 [`b9bd1dc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b9bd1dccfc9cccbe66aa1eaf4c9e06c77a501c2f)
- Pre-Release v9.4.180.dev1 [`0a7c487`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0a7c487c06f0201d2c59ce977429ba09ce36bd53)

#### [9.4.179](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.178...9.4.179)

> 3 November 2019

- Release v9.4.179 [`d685071`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d685071b7cff47061bbe4b9461d05e5e16c8bd4f)
- Pre-Release v9.4.179.dev1 [`16e2094`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/16e2094574e353a518092d7bf7388daab1a0b525)

#### [9.4.178](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.177...9.4.178)

> 3 November 2019

- Refactored main shows page to load shows via web sockets. [`b9b280d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b9b280d708c15a2bc455c92b29763d6a3849ed6c)
- Refactored main shows page to load shows via web sockets. [`828d5f7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/828d5f75a7922a8be43a37179968adfb233a1a8a)
- Resolved issue with daylight savings and scheduler. [`8a252b5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8a252b55a10c8e2e4d3704feafbd825123d4f08a)
- Fixed indenting in template for shows list [`5450dd7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5450dd7f35db9b405e2bdca57b8e54188a3cb1c5)
- Pre-Release v9.4.178.dev2 [`33f9ddf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/33f9ddf35ef53ffc1e68cd9fe54b523408de68ef)
- Pre-Release v9.4.178.dev5 [`062ac69`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/062ac69587d035b98461292f92377186146ae46d)
- Pre-Release v9.4.178.dev13 [`add4a56`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/add4a56cfb4c3fd254f4f103a41fd5deaa82196f)
- Pre-Release v9.4.178.dev15 [`84a5ed4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/84a5ed4bbf18ed6a3e3c8e0b2b27a37fd5b3ebff)
- Pre-Release v9.4.178.dev16 [`222c3ed`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/222c3ed4ad35c02cc7cfebe873f0e279a12f1152)
- Pre-Release v9.4.178.dev17 [`82ee3f4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/82ee3f41cb1d45540db729a73451b199277f2178)
- Pre-Release v9.4.178.dev6 [`0707d80`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0707d807cd106c4737ece9a837dd9c9fb8b90380)
- Pre-Release v9.4.178.dev8 [`749ed1b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/749ed1b54fccd252218d04c670b313d6d1a67985)
- Pre-Release v9.4.178.dev7 [`da38c26`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/da38c261d7f9d1a961ee28617b442f973a1950be)
- Pre-Release v9.4.178.dev9 [`d07f9f8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d07f9f8f3ace8eb9e6a2c9d65da5d10897a77671)
- Pre-Release v9.4.178.dev12 [`60f5423`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/60f542362afa7ed92e56549c8aa6c17885a9a3d3)
- Pre-Release v9.4.178.dev4 [`8dd6f50`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8dd6f503420043288254fb3096c757178a65304f)
- Pre-Release v9.4.178.dev3 [`4cf7fbb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4cf7fbbcf9583bf4f82ec76e0a376d767a5ba750)
- Release v9.4.178 [`7616019`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7616019b7f3076c511f9baeb546a1b5d6af02cf5)
- Pre-Release v9.4.178.dev10 [`4e0a44b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4e0a44b46d222347f6fd0dc40dbf386f9de783ec)
- Pre-Release v9.4.178.dev14 [`2537f0b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2537f0b44c56ee64634f34febe41d88e10cf9c6f)
- Pre-Release v9.4.178.dev1 [`ed9a94d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ed9a94df5d2b30ca0e0a6a18a1d96789db23e83c)
- Pre-Release v9.4.178.dev11 [`66f810e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/66f810e9a827669f89ac0c6ff154f7c48fd2217d)

#### [9.4.177](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.176...9.4.177)

> 29 September 2019

- Release v9.4.177 [`87a6ec6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/87a6ec61a7f56a492f04d1376c85f623dd107631)
- Development version bump. [`0f10d34`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0f10d349cc1f3792472f16d061490e0cb0c24f11)

#### [9.4.176](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.175...9.4.176)

> 29 September 2019

- Release v9.4.176 [`6be984f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6be984fe6dd6e30b6a1e1d19b207f6650471f71d)

#### [9.4.175](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.174...9.4.175)

> 29 September 2019

- Update .gitlab-ci.yml [`c3aed9a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c3aed9a0178a04e1cef53977f0848b5bf4f4a1de)
- Release v9.4.175 [`43fd875`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/43fd8756da6620832f4bcbcb0a56f7296d0a099d)
- Pre-Release v9.4.175.dev1 [`d35176f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d35176f2f4efee801c12b93ebf0a6f2d3cd0e1b4)

#### [9.4.174](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.173...9.4.174)

> 18 September 2019

- Refactored speed.cd to use cookie login due to re-captcha on login forms. [`7f6bdf7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7f6bdf7ab1ce4c3d6a66b6a68e721e95e6d8f466)
- Release v9.4.174 [`4a98d7f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4a98d7fe26c36cc60d73db9250758db27c191f14)
- Pre-Release v9.4.174.dev1 [`b783172`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b783172a63347e0202b6abd8e01cf570c267803a)

#### [9.4.173](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.172...9.4.173)

> 16 September 2019

- Release v9.4.173 [`73d8223`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/73d82236beaba02590f4d4800628225187c59fd2)
- Pre-Release v9.4.173.dev1 [`f354ce8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f354ce83e759c41db0e85391c1034828a0750d25)

#### [9.4.172](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.171...9.4.172)

> 16 September 2019

- Bumped version for cfscrape to v2.0.8 [`1706331`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/17063315137431858dfeb700f758e4b571694013)
- Resolved issue with enable/disable of provider daily and backlog searches. [`ae7acbe`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ae7acbe0d853407610db9d000125087233095a56)
- Release v9.4.172 [`483e4db`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/483e4db337154dafa471c898ac968873b61248b0)
- Pre-Release v9.4.172.dev1 [`fa32f37`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fa32f37af8a5969d1b53816a43391c1ed86f9500)

#### [9.4.171](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.170...9.4.171)

> 14 September 2019

- Release v9.4.171 [`288e419`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/288e41982bc1116aa79dc310d3b3cf7645577289)
- Pre-Release v9.4.171.dev1 [`5eb814d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5eb814d013940fdd0bfd5ddbed7f480f5c1900d3)

#### [9.4.170](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.169...9.4.170)

> 8 September 2019

- Refactored config view for search clients to require NZB host/url to be [`e40869f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e40869fc7a3acd6d0503b4238829f7f1b9a758d3)
- Resolves issues for PosixPath being returned instead of string when trying to get subtitles path. [`7df5d8f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7df5d8f40ebfd223c25c415dc4ce770c9bc1b8bd)
- Removed un-required application ID registration code from config [`3817370`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3817370539a923888971d9fb44ac12f67524f42b)
- Release v9.4.170 [`e5ff7bc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e5ff7bc44f0546e8b19346a952268e4e0198e7e9)

#### [9.4.169](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.168...9.4.169)

> 8 September 2019

- Refactored code for getting subtitles path, strips leading slashes from [`44977d4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/44977d45f29f2f2fdb484721d1f42a5ec11a6b0b)
- Misc changes [`6f4fdcb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6f4fdcb74845d8c13486c928c62de5b8e1297931)
- Updated docker-compose file [`db675fd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/db675fdc45f02cd8f1c7561c35291ef1c30230ea)
- Pre-Release v9.4.169.dev2 [`1b448d7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1b448d72f2b18fb8a38fb9171d1b8e78bdaf22db)
- Release v9.4.169 [`003aeca`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/003aecaed6ba09c45e4b97baed521fbff4392a39)
- Pre-Release v9.4.169.dev1 [`d52005c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d52005c6d0e99932f1b90fd706566c582decbbcd)
- Grammar correction. [`30462b1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/30462b1f29d1f687d8604e7e511e3d525ac07f75)

#### [9.4.168](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.167...9.4.168)

> 29 August 2019

- Refactored jQuery search client code, resolves issues with form validation. [`a4e25d1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a4e25d1c6293c004a30f8b28e595ca297342c873)
- Performs a database rollback for episodes that fail to post-process. [`22648d1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/22648d1ec28e3c06246d06594a65bd31e90d5d9d)
- Pre-Release v9.4.168.dev2 [`10e170e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/10e170e9d46fa78139f7270d2cbcdf85046f6a4f)
- Release v9.4.168 [`4638e26`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4638e2610a7ab63c70d44c584d3867bf1f80b0ae)
- Pre-Release v9.4.168.dev1 [`0116b2e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0116b2e29a7053c49cdcf4602e319ee0bcf7e2c6)
- Refactored URL for support forums in readme [`798def6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/798def65a083ed6194cba120d701cc336665f324)
- Raised timeout from 60 to 120 for Boxcar2 notifier. [`5fd62e0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5fd62e07606ca3614c82fd981d2d180653e75249)

#### [9.4.167](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.166...9.4.167)

> 11 August 2019

- Refactored code for searching providers, was causing issues with final results correctly, results where being removed when not matching exact quality. [`25fc34f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/25fc34f9fd621fceb9ac586091c863a4c87b744a)
- Release v9.4.167 [`efc5637`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/efc5637346707ec6a65f55d069aec9c13863ee64)
- Pre-Release v9.4.167.dev1 [`9c20647`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9c20647f7942bc6bc138d3d3774adfa946210d05)

#### [9.4.166](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.165...9.4.166)

> 10 August 2019

- Release v9.4.166 [`bb5635e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bb5635ec34e1562b226ad5b98dc26f213086cbff)
- Pre-Release v9.4.166.dev1 [`f9f51d2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f9f51d24af2e7ed792301268a2af50723ca99df5)

#### [9.4.165](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.164...9.4.165)

> 4 August 2019

- Renamed cache providers column `indexer_id` to `series_id` [`e5d59c9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e5d59c9d124492d208fb8919c2ac9670ff87ec20)
- Resolved issue with int variable being used where str variable is expected when creating metadata for mede8er provider. [`365a16d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/365a16db2baf200917f2f26ade55e674289c0042)
- Release v9.4.165 [`484236b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/484236b8d2a26716084d950ce6a38e15dd54dc08)
- Pre-Release v9.4.165.dev1 [`bfd27b1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bfd27b17ac550be2d082d95f38f6cf0ccb708154)

#### [9.4.164](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.163...9.4.164)

> 3 August 2019

- Fixed issues were skipping shows during adding of existing shows would just return to home page, now correctly skips to next show to add. [`b9e1cec`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b9e1cec52f2981ffb39589c148f6b917bda39b0b)
- Refactored os.path for pathlib.Path [`dae67f8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dae67f8d090cd49b0f9a807acba9a199734b9e64)
- Release v9.4.164 [`dfd9ecf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dfd9ecf67f2181a5b87b33edac766a872a278da3)
- Pre-Release v9.4.164.dev2 [`4d7edad`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4d7edadd052c30b04f1f1e588716e81cdfc95723)
- Pre-Release v9.4.164.dev1 [`0b1d1c7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0b1d1c70d03d98e16bb070d799ce19d7795c8529)
- Refactored python version log tagging to use platform instead of sys [`4b7cdae`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4b7cdaefa0af712687cfb8050ae69ce1d1fd6fa6)

#### [9.4.163](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.162...9.4.163)

> 3 August 2019

- Release v9.4.163 [`8810a83`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8810a8320b108ceca21053042357d99bcf6e0450)
- Fixed issues with startup and shutil.rmtree [`f269aa7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f269aa7ee2439896e4df2711d20bd61a52c31831)
- Fixed startup issues with pathlib.Path, passes string representation of path to shutil.rmtree. [`66c7250`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/66c72505a6047c4dc74f519d814ee7f475fd3f0d)

#### [9.4.162](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.161...9.4.162)

> 3 August 2019

- Release v9.4.162 [`faae82e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/faae82e5445111ae5ffeab2c7710cdb035fb7932)
- Pre-Release v9.4.162.dev1 [`7220352`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/72203528b8f64c2441c0438f2d1ccd32ca4af0ed)
- Fixed startup issues with pathlib.Path, passes string representation of path to shutil.rmtree. [`405dead`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/405dead306aa83c7a8427664a320dafabb74d4f1)

#### [9.4.161](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.160...9.4.161)

> 1 August 2019

- Fixed issues with startup and shutil.rmtree [`f269aa7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f269aa7ee2439896e4df2711d20bd61a52c31831)
- Release v9.4.161 [`c696d94`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c696d9414262c9b36ae29413ac857168e03d3df0)
- Pre-Release v9.4.161.dev1 [`22b5ff3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/22b5ff3c1476277c2de0d52e4aa9050c1a837022)

#### [9.4.160](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.159...9.4.160)

> 1 August 2019

- Fixed issues with cleanup of python compiled files on startup [`2be1836`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2be1836ff4272f40d7a9493e55105c4f8129f4ca)
- Release v9.4.160 [`cbdb2f1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cbdb2f1a774b3aa72813d0395b3d1100996d4aca)
- Pre-Release v9.4.160.dev1 [`95e4603`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/95e46036ae2b8bb510007a9992282210ddcd6555)

#### [9.4.159](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.158...9.4.159)

> 31 July 2019

- Fixed issues with saving metadata provider settings. [`89e4931`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/89e49316f05b1fd59db1901082c1766008daf8ca)
- Refactored cleanup of pyc, pyo, and __pycache__ files and folders. [`763629b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/763629b0503e47c815b5746210f0d47b077bc119)
- Release v9.4.159 [`7b9f412`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7b9f412c40ba56ecedbe8d27dab174a4b6cb1f74)
- Refactored post-processing to properly handle specials. [`e210a8f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e210a8fb3bb898cb99cc16b251437d8d88c8d3c7)
- Pre-Release v9.4.159.dev1 [`cec8a87`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cec8a876a72d6c79b54f8f8990bb2cdc11c7e78b)
- Refactored download link for source installs to accommodate develop releases. [`67acc5d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/67acc5d9fabbf8e6506e061479ab8ba89253ff6c)
- Updated gitignore file [`b4f3226`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b4f32269eb581f063b08644e412070ade5c54aa2)

#### [9.4.158](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.157...9.4.158)

> 31 July 2019

- Release v9.4.158 [`5db54c4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5db54c4bd649f560cca169dbab94b3e08e3b48d8)
- Fixed attribute error `'str' object has no attribute 'decode'` in version updater. [`cfbeee1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cfbeee1abb4d2a3ff76e44bbabd26a1885f8c15c)
- Pre-Release v9.4.158.dev1 [`c7a14c8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c7a14c81a2e60998ae7ad945e02b595017bd8986)
- Refactored requirements.txt to replace package hachoir3 with hachoir, hachoir3 was removed from PyPi. [`67b328e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/67b328efe075a04e6e418965358a9567d9ff08ce)

#### [9.4.157](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.156...9.4.157)

> 28 July 2019

- Refactored dynamic loading of metadata providers. [`90fe2d3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/90fe2d3d3a50a0314575b9a45c3f7e3348757139)
- Release v9.4.157 [`dad896a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dad896a559fd2342dcf11f9ea1fc3ceaa3e8dd5e)
- Pre-Release v9.4.157.dev1 [`324d44f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/324d44f3a9908620c021268e17d83b24deb59340)

#### [9.4.156](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.155...9.4.156)

> 22 July 2019

- Resolved issues with marking failed snatches and retrying snatches. [`7fce356`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7fce35662d902052360241c72b662b6e3bd16150)
- Release v9.4.156 [`7d7e6e5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7d7e6e5b7e8b24745edd78416d1c3bcce2882e78)
- Pre-Release v9.4.156.dev1 [`7cea63c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7cea63c5efec648d20a5face18b359696afb0368)

#### [9.4.155](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.154...9.4.155)

> 22 July 2019

- Updated copyright notices. [`19624f6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/19624f654f1fb2fbfc8bd19eac9ce35b0286e386)
- Release v9.4.155 [`56ddaf1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/56ddaf16574654c59a25ac537e937baf2552f9f9)
- Pre-Release v9.4.155.dev1 [`a70aaea`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a70aaea6b6189efc897a35053f5ef37b958f1ff5)

#### [9.4.154](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.153...9.4.154)

> 22 July 2019

- Release v9.4.154 [`397ac97`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/397ac97c0f46227a8809038c374d7c20ab84d598)
- Pre-Release v9.4.154.dev1 [`3079a6f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3079a6fca99dea79aa52a6b5e542fd40ca3535dd)

#### [9.4.153](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.152...9.4.153)

> 21 July 2019

- Modified startup scripts to use python3 instead of python2.7 [`5b99399`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5b993994a4f3a39d5a001d12efb7973a186ae074)
- Release v9.4.153 [`ae1a14e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ae1a14e49c7e8bebb34986d07b2bbb20b7427d9f)
- Pre-Release v9.4.153.dev1 [`db14540`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/db145403c908ec22850e567b3642458217ec1e4b)
- Modified readme.md to reflect minimum requirement of Python 3.5+ [`08f3d6a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/08f3d6aad3a0f7f1a3b67a3ea173bd0e7d453f8f)
- Removed authentication requirement for robots.txt handler. [`eb4cf0a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/eb4cf0ae6e218a937cb128c6c687995a835137b5)

#### [9.4.152](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.151...9.4.152)

> 21 July 2019

- Lowered requirement for Python to 3.5+ [`16043b6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/16043b63feb0ac9c14e204c2d5f9dc7cef3a0784)
- Release v9.4.152 [`31f9db2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/31f9db26785bbc91e540995405d61cbd6592502f)
- Pre-Release v9.4.152.dev1 [`927bc42`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/927bc42cb7f709bc0414d134a2f64ffc4c1c2adb)

#### [9.4.151](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.150...9.4.151)

> 21 July 2019

- When trying to determine season/episode numbers for air-by-date shows [`2f4076d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2f4076d8f491e4e676ce4c0c7e1aac007892869a)
- Previous archived episodes will now be set to downloaded with original [`4806e15`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4806e15eb34483b4d99597a64a1eb785204f39c7)
- Release v9.4.151 [`54a1397`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/54a1397b22906ba90051e067502592ce28e04c31)
- Fixed issue for NZBGet downloads returning error `decorator() takes 1 positional argument but 2 were given` [`57ea9ff`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/57ea9ffbcbdbb5cb5d4c50bfba4899ce43032a11)
- Pre-Release v9.4.151.dev1 [`81939c2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/81939c28d3dbcc8322fbbafdbd624f7662e5e627)

#### [9.4.150](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.149...9.4.150)

> 20 July 2019

- Refactored how source updates are handled. [`a805f32`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a805f3247e5a58c09c43312fb13d22f0359dd222)
- Release v9.4.150 [`6a275ed`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6a275ed12f72e5b0922b69a89c1137a5f28c35ab)
- Pre-Release v9.4.150.dev1 [`c419de0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c419de010904b45206bcb33860eb9b5fb235959a)

#### [9.4.149](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.148...9.4.149)

> 20 July 2019

- Fixed issues with unlinking account from application. [`05c4140`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/05c414015c1593c2f57d4ee7947c0826230a0052)
- Release v9.4.149 [`fbcf2b4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fbcf2b481d638af8d3c38cad46b681737a30d3e8)
- Pre-Release v9.4.149.dev1 [`1999b15`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1999b1567a0db4b1f4e0e1d740197bb44db0761a)

#### [9.4.148](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.147...9.4.148)

> 20 July 2019

- Release v9.4.148 [`ce02111`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ce0211119dcfc4c3c5cb311a94e62ea348d63eee)
- Pre-Release v9.4.148.dev1 [`ac21414`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ac214149b46ff4679ceea8fb33099b70c2d086db)

#### [9.4.147](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.146...9.4.147)

> 20 July 2019

- Release v9.4.147 [`a702972`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a702972a0b3663cb9dd75cdabc125e3ba44aac6e)
- Pre-Release v9.4.147.dev1 [`c2e5d67`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c2e5d67041523f5118a3b9f08ea500abfddc4f78)
- Decodes output when checking for installed PIP version to convert from [`ae4c4b1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ae4c4b1a047cadfd0630af575ded452740ba3dd8)

#### [9.4.146](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.145...9.4.146)

> 20 July 2019

- No longer need to use url_concat for requests. [`ca7e94e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ca7e94e3e62872a24c7ed65e31f777adb401714f)
- Release v9.4.146 [`130a23b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/130a23bd9b08211ce0b3252e4dd5ccd03a160327)
- Pre-Release v9.4.146.dev1 [`9c6fc09`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9c6fc098957f577ff79b5acaf2ff01ee89833af6)

#### [9.4.145](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.144...9.4.145)

> 20 July 2019

- Pre-Release v9.4.145.dev2 [`2b93b28`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2b93b2856440adc4d47170ba3d28f4dc0f8c667c)
- Release v9.4.145 [`971d032`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/971d03215d67dd9b317933199c495e10e3fb7f08)
- Checks for episode number in provider result episodes list before attempting to remove it. [`a339f1f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a339f1f6ba3bbf5a1bdf1af088dc130ae28b8102)
- Pre-Release v9.4.145.dev1 [`30f6bd1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/30f6bd1be4ba0a8c5c86f453b4b5bc900c0aab5b)

#### [9.4.144](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.143...9.4.144)

> 17 July 2019

- Release v9.4.144 [`88af882`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/88af882666d3092e9678163dd6297575035142aa)
- Pre-Release v9.4.144.dev1 [`c7b8a46`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c7b8a466f3336144c09a444d5cb9e00d34d53331)

#### [9.4.143](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.142...9.4.143)

> 17 July 2019

- Release v9.4.143 [`1155881`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/115588118522957b3476c7270398a81c409547c0)
- Pre-Release v9.4.143.dev1 [`bb11dd5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bb11dd5b7decaff3db72a3d3591500d561e0aa0f)

#### [9.4.142](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.141...9.4.142)

> 17 July 2019

- Release v9.4.142 [`692f9b1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/692f9b1cfcd43db4509844272259d00cfb29ee06)

#### [9.4.141](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.140...9.4.141)

> 16 July 2019

- Release v9.4.141 [`d4bb52b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d4bb52b2ab4d4a54214a56fda5494f4dfbf92005)

#### [9.4.140](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.139...9.4.140)

> 16 July 2019

- Release v9.4.140 [`bf8ba35`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bf8ba3540b083a080bc37cd50e75a1d5b02929cf)

#### [9.4.139](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.138...9.4.139)

> 16 July 2019

- Refactored using data to using json in requests. [`578ab74`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/578ab748cc26c62fcf4fa1da68c55c4fdbb2333b)
- Pre-Release v9.4.139.dev2 [`e749806`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e74980679886635b0add287480a94c8d3f77e262)
- Release v9.4.139 [`0f153a4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0f153a4336c2a948fa31679b1ca329c4b9038e2f)
- Pre-Release v9.4.139.dev1 [`7139f44`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7139f448203018f53462263ef103927347bd1f50)

#### [9.4.138](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.137...9.4.138)

> 14 July 2019

- Release v9.4.138 [`6c1a44f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6c1a44f0e3960b52e52dbe5798b6d2c60a1250b5)
- Pre-Release v9.4.138.dev1 [`5745352`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5745352886984d9ccb472e9542ccb048a4bfbc34)

#### [9.4.137](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.136...9.4.137)

> 14 July 2019

- Fixed schedule category sorting. [`5fe263f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5fe263f3fe4cebc23e778d5e563326ca6938e998)
- Release v9.4.137 [`f3e6803`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f3e68034c06e971b45ce787b52d1cc53c73e896a)
- Pre-Release v9.4.137.dev1 [`e12dfb5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e12dfb570e6ba2d37a81c0137a4533cc648217c3)

#### [9.4.136](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.135...9.4.136)

> 14 July 2019

- Fixed download issues for Deluge Web-UI Client. [`dd3a9a6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dd3a9a6084fb234db8691c51f2d1df99d019fd31)
- Release v9.4.136 [`e6daa57`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e6daa572f7c7a246c4ae2c95917377abedcdbba3)

#### [9.4.135](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.134...9.4.135)

> 14 July 2019

- Release v9.4.135 [`9a12a64`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9a12a645c4af25cb4c2d9cd871b8374f0d6e0dd0)

#### [9.4.134](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.133...9.4.134)

> 14 July 2019

- Resolved issue with renaming episodes not including metadata files. [`2e0b68b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2e0b68b3444009493802ef32a289d80a11d596fd)
- Pre-Release v9.4.134.dev2 [`985b907`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/985b907b4fd95651586f127327c6715d3105ea4d)
- Pre-Release v9.4.134.dev7 [`83aec60`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/83aec6047a0588f1ad3bf01b116624c6ceeacb56)
- Pre-Release v9.4.134.dev6 [`0583b04`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0583b040c89955f8609d07a3eaca79d61d325eb9)
- Release v9.4.134 [`de4f179`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/de4f179d9cfb0b81c4ac8b72562991c94344d253)
- Pre-Release v9.4.134.dev5 [`57198a8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/57198a80d20175090ef6bf18fcfcfefeca522661)
- Pre-Release v9.4.134.dev4 [`5d6bcf5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5d6bcf5c9c85fe31fdb140c52b73e5194560af25)
- Pre-Release v9.4.134.dev3 [`e9c169f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e9c169ffe1b65aca5d5f0e157904d577e622eeb0)
- Pre-Release v9.4.134.dev1 [`6b7e8bb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6b7e8bba72d6bf064e576f950c88cabb427f5220)

#### [9.4.133](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.132...9.4.133)

> 13 July 2019

- Refactoring database tests. [`3e7748e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3e7748e54fdddf1bfd36dc9f64e643ff638fc730)
- Release v9.4.133 [`9aa3996`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9aa3996478978a75d96c2350bebf3f72c64319f2)
- Pre-Release v9.4.133.dev1 [`63d34e6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/63d34e6d1c12b27ad0d509e31dc1ecee94340a40)

#### [9.4.132](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.131...9.4.132)

> 13 July 2019

- Fixes issues with mass editing shows and setting qualities. [`1175f63`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1175f634694268a94ab10898c79df6a7758e4ea3)
- Release v9.4.132 [`fc3b301`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fc3b301799316aac5ac23ab0e8d82fbc848794fe)
- Updated git release flow. [`999475f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/999475fc04666532c7f3fae6db29bc89a2d2e4c1)
- Resolved issue with setting proxy address when global proxy configured. [`7b0f1bf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7b0f1bfbb4d128e9dcb43c23ba281784608da927)
- Pre-Release v9.4.132.dev1 [`faeabc9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/faeabc9473e7284506e562fc108f9706ed4c6c03)

#### [9.4.131](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.130...9.4.131)

> 13 July 2019

- Fixed issue with gitlab-ci and pipelines for master branch. [`4df45f1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4df45f161996e3a6199be3c95699e9c4fbf62cfc)
- Release v9.4.131 [`4072c47`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4072c47a255a1c0b180bf02fbdbd04d2d071e398)
- Pre-Release v9.4.131.dev1 [`f7067e9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f7067e98798a4e46bd1f92fce4e6dc8eda297d02)

#### [9.4.130](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.129...9.4.130)

> 13 July 2019

- Release v9.4.130 [`368e70c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/368e70c185050d2a3ca41b1681e2b669b0baafe2)

#### [9.4.129](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.128...9.4.129)

> 13 July 2019

- Release v9.4.129 [`9628b36`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9628b3657b82a0f1f34bf45cb96543e7456ccc3e)

#### [9.4.128](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.127...9.4.128)

> 13 July 2019

- Release v9.4.128 [`705d0bd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/705d0bda1d9fc7435361092756fe5d193e189291)

#### [9.4.127](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.126...9.4.127)

> 13 July 2019

- Release v9.4.127 [`45aab9a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/45aab9af9858484f57cb05eff4b85e5273d1d9b9)

#### [9.4.126](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.125...9.4.126)

> 13 July 2019

- Release v9.4.126 [`32308be`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/32308beb65137eb8630e6247a454e31bc4a4ec9c)

#### [9.4.125](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.124...9.4.125)

> 13 July 2019

- Refactored release flow. [`0ff1e9d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0ff1e9d821017f738102d167e5a7deb9e6dd4e53)
- Updated gruntfile. [`bc7c359`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bc7c35998ff6f4575164e3d009d44097f814b9d1)
- Release v9.4.125 [`a411278`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a411278c61e6794015ef692d0ee5c9f414bd7302)
- Changed close to remove for database sessions being access from web handlers, helps resolve QueuePool overflow issues. [`b9ea97e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b9ea97eb33917cb5d59707d52d4bd471a496c80f)
- Merge tag '9.4.124' into develop [`ecc4ad7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ecc4ad7c43574581d95a376b21c5dd211a068f3d)

#### [9.4.124](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.122...9.4.124)

> 12 July 2019

- Pre-Release v9.4.124.dev1 [`1ad0be6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1ad0be62db17a5f34be52bb25339fddfd97cad31)
- Release v9.4.124 [`65f3178`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/65f31787404cf7dd90229e654b90ed169501c4ad)
- Pre-Release v9.4.124.dev2 [`c878cc0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c878cc06a2ebd0b760d4bcb2d022970f6ed444dc)
- Merge tag '9.4.122' into develop [`4bf4a79`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4bf4a79c199ad18610e8c94c3f2347a785070a43)
- Merge tag '9.4.122' into develop [`d37bdcd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d37bdcd25105f094bb0def5e0a478b03c100f22d)

#### [9.4.122](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.120...9.4.122)

> 12 July 2019

- Updated gruntfile. [`3e2a870`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3e2a87007c762b096046e9f0e48cba687ddd5121)
- Pre-Release v9.4.122 [`9e9f867`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9e9f867fe05714066332d87d9ae839b6b9436852)
- Pre-Release v9.4.121 [`7d9f054`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7d9f054135beb2b324bade0bef6d39e93b1b15c9)
- Pre-Release v9.4.120 [`7e3a1e8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7e3a1e8843957996babe2a7d907ce2be4c5e7a0b)
- Release v9.4.122 [`3923c2d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3923c2d090c315492f6da052862a196e35e07574)
- Merge tag '9.4.120' into develop [`37d1c92`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/37d1c92859bb09920b8cd4bec10904dacf924851)

#### [9.4.120](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.119...9.4.120)

> 12 July 2019

- Migrated Docker builds to their own repository. [`01678da`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/01678da7bcd22092c7756e623ec87b0904f90c50)
- Pre-Release v9.4.120.dev1 [`17ee7fb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/17ee7fbb1a0f1ff04789bc22ba4814502c9baebe)
- Release v9.4.120 [`a586ca0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a586ca0433b1139605797f21e06f223c2e25e509)
- Merge tag '9.4.119' into develop [`523b457`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/523b4579b9ea752aa78bfb2935eb5c2787b87969)

#### [9.4.119](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.118...9.4.119)

> 11 July 2019

- Resolved issue for saving custom qualities, black/white lists, and scene exceptions. [`edc07c8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/edc07c8d7fb00a2a23c3c82a1a3297ad15bb7cc8)
- Release v9.4.119 [`30e8a1b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/30e8a1b7d5f073b12b0b6c986be16ec166f0f884)
- Resolves `can't concat str to bytes` in sickrage.providers in _get_season_search_strings [`3b88e82`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3b88e82e0ee0c59a66722a564b3b5b751c127625)
- Merge tag '9.4.118' into develop [`a52948d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a52948d19a5a56adeaf150093f0d0f7eb61121c9)

#### [9.4.118](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.117...9.4.118)

> 10 July 2019

- Release v9.4.118 [`63354dc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/63354dce53a4b3888c8a3d25945e4252891f183a)
- Places search result from indexer into list object if returned as dict. [`f6fce27`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f6fce27667b2859843e2bf5cfef57a9d62baa095)
- Resolves error `can't concat str to bytes` in `sickrage.providers in _get_episode_search_strings` [`7ad8c0b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7ad8c0b06299462bc1ce471680e2aa4d6dff9c45)
- Resolved unsupported operand type(s) for +=: 'dict' and 'list' [`8a423fd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8a423fd15bc61b20045d380802fcbd2b7069a346)
- Merge tag '9.4.117' into develop [`1548288`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/154828840a40199c1de3cea064c6e3104455f371)

#### [9.4.117](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.116...9.4.117)

> 9 July 2019

- Release v9.4.117 [`1ee3cdb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1ee3cdb90e060881b0e9a5f4054087e5cc46bc58)
- Fixed issue with post-processing and logging downloads to history when unable to determine provider result came from. [`edd6289`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/edd62897563e4b3a9399a49b203c5cddd7de2a69)
- Fixed typo in container name [`134fcfe`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/134fcfe23fccb7a4234b14b591039a7ba0dccf3e)
- Merge tag '9.4.116' into develop [`a953ad5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a953ad53a2b6804808a77dccfecd943de6373f98)

#### [9.4.116](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.115...9.4.116)

> 8 July 2019

- Release v9.4.116 [`42aec55`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/42aec5573026710a0ff8d4f26292ff28d9c25a68)
- Merge tag '9.4.115' into develop [`de17715`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/de17715c33d0070779236695e40848a819d552d6)

#### [9.4.115](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.114...9.4.115)

> 8 July 2019

- Release v9.4.115 [`8f08c10`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8f08c10c2e900f58ffb573cf02529a9b30a59ea8)
- Merge tag '9.4.114' into develop [`939b921`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/939b921eaf09e65fe5979c04cf151926a9f495be)

#### [9.4.114](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.113...9.4.114)

> 8 July 2019

- Release v9.4.114 [`b0731df`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b0731df1538aaf17dbff3e88e29250f7f156f318)
- Merge tag '9.4.113' into develop [`daaa163`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/daaa163d3fd177c9a840fdc2a426e4765268169d)

#### [9.4.113](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.111...9.4.113)

> 8 July 2019

- Release v9.4.112 [`2df3ed9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2df3ed96967463e9d93a6335c30099e40c3b5eef)
- Release v9.4.113 [`f369fde`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f369fde9f2c9b9468660366487667c7a68a7e4a4)
- Merge tag '9.4.111' into develop [`9f19c8e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9f19c8e9aa077ebb71caa63ece67c46b460cf332)

#### [9.4.111](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.110...9.4.111)

> 8 July 2019

- Refactored GitLab CI/CD script and Dockerfiles to cut down build times. [`6b4378a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6b4378aea31ff52575c21de60db3a6e0f3f06a74)
- Release v9.4.111 [`07d2e3c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/07d2e3c3519b7b31a8af906ae854fdd54f1a59a0)
- Update Dockerfile.arm32v7 [`b861832`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b8618323f0f3c4a47733f23f9eb3c3e43efee2c9)
- Merge tag '9.4.110' into develop [`d263df4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d263df474f00cfbb164b356cb76e10e218848af7)

#### [9.4.110](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.109...9.4.110)

> 8 July 2019

- Fixed issue with manually post-processing episodes, was a typo. [`9d17dfa`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9d17dfa420c1901519c26f1e4328f2451aeea284)
- Release v9.4.110 [`43d40c3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/43d40c38ad8119c8c84ae79056057b3864233c32)
- Merge tag '9.4.109' into develop [`2612012`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2612012fa3d87d9c9bd0af254a96b9aba4871026)

#### [9.4.109](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.108...9.4.109)

> 7 July 2019

- Release v9.4.109 [`9521413`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9521413b70f351077e5ca7addbd1e78ec10a4f2c)
- Merge tag '9.4.108' into develop [`b877a36`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b877a3647ec8339ba44ba2b90cc88313f1e358cd)

#### [9.4.108](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.107...9.4.108)

> 7 July 2019

- Updated Docker image tags to correctly represent multi-arch [`ea56a8b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ea56a8b17f0a28c5cb59162a0c6bef9bb04174ad)
- Release v9.4.108 [`ca70d11`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ca70d11b606672eac2feaf9cd0b7535bb6d890f5)
- Merge tag '9.4.107' into develop [`447124b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/447124bab77ac74be790aae59bab27ec44354d9f)

#### [9.4.107](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.106...9.4.107)

> 7 July 2019

- Release v9.4.107 [`5b3fb85`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5b3fb85a012fa12f6e9f86194199c3b0916b8a82)
- Merge tag '9.4.106' into develop [`57cceaf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/57cceafb2094f4b41fca6ba89bb526d7e6caeb74)

#### [9.4.106](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.105...9.4.106)

> 7 July 2019

- Release v9.4.106 [`3c710c6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3c710c6eee96919a560da7103fe7f936c205b3fb)
- Pre-Release v9.4.106.dev6 [`1a2908e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1a2908e11f089935dd54ad9592c212f1b1e559c0)
- Pre-Release v9.4.106.dev2 [`ab0fcd1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ab0fcd1fa9572513c99db533f95ad89390946ea9)
- Pre-Release v9.4.106.dev3 [`86e80dd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/86e80dd0493146e9e52097f3e6d50cbc57d2abef)
- Pre-Release v9.4.106.dev5 [`bd8dc67`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bd8dc67586c4ed46804bfc17548a4b5633fe381d)
- Pre-Release v9.4.106.dev4 [`c8067c4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c8067c4f946cb1e8fca92cf9b7d830a093d0ed86)
- Pre-Release v9.4.106.dev1 [`b0c73bf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b0c73bfd3d2b1f265184374dcf181cb9cb8341ee)
- Merge tag '9.4.105' into develop [`9ebfde2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9ebfde2307672b58191694026450ac0a3c20e41d)

#### [9.4.105](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.104...9.4.105)

> 7 July 2019

- Updated gitlab-ci.yml file [`cb5b159`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cb5b1592d53f9b48e359dfd83129ba86e2107714)
- Release v9.4.105 [`2070a5b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2070a5bed225ddcedb724fdc3c88f9d0e726f948)
- Merge tag '9.4.104' into develop [`b0838ba`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b0838ba031edf0f0aa5ba9eb790d7188adaa5ac8)

#### [9.4.104](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.103...9.4.104)

> 7 July 2019

- Release v9.4.104 [`0a2f554`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0a2f5542d08db04a197f5140905e6873bfba463f)
- Merge tag '9.4.103' into develop [`174579e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/174579eae0d8cf2111f19f8a6882e2ae6b8fdef0)

#### [9.4.103](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.102...9.4.103)

> 7 July 2019

- Release v9.4.103 [`73ad9a4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/73ad9a49863e5e5347327e29a68ae31f67223668)
- Confirms that there is a year to be added from series pieces to show directory if requested. [`331fb7b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/331fb7b29cc114bd133694a7960d89bf5f523604)
- Merge tag '9.4.102' into develop [`74ff12d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/74ff12d83d8cfefbcd470d71a982daeb584ce89d)

#### [9.4.102](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.101...9.4.102)

> 7 July 2019

- Release v9.4.102 [`e59ea00`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e59ea00f5b2cd4c7212cfbcc037bd52461dd6d8e)
- Merge tag '9.4.101' into develop [`ae8f473`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ae8f473592fb55ea4552ae47b6f5b303b0807db5)

#### [9.4.101](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.100...9.4.101)

> 6 July 2019

- Release v9.4.101 [`c768c9a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c768c9a4871e4c407813c700c04012f4c6589a94)
- Merge tag '9.4.100' into develop [`a45e606`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a45e60631a34ab8f87dbd5aaa9300f6a91963dc6)

#### [9.4.100](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.99...9.4.100)

> 6 July 2019

- Release v9.4.100 [`2f5e07c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2f5e07c8d1e8ccd14c7b2728da8fe2787d26ce68)
- Merge tag '9.4.99' into develop [`e7feb74`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e7feb74d41dc63c8f3c3b1111851f5f4295ddd73)

#### [9.4.99](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.98...9.4.99)

> 6 July 2019

- Misc typo fixes. [`c8ac2d4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c8ac2d441475e4b215145d7d453aea9833b8d89b)
- Release v9.4.99 [`2f4236c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2f4236c989db5325d643296dd54f673b5e5f2664)
- Looks for provider search result by URL and if exists it does not add to cache. [`5ceded0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5ceded0af18cab44540e2f21410ec576de5b813f)
- Converted misc errors to warnings [`c446e18`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c446e185b9d6250e6522bc2c162fa5b0eb7aa12b)
- Resolved issue for combining quality when qualities list is empty by providing a default. [`1de0584`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1de0584abc7a975e7c08ffa8e6fd5b338929f91c)
- Passes database session object onto add keyword function to avoid database locks. [`5dff80f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5dff80fb0b06a8626b64a40a8fdc4112d6306dfd)
- Merge tag '9.4.98' into develop [`ac97203`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ac9720385eb9b9e596e8105471ace881bd4c82e3)

#### [9.4.98](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.97...9.4.98)

> 6 July 2019

- Resolves timeout issues for internal http requests. [`d426b5d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d426b5d7309c989583321c2736bc3aac516fff5f)
- Release v9.4.98 [`6ddee98`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6ddee98ef99d0eca645229cbc4c7202535b61d35)
- Merge tag '9.4.97' into develop [`9ba8828`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9ba88283373ede6e57c198b404571c3f619a0631)

#### [9.4.97](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.96...9.4.97)

> 6 July 2019

- Resolved issues with subtitle downloading. [`466bb28`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/466bb283809b4ec780f6b19647bc21ac642380eb)
- Release v9.4.97 [`0603b4c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0603b4cc9a434b1927ec344b185ab62cbd03c896)
- Pre-Release v9.4.97.dev1 [`569cda3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/569cda3416bc8fc1f3129d69c6b9b0d140d2bbb6)
- Merge tag '9.4.96' into develop [`32beab2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/32beab224bb087476abf209df5bd6e0549613158)

#### [9.4.96](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.95...9.4.96)

> 5 July 2019

- Release v9.4.96 [`97f0ddc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/97f0ddc7de51c1e2314ed7dc2a3f118cef91c72f)
- Pre-Release v9.4.96.dev1 [`fbbeec4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fbbeec4aef4700fb429c1bfb7437ad46ebd667db)
- Pre-Release v9.4.96.dev2 [`6c06ea1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6c06ea1f7b7efaf397d23a08e4845721bbaae30c)
- Resolves unbound exception for variable `imdb_exception` [`d0aae5b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d0aae5b394f9f2eb819097c3de4ab314af99f1c1)
- Performs select count on provider cache results to determine if its ok to insert provider result. [`140e129`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/140e12938db2578f38fb2ebc7990d155753dd3a1)
- Merge tag '9.4.95' into develop [`90d1ea6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/90d1ea6d7676e6f74c2d807b6d8ba5dbc391a067)

#### [9.4.95](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.94...9.4.95)

> 3 July 2019

- Release v9.4.95 [`f7eea90`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f7eea9011e07db94dd73bb264c58e7842c9e5e28)
- Merge tag '9.4.94' into develop [`4d39393`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4d39393385d33612c42ea1654484808318f4572d)

#### [9.4.94](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.93...9.4.94)

> 3 July 2019

- Resolves issue with saving subtitle settings. [`8fb2de7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8fb2de789668bb7b2559707cb774bf8d8e88f9dc)
- Release v9.4.94 [`0d476b6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0d476b6caaf98e9a945a3a502973a23070be2e17)
- Merge tag '9.4.93' into develop [`4d45298`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4d45298148f7b1a6cb59a029a1589d94e6b21b41)

#### [9.4.93](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.92...9.4.93)

> 3 July 2019

- Resolves `a bytes-like object is required, not 'str'` [`831787e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/831787e65b2ad05aa986574abdd97f68b141ac52)
- Release v9.4.93 [`a2bfb77`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a2bfb7721a9bdcd1002334e3aac36b37f7b3b173)
- Pre-Release v9.4.93.dev1 [`d6a1ed2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d6a1ed2ef5ea3cc3f18e5f4d8e588009119c7248)
- Fixed key not found issue with migration table column mapper. [`32ed358`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/32ed35832cf7aa0c4d47918a843819049bce2a00)
- Merge tag '9.4.92' into develop [`86ed469`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/86ed469f120d8425c3a82b6c1535d4c4759870bf)

#### [9.4.92](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.91...9.4.92)

> 2 July 2019

- Refactored Deluge Daemon client to PIP install and removed old lib requirement. [`9a08345`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9a08345479bf2cfd0b84c51a5674df02a6a9f76a)
- Release v9.4.92 [`79bd8f1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/79bd8f1e9ac2c60838e8a9431d37655aeeb80f1d)
- Pre-Release v9.4.92.dev1 [`60c2498`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/60c2498fb1288ddb0a7c4ed3cd4211c9a95afa88)
- Resolves version updated issue `'str' object has no attribute 'decode'` [`22240c9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/22240c96a4fae5f6eb467958b7653fda6f47417c)
- Refactored display show mako code to check if imdb_info object has attribute genre. [`526b345`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/526b345cba2bccd58f2c7cbabd4082e8fe9290ee)
- Merge tag '9.4.91' into develop [`7183e59`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7183e59fb187265d6af6bc2589ab6068d505daea)

#### [9.4.91](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.90...9.4.91)

> 1 July 2019

- Resolved issues with installing requirements.txt during updates causing updates to fail. [`df757f5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/df757f507110e376ecb7b6d2bb4755366b7ad749)
- Release v9.4.91 [`3425338`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3425338989c55bcf7d2b46da0085cc1fbd0ca0de)
- Merge tag '9.4.90' into develop [`3b118f1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3b118f1ea456ce4d4c7268b15853b6d219363584)

#### [9.4.90](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.89...9.4.90)

> 1 July 2019

- Release v9.4.90 [`2f63091`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2f63091d3f4d17e17c8d4491a54e92fe3eb95645)
- Merge tag '9.4.89' into develop [`c272ea3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c272ea3975c718c56cbb99d5276b94426bc16e33)

#### [9.4.89](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.88...9.4.89)

> 1 July 2019

- Resolved issues with NZB searches and not snatching found results. [`c3957e4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c3957e4dc5220c471721d95ffe04e73fb5febeed)
- Release v9.4.89 [`2908018`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2908018017261d407e7f083fb130d42299158de0)
- Merge tag '9.4.88' into develop [`bfb84e8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bfb84e872ce32b0328e3443e9fc1271e83320ad7)

#### [9.4.88](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.87...9.4.88)

> 1 July 2019

- Refactored how we gather query and body arguments to use one method. [`5bffa94`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5bffa94a2ec9bf3bd468924c21f522a0aed801df)
- Refactored async http client calls in web handlers. [`a4f2d4e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a4f2d4e5626b83974350106fc7f97caa56ebeef2)
- Refactored show search list to not select shows already in library. [`5e05f9c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5e05f9ce7ff2fb574e6d602457cbebb252701bfc)
- Resolved issues with unicode decoding output from version update commands. [`c894e74`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c894e74593d71486f84cfdb1422968be7cb7cbf6)
- Pre-Release v9.4.88.dev4 [`8b2b290`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8b2b290351a9f6794a28390d7d591387debf3be2)
- Pre-Release v9.4.88.dev6 [`aa389b1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/aa389b1006a4816354c492fc23a6bd277dec6987)
- Pre-Release v9.4.88.dev5 [`60ad77f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/60ad77ff856c170f1211921b3409dbb221d73b8d)
- Resolved issues with sorting main show poster view. [`c71c5ce`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c71c5cefc9cdc668229257175c2ab816ecd8cf45)
- Pre-Release v9.4.88.dev3 [`2c95398`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2c9539800266a20fe69e5c111ac229288d416b8b)
- Pre-Release v9.4.88.dev2 [`4ba9839`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4ba9839f7ae543f1f616a9ea21af8da944b73b78)
- Release v9.4.88 [`a15394b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a15394bf1ea908d5b3d3b449a81ee874c644ed54)
- Merge tag '9.4.87' into develop [`4484245`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/44842450815de800de9e90fe983a75b330522dd9)

#### [9.4.87](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.86...9.4.87)

> 30 June 2019

- Refactored cache database last_search table provider column to be the [`b8d32c7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b8d32c76f4e9e858073b32ca6dc700bd96ec1080)
- Resolved yaml issue for CI/CD [`b4eb0e7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b4eb0e71ac8a12389ce285285ee51b73947a2743)
- Pre-Release v9.4.87.dev4 [`352931e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/352931e93612cd0b5ad49102adb6cecd155d57de)
- Pre-Release v9.4.87.dev5 [`0a574b3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0a574b3635f6b490c4b664dc3bc908e239da1b4a)
- Pre-Release v9.4.87.dev9 [`3c4a9b9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3c4a9b9271e5422b2a6d229878e8ce92100b115b)
- Pre-Release v9.4.87.dev1 [`fda4adf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fda4adf7b754cd9c583e951ebe40927bf0f6c439)
- Pre-Release v9.4.87.dev8 [`a4fc5c9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a4fc5c9592bcc3494312356f299b322e67799fa9)
- Pre-Release v9.4.87.dev7 [`db4a94b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/db4a94b20afd37fe0695d82a80b21937c9a1d185)
- Pre-Release v9.4.87.dev3 [`25f4b66`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/25f4b661f420222883df42ffa711aa63646a7743)
- Pre-Release v9.4.87.dev2 [`d8ef193`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d8ef19390a193fc18a7d789a07378aad0cf2e822)
- Pre-Release v9.4.87.dev6 [`2a6d3de`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2a6d3de117c84b2c33fe29935d3b172d64506a33)
- Release v9.4.87 [`0f183b7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0f183b7700e372470e5663679ae00efd1d7c09c0)
- Merge tag '9.4.86' into develop [`625ccfa`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/625ccfa0bb8f3e23e1b736bccdedaeb7d7766ae7)

#### [9.4.86](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.85...9.4.86)

> 29 June 2019

- Release v9.4.86 [`5c877f4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5c877f45fe86bbe7aaf275f043590b8c01f60699)
- Update readme.md [`81c32f3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/81c32f3b4320f6075fe89bfc4f3f538195fd84ca)
- Update readme.md [`4deb267`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4deb2671f0e7d6d9712289e3cc7306da608d15b4)
- Merge tag '9.4.85' into develop [`686783f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/686783f2190e5f5acd180c51d10dd8c7a379dbb9)

#### [9.4.85](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.84...9.4.85)

> 29 June 2019

- Migration from Python 2 to Python 3.7.x [`c8c1995`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c8c19951b34b3b30df9b07f92e90e4b0ff4280b6)
- Restructured web view folders and classes. [`1f9f2c4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1f9f2c413129513488aaca9e13c278d8be41a284)
- Migration from Python 2 to Python 3.7.x [`7f5696f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7f5696f950ebb3f078ecc68c539f010b9f775fcd)
- Refactoring provider searches to search for one season/episode at a time, this will allow for better multi-thread handling of search queue items. [`81d9d7c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/81d9d7ce1b3659f5ac0841826e4f8c79a77ccfc9)
- Refactored file headers [`19708c3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/19708c3c956b3cd4f12a20894611d9212e75fb0a)
- Refactoring code for performance [`6f6e1db`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6f6e1db2508ebbd5897e31ec1980bc280ff2ecde)
- Refactoring post-processor code. [`4d9e816`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4d9e816729b3ddb380512efd17c983011c42568e)
- Refactoring database calls to properly use session context. [`ced8924`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ced89247453064a7d4dd5d71098157a881816dd3)
- Refactored schedule calendar view. [`50275d8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/50275d8703ab4d199bc1585252081f086d920276)
- Improved load time for main shows page by loading episodes into memory. [`f01d04b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f01d04b128fbf211ab3b56438d02684a9ca51857)
- Refactoring database calls to properly use session context. [`5684a09`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5684a09482cfcb67e4ea62a1169ba5c411756724)
- Refactored `searchProviders` method [`7fa3757`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7fa3757e0e1e575bdac0d5b4f47dffc50e3f6b9f)
- Refactored History methods [`c31c7c4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c31c7c4e83a2be7890a8d8602a5c2af0de0fe29c)
- Refactoring database calls to properly use session context. [`02d3bdc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/02d3bdc388a4b839b332261271eb4e871e4c92dc)
- Refactored core main helpers module. [`8d70465`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8d7046525b9f654eaf1fbfcf64614fa2cab715ce)
- Pre-Release v9.4.85.dev1 [`45c6de2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/45c6de2a2c6ca4072b0049413347463903e130ee)
- Refactored more database calls [`a5c700f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a5c700ffd2be7102c3b6502481bbd7b1ae9ff471)
- Refactoring database calls [`98df301`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/98df3016fec61fe3b178f002c1b2977ee576cd5f)
- Improved performance of loading main shows page and gather statistics. [`ca56cad`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ca56cadee491dfa6b06750947f29def994104cbf)
- Fixed issue `install() got an unexpected keyword argument 'unicode'` [`8baf524`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8baf52440a720903575dae317da452d03671e1f5)
- Refactored configuration encryption routines [`762a0f1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/762a0f10228330128e1b721a28dbda819028f3de)
- Refactoring post-processor to pass show and episode IDs instead of objects. [`c478beb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c478bebc3d3132f42604024fc4da0e6eb1f63c67)
- Enabled `autocommit` for database sessions. [`9ddf71a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9ddf71a71846ab85c6472fd10a92d115b2ad5b89)
- Refactored `find_search_results` function [`ac6ef8c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ac6ef8c150e3ef76efbc8160a630f88ad57d6da2)
- Refactoring of misc class names. [`b1e3ed9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b1e3ed92f4b08cb50746277586ac3410661277c0)
- Improved performance of loading main shows page by doing away with overall stats and moving stat gathering for shows to views. [`b1dd65f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b1dd65fa0977f7f221cf9ad49ec7c86c47cb933a)
- Working on fix for locked database issues [`c6f5543`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c6f5543332ea482b634ea2ff7a078df2f4c65ca8)
- Refactored search provider HDBits [`49b3286`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/49b32863378296074f1046b08f5862308f09cece)
- Refactored `show_names` module [`468638f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/468638fb9d9e45c744292bf0949e81544ee769de)
- Refactored database calls to be more multi-thread friendly. [`fc34dac`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fc34daca5ce7e703d2a8809d4ca67fab982a9f10)
- Refactoring show object code [`b2d7407`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b2d7407d97f8dc6d3cb6a881a2f4da0d2b52275a)
- Fixed attribute issue for show object release groups [`45cdfe1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/45cdfe1d293c75fdc745f378e97b10e49f258ef5)
- Removed remaining custom database functions no longer needed. [`9f4c8df`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9f4c8df89f0cb3dead44340c400e183a386806b7)
- Fixed issues were season packs and multi-ep search results would cause [`164b687`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/164b687cc9a309b2f123cf9f9a64d1d789567dda)
- Cleaned up search queue code. [`6af5a7d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6af5a7dee78f34bf2c7edae0db405923cccf75ec)
- Refactored schedule calendar view. [`6f3e014`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6f3e01496085f6045817d36c9eb32d6f6020fa48)
- Refactored encryption functions [`a13c1ef`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a13c1efc62ca815feb14264bb44f2271570e582a)
- Refactored post-processor class code. [`8f8968b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8f8968bc9cf02548f70cb13f4256621483e5b934)
- Refactored database insert calls [`1bff88a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1bff88aa81e170039c394b6d794b965f7c49a5d1)
- Refactored how we delete database rows [`b65e3ac`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b65e3acee78b2aa2c807ad4dc1cbe27adf13a98d)
- Refactored provider search to return single result, avoids multiple snatches. [`80cc2c4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/80cc2c4835243655227181e651dff75933317556)
- Refactored tornado web handler to perform async calls [`c55f378`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c55f37875b5dfe29d0ff7ee3deb0571bc4fbe767)
- Refactored remaining database query calls [`da76cd1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/da76cd140835dd730b65aec0558b13296677c8dc)
- Refactoring database delete calls [`a495abb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a495abb035065877870b38488a4212f512b06156)
- Misc code refactors. [`e743c7e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e743c7ec3e26fa65830613da3de8ce305e90d2d6)
- Refactored database update calls [`2edaad7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2edaad7769558a484187283208745fee9e005e9a)
- Refactored show stat handling. [`a53079e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a53079ed0bcf736ccfb8389d2d28445253ec2330)
- Refactored scene numbering function conditionals [`87cabbd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/87cabbd1a721712aad2ae71f9fd77726c54e78f7)
- Resolved issues with show updates and refreshes related to database sessions. [`c6818d8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c6818d8b08ae882d3de48f94d2abb3954ddcb3cf)
- Refactored pip_path to pip3_path [`eed9186`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/eed91867cf108b438b5f38806634ac7ccb2a9949)
- Working on fix for locked database issues [`2dd6518`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2dd6518872e4990b2b3147b9cc85c218ac923ec8)
- Fixed issue `name 'table' is not defined` [`3d8c877`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3d8c877684ca88e712b864e4cd47f80d11709050)
- Fixed issue with main show page including downloaded specials in [`9906b49`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9906b4952a2506b609beb09910ca15304f0ef829)
- Moved encryption startup routines to its own function call [`326cdd7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/326cdd71a33e96e3961e2a6408f571a92447182d)
- Fixed issue with calling backlog on newly added show with wanted episodes. [`e850bb0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e850bb0f99200337ed6409414701f0469e6c70e4)
- Fixed Zooqle torrent provider search issues. [`a2040ab`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a2040ab6a7463b1bb3be1213ccb4741b6ca4cc8a)
- Fixed issue with internal http client and auth [`c0cbb15`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c0cbb15f48bef05833360acff51df8a6e943c1f8)
- Refactored search code to account for season packs and multi-episode results when determining quality size constraints. [`30c9bda`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/30c9bdacfa45f609f40356bc2f19149a8084504e)
- Refactired database update calls [`87ae736`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/87ae7363b95779c8d2765e360a1dfd32f40cd541)
- Refactoring scene numbering functions. [`2803fa9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2803fa9f366b44cb3beaea92442a1e5dda92332b)
- Reverted scoped_session as it was removing session binds from models. [`d84f863`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d84f8634a05478089ed7738c93665044fb52ed71)
- Refactored `backlog_searcher` module [`f7cf3a1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f7cf3a184073ae5cfc06d0d16566fde3c58bc0dd)
- Misc code refactors for using show episode relationships [`b91e49c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b91e49c1450e7aa700a750872195229572b8e3ec)
- Refactored database migration code to handle unique constraint errors. [`7f15e46`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7f15e46542fb7f0f99b9f9d1f9e6dbd9fe27cda9)
- Refactored search provider Zooqle [`17bb034`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/17bb034ff4408c2af1c750c53bd4315e5562e684)
- Refactored `daily_searcher` module [`c337738`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c33773841941732cd27c339e519b1f2cf4b2b281)
- Downgraded main database from version 13 to 12 to revert changes made to imdb_info and tv_shows tables. [`77a73fb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/77a73fb3b07656e1dce6d4a24dbc167bbe8a0312)
- Refactored database update calls to merge object sessions before committing [`f05f45b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f05f45b220176e75348739bc288a25682b47badc)
- Refactored database update calls [`c382663`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c38266317b47e6c144cfbdc006b3a5a657263c8a)
- Fixed issue with post-processing manually and async. [`06aec91`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/06aec91d6bb9f2292aaf67508bf7a41b23a79d63)
- Improved app performance in regards to startup time. [`ad47082`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ad4708281f9b5228abb5dad0c8bff24d3aa5e2d7)
- Refactored old code used for getting show episode images. [`1b78049`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1b780497928088764585c84383aec5a83eee6401)
- Refactored `set_sqlite_pragma` function. [`99b8bb8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/99b8bb820f00a2a439651ec13ca447232db31e7b)
- Refactored IMDbInfo table nullable columns allowance. [`b736150`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b73615052a90866b038a547e5b9f4c8f74c5a060)
- Refactored database update calls [`d55538a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d55538a86ffa9ed097f0ce4b789372c7448eae4c)
- Refactored database update calls to grab session from object first that we want to update to use for committing the data [`7383dce`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7383dce629513b5b5fe1ad0bc1465e4e8da22765)
- Refactored `new_episode_finder` method [`f8ee032`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f8ee0322056eda71d7b2556131b9cba3e40bf976)
- Converted schedule and display show handlers to async. [`e34a1ed`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e34a1ed82c26b377ff416eecadd8ac551ccea5b0)
- Fixed 'InstrumentedList' object has no attribute 'all' [`0e375e1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0e375e144d6d5ecc9e9762aa5256f0ef3b9be3c7)
- Refactored show queue to retrieve show objects from database via indexer_id attribute [`f571a00`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f571a00ae11f04f1c46b9175fba81d9ca06b1d1a)
- Refactored code to backup/restore `-shm` and `-wal` database files. [`0a963af`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0a963af2981459660c14d2ea5d8f4e0aa09a5333)
- Fixed issue with History table migrations. [`69abaf4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/69abaf43ebaba9f2f5dbdbbbe5ef4576627918de)
- Fixed issue with displaying show stats when adding or removing a show. [`bbfd1ce`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bbfd1cea1e4aa6e14394352d38b858a33d9c6dc2)
- Fixed Quicksearch, was incorrectly encoding data. [`1f9477e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1f9477e894502fde83da0ba8d4f0a62bba4e6ea1)
- Misc cleanup of database models [`cc98260`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cc98260942c8b402319d65bdd59cb0540e86b855)
- Refactored main shows page to not include specials or unaired in totals. [`4b8e9f0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4b8e9f03c0f4e47236ca8ec947e22659b6bc017e)
- Working on fix for locked database issues [`521828f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/521828f94c094b8e855bedfb80c47fc3e05c27b3)
- Fixed issue with forcing backlogs and finding nothing. [`356ab93`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/356ab93562b8202aa031a83b75ec45db219c8998)
- Fixed issues with manual searches, added session decorator to snatch episode function. [`225936a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/225936aeaf3b7d64b44816a0915a7c0b697ef9cc)
- Refactored progress-bar for poster view. [`f75ab47`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f75ab4795ef2eb60d104ac2c9acc2fdd132d72c8)
- Fixed issue where scene_season, scene_episode, and scene_absolute_number got reset to zero if not found on XEM, caused search issues. [`2559549`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/255954995c836d748c07727e47eb89864cc7a378)
- Fixed issue where main show page will show duplicate show entries when adding a new show. [`c76465f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c76465fc93ed8c8fddde403c9da08469c0281cf5)
- Fixed issue with getting IMDb info [`5b74195`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5b741954a50908ed7c8abca4331be4b7a0bf04e0)
- Refactored `BacklogQueueItem` [`f52da13`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f52da1338c669c1f1e2a82f03a2afc117bb4dd7e)
- Fixed issue with backlog searches not working due to async not being properly implemented on queue items [`07dc6b4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/07dc6b47f05bd9cc209295d67f0e16f246b06db9)
- Refactored `set_sqlite_pragma` function. [`85e8749`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/85e874939de69c3df9dd7e874becb98f77665cf6)
- Fixed issue with adding existing shows and being unable to parse a filename into a show object. [`16d0db4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/16d0db46e116fa5af2a0622d147f08b4d912d876)
- Fixed issue with unprocessed videos being skipped due to being processed. [`52691bd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/52691bd6a55704e052ae3e839fd6f93628f3f62a)
- Refactored remaining incorrect database calls for CacheDB. [`6e27416`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6e274160ff90a411fcf6d94c9e6a6f17d62e3895)
- Fixed remaining calls to variable `current_item` [`d30471a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d30471a50e6b6062619b2f112c2b58e14290ba93)
- Fixed a typo [`f3877e7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f3877e792685e7ff186173a2f4773a8bde780a36)
- Refactored xem_refresh database update call [`264d5c8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/264d5c80e9a23e1fa549a6ea5a442fd95b5e39a3)
- Fixed issue with creating processed marker files. [`c7e61d6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c7e61d642886a912a63a3091d08e2f88d249343c)
- Fixed issue with show name not being displayed correctly when a show is being added to the database on main show display page. [`47e5445`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/47e5445f74be75493659435f7c6775ddb62c0a5d)
- Refactored `run_task` function to not be async, returns future that can be awaited or fired and forgotten. [`f8b9e2d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f8b9e2df234271998b038715bc141aa05ec5a64b)
- Fixed issue with displaying existing shows from multiple root directories. [`b1e7d1d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b1e7d1d1923b6af6f7d3957bcffe6a1cbf9f23cf)
- Fixed issue with slack and binary messages [`baf2f48`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/baf2f48aeeef3231e4a8496d98187c2674762a31)
- Fixed issue with adding duplicate provider results to cache. [`cef3044`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cef30445213a0381e0d1c90eca6a5311cd0d7623)
- Refactored misc errors to warnings. [`3832745`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3832745f4428bcf58c65aed8357046ce6283d26d)
- Refactored configuration encryption routines [`124ce33`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/124ce33cf6370c7c240bd9777856ff81187534da)
- Fixed issues with parsing xml data for Plex and NZB [`516bec5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/516bec5a251ec7cca98048a07524fd418e851c86)
- Fixed show display page to sort drop-down of shows non-case-sensitive [`fea454a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fea454aad1c3196df74614be83450715fc0d52a3)
- Fixed issue with history of snatched episodes not having their statuses updated after being downloaded and post-processed. [`a2d0eb7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a2d0eb747fc97a573b4efc83543852f4f1bea0ce)
- Fixed issue with initial setting of app_id [`9d884af`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9d884afbae19e8e8518c9e0ffaee842176d98a2f)
- Refactored remaining database calls using old-style dictionary calls [`4d7d73e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4d7d73e422e2590e0e2d71717c82eb9922164399)
- Refactored main layout submenu creation to honor required setting [`3382e14`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3382e1427fc1613b8510a1d2a8894ff2c3b006c0)
- Python 2 to 3 database migration happens against files in root of data directory instead of seperate migration folder. [`0e1b42e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0e1b42e198bc1021bea0020bb2f1188f70edca78)
- Fixed select issue for display show drop down. [`42607c3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/42607c3b1aa4fac277470c748f4455de9222cc8e)
- Updated primary keys for quicksearch database tables [`78fa24f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/78fa24f70e6609e4b0612519664a82a78b9bed76)
- Fixed issue with clearing errors and warnings [`61cce7c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/61cce7cde91518f1f582c4d7e08143c9af1d5e96)
- Pre-Release v9.4.85.dev19 [`ae7eff4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ae7eff421cf90e01cbd752c14c6d92f160cb2e74)
- Refactored database engine to use a QueuePool with a size of 100 connections. [`ab3d032`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ab3d032de14f8585b86b3fed3da9a39077a02194)
- Fixed issues with version updating. [`b69acd0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b69acd091650424d5e97ac265337ffa4817bb7ed)
- Fixed Mako error for status page [`caaf36a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/caaf36a3eacc9f08c7190c45e2aefa09fd6310fa)
- Fixed issue with show not being added when trying to add show via queue. [`77ac496`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/77ac496ba50b590c35b5d541f9a822de66a120fd)
- Fixed issue with black and white lists [`a4929e4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a4929e4291fa17d428315994aa1a3de306ad1ec5)
- Refactored episode properties to not include specials. [`37f7632`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/37f7632d50544645e64660063dbac83834be258b)
- Refactored history lookup to return first result instead of only trying to return one or none [`1dc9ad9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1dc9ad934598ead1472c3646f9b87683b1cacabe)
- Refactored variable to function call. [`289685b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/289685be2f0e9d114e64ccbc5b254cdb6d150122)
- Made minor adjustments to queue [`fbe61c6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fbe61c6d691646f632de99c4812c98f6b165d4b8)
- Fixed issue with loading episode details from .nfo file for multi-episodes. [`255da20`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/255da20e83e4761234f1ea7ba31bf1b570bca286)
- Refactored history clear and trim web handlers to be async. [`f3e2f64`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f3e2f64098d1ca4311ce03d0d41e2a64a2b12712)
- Fixed displaying queue priorities from server status page [`ff4ea98`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ff4ea982ad505f622c16d5f9950cf5e060f14fc2)
- Refactored backup/restore functions to include public encryption key [`2fccd96`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2fccd962274ed82cca9129fe5ccc039e1f565dfe)
- Refactored database delete function to check count of query results before attempting delete to avoid errors [`7b833ac`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7b833ac6d88352d0aafffa826a71f225477108ed)
- Fixed issue with searches and picking best results when multiple results presented. [`3867759`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/38677592b333a806dfa5e7fe7f15e768adb3b786)
- Pre-Release v9.4.85.dev23 [`eef0ad4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/eef0ad4b26d9736df2d737833d92a667333d3bef)
- Pre-Release v9.4.85.dev21 [`7d0b6b2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7d0b6b2a31cc7a39ef4d0740f0377263fa31eb55)
- Fixed issue with queue and `max_queue_workers` variable [`8917d88`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8917d8874c0de12da945462473448a7a2635d473)
- Fixed issue with calling backlog on newly added show with wanted episodes. [`29b7ce4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/29b7ce4cd7559a7c1531606e2733b57b908c249c)
- Fixed a issue with relationships for tv shows and episodes [`a305c92`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a305c92b5be3ca78ae1c184046a29f8c6dedeec6)
- Fixed source commit variable to point to correct enviro var. [`0aae828`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0aae828af6ef762ead68d3660c9e11c5c8b70d2a)
- Fixed missing handler for post-processing view [`2ac7b86`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2ac7b86d4cadc2397b4676d174cfb53a953a25fb)
- Pre-Release v9.4.85.dev10 [`4efd8a0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4efd8a0b9c766f409e9103887279c1616dbe58a1)
- Fixed issue with polling for episode search status from scheduler page when no show ID is provided. [`80ebdad`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/80ebdad5e385a2341bdcb379cac815c4d2937998)
- Refactored backup and restore functions to include `privatekey.pem` [`208a6d0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/208a6d03e9a9477698c41f5e1e942dfe87c2363f)
- Pre-Release v9.4.85.dev6 [`4c7abdc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4c7abdcb3212d6c4792c883c208ed246011ca030)
- Fixed typo for restore function [`622650a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/622650abe5f8b1e4c9e5fc99d6361dd238f2557a)
- Fixed issue with automatic post-processing [`aca0067`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/aca0067d8b974c343b4a35fbb31841c81b2ca241)
- Fixed issue `OverflowError: date value out of range` [`3d9725a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3d9725a5157da65d642d0fc050688c25d4f1d0bd)
- Pre-Release v9.4.85.dev32 [`d37b9d8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d37b9d8033a68f88a2978f9c7f17f53b239041fc)
- Pre-Release v9.4.85.dev37 [`859f7d3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/859f7d3e2f8cc01533676c7b75124dedeaaf26cd)
- Fixed issue `Missing argument pid` [`eea340c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/eea340c9522dd92fb3eaaccc1ebf0d8b5ba47c2c)
- Pre-Release v9.4.85.dev30 [`a75533a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a75533a33d5b2c4e63fb31d1b61536ef22197cc8)
- Pre-Release v9.4.85.dev2 [`d9cccea`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d9cccea9be1f40422a8b02b86212e070982d5125)
- Pre-Release v9.4.85.dev4 [`acb8383`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/acb838359585b0d80c8d611b5cfc1a17d9887b8a)
- Pre-Release v9.4.85.dev17 [`0d74c97`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0d74c97948179be1d67cca74eae02462f37d2188)
- Fixed web call to force daily searches. [`887cb3a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/887cb3a8bd681aae08f833a7cb006917faedd0c7)
- Pre-Release v9.4.85.dev36 [`3bb44d0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3bb44d02281d62efa72fc98298e11c5cf4edea33)
- Pre-Release v9.4.85.dev3 [`9e93282`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9e932820f2cb98045cbf9dc92bb9e2ac995fea1a)
- Pre-Release v9.4.85.dev26 [`71c7f47`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/71c7f470e5e19ed3525df29a4612f60b6fe6759d)
- Pre-Release v9.4.85.dev25 [`0fe4cdd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0fe4cdd0455f80914972079cc6f0f115fdc6822e)
- Pre-Release v9.4.85.dev20 [`8403749`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/840374995c6545c16e096b6d1d214ba15ab9009d)
- Updated requirements [`410b5fd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/410b5fdddbf69410bbc4025af3debd5b36e30823)
- Pre-Release v9.4.85.dev8 [`ed7d5e1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ed7d5e1468a84bdeeffb8760e977a878338d654f)
- Pre-Release v9.4.85.dev13 [`d8b37b3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d8b37b3538a08a4a5d52c92c7febf0ebe7e74194)
- Pre-Release v9.4.85.dev29 [`242607a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/242607a985743959caadb9f5fbad9faebe629563)
- Fixed issue with viewing logs and max lines [`a4ee42f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a4ee42fd7f791c37068bc1c4fb28b1764028c7ba)
- Pre-Release v9.4.85.dev24 [`7a7446a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7a7446af4bd4ee5fccf300d374559c9346815046)
- Encrypt config only if able to save encryption key [`78f5288`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/78f5288090b095c4c49f586a33b7d64f43b8172c)
- Pre-Release v9.4.85.dev14 [`a229286`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a22928603bad513405d01b61bb02ec0ca53d8ebe)
- Pre-Release v9.4.85.dev31 [`d50d140`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d50d1406ce04b18b865944d1f18b0be3ad2b6006)
- Moved call to register app-id [`555d960`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/555d9603ac48c4ab5fd2c06c7d79b1fa20326984)
- Pre-Release v9.4.85.dev11 [`fb2f3b2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fb2f3b2f81b752a5198deda873ce7323ba226e17)
- Pre-Release v9.4.85.dev12 [`c8e8d12`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c8e8d1279a568c93403da7cad978884fd27f1ce8)
- Fixed episode total to not include specials. [`5478146`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/547814611e743a331fde0dad02dcb1e75de88725)
- Pre-Release v9.4.85.dev22 [`a5032f1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a5032f12472445146d901c36aabe5418d740761e)
- Fixed issue with looking up show in database using string search terms. [`2eb5847`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2eb58478ceb0c6f1525afed34c5311595bdc06d5)
- Pre-Release v9.4.85.dev15 [`1e38c3c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1e38c3c0ac2b6fc4bb7412b9d5d92dbedcf24ee0)
- Pre-Release v9.4.85.dev16 [`5ed3462`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5ed3462f803da9a487602834ba192b178c1e2c34)
- Fixed issue with daily and backlog searches not running. [`271a443`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/271a443f94bde7db70dccf9bd9923dd46adb4139)
- Pre-Release v9.4.85.dev27 [`8545559`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/85455596c5820c1a782921407af39db97895f736)
- Pre-Release v9.4.85.dev5 [`9c4bfe1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9c4bfe19bebca1f629f39d7142032302fc093550)
- Fixed issue with loading of imdb_info attribute for shows [`d93dc9f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d93dc9f624da214e45d4801562b8bc0db39e504c)
- Pre-Release v9.4.85.dev35 [`b7bc6f3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b7bc6f3ee451548abbad82bf4d5826ef73f1201a)
- Pre-Release v9.4.85.dev7 [`20831e8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/20831e8bca8de07dd51d8a6f8ad267ed07ce5d90)
- Updated YGG torrent provider URL. [`0f90596`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0f90596670720268939310f74a9914ede86aa5ab)
- Refactored backlog and daily log messages to indicate number of days its searching for. [`3c3aed5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3c3aed5d3f7167a8288c50a95cf4e76550153572)
- Fixed more logic with `max_queue_workers` [`a4b1b61`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a4b1b6188b26aae82f41a3c8122b10da90e8f060)
- Pre-Release v9.4.85.dev18 [`fc59ac3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fc59ac305095b37b516314cf29de17f2892d19f1)
- Pre-Release v9.4.85.dev28 [`f3b429a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f3b429ade7d0526b9facc5ddc9b97a469f5b0f1f)
- Pre-Release v9.4.85.dev9 [`2c370dd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2c370dde3e70965ce4edd52daecd62c8e84344b5)
- Removed un-required sleep for post-processor [`a2fb2db`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a2fb2db61c6dcef98d6a57c72e8f6f5a58489303)
- Pre-Release v9.4.85.dev33 [`13c6d5e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/13c6d5e05eb7c9d8c6f25449f302dc124e78f98b)
- Pre-Release v9.4.85.dev34 [`17f4e24`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/17f4e245c9d7225d3d87f8804644d98e219ba09f)
- Refactoring post-processor to pass show and episode IDs instead of objects. [`52147ba`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/52147ba694bc76997eda067ab8067015ceefda05)
- Release v9.4.85 [`1ca6bcd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1ca6bcdec27660c6a0436fca8ef087ded58479ce)
- Update __init__.py [`6b8ef37`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6b8ef374b450f9916eaed376583a21981b0662f1)
- Refactored public encryption key to be saved only after private key is saved [`5d65e31`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5d65e31cb35ec0382e4367296ebaab48316c57a7)
- Fixed issue with mapping when called by reduce, wrapped in list call. [`aaefbb4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/aaefbb428a20ec517586020ce54523336407a672)
- Updated version to 9.5.1 [`8f59e6d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8f59e6dc25ad7838b758ab560bbeac00663e32b1)
- Refactored database update calls [`412de15`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/412de15dcf3b7ebce4c687691f780b708c6c7171)
- Refactored queue to process all items that are queued at once instead of one at a time. [`2ce606e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2ce606eb95d0c22ac67f975b6cb6ac41b017af1b)
- Fixed missing params from get method for post processing handler [`afece73`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/afece7307c69fa82a8d999c2c7af2026c5e1f7f1)
- Fixed `In Progress` for show queue status in Mako code [`48438eb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/48438eb666f10c16e70b69e37e9db2ac5a6bc875)
- Fixed issue with queue and `max_queue_workers` variable [`506ed4c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/506ed4c38a4e20a0208892524061a53481190daf)
- Changed logic for queue and `max_queue_workers` [`5b01682`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5b01682461e64aefa9da922c772403b3dda0b657)
- Removed ajaxsearch init from schedule core js handler [`11903dd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/11903dd263775f34d5145396250fbf02246dcd7d)
- Fixed `can't have unbuffered text I/O` value error [`a228f02`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a228f02ccc26999b4b7f093b15f69f6c698babee)
- Fixed issue with trimming history. [`4375dff`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4375dffcc86a8f572d6d5c547ded9d292cd32c6b)
- Removed committing to add and delete database methods. [`5f870d9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5f870d9ba4755aeed6a7de54edf609d4299b654b)
- Misc typo [`d8ba166`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d8ba1666c3cc30c5a90741d59bd2d1d13ae3bfbb)
- Updated python-keycloak-client to 0.2.2 [`c7a4409`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c7a4409b70d9aae1f118bdda2609d83b09cade4f)
- Fixed typo in CI/CD script. [`c3f6024`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c3f6024329bda0cccc8ba57cc9f32e7f42e35bb2)
- Downgraded main database from version 13 to 12 to revert changes made to imdb_info and tv_shows tables. [`0cf4b20`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0cf4b20fdeccdab95724e7a574da086e1db652bc)
- Fixed issue `run_in_executor() got an unexpected keyword argument 'webui'` [`57e5d92`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/57e5d92bfb57d46b4e141995026a2fd8b7887e0c)
- Refactored code to backup/restore `-shm` and `-wal` database files. [`302fb73`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/302fb737c5946c5f9c949f9265294a8973bd955d)
- Removed ajaxsearch init from schedule core js handler [`fb7f665`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fb7f6659bd82936b9f25714df73af7c01874f23d)
- Fixed issue with drop-down show list for display show page [`0fd669b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0fd669baae995a3115dce98a3066a6c1c174215e)
- Fixed status page to display show queue item progress correctly [`faa271c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/faa271c4e3b6e5fd3732ba4dd3d78884496b0214)

#### [9.4.84](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.83...9.4.84)

> 6 April 2019

- Pre-Release v9.4.84.dev2 [`611cb16`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/611cb16d69ed6068e75b3d230197b93f334bdb32)
- Release v9.4.84 [`c41a995`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c41a995d1618af450cbc8a3d4d36f6e367fa46e1)
- Removed py-unrar from requirements [`96aab9c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/96aab9ca4dbb0545147b3436324e3615a9b3be74)
- Merge tag '9.4.83' into develop [`fb6f06f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fb6f06f2c9cb2dd2f61ca736dbcfed0edd1f7b87)

#### [9.4.83](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.82...9.4.83)

> 9 March 2019

- Release v9.4.83 [`d8b8087`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d8b8087e86d8ba04b2de809f7970c3e408c23f61)
- Fixed issues with source updates. [`471976b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/471976ba7c7c1fb7b4b6e925beb184caf9f56d7b)
- Merge tag '9.4.82' into develop [`5b429fc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5b429fc1871da1cf566760e8393787cdc8169321)

#### [9.4.82](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.81...9.4.82)

> 6 March 2019

- Release v9.4.82 [`ee7439e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ee7439e9ed2faf634119fab6eff24b362f2033f6)
- Merge tag '9.4.81' into develop [`57650a0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/57650a0236f438502db24c12756dc6cb4983596f)

#### [9.4.81](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.80...9.4.81)

> 6 March 2019

- Release v9.4.81 [`8a67674`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8a67674262155f52a63973c374e63b433041bef0)
- Merge tag '9.4.80' into develop [`4662673`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4662673088f6b993c58c9d567adbaaea501bb723)

#### [9.4.80](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.79...9.4.80)

> 5 March 2019

- Release v9.4.80 [`6de5fa5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6de5fa566c1456866b28b11ed254471c443b4b14)
- Fixed saving of provider settings so that booleans are saved as integers [`43baedf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/43baedf8e0d91ee7f4f6bda98e6dec4a9ccac554)
- Merge tag '9.4.79' into develop [`7fe3583`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7fe3583471a3e6738f838cb7cb834af89cdae8c3)

#### [9.4.79](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.78...9.4.79)

> 4 March 2019

- Release v9.4.79 [`4f0d739`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4f0d739a2a935b9ab30aa1bc9402f9df68b18184)
- Merge tag '9.4.78' into develop [`78e1194`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/78e11941211fccaf18ac06682fc2208eb9de7b52)

#### [9.4.78](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.77...9.4.78)

> 4 March 2019

- Release v9.4.78 [`74f6d46`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/74f6d4603df82d7570874b282330a00415319721)
- Cleaned up backup and restore functions for database. [`3151280`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3151280c7ef0bead219c4ba8d8497607f26a1f2f)
- Merge tag '9.4.77' into develop [`01dfecd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/01dfecd8c51df568d9372f0240422be24c3a6e43)

#### [9.4.77](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.76...9.4.77)

> 24 February 2019

- Release v9.4.77 [`a72ca25`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a72ca25f7e2d6a69ee61b82d67782a0db15200b6)
- Merge tag '9.4.76' into develop [`377a573`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/377a57341a4ba374c9ee5c5d264df6f6b5981901)

#### [9.4.76](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.75...9.4.76)

> 24 February 2019

- Release v9.4.76 [`e0f2db6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e0f2db68575041a45ea428afea004546267db62a)
- Merge tag '9.4.75' into develop [`897dea8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/897dea8e160aa2f982ec98890d01a0d96a4c20a5)

#### [9.4.75](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.74...9.4.75)

> 24 February 2019

- Release v9.4.75 [`abe73d7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/abe73d7802020778aa01226480f6ae46fa00278a)
- Fixed issue with scene exceptions not being retrieved. [`f4b1e65`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f4b1e65d9f8dffe31d6a152c3f7ab125c175098d)
- Merge tag '9.4.74' into develop [`9b5dd59`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9b5dd59468796397c3f61af6893b23635030dfeb)

#### [9.4.74](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.73...9.4.74)

> 24 February 2019

- Pre-Release v9.4.74.dev1 [`1ebefb4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1ebefb42e3a5753c9e44126fefe847ab24957d83)
- Release v9.4.74 [`78d6b6e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/78d6b6ecc45b7bf64c3962936ef19496ac1b0037)
- Pre-Release v9.4.74.dev2 [`90fa33d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/90fa33d218235bb09a2df4f886a4233779d1ab4d)
- Fixed issue with default add show options and add show year feature. [`b690738`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b6907389629b0891a73229c54811a28aed670740)
- Merge tag '9.4.73' into develop [`045620b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/045620bfc7e85a89d436d636629d9d4595389a7a)

#### [9.4.73](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.72...9.4.73)

> 24 February 2019

- Release v9.4.73 [`ffd8fa4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ffd8fa4791a0bb0d75d5a0419f550e7d93faa3b8)
- Merge tag '9.4.72' into develop [`337acf9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/337acf90960c8a2806426c7ad8e693256514f0f8)

#### [9.4.72](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.71...9.4.72)

> 24 February 2019

- Release v9.4.72 [`47572b6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/47572b673012e75705b9e7dcec6edac150a3c8ce)
- Merge tag '9.4.71' into develop [`7ef8aed`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7ef8aedc97ab3ff087062e29a40795594f5bebfd)

#### [9.4.71](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.70...9.4.71)

> 23 February 2019

- Release v9.4.71 [`b86d9d2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b86d9d2eda05f4edae03bb2ff76c625085b5bc0a)
- Merge tag '9.4.70' into develop [`dd79285`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dd79285cedd8065a626f06e4d114f4515f22f798)

#### [9.4.70](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.69...9.4.70)

> 23 February 2019

- Release v9.4.70 [`ea526d2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ea526d22fee7dc3b31256741ade628576084d048)
- Pre-Release v9.4.70.dev1 [`2e4fa85`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2e4fa859c8cc6fb77cddd04135d1e1c32c7ffd3c)
- Merge tag '9.4.69' into develop [`df9fe01`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/df9fe01ea0b5b46d112b1a78ed8cb8151c30ebcb)

#### [9.4.69](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.68...9.4.69)

> 23 February 2019

- Pre-Release v9.4.69.dev1 [`2f89453`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2f89453ad18ae9bbf5008dd875ff41799b9a82c9)
- Release v9.4.69 [`502eb01`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/502eb01636c0bef2bfd1ea73f8635525e1f68884)
- Don't attempt daily or backlog searches if nothing to search for. [`ffa69b5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ffa69b5186fb2de9c996a2a057c80d3b38fcc86c)
- Merge tag '9.4.68' into develop [`954c634`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/954c63461afe5caaf7bf036135868d9f0cb8772b)

#### [9.4.68](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.66...9.4.68)

> 23 February 2019

- Release v9.4.67 [`3f6df12`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3f6df121d9a4e7dd708dbfadb87925ca9e3ecf4d)
- Release v9.4.68 [`c3441ed`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c3441ed155c761f553d9f8772de514bad7d66378)
- Merge tag '9.4.66' into develop [`9a730c4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9a730c4d3854bc4eb25b7a5e722daac8eda40d22)

#### [9.4.66](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.65...9.4.66)

> 23 February 2019

- Release v9.4.66 [`9c78d0b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9c78d0b1c6acd2edab8016f5120069e97f17fb5d)
- Merge tag '9.4.65' into develop [`4acabb9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4acabb945597fde0d5d4f65c14eba0a3580b39f4)

#### [9.4.65](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.63...9.4.65)

> 23 February 2019

- Release v9.4.64 [`15ffdce`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/15ffdce8031c36b881a477041865040a458b09ed)
- Release v9.4.65 [`8275fd1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8275fd1ebaf370c24b6af9bfde7a7078475a29f1)
- Merge tag '9.4.63' into develop [`caf00c9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/caf00c99483ba378406956b1b412ccc7cd789b30)

#### [9.4.63](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.62...9.4.63)

> 23 February 2019

- Release v9.4.63 [`33a4acc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/33a4acc8ecc4b409b51cf3c5927d4470f7cfc378)
- Merge tag '9.4.62' into develop [`e4c0f75`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e4c0f750ab564ae2fb21116d160c7f016dfaf618)

#### [9.4.62](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.61...9.4.62)

> 23 February 2019

- Pre-Release v9.4.62.dev1 [`04b3d37`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/04b3d3784b5ba3642c02b6153623ab59922541bd)
- Release v9.4.62 [`1e6bcf9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1e6bcf9746d276f7c9d56911820940be2900573c)
- Release v9.4.62 [`e648c9e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e648c9e8b84ef2c7baf0fc34a6887125188e9655)
- Merge tag '9.4.61' into develop [`1207d88`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1207d889dedb8f60c58a0020b51224443340e9b1)

#### [9.4.61](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.59...9.4.61)

> 20 February 2019

- Release v9.4.60 [`9467ad1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9467ad108a5173703d2ef5ac32190d7b59e1366b)
- Release v9.4.61 [`724fc6b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/724fc6ba708a19e14e573d80d38b5f2bbb6dba38)
- Only shows in library are cached. [`e9b99d5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e9b99d5b057463a8a4796e96e79cd4de5406d964)
- Merge tag '9.4.59' into develop [`049deab`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/049deab420285b2f545a5c747dde82f9b724b02b)

#### [9.4.59](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.58...9.4.59)

> 17 February 2019

- Pre-Release v9.4.59.dev1 [`0a29873`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0a29873ba114f3e2ac29432f95619438fd0d9b93)
- Release v9.4.59 [`13659fe`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/13659fef5b7825b13824229cd553fc20e456aaca)
- Pre-Release v9.4.59.dev3 [`01ad8b6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/01ad8b6645d86bfaea24818f4537a1b210a0b063)
- Only update indexer details for shows when performing show updates on shows marked as updated on indexer, full updates performed every 7 days. [`141d1ce`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/141d1ce7a3addfd276b2a1e839048b613673b86f)
- Fixed issue with "unable to verify the download url" [`d41e525`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d41e5256e38eda52d2a7fde890eeae745959c775)
- Removed redundant automatic show refreshes as these happen during automatic show updates [`3af8cda`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3af8cda0fc6c253580d77e0b9c3edc6eeb3b9c9c)
- Merge tag '9.4.58' into develop [`dd0f62c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dd0f62c84171d40926ec4c126d291e5b74337aa9)

#### [9.4.58](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.57...9.4.58)

> 22 January 2019

- Pre-Release v9.4.58.dev1 [`c128f16`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c128f166eefc7733dabc98e340f8017a6b9345e9)
- Release v9.4.58 [`9a10462`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9a10462301ee20f3b9d6a0f477f5569905db2bb3)
- Merge tag '9.4.57' into develop [`5fca1bf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5fca1bf5485824ecf352f9d1f86b0a26e0163779)

#### [9.4.57](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.56...9.4.57)

> 21 January 2019

- Release v9.4.57 [`8913178`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/89131788d9bc994532f2d290941d8d5028665896)
- Fixed auth issue causing redirect to home page every 5 minutes. [`ae5c478`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ae5c4788465bad410d7f9d55749d42d21a04d8ab)
- Updated Dockerfile. [`f065a3e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f065a3e32e14c367f00795726798a30d21a84e48)
- Merge tag '9.4.56' into develop [`aaec028`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/aaec028645747e043e2aba047ab07e775e1f6eaa)

#### [9.4.56](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.55...9.4.56)

> 20 January 2019

- Refactored processed marker code [`6e96928`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6e96928bf650de4e567ef03f219857e6bf9de970)
- Pre-Release v9.4.56.dev3 [`79db85e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/79db85e8a16013bccb9535051b5b86676a4217c4)
- Pre-Release v9.4.56.dev2 [`8087452`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8087452142626d3a8f99de3b8fc5d3ac25789456)
- Pre-Release v9.4.56.dev1 [`65c449e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/65c449e5f5fe948dad98d9086297de6194bf6572)
- Release v9.4.56 [`b2b9f0d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b2b9f0d37dc50598eb4ff0cf94c70c9de8e75c4c)
- Building of DEV docker images now implemented [`a26f1df`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a26f1df52da1bf106ecd6f87bc0dd1e656b47f41)
- Merge tag '9.4.55' into develop [`568a883`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/568a8833b5a0cfd721d7724aefcc906117ad3d55)
- Update .gitlab-ci.yml [`7c6290c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7c6290cb526cbae000757b670d25a8478dc0333b)
- Update .gitlab-ci.yml [`bf51f72`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bf51f728fddc2b71fe500197e13ae59a740ba1e5)
- Update .gitlab-ci.yml [`560357a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/560357a4d1204bc743e1b2f1a6a0e7e00a6cbaee)
- Update .gitlab-ci.yml [`2543e7c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2543e7ce2463e5cab616f146ae2a3efa272ae41d)
- Fixed typo in show schedule page, double web roots. [`a2596ce`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a2596ce07e09bfa12f435b7dc0de182787628adb)
- Update Dockerfile [`60c219a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/60c219a511af217fa586ba76dd14fb3ae8686f04)
- Update Dockerfile [`74f25eb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/74f25ebf02414fdd2ea2748ecf56c06ec3dfcdec)
- Update .gitlab-ci.yml [`831f077`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/831f077c87d75152bf310661e8fc6c375b3508c0)
- Update Dockerfile [`c27cdf7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c27cdf73c1c94c4711f6bbd2ae154bd4d39be7e6)
- Update .gitlab-ci.yml [`68a9176`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/68a91769630161e2171cc53e98341d3572e9b599)
- Update .gitlab-ci.yml [`3f76554`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3f765548a0e64b9f7951a42d0ada39d647cec9af)
- Update .gitlab-ci.yml [`d326930`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d326930d1c36e02d1cf16a80fd9b5d811b7e12a8)
- Pre-Release v9.4.56.dev4 [`14f8938`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/14f8938b1010598d8eeff5e2bda480faf084d388)
- Pre-Release v9.4.56.dev5 [`25bcd7f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/25bcd7fb8499aafa535aa8b5631ebf37d7d37be2)
- Reverted usage of `next` to `continue` in mako views [`1d012df`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1d012df56bec0bb8221b6994e9f593a32c25b69f)
- Update Dockerfile [`5fcae91`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5fcae915c1f6d07c6f35eece08aa7d950cc9d533)

#### [9.4.55](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.54...9.4.55)

> 16 December 2018

- Release v9.4.55 [`3865c15`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3865c15e951608ea2036a2207335bd4b4ce8ea68)
- Moved columns button in display show view. [`164c01f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/164c01ff93ee080a7f24f82f504e427a941d8278)
- Merge tag '9.4.54' into develop [`eb6a6f8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/eb6a6f8c7ec5bd112e73908872b44ecb7b37b83c)

#### [9.4.54](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.53...9.4.54)

> 16 December 2018

- Release v9.4.54 [`5e64b16`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5e64b164f0024ca833c652a65be1ec97be49f100)
- Refactored display show view. [`76c2230`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/76c2230ca60ac3f8191592818d28ab06defd6f5b)
- Merge tag '9.4.53' into develop [`e54f2cc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e54f2cc2457f45e1fb7efe83b54d1456daa35556)

#### [9.4.53](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.52...9.4.53)

> 10 December 2018

- Release v9.4.53 [`91bc24c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/91bc24cb4bb32e78779541370b61bad59a688bd5)
- Merge tag '9.4.52' into develop [`571aae1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/571aae1ae31f67a9be2d1edeb20795c7bf60c0cf)

#### [9.4.52](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.51...9.4.52)

> 9 December 2018

- Release v9.4.52 [`7dd5263`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7dd5263954634a499b9fd8fe460654c6ea04c7fb)
- Fixed issues with display show poster positioning [`c65074d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c65074d9adfde9a91dc9dc84b92501691da522e8)
- Merge tag '9.4.51' into develop [`490fb47`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/490fb47c52404c311f4aa3bf00d063f4ae434edd)

#### [9.4.51](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.50...9.4.51)

> 9 December 2018

- Release v9.4.51 [`65486af`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/65486af604d684f1dc77b4554a442a3e19daab0f)
- Merge tag '9.4.50' into develop [`9cd3f0a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9cd3f0a8ae315ffd94228b5bc801a1804454a938)

#### [9.4.50](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.49...9.4.50)

> 9 December 2018

- Release v9.4.50 [`8bfcd44`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8bfcd4453c18f0de02c3ec361b00f8e68a0f5866)
- Refactored menu icons to be fixed-width [`2d4e3dc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2d4e3dcf576a531ff62ffbc9b9b35cebda0eb353)
- Refactoed display show view [`b3b4d7a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b3b4d7a8ff603ca847be49cacc80d8097bae1eb9)
- Refactored quicksearch menu [`c97cce5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c97cce59de59ddd3610e0541b07f2e42ac5ebe27)
- Merge tag '9.4.49' into develop [`e5cadea`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e5cadea8b9fd783b9d09cf36c0a4f5c4d14bedc2)
- Refactored display show view header [`60cabed`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/60cabede594dc8434b2146a483df02845ca6e3d4)

#### [9.4.49](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.48...9.4.49)

> 8 December 2018

- Release v9.4.49 [`c1aed13`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c1aed13381c1ae4c965917657d4c42d6c31a1ebf)
- Merge tag '9.4.48' into develop [`8e662ef`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8e662ef3c1e90311b75658d1e06f4c99087762f0)

#### [9.4.48](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.47...9.4.48)

> 4 December 2018

- Release v9.4.48 [`5663214`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/56632140c6c822a4925a3424c0c653396edf34dd)
- Merge tag '9.4.47' into develop [`a2e4b43`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a2e4b43602ccebbb648ad01278370cc4c60805ba)
- Pre-Release v9.4.48.dev9 [`b55a806`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b55a8060f0a542a84c5606a98cae87c5fc80a3fa)
- Pre-Release v9.4.48.dev8 [`97cf604`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/97cf6049956ebe3536b32c5c3f65a0c98f00ceda)
- Reverted tornado back to v4.5.2 [`977b8be`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/977b8be2492d50f78f18d0e9915743aa78e3a497)
- Pre-Release v9.4.48.dev7 [`4e68fe8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4e68fe80a4aecbb9effdedab3c8d53824154f1f9)
- Updated message regarding installation of requirements if needed. [`bb861f9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bb861f9a71c0758b0ba98c6875597efd2d38a485)
- Cleaned up mass edit view code. [`e0fd191`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e0fd19148b599a2ec6c2a2a6114d4d7fd6fa8ef7)
- Pre-Release v9.4.48.dev5 [`7322bff`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7322bffb735a3545a8a2197788ef3cbbd76ffce6)
- Pre-Release v9.4.48.dev4 [`dfcf530`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dfcf530c414eb3af7ec787bfccc4bdc602fce7a5)
- Pre-Release v9.4.48.dev3 [`6fb14eb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6fb14eb0a98377c5a82c97ab7cf98155bf70e7d4)
- Updated requirements [`c3de274`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c3de274e23772ea508905f78da6396d337b535a7)
- Pre-Release v9.4.48.dev2 [`99e28af`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/99e28af8ae8ea4f7395dd5f5f6653fd9d21bb4ec)
- Pre-Release v9.4.48.dev1 [`23e7005`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/23e700509793a49344e9b2ac02aecf5158a5c8a2)
- Pre-Release v9.4.48.dev6 [`7c81274`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7c812742555cf4ac7a5a67787f92229137b8d878)

#### [9.4.47](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.46...9.4.47)

> 29 November 2018

- Release v9.4.47 [`b266867`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b2668675d45d0a30d203eeff9ad469e9797aa1bf)
- Merge tag '9.4.46' into develop [`f8c4e2d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f8c4e2d4869478dd25daf59a827ce796039cad06)

#### [9.4.46](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.45...9.4.46)

> 28 November 2018

- Release v9.4.46 [`80b928a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/80b928a4563a4e25b15ef1971c4f98b6954fa9bc)
- Merge tag '9.4.45' into develop [`4d4981d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4d4981d2d7f9f4a36aedb5d71559888d58d2067c)

#### [9.4.45](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.44...9.4.45)

> 26 November 2018

- Release v9.4.45 [`e444d97`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e444d97edb7048df22a3eb02a86fc4d2a398f10b)
- Fixed Windows unicode issue with tzlocal. [`20da5e1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/20da5e13daa5256d3c266b92ccdd6f9956d2258e)
- Merge tag '9.4.44' into develop [`d7695d3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d7695d3b24b2517c68ae97b74b012ab993349663)

#### [9.4.44](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.43...9.4.44)

> 25 November 2018

- Release v9.4.44 [`d07ac9d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d07ac9d0c5e7f9d1633c145c4a0cd253005dd5bf)
- Fixed issues with searching by scene numbers. [`29011fc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/29011fcc9aa0c670f5b18788f66634b981201c12)
- Merge tag '9.4.43' into develop [`7db2b7b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7db2b7b24c7c2ff9246fe284a9104020bbb90059)

#### [9.4.43](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.41...9.4.43)

> 25 November 2018

- Release v9.4.43 [`5882a99`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5882a9994378cb0e1c7cbeac4ed905f807d8da0b)
- Fixed episode search string fallback. [`db39bd2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/db39bd2f4a2d59e55cba2c7731b82bce84a0b96f)
- Merge tag '9.4.41' into develop [`adcf7e1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/adcf7e114b2c1ea9141f1b23fc5719fa490e5d9f)

#### [9.4.41](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.40...9.4.41)

> 20 November 2018

- Fixed residual issue causing shows not to update from changes made to network timezone updater in previous update. [`461d0cc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/461d0cc741b2fc149339cd16c5e6f7c5af320e86)
- Release v9.4.41 [`dff28fe`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dff28fe492f33f9b8f811d8badfe3ec508c9435c)
- Pre-Release v9.4.41.dev1 [`0d519ff`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0d519ffe7417a3feb6dc730a3d305c5e05ee71ba)
- Fixed show refreshes to work when show is paused if end-user edits, manually rescans, or mass updates. [`c578ff0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c578ff0ee3ca9ab6fa501dfd7d67dc3c15699ed7)
- Merge tag '9.4.40' into develop [`8a0fd2b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8a0fd2b6ebc57903e091fb11bb9048b26bdf5d29)

#### [9.4.40](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.39...9.4.40)

> 18 November 2018

- Release v9.4.40 [`735245c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/735245c297546015e6be837ce63f94e2606dfe8c)
- Refactored network timezone functions. [`b538435`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b5384358eed524dfe61487cf826bab21ec0c5e2d)
- Refactored app to use pip2 instead of pip. [`b005c24`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b005c24a31296852096678475c7d56fde6f5272f)
- Refactored pypi publish to use twine [`8d1c1a6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8d1c1a609fef0e35ef112ece58944bc98fbcd8db)
- Fixed issue with database integrity checks. [`79d9ea1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/79d9ea150c48f3c5015bdafc3328ed18409eac20)
- Merge tag '9.4.39' into develop [`555d0dd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/555d0dd295fa73832c3284758a2e7b23bb6f5e40)

#### [9.4.39](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.38...9.4.39)

> 18 November 2018

- Release v9.4.39 [`d49c03b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d49c03beedb35d77a4cad1b9ef385c41e32d4913)
- Refactored grunt python commands to use virtual environment. [`4d3e19d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4d3e19ddf976033fbbf8a540cc6bf6e11a44e2fe)
- Fixed freebsd init script, runs as sickrage user [`eff3ee9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/eff3ee9c35da746ed47ab3585f876d15b3e057ef)
- Merge tag '9.4.38' into develop [`92e9f20`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/92e9f20b57613d2f8ec5b73a078ab218422bb20d)

#### [9.4.38](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.37...9.4.38)

> 17 November 2018

- Release v9.4.38 [`0aa52f3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0aa52f301d22ea3c7a4624c885d270dc7aa4ec1f)
- Merge tag '9.4.37' into develop [`65ebf15`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/65ebf15a0a0032d48ad4fa97a73844380a771b6a)

#### [9.4.37](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.36...9.4.37)

> 17 November 2018

- Release v9.4.37 [`ee79b9e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ee79b9e5e764d4ae204f79604772d88140d69515)
- Merge tag '9.4.36' into develop [`c2cc7d7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c2cc7d76b58869ea789a9e8a030f6915ae9fddb6)

#### [9.4.36](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.35...9.4.36)

> 17 November 2018

- Pre-Release v9.4.36.dev3 [`5acf339`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5acf339c4127ab67dd153ca1899a8f8b97a37b85)
- Pre-Release v9.4.36.dev1 [`3f51fb3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3f51fb3a572063c04ba756ed6e7b3a6a947aafcb)
- Release v9.4.36 [`3c599a2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3c599a27c883ed3f035946a5134bd456de46cfcf)
- Pre-Release v9.4.36.dev2 [`3299a1e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3299a1eb2a677b9df0618517c31d61e98291641d)
- Refactored DanishBits torrent provider. [`9048cd4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9048cd427b7eb3dce28bd0e11cace434624eff67)
- Merge tag '9.4.35' into develop [`202e359`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/202e35990d0b1dbaf1eaa69da85e8fceef2fa862)

#### [9.4.35](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.34...9.4.35)

> 16 November 2018

- Release v9.4.35 [`c92467e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c92467ed375e3af6f4dc1ab3ab3d215062cd4c38)
- Fixed Mako error related to no imdb_info present. [`11ac4c6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/11ac4c6c7d2e9c17495ab0218a67fc59ec2c0eff)
- Merge tag '9.4.34' into develop [`4688a3a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4688a3adddad1abacb7ffa33f5fdcfe6eed03594)

#### [9.4.34](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.32...9.4.34)

> 14 November 2018

- Release v9.4.33 [`4478e39`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4478e395ed88be67dd006cd6fe59a7075352a90b)
- Refactored new version string to web socket message. [`aaf7acf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/aaf7acf967c9b7aa8604fb9e8f36f19b5b2a652d)
- Release v9.4.34 [`70d42c2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/70d42c244019b79947c5d28958c1c49861af912b)
- Merge tag '9.4.32' into develop [`116f31d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/116f31deded64a0c460f0d7052bd8f4ab027adea)

#### [9.4.32](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.31...9.4.32)

> 12 November 2018

- Release v9.4.32 [`d831f6f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d831f6f6bee01ef54070353ee59122c9406bdaae)
- Refactored speed.cd torrent provider to use cookie login. [`f298b17`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f298b171d9d69a3c5a0b801795efd18a3f46a7dd)
- Merge tag '9.4.31' into develop [`c84cb03`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c84cb03354ea6bc0038636460a980a8c6f946b03)

#### [9.4.31](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.30...9.4.31)

> 12 November 2018

- Pre-Release v9.4.31.dev4 [`4d0d839`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4d0d839fcd143a96de38e88f88d5a3828348b0ba)
- Pre-Release v9.4.31.dev1 [`bbac0e2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bbac0e2957bd9d4c317dd098a11fa253dbcc7462)
- Release v9.4.31 [`2abdafe`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2abdafec3aa252ce0de276ff2c4cac96e31b3dca)
- Refactored show object class, cleaned up naming conventions for functions. [`34aa88c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/34aa88cd3ffddee185eaaa0fa008ed651dbeea81)
- Refactored queue current item property to always represent current running task. [`753625d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/753625dbef0962090721deb63d77f362518c6a9e)
- Pre-Release v9.4.31.dev3 [`12f8ad6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/12f8ad6f656b3a55ea2d020d0029af4eb439e534)
- Pre-Release v9.4.31.dev2 [`82115fc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/82115fc14e80baab2c4832c9db3b3c44d632e811)
- Pre-Release v9.4.31.dev5 [`971fc67`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/971fc67378c9baf21c51499080736f5e26a17fb0)
- Updater now waits for show queue to finish before updating. [`ae00748`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ae00748db9feb25234f381c08b8588eada2c1cd6)
- Merge tag '9.4.30' into develop [`d599f2b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d599f2b74cbd628c9fe50a630ced69ec0ab1a89e)

#### [9.4.30](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.29...9.4.30)

> 11 November 2018

- Pre-Release v9.4.30.dev1 [`90fdbb1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/90fdbb120479786ffe9eb0654bb3201a24fed339)
- Refactored get, all, and get_many database functions. [`007df0a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/007df0a3da2b50466603d0eee51b96f5cb9159b0)
- Release v9.4.30 [`8bd128e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8bd128eb2b4696ec9adce3ae44b7bd9a4707a703)
- Merge tag '9.4.29' into develop [`e0edcfe`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e0edcfe80f3e21c7fc74d9a58c19b7f5f99adfcc)

#### [9.4.29](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.28...9.4.29)

> 11 November 2018

- Pre-Release v9.4.29.dev1 [`5eef56e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5eef56eaea05eb66fe70e7ae5222cf41de7217f1)
- Pre-Release v9.4.29.dev2 [`7d0812a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7d0812a7ee85ce229bbb054c475c70bd0ed7eaf4)
- Refactored naming convention of misc helper functions. [`eca1d42`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/eca1d42f5af8e50bb7476fef0b23fe5a54b675bc)
- Cleaned up subtitles code. [`63f98ef`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/63f98ef01d6e6ec7ec13a87d8515e37a61b89b2d)
- Release v9.4.29 [`f87d6ad`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f87d6add4ea8ade3a08f35d8eb429a51a733206c)
- Fixed issue with displaying language flags in views [`1558dce`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1558dceaeeb9812b937071dd8128c1bcaa32ce5c)
- Default subtitle language of English choosen if no language is specified in subtitle settings [`8028ae9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8028ae9787f27398b279ee548c405a7eaffb3f25)
- Merge tag '9.4.28' into develop [`02bdffe`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/02bdffec8bf87c72b6911f61376069b8433569da)

#### [9.4.28](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.27...9.4.28)

> 10 November 2018

- Release v9.4.28 [`0173a0f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0173a0f21eba802621552a799b7ee170c4dbf03c)
- Merge tag '9.4.27' into develop [`d0c7b83`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d0c7b837109ea1b294f322a82788a07e045352dc)

#### [9.4.27](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.26...9.4.27)

> 10 November 2018

- Release v9.4.27 [`c5ea143`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c5ea143edc7b8519afe2ffd8d63a755e102cbf96)
- Refactored misc errors to warnings. [`4127ed3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4127ed3ad22d784f116c9885096433ef3b9f0f05)
- Fixed issue for missing database indexes. [`7c31b0c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7c31b0c7715cde8881fee90265fdb32d51970923)
- Refactored misc errors to warnings. [`3f20cdd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3f20cdd00a238a98703bf813c201282e1967be2b)
- Merge tag '9.4.26' into develop [`83909dd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/83909dd6b414299ee68fb89194560a0f973783a3)

#### [9.4.26](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.25...9.4.26)

> 10 November 2018

- Removed restoring of application ID from backup/restore functions [`0972ec5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0972ec5000a20818a5e0aba57b962cbb060eb8aa)
- Fixed issue with file browser and clicking on files not properly choosing file and closing browser dialog. [`9e4dc5f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9e4dc5ff61163b33bb0f8bf3683def9b2cee84b3)
- Release v9.4.26 [`78c64b1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/78c64b17ff2deebd3c35696fc0ee6255d2f976e2)
- Merge tag '9.4.25' into develop [`2cfa68a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2cfa68aede1fb7b92bd9e78b4174fdae6ad14091)

#### [9.4.25](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.24...9.4.25)

> 10 November 2018

- Refactored misc logging errors to warnings. [`af3348b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/af3348bae91f0621eb442bcaae1e0d390025cce1)
- Release v9.4.25 [`9cf70c3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9cf70c3f7aa2800f33f852a663525d9a6264a188)
- Merge tag '9.4.24' into develop [`bdde3e5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bdde3e54d31c2b46c64a6df5a351923af7964d82)

#### [9.4.24](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.23...9.4.24)

> 9 November 2018

- Release v9.4.24 [`73acd71`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/73acd711e3e05f0c125990741d412f4600428f0c)
- Merge tag '9.4.23' into develop [`fd0de4a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fd0de4a6397a3ec6020794151eab26bacb1de1bd)

#### [9.4.23](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.22...9.4.23)

> 9 November 2018

- Release v9.4.23 [`e9ca9af`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e9ca9af36b48629393807c2c90cf86156ce163e8)
- Merge tag '9.4.22' into develop [`d023922`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d023922e259a257a908d4fcb93c4761e011faac0)

#### [9.4.22](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.21...9.4.22)

> 8 November 2018

- Fixed startup issues with systemd init script. [`d705db2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d705db2a044ecacfa7021453bce2f09cc4771385)
- Release v9.4.22 [`f98b5e8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f98b5e824299aaad42ae376002f8b9b2bb2e9e56)
- Merge tag '9.4.21' into develop [`3f9541f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3f9541f194d98a8c100a6ed377c8a2217b7047d4)

#### [9.4.21](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.20...9.4.21)

> 8 November 2018

- Release v9.4.21 [`5bb165d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5bb165de7e5d82eef90baede54754465774cce05)
- Merge tag '9.4.20' into develop [`b9f9540`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b9f9540e9f67bd9a1a5357ef12cc2315f3e05d79)

#### [9.4.20](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.19...9.4.20)

> 7 November 2018

- Removed backlog cycle time [`dfa2238`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dfa2238d55530ffce0184168b14e04e5d0ca9579)
- Release v9.4.20 [`6b3ab52`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6b3ab522c6c7fd74750336a5b6ea181957c0751c)
- Merge tag '9.4.19' into develop [`21d71b2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/21d71b210bf709c94f99597169d56a3ed35fa328)

#### [9.4.19](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.18...9.4.19)

> 6 November 2018

- Fixed issues with saving provider settings. [`d394cb1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d394cb1cd789fd8e51ec10a37129c85403bb51ab)
- Release v9.4.19 [`e7526ee`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e7526eeb70c42443b53e78916b9f7dd0e1ddaf4e)
- Merge tag '9.4.18' into develop [`572f53c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/572f53c535739d148a7a6b718d631cf72fa0dfe6)

#### [9.4.18](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.17...9.4.18)

> 6 November 2018

- Release v9.4.18 [`6d5e91c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6d5e91c8686149aaf5733fd6bb17fb1abb70fe8e)
- Merge tag '9.4.17' into develop [`8d5d216`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8d5d216af27c20ef5c3bf059fae9a8f4aebde182)

#### [9.4.17](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.16...9.4.17)

> 6 November 2018

- Release v9.4.17 [`3bbf2ca`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3bbf2caa4c32999cfa2d4d07093600abd5aec438)
- Merge tag '9.4.16' into develop [`b156ea3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b156ea3ab293283d1e3533d9833816737a488138)

#### [9.4.16](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.15...9.4.16)

> 6 November 2018

- Fixed issue with Media Browser metadata nfo creation [`086e274`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/086e2749b57b839ad900e356d67ceb9f8a277e21)
- Release v9.4.16 [`8963ac9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8963ac9cb6b2a5f6246d431f49efb522c12409bd)
- "Unable to find episode with date" warnings now only shown for shows in library. [`8869731`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8869731c44a5341af04f91ea5433f07e5fa8fd8b)
- Fixed active column for home show display [`6441354`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/64413549af1935df06f012fe69df4b49a55ff069)
- Merge tag '9.4.15' into develop [`e8e6151`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e8e6151772bd9f696d22e2ac9f214264d02fef12)

#### [9.4.15](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.14...9.4.15)

> 4 November 2018

- Fixed attribute error caused by none type when shutting down web server. [`9ca8af6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9ca8af6baee61c6ef9118df6c483e9c99cbe122a)
- Release v9.4.15 [`180d59d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/180d59dd36e8d074166b4cafb7159dd45af33792)
- Merge tag '9.4.14' into develop [`e8b39fd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e8b39fd9fdf23f879169a992d9ece2faedd10baa)

#### [9.4.14](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.13...9.4.14)

> 4 November 2018

- Release v9.4.14 [`7596f3b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7596f3b91e72e51082614d02855711f1d5376ef5)
- Merge tag '9.4.13' into develop [`c580156`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c580156313886207dc0691e8178b8e093a81cddd)

#### [9.4.13](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.12...9.4.13)

> 3 November 2018

- Release v9.4.13 [`c506406`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c506406c03832405a88472f4d10309f240aeaf6f)
- Merge tag '9.4.12' into develop [`c59b9e9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c59b9e9216dae2bd8efb9efbb4fe0d718cf99840)

#### [9.4.12](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.11...9.4.12)

> 3 November 2018

- Release v9.4.12 [`73b760b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/73b760bf018bee6c8ee2218594a01a9eb4564394)
- Merge tag '9.4.11' into develop [`9e677d3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9e677d3c09fd59403e850c5f785cc952740e47fb)

#### [9.4.11](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.10...9.4.11)

> 3 November 2018

- Fixed issues with properly identifying multi-part episodes. [`e8e2d80`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e8e2d805fedda3e72c21f0f82f516a20c7a3b985)
- Release v9.4.11 [`f6754e4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f6754e444ae048fbf7c30fcb21d9ee2609969ca9)
- Merge tag '9.4.10' into develop [`bd02659`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bd0265980edb97b73405bb188e919061860e0d1d)

#### [9.4.10](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.9...9.4.10)

> 3 November 2018

- Release v9.4.10 [`429568d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/429568d3239beac99d0764abf0c2d244624759fe)
- Merge tag '9.4.9' into develop [`36bd6a6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/36bd6a669aaf50659cfef9c32c8067ae2a314692)

#### [9.4.9](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.8...9.4.9)

> 3 November 2018

- Moved building of name cache for app start to io loop callback, [`e073791`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e0737918ebe11186b25e852d455d4a7df66722cd)
- Release v9.4.9 [`39c0a09`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/39c0a0985ae7ff7600f1f3f0c046c47d28822fc8)
- Merge tag '9.4.8' into develop [`f7f2f89`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f7f2f8953c7aa2f3e53dc5f2cf000925842e872d)

#### [9.4.8](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.7...9.4.8)

> 3 November 2018

- Fixed typo [`231a032`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/231a032bc9b2aa3b26e4259e3b424330f063be15)
- Release v9.4.8 [`c35d07b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c35d07b4be041fe88114ac9cb6ec54014b29c2cd)
- Merge tag '9.4.7' into develop [`14f03a8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/14f03a8fa0b0863f97e7681bad3581d91caf5bce)

#### [9.4.7](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.6...9.4.7)

> 3 November 2018

- Refactored cloudflare bypass. [`63eed66`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/63eed6657c6c3a47aa989ff9eaba21d9fa98c248)
- Release v9.4.7 [`697d36a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/697d36a14f9913f2b4d74e4e8a6a210f992c0d90)
- Merge tag '9.4.6' into develop [`613dae0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/613dae03745a2e16672f1fe0f930d8fb7c1d0ab7)

#### [9.4.6](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.5...9.4.6)

> 3 November 2018

- Release v9.4.6 [`ad3bf92`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ad3bf928a89ae4db5d6fecdc561dab7ed1bec009)
- Refactored speed.cd provider code. [`9678e16`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9678e166b021382c395109f4157953d336439c93)
- Fixed issue with email notifications and saving addresses. [`68b1f56`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/68b1f564c8bef3cc0f56c4e4fcd2595a54d6fcc1)
- Merge tag '9.4.5' into develop [`a125bed`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a125bed116279a8b65fc07e68f82cf7b6f321938)

#### [9.4.5](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.4...9.4.5)

> 3 November 2018

- Release v9.4.5 [`bcccf74`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bcccf7419752b4f591556d0f7fe31dcadac85e3e)
- Merge tag '9.4.4' into develop [`f00e4ac`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f00e4ace6af50d983f6c7b26f101fbc0cc290ded)

#### [9.4.4](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.3...9.4.4)

> 28 October 2018

- Release v9.4.4 [`f91c70b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f91c70b0c667ad9141af355ee85e1fac24e3c218)
- Merge tag '9.4.3' into develop [`14251ef`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/14251ef55f2b4c25293d32c131d459bb0db33b13)

#### [9.4.3](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.2...9.4.3)

> 28 October 2018

- Release v9.4.3 [`d32be97`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d32be976f90f1add837d03e201a24c847a12784a)
- Fixed issue with unrar unpack directory setting [`f7c0464`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f7c04648e0708a1755d3e1afe7957a646c78bad5)
- Merge tag '9.4.2' into develop [`15c00e7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/15c00e7205fe5de6e8ff1720fe28cce2cff1007a)

#### [9.4.2](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.4.1...9.4.2)

> 28 October 2018

- Release v9.4.2 [`206857b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/206857b39bea7958a779b6d3cfc8cca1c1c7432a)
- Disabled warning for when no nzb/torrent provider is picked if no nzb/torrent client enabled. [`7e3baa8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7e3baa8fc05eb3dcdae3a8d422ed9121a65ea8cd)
- Clears name cache with indexerid and show name [`1ad42fe`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1ad42febe7f57c17e2f548bbda4acb1ab1a84c4c)
- Merge tag '9.4.1' into develop [`89fd3bc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/89fd3bc50c18ea6b7b1728592e7dc09009e272b7)

#### [9.4.1](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.99...9.4.1)

> 27 October 2018

- Release v9.3.100 [`3dbd257`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3dbd25703277c6fbc73b7b1e1ae6a0096fb39f09)
- Release v9.4.1 [`bf93454`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bf93454fd4bfd6463a9c0001ff1d8deffff94cf3)
- Removed app_id and replaced with app_sub. [`479d80e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/479d80ec2f35a155d519dc2d3f6506ec6a06abc2)
- Merge tag '9.3.99' into develop [`0ebb11a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0ebb11a36147ef72a930f865a08f12e5b41522cb)

#### [9.3.99](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.98...9.3.99)

> 21 October 2018

- Release v9.3.99 [`33ea2f1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/33ea2f1c98c084371bbb7021eb25cffe7fc6e710)
- Merge tag '9.3.98' into develop [`147e412`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/147e412b640e34f1bde856fda4db6f4a6bc94ae0)

#### [9.3.98](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.97...9.3.98)

> 21 October 2018

- Release v9.3.98 [`e3b3be9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e3b3be9f191f4fafd21c385789d361dc1f489e07)
- Fixed issues with matching shows with parsed results when containing accents [`d5ec001`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d5ec0014afafe9aa97b03350497d99c1a39eae1b)
- Merge tag '9.3.97' into develop [`d4214c5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d4214c534c36e9dbfa8c16500fd66fec68aeae46)

#### [9.3.97](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.96...9.3.97)

> 21 October 2018

- Release v9.3.97 [`84de9fe`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/84de9fe24e88bfcffebd1ac33482e18b9839800c)
- Fixed issues with network timezones [`a5f7b6a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a5f7b6ac95fe8f2c0a2916acea6ff7f8e86ce6b5)
- Merge tag '9.3.96' into develop [`6ab4906`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6ab4906d9ce29604eb0cf5c021381965d8149146)

#### [9.3.96](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.95...9.3.96)

> 17 October 2018

- Release v9.3.96 [`ed1b33e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ed1b33ed9052af24a391604c39e237a191c1dccd)
- Fixed setting caps issue when searching newznab providers [`ecb1600`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ecb1600225377ba04aaa9699d8b6eeb0320d23ad)
- Fixed 'Notification' object has no attribute 'type' issue. [`bbbc6cb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bbbc6cbe75d14eba7b890550f39ace75a611746c)
- Merge tag '9.3.95' into develop [`9730121`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9730121d44a0525910f591fecfc29531158db5e0)

#### [9.3.95](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.94...9.3.95)

> 16 October 2018

- Release v9.3.95 [`aad016d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/aad016deedf92ea4ae29675a62d2253307d12107)
- Fixed issue with checking for stash in output of git cmds [`0f07f4b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0f07f4b092f65527572cfb56dbaddb7b9e6fe777)
- Merge tag '9.3.94' into develop [`b69a6ce`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b69a6ceb3ce76dd2ce26fdffd860a5d4b67a31a0)

#### [9.3.94](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.93...9.3.94)

> 15 October 2018

- Release v9.3.94 [`8b3319d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8b3319df798a16e62187d9d8af96c7b28faa4584)
- Update .gitlab-ci.yml [`bc472cc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bc472ccf5a6d46f9734f1150ea47bed831bc3082)
- Update .gitlab-ci.yml [`47ce84c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/47ce84c3748cde76dffc352bf804f5fa40142ed6)
- Merge tag '9.3.93' into develop [`bdf23cb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bdf23cb9e2641ddfc98045dd2876ca3ff14169c0)

#### [9.3.93](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.92...9.3.93)

> 15 October 2018

- Release v9.3.93 [`eb1a642`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/eb1a642f843c8a63238ec69351f628f17c44a4b6)
- Merge tag '9.3.92' into develop [`91b372f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/91b372f692238efceb469ab50100eb8d344f0b5c)

#### [9.3.92](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.91...9.3.92)

> 15 October 2018

- Release v9.3.92 [`13ff53a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/13ff53a20dcb256d8afdb03fe45797e55b6f2330)
- Updated .gitlab-ci.yml [`def0213`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/def0213d5ecd81075da20aee2947973a3f247ce2)
- Merge tag '9.3.91' into develop [`ba167b1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ba167b1fcf1eadc45ba498f053f4d8e2ce80b5ab)

#### [9.3.91](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.90...9.3.91)

> 15 October 2018

- Release v9.3.91 [`4500af0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4500af0d8c996bd2dfd34c6884daab86a4924d1d)
- Updated .gitlab-ci.yml [`b226cf4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b226cf406524f7b076038cec467fa6522abffdd7)
- Merge tag '9.3.90' into develop [`a36dfab`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a36dfabdb96ec4ecdd77ef3fe57f5866cdc0edd0)

#### [9.3.90](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.89...9.3.90)

> 15 October 2018

- Release v9.3.90 [`b4d3c18`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b4d3c180e53331cd7eb5451ae861f8ee63191f84)
- Updated Dockerfile. [`01f719f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/01f719f66acd031d18a024d00a8f9fca933ce2ca)
- Updated .gitignore [`70b40c6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/70b40c6e89664e9d5e7d4bfef7d12415b945b991)
- Merge tag '9.3.89' into develop [`5fe3b52`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5fe3b5205920085d7c361fb8e49e8ef591a81926)

#### [9.3.89](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.88...9.3.89)

> 15 October 2018

- Release v9.3.89 [`89b5a00`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/89b5a0033806d558742fe715be6ba13d373aed9c)
- Merge tag '9.3.88' into develop [`184a4c5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/184a4c53b0510c576ec9a904e530450144cb6c94)

#### [9.3.88](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.87...9.3.88)

> 14 October 2018

- Release v9.3.88 [`b01ca47`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b01ca4726d3968c397544e6581b085ef35cf7cac)
- Fixed issue with custom provider not being saved when using spaces for names. [`79735d7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/79735d78234be196897b9d89b1d2a2968af8f4f5)
- Fixed issue#286 - added support for non-english indexer images [`e2132a2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e2132a29f4a352d9968b2e0edb36de7873e62bab)
- Fixed issue with custom providers having spaces in their names that was causing settings to not save [`6d8c60a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6d8c60a0be25c688dac4c68becb5d4d9c3fb3fb0)
- Fixed issues with removing custom torrent/newznab providers [`23f9684`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/23f9684ea44d40b25e0bafbc97d97aef192c432c)
- Merge tag '9.3.87' into develop [`ef827f7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ef827f755358f23bdcbb7ee25c251673ec1f9ab0)

#### [9.3.87](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.86...9.3.87)

> 14 October 2018

- Release v9.3.87 [`d186f55`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d186f557ff504abf5c43163ca5b98793eef5e6ec)
- Fixed issue with freebsd init script not daemonizing the app [`ca05ceb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ca05cebac405049854ff28d372815f62ff240858)
- Merge tag '9.3.86' into develop [`f17fcbb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f17fcbb57fbe9d247f20c2ad63910bab6cabca22)

#### [9.3.86](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.85...9.3.86)

> 14 October 2018

- Release v9.3.86 [`10fc6b3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/10fc6b3ff0b4e7d9591c666a1f4ddc8bc3290d82)
- Merge tag '9.3.85' into develop [`2736e83`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2736e8393cff5de3ae4c458d946e3bc2ca4dcefd)

#### [9.3.85](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.84...9.3.85)

> 13 October 2018

- Release v9.3.85 [`b0c7dc9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b0c7dc9a20ef1b7b61832e67067223f3ddd93335)
- Fixed issue with saving subtitle language settings [`2e0a378`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2e0a378077fba575c27980a9a07906bbcb81d2a4)
- Merge tag '9.3.84' into develop [`8a79fa6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8a79fa698750fa1695b7a8e44929703a92c3cb65)

#### [9.3.84](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.83...9.3.84)

> 13 October 2018

- Release v9.3.84 [`57a541f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/57a541fed7e96cbef3406aa7c81e8f6b9530616d)
- Merge tag '9.3.83' into develop [`56e078d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/56e078dc67da782559ebfc435082c4412d6dbb73)

#### [9.3.83](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.82...9.3.83)

> 13 October 2018

- Release v9.3.83 [`7891d45`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7891d45004ec3773379c27602cabcf8a5e220a38)
- Pre-Release v9.3.83.dev1 [`256f26b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/256f26b6220fb4659cd08beb95106f3ca4b173ef)
- Merge tag '9.3.82' into develop [`fad12a4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fad12a41ec821cfe817533a0be98c84e9ec30786)

#### [9.3.82](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.81...9.3.82)

> 13 October 2018

- Release v9.3.82 [`536c3ba`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/536c3bafcc6e22397008633f0b3dfe3e57b8a47f)
- Fixed issue with displaying provider icons for custom providers [`a216e2b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a216e2b06b5453dd3509ef2ce8595550b22ec8b9)
- Fixed issue with re-scanning existing show episodes that do not contain the show name in the filename [`a120b3e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a120b3e893df61f362804a8aef78cfe2d56c1c00)
- Merge tag '9.3.81' into develop [`b798eb6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b798eb6f5bc7da8ed743c869b1109ff5bdf09ee8)

#### [9.3.81](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.80...9.3.81)

> 12 October 2018

- Release v9.3.81 [`f29e97d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f29e97d24b19eb8c087c458d41dc20f6a4cf7b4f)
- Fixed issue with building Dockerfile. [`35fb7f1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/35fb7f1e4cf42ce030d6971702cec24130c1e28a)
- Pre-Release v9.3.81.dev1 [`7141eec`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7141eeca8bf0985be8d4291a61129f6522ca7bd3)
- Merge tag '9.3.80' into develop [`37896dd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/37896dd2392bdc2737d1a8a90ff696355cf84511)

#### [9.3.80](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.79...9.3.80)

> 8 October 2018

- Pre-Release v9.3.80.dev5 [`f64a196`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f64a1968771fc7644272c29aa53612fe4fa41390)
- Pre-Release v9.3.80.dev3 [`be55b94`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/be55b94549dd1d2bd9386e0fbe065b11a313ff77)
- Pre-Release v9.3.80.dev2 [`6e16bcc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6e16bcca027dddf89bd5633ae1a9ee1b426174e1)
- Pre-Release v9.3.80.dev1 [`ec020ec`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ec020ece8c95746d5e966585394a244589e2d2d1)
- Pre-Release v9.3.80.dev4 [`8a1fd06`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8a1fd0616b650043512503d4111b31d9f7a9bce6)
- Release v9.3.80 [`a9e7913`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a9e791391a49aa91f821d5722ea890a9197b28c8)
- Pre-Release v9.3.80.dev6 [`615cf7d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/615cf7d959426718a5ddaf7ba8251290c703c9b3)
- Fixed issue #273 - location not found when adding/removing a show [`7b0a85e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7b0a85e3733dfc9569113501da8e4f8513bf08b4)
- Updated remaining ui-icon icons to fontawesome. [`bf4e106`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bf4e1063f87dc4da35eac7551ffb028e7da628fa)
- Fixed saving allowed video exts [`e3e893f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e3e893f09a3d0f6f2bc981ded7ff80c820e72cdc)
- Fixed issue with magnet links missing torrent trackers [`d2b5aab`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d2b5aab6e9defdce9be205d5fd0aed8f8210e19e)
- Merge tag '9.3.79' into develop [`ed4cc53`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ed4cc53d4859a6e5ba7f21e78dc33bf20a5d6249)

#### [9.3.79](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.78...9.3.79)

> 18 September 2018

- Release v9.3.79 [`5bf995b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5bf995bb97fbf884f9dfa37b19a435706aa6b899)
- Merge tag '9.3.78' into develop [`a22d25c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a22d25cffc14bef7d44cde5a456e0e4042dfaa1b)
- Pre-Release v9.3.79.dev10 [`a7d0209`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a7d020967a2270f453a4e5a6529d714b58f20410)
- Pre-Release v9.3.79.dev9 [`09b1857`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/09b1857d7c156036d686063c05d080f72b3c454d)
- Pre-Release v9.3.79.dev8 [`3419702`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3419702f782c6b759391e4997a576ea56c0cac03)
- Pre-Release v9.3.79.dev7 [`a4a4814`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a4a4814be6c2329eeb061e34dfcfc805aa6f89d2)
- Pre-Release v9.3.79.dev6 [`605f75c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/605f75c12c716ef9be66de777e2abb7fe28cf246)
- Pre-Release v9.3.79.dev5 [`bd67a69`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bd67a69eb4f8ced22a8a28248cb22684b53a12d4)
- Fixed issue with custom webroot and too many redirects [`dbb7543`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dbb754376bf9c6ea775bc829852194f17eb33aad)
- Pre-Release v9.3.79.dev4 [`31a9c17`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/31a9c1719b4f7d51f309b9cd273e063ee71c88c9)
- Hardcoded Zooqle torrent provider to search for english torrents [`69668c7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/69668c720b0c8ec1175a301621f9553763aa2a68)
- Pre-Release v9.3.79.dev3 [`2868350`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/28683500d7cb793aba4a8754ede440b9dc13ca11)
- Fixed issue when displaying multiple modals same page, 2nd modal wasn't removing scrollbar. [`e8445dd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e8445dd06f8c1ffa1b446867861e59366b50dea5)
- Pre-Release v9.3.79.dev2 [`15f9781`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/15f97813bf9668fa219916518910667500f3760c)
- Fixed search issue with Zooqle torrent provider. [`f87f0b0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f87f0b0a8e1c60510f3c4bf827b12a15af90ca59)
- Pre-Release v9.3.79.dev1 [`e6fab35`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e6fab35257a8293b47ed28dea662b6222b47c51c)
- Refactored Zooqle torrent provider to handling paging results [`f39ab1c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f39ab1c2c36465dba8d6e4d3117af4e7e9df4e4a)

#### [9.3.78](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.77...9.3.78)

> 14 September 2018

- Release v9.3.78 [`90f31c5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/90f31c5e916cf4755f1ed84a31d3bf6b41e61f11)
- Merge tag '9.3.77' into develop [`77bbb38`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/77bbb38fa78ad9f34d3adb83505eded380aea41d)

#### [9.3.77](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.76...9.3.77)

> 13 September 2018

- Release v9.3.77 [`d6195df`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d6195dfab470cc44706bbde9cbc7d9e9d12159b8)
- Merge tag '9.3.76' into develop [`58aabf0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/58aabf0c22f6fab661fc464d722229be5dad083d)

#### [9.3.76](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.75...9.3.76)

> 9 September 2018

- Release v9.3.76 [`23d3379`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/23d3379e78cdd86102e4a3b3fddcbfaf19dd36b9)
- Merge tag '9.3.75' into develop [`fd577ef`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fd577ef0e0e2f070e26ff60d5cc4568c045c8d13)

#### [9.3.75](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.74...9.3.75)

> 9 September 2018

- Release v9.3.75 [`80a1cf8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/80a1cf8db3cc7baa7f5df97434899d8c37c22b0d)
- Merge tag '9.3.74' into develop [`f16c8f1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f16c8f14b2d17e46d4e84766303b961efee3d7e6)

#### [9.3.74](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.73...9.3.74)

> 9 September 2018

- Pre-Release v9.3.74.dev1 [`fd54d1e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fd54d1e939057f2e13a7627e0ab23da1bc1bb2ff)
- Release v9.3.74 [`0a5590f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0a5590f810546e100ac94cb836983cb323f67429)
- Merge tag '9.3.73' into develop [`2120c47`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2120c477def535e21af001383d9da4b600736dfb)

#### [9.3.73](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.72...9.3.73)

> 8 September 2018

- Release v9.3.73 [`d4b634c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d4b634c47a3bb9b2362921fb75a03874c54c4e66)
- Merge tag '9.3.72' into develop [`be3c708`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/be3c7088ede0a9db31742e38b1f6ac1631be0fe3)

#### [9.3.72](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.71...9.3.72)

> 8 September 2018

- Pre-Release v9.3.72.dev1 [`5c3c795`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5c3c795e74f52a561641e4ae8b615c055b11683c)
- Release v9.3.72 [`0f56bf7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0f56bf7cd4a91b001a2f6457207145f7455459c0)
- Merge tag '9.3.71' into develop [`a658730`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a658730fd95953bb43a4fec5c0433206e939d051)

#### [9.3.71](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.70...9.3.71)

> 8 September 2018

- Release v9.3.71 [`3b8de1e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3b8de1e63623707333254a886b5a84325320a25a)
- Merge tag '9.3.70' into develop [`874b988`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/874b9884ceb51f1926e8da5aa3bebffc5f942a5c)

#### [9.3.70](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.69...9.3.70)

> 8 September 2018

- Pre-Release v9.3.70.dev2 [`d1aa98d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d1aa98d46d344f8e7ecfa69f5c99b8b328048b38)
- Pre-Release v9.3.70.dev1 [`1c0d920`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1c0d9201e0be3a430e555da15ce185f7d0053377)
- Release v9.3.70 [`cf75694`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cf75694a08562c62c39dc5b3187afe3cc3530e74)
- Merge tag '9.3.69' into develop [`1b9fd1c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1b9fd1c827c84cd52aaa9b182ac0d68ad1b04798)

#### [9.3.69](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.68...9.3.69)

> 5 September 2018

- Release v9.3.69 [`e93f949`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e93f949d25fefdde8ea647cd3a8a5f345f70834e)
- Merge tag '9.3.68' into develop [`26e066b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/26e066bb7eaf2e86aa972f3a276d837948470e1e)

#### [9.3.68](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.67...9.3.68)

> 4 September 2018

- Release v9.3.68 [`51f6fb2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/51f6fb2d3f09e106c936f1995e1428d04a99bef4)
- Merge tag '9.3.67' into develop [`e3a9fb9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e3a9fb98660bd26611455103ec863ccc4c207ffa)

#### [9.3.67](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.66...9.3.67)

> 1 September 2018

- Release v9.3.67 [`c11dace`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c11daceaebf727ac512d0f237da2e8386c70dfa7)
- Fixed issue #255 - total episode count incorrect. [`1430717`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1430717a2e9c06a26ba2eee5db6b23337d833343)
- Merge tag '9.3.66' into develop [`f8a371e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f8a371e5286258ca277c6c43cbde6fae2ce13d93)

#### [9.3.66](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.65...9.3.66)

> 1 September 2018

- Release v9.3.66 [`569f95c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/569f95cf36a10efee2f43fa2728e0c13f04dad2e)
- Pre-Release v9.3.66.dev1 [`4ac6773`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4ac6773b2703eef9f7466987b7770254e8aea77b)
- Pre-Release v9.3.66.dev2 [`4c62c8c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4c62c8c361325f6fbba7a35e7413e7c3eb65d7f6)
- Disabled changelog from popping after a new update [`33b3f9c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/33b3f9cdbb4a5bc694a8bb144045eb6f0cd058c1)
- Fixed issue #265 - Unable to detect internal IP address in order to add UPnP portmap [`1ee6798`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1ee67982e3c4c1a248e482eed74cdcce511bf215)
- Merge tag '9.3.65' into develop [`1e9d65b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1e9d65bf6bf3c9c9672bc5845a4eecea9aa94c0f)

#### [9.3.65](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.64...9.3.65)

> 30 August 2018

- Pre-Release v9.3.65.dev1 [`a534896`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a53489648115a9bbaf51fa44e96a266d48d4add3)
- Pre-Release v9.3.65.dev2 [`61c0376`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/61c0376896c1cce4c38d18e3cd97d232fa0e42a6)
- Pre-Release v9.3.65.dev3 [`cd59c7f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cd59c7f270c1ab092f8a688eb13d6258fc29b456)
- Release v9.3.65 [`ab769b0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ab769b0e0ee46bfd9499874266864becb4e31d4d)
- Failed processing skips paused shows and archived episodes. [`9d880bd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9d880bd135506f4008b208af72627e83d04daab7)
- Fixed issues with failed snatch searcher attempting to re-download archived episodes [`889fa19`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/889fa19ff518bdf1e86cdab414148a4c6621bbf8)
- Merge tag '9.3.64' into develop [`f11067d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f11067d8927606aab66fa5f999966d3e155acb02)

#### [9.3.64](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.63...9.3.64)

> 29 August 2018

- Release v9.3.64 [`dc90396`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dc90396a10734b50e4f0d46b780a6db26d851408)
- Merge tag '9.3.63' into develop [`b763c62`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b763c62c3106b0a89580a31d2525078cd74cb8a4)

#### [9.3.63](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.62...9.3.63)

> 27 August 2018

- Release v9.3.63 [`0c2e95d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0c2e95dbb0b24f0c3fac001ee9fc5cf98654f4e5)
- Fixed javascript issue when adding existing shows [`9e66cf5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9e66cf5e245e3ae1f1a08dfa5b38cb36611068b1)
- Merge tag '9.3.62' into develop [`b6f7597`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b6f759757eb9085831869b25234578892b976d1c)

#### [9.3.62](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.61...9.3.62)

> 27 August 2018

- Release v9.3.62 [`6b01822`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6b0182242e42e2ec31ecd43b24d04aca288de620)
- Merge tag '9.3.61' into develop [`36d258d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/36d258d4ea697dbf47bb160e06d7687bef60da8c)

#### [9.3.61](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.60...9.3.61)

> 27 August 2018

- Release v9.3.61 [`c4c732f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c4c732fa42ea37bc0bc82cfefbf1647cd5d71cd4)
- Merge tag '9.3.60' into develop [`c0274a9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c0274a9019d031ae52aa58ee54d79c0f5cec44b3)

#### [9.3.60](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.59...9.3.60)

> 26 August 2018

- Release v9.3.60 [`ebd6252`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ebd6252d2dade3c3931b5828a042a775bb5c6e0e)
- Pre-Release v9.3.60.dev1 [`1b42b83`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1b42b83bc30892253a55e510738a2664ddf71b01)
- Fixed quality badge for manual searches [`8279ece`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8279ecea96d594c017810795d90d813fbdba1ac4)
- Fixed unicode issues with timezone updater [`8b6981b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8b6981b478593465a16faa7d38362c8c13ae011f)
- Fixed issue where click event for adding root folders was being fired more then twice. [`55e4104`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/55e4104173d6df8b2be134b0bf8e8cb9fb5ce9b6)
- Fixed spacing for status view [`9797220`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/97972204b3b15f5b2aceaf991d9f8c64e24dfa6e)
- Merge tag '9.3.59' into develop [`7530eec`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7530eece814a208d5737d7618b03d708998b084d)

#### [9.3.59](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.58...9.3.59)

> 24 August 2018

- Pre-Release v9.3.59.dev1 [`5ddb5de`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5ddb5de239de1e31986b4010eef274ef6933601f)
- Pre-Release v9.3.59.dev2 [`a1cc57d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a1cc57dcc11764d1c983e4c188e6a570f8575f42)
- Misc improvements made to websockets code [`30e4803`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/30e4803ccc3ec064691b0263f1ca6306141f27f0)
- Improvements made to tornado web handler code [`096b055`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/096b055df997d63670dfa3c845e3d0fd80e4f41b)
- Release v9.3.59 [`fb31d87`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fb31d8799d439f98b1682f590b6ecad337cad3a6)
- Pre-Release v9.3.59.dev3 [`2a1d2ce`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2a1d2ceb466e1e2155931acc2ab524f52b8e9ecc)
- Misc improvements made to websockets code [`b18bd58`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b18bd58357342e823913f7fc1434340ce7b4ff43)
- Merge tag '9.3.58' into develop [`c5e3128`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c5e3128287f8fad0528d6a4a9560f8862a63f1db)

#### [9.3.58](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.57...9.3.58)

> 23 August 2018

- Release v9.3.58 [`a7f3541`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a7f3541d68ff702581a809fb3a6e12d92e847e9e)
- Pre-Release v9.3.58.dev1 [`2f40c76`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2f40c76d01bb7c81f042bb7cd0e2c192744a158d)
- Pre-Release v9.3.58.dev2 [`bd35aae`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bd35aae62a625f68ced0d5ba8fdd12efa40b315e)
- Fixed issue #253 - Provider Option Missing Cookie Field [`5f0e3bf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5f0e3bf8c20140374c45e9cf5930041ad9e9b91b)
- Fixed issues with custom web roots and redirects [`faefa9d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/faefa9d122f6987d7caad8ba21391d83745a8d81)
- Merge tag '9.3.57' into develop [`e25112d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e25112dafad5231b42389277089737772582c522)

#### [9.3.57](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.56...9.3.57)

> 19 August 2018

- Release v9.3.57 [`e5b5706`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e5b570692527782465406d7253b400a59f1c3ad6)
- Merge tag '9.3.56' into develop [`a7128ce`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a7128ce75605ee6c847984b6923d97de2724af32)

#### [9.3.56](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.55...9.3.56)

> 19 August 2018

- Pre-Release v9.3.56.dev1 [`900b680`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/900b680a94948ddf8c144ea497b197770af46a52)
- Pre-Release v9.3.56.dev13 [`c6f1503`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c6f150349a7c0e6a8329963ddef3036a0841b43d)
- Pre-Release v9.3.56.dev27 [`10de224`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/10de2248a6d6dcecdf776d9323084789d95ffce8)
- Migrating away from Bower to NPM/WebPack [`d73439e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d73439ecfc8f010c369bde03ffdc7fc79a370165)
- Pre-Release v9.3.56.dev10 [`8c90243`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8c90243e9fe40cb9519662fab42f1733f38b15de)
- Pre-Release v9.3.56.dev18 [`d6b5a4a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d6b5a4a06ecb13aaa0501bc168ecd69ef4ebcee5)
- Pre-Release v9.3.56.dev12 [`07e1703`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/07e1703efdf86f1eb97a3149368b7aa28cda61bf)
- Migrating away from Bower to NPM/WebPack [`a4b58c9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a4b58c9a05e7496a0ba9bc21683608fa662723b6)
- Pre-Release v9.3.56.dev14 [`b40951e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b40951e9ce2de7ae4b9a7a984032dcda50a9324e)
- Changed table text color to dark for display show view [`443ec81`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/443ec81baa6398f307b802f64c7fe45c80b09318)
- Pre-Release v9.3.56.dev17 [`d569f06`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d569f06fb00e746a59862794ea2ee6f2e25449c9)
- Pre-Release v9.3.56.dev5 [`e39068a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e39068a610caefc862c178ca1645caa3d794f146)
- Pre-Release v9.3.56.dev9 [`f33330a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f33330af7cfd665b311f5486a1f12c1f9edcedf3)
- Migrated tablesorter theme to bootstrap 4.x for home view [`9f14867`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9f14867bbd204547222a55c67a9154cc84eb94a8)
- Pre-Release v9.3.56.dev4 [`24b4751`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/24b47510b5fe007ddb4167200f835b98c82fd30b)
- Pre-Release v9.3.56.dev8 [`e588aa6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e588aa6bcf02582eea96291d7c2a62620d2749af)
- Pre-Release v9.3.56.dev3 [`45d2074`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/45d20742591c605e6ed3ac2a83a8f3cc3731abf4)
- Pre-Release v9.3.56.dev11 [`3acc96b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3acc96bba90d8e06b859cb9eeb578641d34b96a2)
- Pre-Release v9.3.56.dev7 [`876ddfc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/876ddfcad0729e88a8f858ae05767859f70c3952)
- Pre-Release v9.3.56.dev24 [`26635da`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/26635daa55d5cae649a0f2f8d3377c26d87604bd)
- Refactored table class spacing/padding and column widths [`19cb817`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/19cb817eb85d0e3117d17c1935a7f7163301d075)
- Pre-Release v9.3.56.dev19 [`e69a0e5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e69a0e5d4789e07bae0d1903f950041b2b5b8daf)
- Pre-Release v9.3.56.dev6 [`5a27b14`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5a27b146673ba5659e45c01b3624ccbc9d2c06af)
- Fixed broken toggle buttons [`8efa7cb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8efa7cbffecb21330813e568584228887f2cef08)
- Refactored config views to Bootstrap 4.x [`b912b2e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b912b2ec53a842ac171a2d2dd257cda0f984f4ec)
- Fixed issues with modals not displaying correctly [`93bd3ce`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/93bd3ce1495b0210f3518bc909aca31b3dd543aa)
- Pre-Release v9.3.56.dev2 [`5ac6bac`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5ac6bacb4ad89e420bc2be99bc4cd82f14cf6f63)
- Fixed issue with saving provider settings [`332017d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/332017d2dbd1f34353bfbcbfa455ed8601a0018f)
- Pre-Release v9.3.56.dev16 [`096927a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/096927ade8d3f6b15ae77fd89e207ed828c8699d)
- Fixed status text styling issues for episode rows in display show view [`479026c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/479026cf6c6a0a395738adef7364d493791860a5)
- Removed bootbox jquery package [`e12e04f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e12e04f1986575925a6603d5653fd218c5168bc3)
- Fixed IMDb star ratings for display show view [`96a1978`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/96a197855ad5b6316237479112d3fa32dd2eb580)
- Removed focus box shadow for quick search form control [`b96888a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b96888a09940d5e1a877c19c5cf6a9e98c39e69b)
- Fixed file browser modal [`1243962`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/12439625cbfc0725751d29226f435424074fd925)
- Refactored responsive column for views [`fbc0c9e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fbc0c9e559749a6c8144a27c22290d4f9a3223c6)
- Refactored schedule view [`453ca1a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/453ca1a9ce96bfc2e028819996455f28d2ef55ae)
- Refactored display show view to Bootstrap 4.x [`a4fa4da`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a4fa4da5752d7a72d2188bb25792b0b488ea2cbb)
- Pre-Release v9.3.56.dev25 [`c9367a6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c9367a673cf0dfd20b9b7835c8e07fb3326ea597)
- Pre-Release v9.3.56.dev29 [`e26fd2e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e26fd2ee8f0c7394b68aa9d42be2e660115efa87)
- Created themed scss classes [`6cd3963`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6cd3963fbf8eba31732bcbeb8998348c959f5aa6)
- Refactored notifications config view [`085af56`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/085af5605885ecbdec2181da13c524264109dcfc)
- Refactored episode naming view and misc config views [`8b4add8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8b4add8014e9ed7ed0458e0bb855748a570d48a1)
- Migrated file browser modal to bootstrap 4 [`bce28bd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bce28bdfd25cb7443850f0b64190d3079e46b86c)
- Refactored edit show view responsiveness [`2466e65`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2466e651ec48ed6e2d67d5a91d0537d3decd82bd)
- Refactored all config views [`ef5ceee`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ef5ceee60989a6d2220947a7828e15a9e910d2e2)
- Converted all glyphicons icons to fontawesome icons [`0672255`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/067225529f48d1693ba3b3d36b86d03ace6123f9)
- Refactored add new show view to bootstrap 4 [`a3ff9ab`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a3ff9ababd29a8774b68d817d7f2e70f9e40d2fc)
- Misc code corrections and cleanups [`97b4239`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/97b423963a3f7e8c6a6d8af201bb983d96cf0d27)
- Refactored history view [`0fdb6df`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0fdb6df7d861b587d02abe74ca4848281cf8833a)
- Migrated status view to bootstrap 4 [`bc2a0f2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bc2a0f212079516f628e02240dd67527d4ca54ba)
- Refactored mass update view [`1df34fa`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1df34fab96e9edf68d65dbf5f304ace7407a38cf)
- Merge tag '9.3.55' into develop [`ff10465`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ff10465acf3fd910f433f1e6a1f98876e2ead724)
- Fixed responsiveness for add shows template [`e8d562b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e8d562b830b752e6d2663505ddfd44511f92cd67)
- Misc style changes [`0beb0e7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0beb0e799c9badc7627068b52749c1b786f01133)
- Fixed main shows page show details footer [`03c08d7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/03c08d7038da8e37f1c055753ab3f21414765a3a)
- Upgraded tablesorter to use bootstrap 4.x [`fc2ec2b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fc2ec2ba4997c9f02d391f6d719dec579563a14e)
- Pre-Release v9.3.56.dev28 [`a2aa340`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a2aa3404e6382d13c91b0e0cd6b252882aea4431)
- Migrated provider and subtitle image references to sprite references [`b3107c2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b3107c267821831fe7a0c085ef47201921c809c6)
- Updated grunt tasks [`6afa4c2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6afa4c2cc91cbb96fb93657288d952e4df9301ce)
- Converted provider icons to sprites [`f94568a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f94568a0c163f6da1b925ceb5318327b0f99f0fb)
- Refactored edit show view to Bootstrap 4.x [`fd227d5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fd227d51aa9196d16bbee479a25b2c13d64322de)
- Migrated add existing shows view to bootstrap 4 [`e1ea56c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e1ea56c41682fb9d28c29f07578241736319f642)
- Migrated add trakt show view to bootstrap 4 [`7abe9f9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7abe9f9b7e39cacc0b2e4f607febadfea825843b)
- Misc code cleanup [`71b4cfa`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/71b4cfac26c0ed9c73460ae80041a1243dcb14b7)
- Migrated home view network logo's from images to sprites [`961b90c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/961b90cbd137d80194ed4691994b1cc449a6cabb)
- Migrated imdb popular shows view to bootstrap 4 [`2fa2261`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2fa2261c4a361e7dcde8aa15abe0fcdccec4ef65)
- Refactored mass update view and manage queues view [`dfb4f99`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dfb4f992376ddc562543ca83f860283a4d574b28)
- Refactored metadata config view [`22d3071`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/22d30716fa5c72d6490c2a42815290f9e328ace4)
- Misc style changes [`524cb0a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/524cb0a8646c1bcf8a98c31c5184f426185d6d2c)
- Pre-Release v9.3.56.dev21 [`b8c4de7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b8c4de70c544de7ff3cf0a790f7c81deccdbc605)
- Refactored missing subtitles view [`427b651`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/427b651a8b06520452115f5bab5e692f12c43d11)
- Merged overall_stats and show_stat functions [`08cb03c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/08cb03c443c4346592e7647f2e1ec7e4347eff49)
- Migrated config providers view to bootstrap 4 [`d2cea58`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d2cea5803a25523e1824bff265620acc2ab40b57)
- Misc code cleanup [`69cee25`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/69cee2531d167d309a1222bb3caad0d11b21739e)
- Release v9.3.56 [`b1dc06d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b1dc06dd712af50d50c1df9ca181e29324450028)
- Misc updates to tests [`b9bbb26`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b9bbb261c1592787dec2adff133608acfdd199ca)
- Refactored failed history view [`6727208`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6727208ca2efca90f10dcf6afc5102a65eb03a5a)
- Pre-Release v9.3.56.dev23 [`3ae007d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3ae007d538a75893712539d98d0672b26df5e58f)
- Pre-Release v9.3.56.dev26 [`c60cbb3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c60cbb3162b041bc7da1dfead6dab7acfe46a074)
- Pre-Release v9.3.56.dev22 [`908bb53`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/908bb53f6fc654ea90a5b32dec9e7a45ed4409d4)
- Pre-Release v9.3.56.dev20 [`fdeaf28`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fdeaf28c7ea28601f390ceb00aa724bffbe78b41)
- Pre-Release v9.3.56.dev15 [`486eb8c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/486eb8cbe9853a9881e71593d5589167cf54b1df)
- Migrated more icons to font awesome [`fe6e1f0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fe6e1f04a2bfc1e79f172cccc2336bd99fec1ecb)
- Migrated loading, queued, searching icons to font awesome icons [`1e21e2d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1e21e2d241fa8b704555d7bc3b8f55127caa3222)
- Fixed progressbar backgrounds and misc margin tweaks [`8aefe4c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8aefe4cc583e9772976ebdc5b85e2ba819fcb16a)
- Fixed table text wraps [`b0e6922`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b0e692288ab85ad77c1ee9ce9af69be28c11d578)
- Misc changes to package tests. [`46f21f5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/46f21f5bc0c19519578eca36226cad655ea97b23)
- Fixed logs view [`efff7db`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/efff7dbcd166f1edd3a9363f858298e71f3bb6cf)
- Migrated upnp client from threaded object to scheduler job, resolves shutdown/restart problems [`d590b01`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d590b016e8982b950f55fb28a7c8775affc5a294)
- individual shows view now gathers total show size from episode file sizes in database [`ea140ab`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ea140ab2ee63c5e4f11885aa681da354571ade33)
- Refactored content column size for large devices, small to medium devices are now full-width [`76afe3b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/76afe3b42bbfca13a33fe28271af132045433730)
- Fixed issue with network logo being off-center [`ebcd017`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ebcd017397426b153f39fd1a66e1bec653eb0389)
- Updated notifications view [`df9b9e3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/df9b9e3ef509fd816d4ac0b4df0884ab1e3b4a85)
- Refactored restart view page [`d5f8615`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d5f8615494a4afe409f2ffe7ffcb47bf6e3a38a9)
- Converted provider icons to sprites [`f626619`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f6266197c8bab0fb3e7340e708c63e78fdb60a5c)
- Fixed issues with displaying show network logo's [`6004bc4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6004bc4f5aa2f317ff32b467346f20e5ca671e7e)
- Fixed issues with multi-episode search results with more then 6 episodes in result. [`9cba816`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9cba8168297963d1862815575072590c1a68f018)
- Refactored manual post-processing view responsiveness [`2742737`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2742737d9788251b752efb992e53843c64a5c5fc)
- Refactored display show view [`b24cc27`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b24cc27343531390e135a9a6ed6d6b5178ac14ef)
- Removed select column control from shows view [`3a87793`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3a8779317a9ddfc98bdc77c4510986be1ce95abb)
- Fixed gaierror's for ssdp [`e27a959`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e27a9595f2846cddf51fd708825151613cfbc5b3)
- Misc code migrates to bootstrap 4 [`476f90a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/476f90ac336e4ae4ade0f60a6e6b1f29a18eda2e)
- Re-enabled closing of databases on shutdown/restart [`af4abb6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/af4abb699721354e60b28bcde1ce9eeffab83c15)
- Fixed provider view list items [`1867aaf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1867aaffbaa23eb4389621a8140dedc8c63fc039)
- Removed code that was preventing show refreshes from happening due to show updates being in queue. [`481f291`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/481f2910b85bbbf9054185e414694032d80b3749)
- Disabled closing database on shutdown/restart of app [`e6f1422`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e6f14220633089e7201ef27180750f03eeb97c8a)
- Fixed missing icons in navbar [`c702306`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c702306d0cef31e4825d7ecf920029d173518313)
- Fixed genre row alignment for display show view [`9c41f4b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9c41f4b3c445771861a4832e77185d454bfd3e5f)
- Refactored table show show/episode column for history view [`d086087`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d0860872dc9022ffbcdb7f26dcd4b0a892cbf2f9)
- Fixed redirect issue when trying to login to a app thats already linked to another account [`9b5ed21`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9b5ed215b3d6b3a660fbd6e1e267abbf59287ef7)
- Refactored list group in subtitles config view [`169b960`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/169b960801fedcf35daeb12084d0009c17d7b3eb)
- Updated gitignore file [`901a870`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/901a870520509c8a42f6537a977f406617eb914e)
- Removed unrequired top margin spacing [`1a7bca1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1a7bca1e8434a188a05f123f38848a7a24e28feb)
- Fixed case-insensitive sorting for small poster view [`f52c99b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f52c99be489c98f1646e34690d2327b889f07dd9)
- Made quicksearch content easier to read [`d56b876`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d56b876d25cf3e3a2adc68f0b53f8ad0b4b80dbf)
- Refactored layouts for main shows view [`e61f206`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e61f20638d5519e3125b28f148238ae1471de9a5)
- Fixed issue where MultiPartEpisode was being appended to all episodes and not just multi-part episodes. [`1cfa2f9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1cfa2f95f362216b185095d8c91578fd388626a4)
- Fix for issue #244 - reverse proxy [`764a9f1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/764a9f16c59980b561f75a293e844454b3f723de)
- Fixed newline issue with error view [`51b6726`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/51b6726d2956b89c3888c12ecf55d39f6aed93af)
- Reverted text-nowrap class for schedule view table episode name column [`7020ea5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7020ea5e44ceb2faace014c98c240aa5d3b94d25)
- Misc code cleanup [`d115e61`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d115e6163fb514c7a6445ce880ed255f9216139e)
- Fixed issue with retrieving image thumbnails from Fanart.tv [`1f9d56a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1f9d56ac8685c2088caf6844a2035fb3a4b7b394)
- Updated gitignore file [`6f84b0d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6f84b0d10f202213bc2ce957670eac7e0088932a)
- Re-sized buttons bar for main view [`736d021`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/736d021ed99d9645a229a2f6e33b0d98352a7cd4)

#### [9.3.55](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.54...9.3.55)

> 13 July 2018

- Release v9.3.55 [`fd36e3d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fd36e3df4b72bf8bc2d11c0dc4a3ee068e1927df)
- Updated gruntfile [`a60f7af`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a60f7af44a6cc44f16a470eb526140ed79f521c0)
- Updated Yggtorrent provider base url [`2f5ba4a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2f5ba4a35d50d71ec2b68028110c6c9dc91609a6)
- Merge tag '9.3.54' into develop [`8c50c1c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8c50c1cb7f1f6237f51d73fa05fe87ee9e306c42)

#### [9.3.54](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.53...9.3.54)

> 8 July 2018

- Release v9.3.54 [`ae015ef`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ae015eff31db5344dec4e710d5c9ae49aabe372a)
- Pre-Release v9.3.54.dev1 [`2923c07`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2923c07cae8a7acf1e8b78f6a92a3d84a075b051)
- Fixed getEpisode function to handle absolute episode numbers of zero [`e666331`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e6663313f550ce268e928be38af3182e4f40f061)
- Merge tag '9.3.53' into develop [`1ba84b2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1ba84b2b6284b748e55237572193dd4daa002d10)

#### [9.3.53](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.52...9.3.53)

> 7 July 2018

- Release v9.3.53 [`dc3cc1c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dc3cc1c8ad568f239cd1a378f5be8c6bb9923e47)
- Merge tag '9.3.52' into develop [`ece0c59`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ece0c5975e658bf09beacf8cab7af630df79c908)

#### [9.3.52](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.51...9.3.52)

> 6 July 2018

- Release v9.3.52 [`f3b315e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f3b315eeb96237f8e59926a25b6f5efb0b0880e3)
- Merge tag '9.3.51' into develop [`8084037`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8084037ddfe31fd56b5d196d94b0e2480f09291f)

#### [9.3.51](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.50...9.3.51)

> 6 July 2018

- Release v9.3.51 [`9d335cb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9d335cb7b4a8c7bcfad54a99309d9b91ecb6d4f3)
- Merge tag '9.3.50' into develop [`d9b2a40`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d9b2a4064a2f79681aa2f404f78f34bb9831c3df)

#### [9.3.50](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.49...9.3.50)

> 4 July 2018

- Release v9.3.50 [`591578b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/591578b8181ab597d5d44f1c2333c3ee88e4d711)
- Merge tag '9.3.49' into develop [`38b2e05`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/38b2e0550e47ae9eee568da0ead55c9bb02a6205)

#### [9.3.49](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.48...9.3.49)

> 29 June 2018

- Release v9.3.49 [`867b799`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/867b79907e086696384a3ab1668a91ae3b4c5824)
- Merge tag '9.3.48' into develop [`86b57e4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/86b57e4a158e06d32ded32becc2040b62cdd6b53)

#### [9.3.48](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.47...9.3.48)

> 28 June 2018

- Release v9.3.48 [`3d27b4e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3d27b4e42ab25b2c6fdaebf0cb3b92cfdc63d8e2)
- Minor updates to login handler [`b3ca706`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b3ca7065047a62ebc369c1f8f3c831537d230d9e)
- Merge tag '9.3.47' into develop [`5136f53`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5136f53d66195d6047898ea6f0a75aafefc490cc)

#### [9.3.47](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.46...9.3.47)

> 25 June 2018

- Release v9.3.47 [`ecf829f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ecf829f521f4858d03fc172f2cf7f043103c6e17)
- Merge tag '9.3.46' into develop [`28e7255`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/28e7255fcf4afa5294850335c70f1da6db45f0ac)

#### [9.3.46](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.45...9.3.46)

> 25 June 2018

- Release v9.3.46 [`40ffc7a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/40ffc7a9b3544feca04f0e161178306959507db3)
- Merge tag '9.3.45' into develop [`c1e8863`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c1e8863a01a5ad0db8289cca15478cf6bf8ad2a9)

#### [9.3.45](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.44...9.3.45)

> 24 June 2018

- Release v9.3.45 [`05e41d5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/05e41d58a916e0533b47dbbd808cf28599a3a8ea)
- Fixed issue with UPnP getting incorrect internal IP address [`dcaff48`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dcaff48e85047acfe26a74ed4abfb9fa9589e92a)
- Merge tag '9.3.44' into develop [`84c951b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/84c951bdbf5183beb95d7131721eb9ada020cfab)

#### [9.3.44](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.43...9.3.44)

> 24 June 2018

- Release v9.3.44 [`38bd1fc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/38bd1fcfa5d021a9ce0c7350de8029128c13511f)
- Merge tag '9.3.43' into develop [`6a716e6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6a716e69f8e5dda9a3bd1e42aa0b2c0d92451bc8)

#### [9.3.43](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.42...9.3.43)

> 22 June 2018

- Release v9.3.43 [`21d03f9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/21d03f967d9d08fa150b43bfcb2cd396e45c0477)
- Merge tag '9.3.42' into develop [`f48f9d6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f48f9d6b9aa92a6f7b44907b4a3e5d36333485bb)

#### [9.3.42](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.41...9.3.42)

> 22 June 2018

- Release v9.3.42 [`42893d0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/42893d01393ce103a2953a36df827a5c3ff14052)
- Merge tag '9.3.41' into develop [`92d0968`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/92d0968c38111e4e173ddd624ca0213e9cb146a5)

#### [9.3.41](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.40...9.3.41)

> 21 June 2018

- Release v9.3.41 [`abf1b98`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/abf1b98e6e8651c32232884645211c5663d75676)
- Merge tag '9.3.40' into develop [`4de2ca5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4de2ca50280bd54ddad6607420dc0911444a5b22)

#### [9.3.40](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.39...9.3.40)

> 21 June 2018

- Release v9.3.40 [`8bd7022`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8bd7022e937f3ef428454e9a344be5704130a318)
- Merge tag '9.3.39' into develop [`3604c27`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3604c274a8b808d21d4370f5d29b5aa1a447f7bf)

#### [9.3.39](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.38...9.3.39)

> 21 June 2018

- Release v9.3.39 [`36ce10b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/36ce10b33b298ca2c6a64010ef6cb73d1b697136)
- Merge tag '9.3.38' into develop [`56451a3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/56451a314dd7898fd0ecd04add4f7dd7d66d8e87)

#### [9.3.38](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.37...9.3.38)

> 21 June 2018

- Release v9.3.38 [`c2a903e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c2a903eea1833a941e07f01fba7b612fc3453fa7)
- Fixed issue with how data is formatted on return for app api [`4ee3db6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4ee3db6abd667085971f8a4a4c19f81b2e74e250)
- Merge tag '9.3.37' into develop [`074994d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/074994d64d019bf3a959d95e0a1aec6e08f467d1)

#### [9.3.37](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.36...9.3.37)

> 20 June 2018

- Release v9.3.37 [`08580c9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/08580c93e4b6044011cb45fc8a4e31302ba33568)
- Merge tag '9.3.36' into develop [`05918e7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/05918e7d52b5b378e74da3624a4d5fce36fc95b2)

#### [9.3.36](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.35...9.3.36)

> 20 June 2018

- Pre-Release v9.3.36.dev1 [`e6f02d4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e6f02d43e0c503e2aa0467586e387010b3c08d82)
- Release v9.3.36 [`5e91170`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5e91170ee506ef0e20365103185efb7b531f6de9)
- Merge tag '9.3.35' into develop [`39b4fd7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/39b4fd74c1709e85ff85bc157b2cea8bf0e48232)

#### [9.3.35](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.34...9.3.35)

> 16 June 2018

- Pre-Release v9.3.35.dev1 [`bcdcce3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bcdcce3b46dbfbcc6bbd4c0656f7bce8131d420d)
- Release v9.3.35 [`c800afc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c800afc496f6a5cb1da455d61e19e8345523cabf)
- Pre-Release v9.3.35.dev2 [`8ee962a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8ee962a2148a8694f1f149c2a3a53b334af5fbd7)
- Changed placement of announcement's for main layout [`f316113`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f316113c5dcdf44ee459350ac6dea6b70db32a93)
- Fixed requirements issues [`2eef0d8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2eef0d80ca90196964f86c5a494b112333bad48f)
- Merge tag '9.3.34' into develop [`0a9a43a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0a9a43af3064b993f654289d554f8c7664ad7f29)

#### [9.3.34](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.29...9.3.34)

> 10 June 2018

- Release v9.3.34 [`7bd322b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7bd322b57e86b9139d8458db0d00601dd737b7c4)
- Merge tag '9.3.29' into develop [`10d35c4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/10d35c418e9d72cbf1f3c3c6c267a8046b801141)

#### [9.3.29](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.28...9.3.29)

> 4 June 2018

- Release v9.3.29 [`a65bc0f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a65bc0f10881de71fea5e2d72261209b47172216)
- Merge tag '9.3.28' into develop [`df57762`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/df57762923edbe048eb5e635c14df62660cf2ad9)

#### [9.3.28](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.27...9.3.28)

> 1 June 2018

- Release v9.3.28 [`1277227`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1277227ca2b9c2ddbdf7c7908a1fc8606db78493)
- Merge tag '9.3.27' into develop [`528077b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/528077b2a6c53b50fc3ee909e6028b9758f3a388)

#### [9.3.27](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.26...9.3.27)

> 1 June 2018

- Pre-Release v9.3.27.dev1 [`22b37e3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/22b37e36d3a93606a3055f24999eb35d9fe0983e)
- Release v9.3.27 [`924a877`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/924a877bfbb0603adf16ee83b003ff514b279229)
- Migrated from oauth2 client credential grant to password grant [`4dd25e6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4dd25e6125773c1d385e47d32e70c4fdfd62a89f)
- Removes existing symlink or hardlink file if exists when creating new links [`1ad45d2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1ad45d2473107d2f525215bb3251b87ae0c7e9ee)
- Misc changes/fixes for database calls [`510fe7d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/510fe7d224def156a0b274290255767b123f31eb)
- Fixed issue #224 - backlog searches not working [`7f39cc3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7f39cc3322dabfd739460d7acf95101d74640b15)
- Merge tag '9.3.26' into develop [`0103654`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0103654b00051ee11dafcf0a1e74baffbbdfb59d)

#### [9.3.26](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.25...9.3.26)

> 24 May 2018

- Release v9.3.26 [`d861c0c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d861c0cd554e51ba80f881eb50d6572017da2777)
- Fixed issue with parsing failed quality for episodes [`eee20d0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/eee20d009c78a03c63448cc6ec9cd76e9124d6bf)
- Merge tag '9.3.25' into develop [`e7a623d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e7a623dbe8a5220088945fdf62a678be6adb9ea4)

#### [9.3.25](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.24...9.3.25)

> 21 May 2018

- Release v9.3.25 [`06d160f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/06d160f88df0612ba9d26dc58972b72afc4c1969)
- Fixed issue with unexpected keyword agrument 'skip_downloaded' [`f7f75e7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f7f75e7e07e915047a786d7508520cef1948118d)
- Merge tag '9.3.24' into develop [`f20942e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f20942eae5b365b83612664615e4e6566a9be58b)

#### [9.3.24](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.23...9.3.24)

> 20 May 2018

- Release v9.3.24 [`706c89e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/706c89eb74b4681c829219a75f78dde4f63b2946)
- Merge tag '9.3.23' into develop [`bcdaf05`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bcdaf056dea568ad41897e048f46180242214d53)

#### [9.3.23](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.22...9.3.23)

> 19 May 2018

- Pre-Release v9.3.23.dev2 [`8a40c41`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8a40c418e985161825a6be803bf4bbe831582d4c)
- Pre-Release v9.3.23.dev1 [`c6fd81b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c6fd81b4814c5288a1eaf22f1fc640349febc462)
- Converted log error to warning for Discord client [`0f68f72`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0f68f72cf3fe3c40b273957891158b329cc7d4e3)
- Converted archive_firstmatch to skip_downloaded option, skips upgrading quality of downloaded episodes [`249b6b0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/249b6b0b56bb7165b8d5d16703ca4891916cb413)
- Release v9.3.23 [`7bd2298`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7bd22986c1403a51e8579c89de920991b5d84c23)
- Misc typo corrections [`5f5592c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5f5592c0a2d0ec33802a99028b491375ff6c3830)
- Misc small fixes [`a3c7441`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a3c7441c613cd03d325bbf16b02d9a78214b83d4)
- Fixed issues with downloading subtitles [`15c6a47`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/15c6a4781b2b65c1cbcccbf8b02eee0c83bbae07)
- Converted for loop to while loop for database upgrade function [`1ff0bc5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1ff0bc5fad58be966cb57fb16d77f1cd191a6120)
- Merge tag '9.3.22' into develop [`bc707df`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bc707df928139b1b9a7abaeaa0354a6b582a0587)

#### [9.3.22](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.21...9.3.22)

> 17 May 2018

- Pre-Release v9.3.22.dev2 [`d2f59fc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d2f59fc841591ffe4045af45cd6288d2a00b6037)
- Pre-Release v9.3.22.dev3 [`6ea67b3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6ea67b352856f4f8f9afb01b37d4459655c26e61)
- Pre-Release v9.3.22.dev1 [`2476478`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/24764780c26e084c53f1f352422e28f0dd824e31)
- Pre-Release v9.3.22.dev4 [`8acce0d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8acce0d122be778e105c39632f5ad544f2854ad1)
- Release v9.3.22 [`1630902`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/16309028881a327e73138c76630ed54c48e044de)
- Merge tag '9.3.21' into develop [`5256f22`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5256f22ed95acb832f96399ff35788b906a7c7f7)

#### [9.3.21](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.20...9.3.21)

> 13 May 2018

- New Crowdin translations [`#10`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/10)
- Pre-Release v9.3.21.dev3 [`7be1210`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7be1210d2e486d02b477bc45b0190ffbb0a17916)
- Pre-Release v9.3.21.dev2 [`5c626f6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5c626f6f62c03153f2ccf7298ccee82d5ffc137c)
- Pre-Release v9.3.21.dev4 [`52d12af`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/52d12afba09a2402402aa958a91042eb8c563387)
- Release v9.3.21 [`0869c48`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0869c486aaf2144f7c8df8efd494aa7aa3e1110e)
- Changed log levels from error to warning for misc [`fcdf2e4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fcdf2e49c79d28ddda82adc6252cdc1bb47b415a)
- Pre-Release v9.3.21.dev1 [`8b1ac6e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8b1ac6e6fcc815a3aefd7f2201a78b5c7f9bb6fc)
- Fixed bug in backlog searcher that was incorrectly comparing date ordinals causing zero results to be found [`ea98ece`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ea98ecef7163059cd3fa3cee80c8dcebb9c86914)
- Updated Grunt tasks [`5bb7da0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5bb7da01b04b8fa1bb38f8b229a2452acabde4cc)
- Changed iptorrents login url [`d1b612a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d1b612ae89e4fa54d6d947ecc671b774c2407f99)
- Update Crowdin configuration file [`392eda4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/392eda46a334270a16d5e1c23b27d46630b5b0a2)
- Merge tag '9.3.20' into develop [`51a525f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/51a525f9c6e0dfa023116a7d72dfaabd165c4846)

#### [9.3.20](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.19...9.3.20)

> 6 May 2018

- Release v9.3.20 [`7c77db3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7c77db3d79dc2eefa6222556b8c501a95ba9b313)
- Merge tag '9.3.19' into develop [`031cb4b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/031cb4ba760325c45da006671cb58436484880e6)
- Merged failed database into main database [`8ba19bd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8ba19bdc87235321ccfc181bcaaea374051399bc)
- Pre-Release v9.3.20.dev5 [`b89ab1b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b89ab1b124a78bba7c08d06f175a00ddc48e3340)
- Pre-Release v9.3.20.dev4 [`0e6ce30`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0e6ce30622f8cc102a0e08d6db108746ea198d4c)
- Fixed UnicodeEncode errors when saving subtitles [`67d8ac1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/67d8ac1a77fde26fc1c47b24bf68c92d88729138)
- Pre-Release v9.3.20.dev6 [`b9fa094`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b9fa094bf3fc1cd4eedb5c6b6fb5c41277de6842)
- Refactoring search client code [`b7cc531`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b7cc53185ff96b8d1cac6b3eb40ccf2e23c87788)
- Fixed redirect on login [`e0d01bd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e0d01bdd25cc765c6e24966efa2bae50fe84590b)
- Pre-Release v9.3.20.dev2 [`b5b3a06`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b5b3a065c1241acc33616a2cce49e3cf7e13f5d6)
- Pre-Release v9.3.20.dev1 [`ae451c1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ae451c1cc002df20829dd97c1f854f476f944e5b)
- Pre-Release v9.3.20.dev3 [`f69a02b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f69a02bad00e2d23c92f85596e53685ece83bbdf)

#### [9.3.19](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.18...9.3.19)

> 5 May 2018

- Release v9.3.19 [`50769a1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/50769a1bbc6057e239a42baa42cb69262169f248)
- Pre-Release v9.3.19.dev3 [`c478436`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c4784362c64a086b3a880b4179047793a6d13688)
- Pre-Release v9.3.19.dev2 [`ee3e0d4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ee3e0d4da2a2687d1608d9ff4ecda5c3262e3406)
- Pre-Release v9.3.19.dev1 [`793d2a5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/793d2a51e6ae1c24348c5ca7547988e4683630ea)
- Merge tag '9.3.18' into develop [`e599a2a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e599a2a3fbf55fc0cf889b018cd29d8ab808b874)

#### [9.3.18](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.17...9.3.18)

> 4 May 2018

- Release v9.3.18 [`885708b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/885708bba81cb98f99aa7d290e6d788e02378c3e)
- Refactoring of provider code [`821cc99`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/821cc99e46e52e04947e64ccf6ed0ed1e5beaf23)
- View Changelog now reads changelog.md file [`de8804b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/de8804b1c55c63d6db15e5187d539947a13f611b)
- Changed log levels from error to warning where needed [`1759db6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1759db68ef9faa462f243a8a5d855a59d2452008)
- Converted errors to warnings for DelugeD client [`a81ccaf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a81ccafa833d68dfdc8c4df187a4faea6a1ca2ac)
- Pre-Release v9.3.18.dev3 [`4a12c79`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4a12c79426c8cde8f3d283b5f04c6b6eac7c53bc)
- Pre-Release v9.3.18.dev2 [`2a46cba`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2a46cbafc2f3f8270fca583bba4b28f186b2dba8)
- Pre-Release v9.3.18.dev1 [`f85ba73`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f85ba730e2ace8e63ffcca5dd2732a146c8a4b57)
- Merge tag '9.3.17' into develop [`9cd46df`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9cd46df61936922fc5e690f74146f74c16387439)

#### [9.3.17](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.16...9.3.17)

> 1 May 2018

- Release v9.3.17 [`bd058f0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bd058f0914fc5e24b51ae2f690b95f15bd3eb358)
- Changed logging level from error to warning when trying to load episodes from directory and the show or episode is not found [`3781227`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/37812271ac54b8246bd3b33b61566e0ea529efd9)
- Merge tag '9.3.16' into develop [`0781b99`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0781b99651dac7b7265cf64a2e3835fa400f2d33)

#### [9.3.16](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.15...9.3.16)

> 30 April 2018

- Release v9.3.16 [`1a7b0ca`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1a7b0cad3e6fae45dcd75054efcffcb55aadb66f)
- Merge tag '9.3.15' into develop [`11dae1c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/11dae1c45e5c2ed814acb1b8bcda65d115d6631c)

#### [9.3.15](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.14...9.3.15)

> 30 April 2018

- Release v9.3.15 [`49c633f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/49c633f317df7a0530bd397fbfa4ed4a9a053d8f)
- Prevent sentry log handler from having logging level changed [`48105f6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/48105f62076bd257b8eebeb71a05897924d05e49)
- Merge tag '9.3.14' into develop [`8df79c6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8df79c64d6a2974bce83536bcaf04078849b6de8)

#### [9.3.14](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.13...9.3.14)

> 30 April 2018

- Release v9.3.14 [`1c5d2fe`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1c5d2fe33aceb8eb7788cd6469a117b98cf7aa43)
- Merge tag '9.3.13' into develop [`02ff5dc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/02ff5dc0b7b5be8b01ebbb5b75cc84489384960b)

#### [9.3.13](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.12...9.3.13)

> 30 April 2018

- Release v9.3.13 [`ab62087`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ab620872fddd499298b8a2625bcd74a1ec9a1b3a)
- Fixed issue with sending email notifications [`244264a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/244264aa51ea76bafb11d1d08d7849eea8572a4c)
- Pre-Release v9.3.13.dev1 [`e0bc4ae`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e0bc4ae3396423137fb86a432389a44ab458a166)
- Pre-Release v9.3.13.dev4 [`55b2e91`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/55b2e911c04957dfd08145018d33bc15d1c7b120)
- Pre-Release v9.3.13.dev5 [`f3546f0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f3546f0525d708fbb63054876a9e6b446ea046ac)
- Pre-Release v9.3.13.dev2 [`35791f4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/35791f42a3d768cceaac2a3868f3657360490124)
- Merge tag '9.3.12' into develop [`212c0c6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/212c0c62b227f9ae248c4ad1e7a3a1ca0571da1e)

#### [9.3.12](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.11...9.3.12)

> 29 April 2018

- Release v9.3.12 [`3a13aca`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3a13acaffb09e0979baac260ee10454670b729a5)
- Updated sentry api url [`03e1ced`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/03e1cedd38876c78f78c9e2d344fc00c9da863c7)
- Merge tag '9.3.11' into develop [`7419ff4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7419ff4c444b2674a4687dc6eec6bc234e30b9d0)

#### [9.3.11](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.10...9.3.11)

> 29 April 2018

- Release v9.3.11 [`de5e70f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/de5e70f8b0a7237825c0b38493562a2215a97198)
- Fixed log level of sentry logging handler to log errors only [`ae29eb5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ae29eb58b1d40a230ed68236ec2f348363065590)
- Pre-Release v9.3.11.dev1 [`bebb5f6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bebb5f668d8c70ba89d552cdfd74881413486bf8)
- Merge tag '9.3.10' into develop [`58d0f20`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/58d0f20cc4ad27f2f272124d370230b22bcb202b)

#### [9.3.10](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.8...9.3.10)

> 29 April 2018

- Release v9.3.10 [`bcac79f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bcac79f5605f9b1e5bf3a02fa3e10d17ceb544fc)
- Merge tag '9.3.8' into develop [`f1ba80a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f1ba80a55c288f1c9e99106f6ca64cc18edb589a)

#### [9.3.8](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.7...9.3.8)

> 29 April 2018

- Release v9.3.8 [`79bf6f6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/79bf6f61d5c61d611441bb2eba0952187a936dcc)
- Merge tag '9.3.7' into develop [`8cc8b62`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8cc8b620f822731e4dc96cdbb4c9b87ef97acc9a)

#### [9.3.7](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.6...9.3.7)

> 29 April 2018

- Release v9.3.7 [`fd43837`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fd438372f2c3ecd85d855beb9c14bdecd1be370a)
- Merge tag '9.3.6' into develop [`db2d8d0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/db2d8d0b7a252ac1da697c41d77e1428a848a8f8)
- Pre-Release v9.3.7.dev2 [`0d890f1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0d890f1a07215ce69da5f24bb3186d8475cb8baa)
- Pre-Release v9.3.7.devNaN [`7b8402e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7b8402e4bff048a73338f2da1f86f6f3591dabb6)
- Pre-Release v9.3.7.dev1 [`f77cf2d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f77cf2da65de31a0ee847e1ba668bf9b9ed0111d)
- Pre-Release v9.3.6.dev1 [`3afe2b6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3afe2b6d8aa0b0dcb8da7570becf96cd7cb0c660)
- Pre-Release v9.3.7.dev3 [`b9546e2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b9546e2c823a931243362f15f9bab6c212f3acfb)
- Code refactoring for backlog and daily searches [`9f2aac1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9f2aac1b5c3b2f34452b8a7f2e350018df4d25f8)
- Code refactoring for backlog and daily searches [`26ab1dd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/26ab1dd3e9b231b1274355de9b775ed12b211a86)
- Daily searches hard-coded to search from todays date and greater [`37d5cd0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/37d5cd03336d1155965d10fb96999891a98a266f)
- Fixed issue where cloudflare bypass would loop when unable to bypass [`40c2bce`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/40c2bce256cc897790ecf8e050a4b6cd35d70c0b)
- Fixed issue with stuck current item in queue [`be6173b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/be6173b254f8b7886832e84f0f810288f76b4bdf)

#### [9.3.6](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.5...9.3.6)

> 21 April 2018

- Release v9.3.6 [`ee7b8bc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ee7b8bcd28dd215c332a430ac684862ff8dad070)
- Backlog searches no longer trigger cache updates, speeds up searching [`04cf1ef`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/04cf1efe6da932297a0fce1811f9bbed9313be3d)
- Manual searches and Removal of shows now take extreme priority in queue [`aa08e0c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/aa08e0c368730cfc37fd4913288ae3f8f6c736eb)
- Daily/Backlog searches now skip downloaded episodes with higher quality then show's set preferred or best. [`c32702b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c32702b0fb9e099579fff0efa42987cbc8ea42ab)
- Manual searches and Removal of shows now take extreme priority in queue [`b96a3f9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b96a3f9ea7ff9daf29baca3a6f0699a09200d3d8)
- Manual searches and Removal of shows now take extreme priority in queue [`9e76bc0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9e76bc0a0a5d34d7ed3bac473a405c5b7ba98bea)
- Manual searches and Removal of shows now take extreme priority in queue [`a7210e4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a7210e46cb4799723e9c902db8bf9322ba1b83ac)
- Manual searches and Removal of shows now take extreme priority in queue [`e8cea87`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e8cea87b0eb47c706900ca2d91a233ebd389998d)
- Merge tag '9.3.5' into develop [`fbdf6f9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fbdf6f9fb05f8c7b85d38fbd48e9c34da146d1da)

#### [9.3.5](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.4...9.3.5)

> 10 April 2018

- Release v9.3.5 [`57b8a79`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/57b8a7922b29693dc07d7972036064f1bf1e2f15)
- Merge tag '9.3.4' into develop [`c5476b3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c5476b38f539467b1c7cd3a6371ee2a5ba8be70e)

#### [9.3.4](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.3...9.3.4)

> 7 April 2018

- Release v9.3.4 [`c056018`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c056018b1002d12ae4bca8518f27978b670b6db5)
- Resolved issues for post-processing already processed compressed files [`a5e76f4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a5e76f4b1a5007af257a74128b74f83edf61f99f)
- Merge tag '9.3.3' into develop [`e4a0cac`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e4a0caca812f27ad4fee0f9fed68fa922717a6f6)

#### [9.3.3](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.3.2...9.3.3)

> 27 March 2018

- Release v9.3.3 [`8c8feea`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8c8feea039d0b41dcc5ab7ba342c5b0e1183c87e)
- Fixed issue #187 - Qbittorrent failing authentication [`b6885a5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b6885a5d3b95ad387dfffdceec958c11c9d1c39a)
- Merge tag '9.3.2' into develop [`9c4ff81`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9c4ff81be2ae93420873dae10d5d16fea0b3fd33)

#### [9.3.2](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.101...9.3.2)

> 21 March 2018

- Fix call to generate_bwlist on save [`#9`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/9)
- Release v9.3.2 [`f546064`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f546064ed7ae9a67e0659e00fe3fe2b1919bef89)
- Minor code update for provider cookie handling [`98fa8b8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/98fa8b849b57d810eae2aee5805ab847f1048976)
- Fixed issues with cloudflare protection not being detected [`23df733`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/23df73395afc276cc39417670bf1910cf27ca654)
- revertFailedEpisode changed to use debug instead of warning for episodes without previous snatched statuses [`54cc664`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/54cc664f0d207b5080e4bd93e2098021933a82fe)
- Fixed small typo in daily searcher code [`e0fa39e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e0fa39ef348c2e24a4be843e073684698835d1a4)
- Fixed small typo in daily searcher code [`cc43195`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cc43195a81e2c96e01522b13c435eae3e5e2570f)
- Updated .gitignore [`fe0d03b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fe0d03b2980e3e37394274a47b2fd5f771eeb50c)
- Merge tag '9.2.101' into develop [`64d1dcf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/64d1dcf3cbd658adf1f8df0ede7dc771053dbcfe)

#### [9.2.101](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.100...9.2.101)

> 8 February 2018

- Release v9.2.101 [`aa7292f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/aa7292f10a8590f923c3d280087e1c990abc363f)
- Merge tag '9.2.100' into develop [`c0cde58`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c0cde58f4957e6b8393006ed8183078ece1b6875)
- Fixed issue with next airdate and main show page [`f50e104`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f50e104e4f339f74ac2f4650a025ed6b8a4aabb6)
- Fixed issue with next airdate and main show page [`c912546`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c91254644468ee85e703fb9c72510c300b33ec12)
- Fixed issue with next airdate and main show page [`e9494a7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e9494a7b959255dab3b312aae43b55fd754597cb)
- Fixed issues with backlog and proper searches [`c94ad9f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c94ad9f4481a056c9a704ee875becb565a7269e7)
- Fixed issue #176 - autocomplete colors when using dark theme hard to see [`b608667`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b608667834b1b228a5fe1efade0e590e1ba05f5d)
- Fixed issue #176 - autocomplete colors when using dark theme hard to see [`e73b9af`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e73b9afd5226b719e0152dee2e74cb0c93fcf1b8)
- Fixed issue #176 - autocomplete colors when using dark theme hard to see [`e77ea77`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e77ea77e99f716e731dd7181e4818815e5767016)
- Fixed issue #177 - case-insensitive sorting for drop-down show list [`372b59e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/372b59e4ffef6050ac0c19d35e4f69ec06a7f464)
- Fixed issue #175 - autocomplete "Enter the folder containing the episode [`2c89486`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2c8948673931a75cba6d61ada820f5b4072907de)

#### [9.2.100](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.99...9.2.100)

> 31 January 2018

- Release v9.2.100 [`c5bee33`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c5bee33a32d22f60d0d4f14a06ceaa6ccb2d543d)
- Fixed issue #170 - double popup on hover over network in show list [`c91e143`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c91e143363c90de07ccb8466c9e477f6a9bd3719)
- Merge tag '9.2.99' into develop [`de1b8fe`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/de1b8fe0c86877b63378380112c9ebd660189859)

#### [9.2.99](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.98...9.2.99)

> 23 January 2018

- Update torrent9.py. [`#7`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/7)
- Release v9.2.99 [`dff6cff`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dff6cff14c5ad0258408c45d536b0f011caca402)
- reverted requests['security'] to requests requirement, was causing issues for synology devices [`d076678`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d07667815b5b2cb4a5e0dc4d37eaccd7c8edf76a)
- Merge tag '9.2.98' into develop [`d7b68b6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d7b68b638ce3c4e284d823a3b2876dcf111a6210)

#### [9.2.98](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.97...9.2.98)

> 20 January 2018

- Release v9.2.98 [`016ec81`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/016ec8165aeb1f155e5660386373926ff72e6dd4)
- misc range to xrange changes [`0ebcc19`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0ebcc1961bf37968450a46d7d3f3d89053a3e199)
- Fixed missing token error [`927c3c0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/927c3c0d10cd981225c9641cb388cc9cbd490e22)
- Fixed missing requests security requirement [`b8fabca`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b8fabca0c3a51a973ab8b69f5fbd7440c0060bd0)
- Merge tag '9.2.97' into develop [`3c3f2c7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3c3f2c76a29c2899c653b607f56ba5f70e88fed1)

#### [9.2.97](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.95...9.2.97)

> 18 January 2018

- Release v9.2.97 [`7cf97c1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7cf97c114264fe46e75b327ad6b7cf15ddb5fe5f)
- Merge tag '9.2.95' into develop [`3d4a008`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3d4a0080aa44a60414024026614b5db8f5b8dac2)

#### [9.2.95](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.94...9.2.95)

> 15 January 2018

- Release v9.2.95 [`b8ae4e8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b8ae4e83ddc79e722575a92ba74735a1d0b6b0e8)
- Fixed issue #167 - PreconditionsException when saving IMDB info [`70d1ecc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/70d1eccc4eba0f0aa3f3785a5b2c663af54efb5a)
- Fixed issue #169 - Missing parameter: "refresh_token" is required [`0817995`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/081799575c2bf93e2c44506eb10649a89b3be04f)
- Merge tag '9.2.94' into develop [`b882ef1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b882ef1cc400b56ef987881752c8f78c4b0a2f9c)

#### [9.2.94](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.93...9.2.94)

> 12 January 2018

- Release v9.2.94 [`4931383`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/493138316a8b9c8f41b0371dec3c0288c81f0f45)
- Merge tag '9.2.93' into develop [`5d7c0ba`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5d7c0ba570ea62ff4b84b6bf3aece3c6a0a5a0da)

#### [9.2.93](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.92...9.2.93)

> 12 January 2018

- Release v9.2.93 [`deedce0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/deedce044df20a09e8e109ad6ee4704301c36eb9)
- Fixed issues with refresh token when using client credentials [`2af9433`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2af9433efafd46be36fcdf41c1909c2188e059e0)
- Fixed issues with refresh token when using client credentials [`c9449f9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c9449f938fdcae68d8ce58e9b965210b38b775c6)
- Merge tag '9.2.92' into develop [`2f72882`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2f7288240d52483ab534f23f87080da8a9373032)

#### [9.2.92](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.91...9.2.92)

> 12 January 2018

- Release v9.2.92 [`dae404d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dae404d8b2b9cea85a26c4b0872644c41af58a47)
- thread name added to UI warning/error messages [`8bbd2b2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8bbd2b2e63ae9b7135b01f7c8908b18827eb4619)
- Updated requirement psutil from 5.4.1 to 5.4.3 [`b48dd3f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b48dd3f1531bd4276c7012eb9b11dbe4cb509b30)
- Merge tag '9.2.91' into develop [`3a2cc77`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3a2cc77b88f749940b28fcfbb5dc60c2421b6787)

#### [9.2.91](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.90...9.2.91)

> 7 January 2018

- Release v9.2.91 [`1c36a65`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1c36a65f80cd8aa51914f317b4a788e3c6288c05)
- Fixed issues with air-by-date shows not properly being parsed for episode numbers [`8cdd6f2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8cdd6f23d0c3940a5b48a9d345a91873aded90a1)
- Merge tag '9.2.90' into develop [`ec51e1a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ec51e1aff290f2c85ae29d3cae15634335160ad7)

#### [9.2.90](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.89...9.2.90)

> 4 January 2018

- Release v9.2.90 [`17ae529`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/17ae529ed59ab7ba04d62bc70d0a7a79c3c027e5)
- Merge tag '9.2.89' into develop [`94c04e8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/94c04e8fc14642dbc584adf07a9e4c1cf3ff3499)

#### [9.2.89](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.87...9.2.89)

> 4 January 2018

- Release v9.2.89 [`6d49779`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6d4977973a2b1913d60adefc830f9b3d37c493e0)
- Fixed __getitem__ error for managing episode statues [`3a38155`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3a381551601b9a1a93d5578725ed1333199c1037)
- Refactored restart template [`5e417d2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5e417d24a1bf97ee7c2b05be638ee285cbdd509c)
- Refactored restart template progress bar to increment by 1 percent [`81ded5d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/81ded5d444e51f0786fa35f8740c34bc146c3dfa)
- Updated imdbpie requirement to v4.4.2 [`5a2f6c5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5a2f6c55a8545cbbe6fcd642e1c5f152fbb5399b)
- Refactored restart template progress bar to increment by 1 percent [`1e25dae`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1e25dae34e7da338986516637b777ccb046e4a0a)
- Merge tag '9.2.87' into develop [`4c14747`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4c1474786989eb5b02e11a78f674f7c297af202f)

#### [9.2.87](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.86...9.2.87)

> 26 December 2017

- Release v9.2.87 [`975d890`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/975d890f93135293e40c2dfd4187847713c72ff0)
- Misc cleanup [`15ec220`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/15ec2204a517486d61a18718112f44eeb8554877)
- Merge tag '9.2.86' into develop [`1de214c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1de214cb5bc5d8862b066462a3ed321967c7f4c4)

#### [9.2.86](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.85...9.2.86)

> 25 December 2017

- Release v9.2.86 [`1475c1b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1475c1b7a1cdcbaa0e40d0fa4ea1b23e8ce2728a)
- Merge tag '9.2.85' into develop [`224a5e1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/224a5e12dcc8b3503b0b3a421603307e68546e89)

#### [9.2.85](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.84...9.2.85)

> 25 December 2017

- Release v9.2.85 [`a5944f1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a5944f11b106a0c90b3b21d74ae57913f4b31479)
- Refactored restart template to be bare to avoid template errors on updates [`4c548b6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4c548b623cc8379ff3882bc6cd4ec23a66002dcc)
- Refactored changelog to modal popup window [`552c936`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/552c9363af05b27ef232135eb1789dd156236b26)
- Refactored restart template to be bare to avoid template errors on updates [`1b9b39a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1b9b39a65dbc34e3d0695cccd08642a4bfb90cff)
- testing changelog viewing [`cd76821`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cd76821a11f68e8e2cb270a99c2a2da42307aed2)
- Merge tag '9.2.84' into develop [`ec666d8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ec666d8e06e4420123704dba39b284a20f41610d)

#### [9.2.84](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.83...9.2.84)

> 25 December 2017

- Release v9.2.84 [`ced2fd5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ced2fd54646de405208f43c066e3ff06f87c4e40)
- Merge tag '9.2.83' into develop [`2f212c6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2f212c60a49fad0473f97fce3f03280ccd23e566)

#### [9.2.83](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.80...9.2.83)

> 25 December 2017

- Release v9.2.83 [`bf259dc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bf259dcaee1005f8e7ec61374c2af7735ffcbacf)
- Updated more requirements [`0032372`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0032372d2df8928a0b9b7ca53b5e09ecbf246b3c)
- Updated requirement imdbpie to v4.3.0 [`c73c554`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c73c554ba27395ef6393cf98a74b5d4a31598a09)
- Merge tag '9.2.80' into develop [`c5654c3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c5654c3342999129ce52e2d50fcd8a491d7376c0)

#### [9.2.80](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.79...9.2.80)

> 23 December 2017

- Release v9.2.80 [`b592d44`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b592d44951cf9be6e4980534b8f1438ceec834a7)
- Merge tag '9.2.79' into develop [`1f4c8a8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1f4c8a83358277f66c9530ccaf8fe81cf34bdccc)

#### [9.2.79](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.78...9.2.79)

> 23 December 2017

- Release v9.2.79 [`f8908fd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f8908fd062b08b9d007039e6b47ea589bf2d370c)
- Merge tag '9.2.78' into develop [`a62808d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a62808d8ae2fb5779d8d6add0fcff4eed9d8faf5)

#### [9.2.78](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.77...9.2.78)

> 23 December 2017

- Release v9.2.78 [`484002a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/484002a2f7c0d0c123ecaa9451cb8d7b1a71d2ea)
- Merge tag '9.2.77' into develop [`643d44e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/643d44e95bd66fbd7f22910f55f4b5c048668855)

#### [9.2.77](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.76...9.2.77)

> 23 December 2017

- Release v9.2.77 [`5439184`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5439184faa7f332a0f827c288993e693daee4f3a)
- Merge tag '9.2.76' into develop [`2657da2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2657da2451530a85cbae86992c992ddd21b17cf8)

#### [9.2.76](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.73...9.2.76)

> 23 December 2017

- Release v9.2.76 [`d1d0033`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d1d0033a73595df29751e7dc8b862bc1b75bcfa5)
- Merge tag '9.2.73' into develop [`d7764cf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d7764cf4ad6e85be60d423190c5400f78db8195b)

#### [9.2.73](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.71...9.2.73)

> 23 December 2017

- Release v9.2.73 [`bad836b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bad836be8b2a9f1fcaa793d630fbd2ad76186acb)
- Merge tag '9.2.71' into develop [`3c59887`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3c59887ed675d51303e78d47c178de1c31d2f970)

#### [9.2.71](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.70...9.2.71)

> 23 December 2017

- Release v9.2.71 [`0eaf7ee`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0eaf7eea2a948a88122956d514f3a29de283f1b2)
- Refactored core js code [`9dce9e4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9dce9e45836819ebd784413c33bc92729cb32b42)
- Merge tag '9.2.70' into develop [`9f2d905`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9f2d905ccd1d946b622fe435f5bf42ca8c20e28c)

#### [9.2.70](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.69...9.2.70)

> 22 December 2017

- Fix for torrent9 provider [`8ca1761`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8ca1761ef40cdb019b7866864cd5e71158743837)
- URL validation for provider search results added in to code [`c1e9c48`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c1e9c486bfe8df97f3e1206e07808e9e40ac0e5e)
- Release v9.2.70 [`d41046a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d41046ab0394348e82ec03cd3868f6d607fbdd93)
- Fixed issue #155 - version updater bar not showing [`d07716c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d07716c031de0e664ec47aec5aa5b307a788e1c5)
- Fixed issue #155 - version updater bar not showing [`a022118`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a02211827de5a0e3cd31284b3a89e777b1599b09)
- Merge tag '9.2.69' into develop [`ebc535c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ebc535c1eca44b244ff6e9023213cc69c04d9783)

#### [9.2.69](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.68...9.2.69)

> 21 December 2017

- Release v9.2.69 [`af0e32e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/af0e32e04d45b825376cdb1567990c7c1a9052e3)
- Fixed issue #159 - Error parsing provider newpct.com [`7733262`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/77332628337f9a08ce514e408e0c0132b81ee70c)
- Fixed issue #159 - Error parsing provider newpct.com [`7dcd312`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7dcd31271022465d3073776efb0f5f287c9a8f15)
- Merge tag '9.2.68' into develop [`684716d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/684716d6a4669f6c0c151c5089f7a0846f621fbe)

#### [9.2.68](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.67...9.2.68)

> 21 December 2017

- Release v9.2.68 [`c3eb182`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c3eb182be68240807060db1e582ba2d3ca2ce891)
- Merge tag '9.2.67' into develop [`ce10150`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ce101505ce9f7cfb336225843bc06abd1bcb1dcc)
- Refactored cache search function to handle multi-ep results [`7aa5593`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7aa5593001962d3e619caee6900917f4b50c61c8)
- Updated status page to work with new scheduler code [`19a9760`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/19a9760326e4ba40a24091d7b911402bfdc8f9d2)
- Fixed IOLoop to use current instead of instance during init period [`cea3a5e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cea3a5e556b05f3fbb226df997e56594e146f6d4)
- Replaced main loop with IOLoop [`3bc75b9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3bc75b90213f88c611bf63dc6b28df16d4aaaa4c)
- Replaced main loop with IOLoop [`e3f5f76`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e3f5f762044487cbb890592e4db6146db5e66ffc)
- refactored post-process variables [`328e9d8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/328e9d85eaf571559f4d18d1bf779217f06f0cba)
- Pauses background jobs while post-processing then resumes when finished [`def31cf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/def31cf3bd6785efdffde6ae720c9818e2bc889c)
- Pauses background jobs while post-processing then resumes when finished [`52d9960`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/52d9960bf18bb92ccf629f090458c5dbdc387da6)
- Pauses background jobs while post-processing then resumes when finished [`ba50828`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ba508285e347fb2746ff0efcb0bf7ea8767b1c91)
- Fix for issue #155 - display notifications when updates are available [`16a7332`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/16a733282980d1b56c0e1b6f5d93f2dce8fcd414)
- Fix for issue #155 - display notifications when updates are available [`bf5179f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bf5179fc1acb476fed522251b3052e5b5aae0b71)
- Fixed issue #141 - show/hide seasons in display show page [`611ea99`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/611ea99e1c67c906900ad793b9905f4ee35222d0)
- Pauses background jobs while post-processing then resumes when finished [`9e6831e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9e6831e3de94b3f182be4bd93c1217b0281270cd)

#### [9.2.67](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.66...9.2.67)

> 17 December 2017

- Release v9.2.67 [`3b4302a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3b4302abcaa3f08962cae0d93fc8037ac2ee68ab)
- Merge tag '9.2.66' into develop [`5649d4b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5649d4b990f8c5c473cb36045d1d07f60f90fd9f)

#### [9.2.66](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.65...9.2.66)

> 17 December 2017

- Release v9.2.66 [`5f48f83`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5f48f837a16b68b15a5a516b3c94510326c8d87c)
- Fixed issues with unrar and windows platforms [`313d7fd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/313d7fdba97c7449dd775156b3e3dad9aea251f4)
- Fixed issue #153 - Checking delete files when removing a show didn't actually delete the files [`7682ad1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7682ad1cb1cad372f8e57741ddf7aeaa24570f3b)
- Merge tag '9.2.65' into develop [`40fbb92`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/40fbb92a38d47e4be2fbf1c6cba563a23ab8a94f)

#### [9.2.65](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.64...9.2.65)

> 16 December 2017

- Release v9.2.65 [`3c60c67`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3c60c67e009bfae9ec47920d01c4e2076256d1bc)
- refactored torrent cache api calls [`1c5d901`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1c5d90188aaed7430abc1512cc996d59ea9d76ab)
- Fix unicode issues for Newpct torrent provider [`bb8a5b8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bb8a5b8a31728e7fb8e4c8ede5316b8bff2167f3)
- refactored torrent cache api calls [`e5ee3a3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e5ee3a32a69e7c15279111764a7aa5ec5308f16d)
- Fixed url issue [`d53ccb0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d53ccb0c81c01bf9808d8d92a6b8d86541d51051)
- Merge tag '9.2.64' into develop [`774a253`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/774a25363d7e0355664266284fc1d169cc877787)

#### [9.2.64](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.63...9.2.64)

> 15 December 2017

- Release v9.2.64 [`032e9ed`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/032e9edff5cfcb51e665b7712fc472be080a6730)
- Merge tag '9.2.63' into develop [`e6b8105`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e6b81056ebec09df5376c4b59cce7bb2f928e2b9)

#### [9.2.63](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.62...9.2.63)

> 14 December 2017

- Release v9.2.63 [`9d35ea1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9d35ea1b11b05bbac29756d48019d7d486080e9d)
- Merge tag '9.2.62' into develop [`c24bfcd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c24bfcd456b3f99d681fd0e8a6c222999a881bb5)

#### [9.2.62](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.61...9.2.62)

> 13 December 2017

- Release v9.2.62 [`20416e1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/20416e1b54816992410f1476073d45e87f682346)
- Merge tag '9.2.61' into develop [`db0e196`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/db0e196bdb4d7d55ffacb2334b29976dafc34260)
- Fixed issue with thread naming for post-processing [`2c6c207`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2c6c2079370b995c29b362dea0d7ca1b3944cd57)
- Fixed issues with failed and cache database md5 checksums [`8923500`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/89235004066fda4e8443148dffc899fbba2f51c5)
- Fixed issues with failed and cache database cleanup on new revs [`93c5ad5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/93c5ad51ec23ff27dd8fe4bc2569754cbd26d366)
- Py3 compat for queue [`b922499`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b922499a44be30abce4b789c76aae99d7a3780c5)
- Updated misc provider code [`7b19a3c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7b19a3c99e3f0a2e6293e240898ac573fc167716)
- refactored remaining database calls to use custom database calls [`3f23fd2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3f23fd2ba9b84436b5163f9a60d139ff64ea6580)
- Fixed issue #151 - using unicode instead of str to result post-process results [`cf0821c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cf0821cde9679e27c7b105b815bf244e2931f79f)
- Refactored database calls, resolves memory usage issues [`4323d84`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4323d84486972a8de38bec1e20bc31a9a6f441d5)
- Fixed issues with removing duplicate shows and episodes [`8e43de8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8e43de8936695c121f1efde28eeb056be06ccba6)

#### [9.2.61](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.57...9.2.61)

> 10 December 2017

- Release v9.2.61 [`f2d7dc6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f2d7dc6a2139cd3b1b4b18749c85e2ffcbd1771b)
- Overall stats now only displayed for main shows page, helps reduce overhead [`656a038`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/656a0382816a635a7efc2fbb5011779bf83e6c95)
- Merge tag '9.2.57' into develop [`33f6d48`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/33f6d48ab308283cb88d65118acc2232ad3665cf)

#### [9.2.57](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.56...9.2.57)

> 10 December 2017

- Refactored Full Update function to now update/overwrite existing metadata [`f376394`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f376394afeb846230373e23e5b5431428d6ea205)
- Release v9.2.57 [`75fa296`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/75fa2966d5f22ee4234f755fdae5dea5c21d6724)
- Updated git ignore file [`9596e8c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9596e8c6158bf4a25aefedfdbeafe3db643ba708)
- Merge tag '9.2.56' into develop [`71895b0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/71895b0949d77ca056a17d689151688d9d750f34)

#### [9.2.56](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.55...9.2.56)

> 10 December 2017

- Fix for name parser anime issues [`f2405ba`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f2405ba0a015096254311101149ebe90844374bb)
- Release v9.2.56 [`2cd63ba`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2cd63baa48ca00b51ab22e901c7f5d1904a9c8ce)
- Merge tag '9.2.55' into develop [`9f644cb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9f644cb34583bfb3546bde0ca0600b402a8c24f3)

#### [9.2.55](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.54...9.2.55)

> 10 December 2017

- Release v9.2.55 [`73ff883`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/73ff8835752ff9f97684ffe13673fd915bf9cb80)
- Merge tag '9.2.54' into develop [`aa883bd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/aa883bdb3d34dd0afe5e2f1021eac5859b81d00d)

#### [9.2.54](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.53...9.2.54)

> 10 December 2017

- Fixed name parser show validation issue [`0728a1e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0728a1e00c5bd7d6a2e48d99ba1e1d810cde8a34)
- Release v9.2.54 [`d4b4aab`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d4b4aabd3b5fd4dc69be8e5cd968d2fdb82df43b)
- Merge tag '9.2.53' into develop [`9173003`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9173003ba04d26ccc49e46cf35fd4bcf178d06df)

#### [9.2.53](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.52...9.2.53)

> 10 December 2017

- Release v9.2.53 [`e096f6c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e096f6cc841ab116e5ed8b75973d71310367ea9e)
- Fixed issues with name parser and naming patterns [`750a56d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/750a56d9d70bbfa0a54fcda78444e8300f694e44)
- Merge tag '9.2.52' into develop [`d4bf567`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d4bf56740e0eaa2a6ee70f3091010af34a5385b4)

#### [9.2.52](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.51...9.2.52)

> 10 December 2017

- refactored nameparser function get_show to be more efficient [`f0d6a3c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f0d6a3c65b507dd637af2ffd6aa367066e293b9b)
- Fixed name cache, was incorrectly loading database info [`96f7a4f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/96f7a4f24f17d237eb789c93b4d95675d6ef6089)
- Release v9.2.52 [`4346486`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4346486fb81f92b11d204ba4114a6584402d937a)
- Merge tag '9.2.51' into develop [`5653abe`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5653abe2f506ab87bb2a932180e41f29150afebe)

#### [9.2.51](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.48...9.2.51)

> 10 December 2017

- Fixed issues with HoundDawgs torrent provider [`5faefa1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5faefa19a96ef388c896ed710f3618c69ab8ed30)
- Fixed issues with validating search results from providers [`6493584`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6493584a5c5bbb2e241a4b9a069e81fbff4dadfa)
- Release v9.2.51 [`f893d27`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f893d27e33b349a3d56e11696aae0d8d0b08bca1)
- Fixed issues with validating search results from providers [`895ef68`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/895ef682a3f05e3c13289179f90d4529e00e063c)
- Merge tag '9.2.48' into develop [`3b1e211`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3b1e211d2df71b726c560adec636248a5d98dcc3)

#### [9.2.48](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.47...9.2.48)

> 9 December 2017

- Release v9.2.48 [`2626c5e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2626c5ef91edc82b073c42eecc0f5d71297c4ffb)
- Merge tag '9.2.47' into develop [`761162d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/761162d70a35bb352a85683603e62c1921f29b6b)

#### [9.2.47](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.44...9.2.47)

> 9 December 2017

- Release v9.2.47 [`654ae73`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/654ae739658bd7b6dc1a6f4bae4979dec653b38c)
- Merge tag '9.2.44' into develop [`cfac40a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cfac40af498c831de21877f6b682d43f771304b9)

#### [9.2.44](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.43...9.2.44)

> 8 December 2017

- Removed get_files function from providers to stop hammering provider api's [`01eb76c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/01eb76cba40029951e9f1492b944cd8b731a98ad)
- Fixed issues with make_url provider function [`e394ae7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e394ae752d4a9e02695e7a1701b08fc6ec90b69e)
- Release v9.2.44 [`d651b54`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d651b54300157a890e46beee7b49870817c9eeca)
- Fixed issue with picking best result [`59217e6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/59217e6cf20aaa13da9555d8b148eda27fbc998e)
- Fixed issues with make_url provider function [`acfef1e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/acfef1e12607c41cc76de3bb79376465b1212a04)
- Merge tag '9.2.43' into develop [`2d7217d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2d7217de758c90aa9bddca3063bbd2da4e12f5fb)

#### [9.2.43](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.42...9.2.43)

> 8 December 2017

- Release v9.2.43 [`bb5d189`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bb5d1896a6692a4c1a2fe68af01060a7c2b4fcc1)
- Fixed exception handling for post-processor [`2a9bb7e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2a9bb7e5cb14ceee920d23d4e1b0308d730d9f6a)
- Updated provider icons [`8de7690`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8de7690ada0450c41dcf2e21fb779ff89d6f1dc3)
- Merge tag '9.2.42' into develop [`e7e7ada`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e7e7ada6e617a11c465f8135d1abe2c52c042f5b)

#### [9.2.42](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.40...9.2.42)

> 8 December 2017

- Removed unrequired nextEpisode function as code was migrated into next_aired property function [`d1004fc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d1004fc7a6142d4de144734be8ed8d4e0862e0e7)
- Fixed issues with saving episode thumbnails [`78435a3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/78435a30fa41b7403245fa3ee8eea255b8117ec1)
- Release v9.2.42 [`d31018c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d31018c7dc56ebbc24731d7a9ec5bdca7c0d4b0c)
- converted bt cache url scheme to https [`7c1c460`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7c1c4605487d26d81f0990eb5c5d0a2ba93bdd8d)
- Merge tag '9.2.40' into develop [`c49a72b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c49a72b30701dd192440b994aa25f566c62c2bcf)

#### [9.2.40](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.38...9.2.40)

> 6 December 2017

- Release v9.2.40 [`9ba97d5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9ba97d537fd8f3a0cd8add0c78a6647c3dbe1130)
- Merge tag '9.2.38' into develop [`ccf8941`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ccf89419ce3fc9e55ddf4fdc9f9f568d18e79d58)

#### [9.2.38](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.36...9.2.38)

> 6 December 2017

- Release v9.2.38 [`5fdb6d9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5fdb6d93994d3688b2fd5c41b43df09420bfc064)
- Merge tag '9.2.36' into develop [`8bb08c3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8bb08c329837cd78bff26001442a0880a624dd6b)

#### [9.2.36](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.34...9.2.36)

> 6 December 2017

- Release v9.2.36 [`eb795bd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/eb795bd6c16f470177a9e07d8466908f8d5055a9)
- Fixed issues with splitting shows and anime [`418d40b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/418d40b0fe8ed108383e78b7916c032d1f6b419a)
- Merge tag '9.2.34' into develop [`dacb36b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dacb36be513a9d4db1a0b7e2fa45f016f2756620)

#### [9.2.34](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.32...9.2.34)

> 5 December 2017

- Release v9.2.34 [`5b78ac9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5b78ac9b418834871fe709a23531d30a54c0de98)
- Fixed attribute issue when trying to manage episode statuses [`80e8622`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/80e8622555cf1da5eeffc6da6b951fab2150d219)
- Merge tag '9.2.32' into develop [`adf6f90`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/adf6f90b36da5466f2627e627d20ed4ea9b7d93b)

#### [9.2.32](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.31...9.2.32)

> 4 December 2017

- Fixed encoding issues with list_associated_files function [`b300f9a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b300f9ac36a8d63fd38b0925cef2e36048a13754)
- Release v9.2.32 [`e461330`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e461330a967048fd5b528521cbd69e2ade4ccd6c)
- Merge tag '9.2.31' into develop [`361b469`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/361b4691190ab007adc84c1c63850dc4e07deee6)

#### [9.2.31](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.30...9.2.31)

> 4 December 2017

- refactored elitetorrent provider code to resolve quality parsing [`ace1b62`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ace1b62cb59c184ec9fb17f28f2c41dcaa32426d)
- Release v9.2.31 [`c3626f7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c3626f7e7ae93111942051f277b845b3583c5f70)
- Merge tag '9.2.30' into develop [`fe70809`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fe7080954cf541449362dc3189b63e0da8554309)

#### [9.2.30](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.29...9.2.30)

> 3 December 2017

- Fixed typo in ComingEpisodes function, caused schedule to not display [`7e76b60`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7e76b6009f8d25547fb5bc1963e13aad06e76a59)
- Release v9.2.30 [`d3bdc71`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d3bdc71b3c1fde750fda02123cd7c4a634f82e4c)
- Merge tag '9.2.29' into develop [`acb8731`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/acb87310c708b808760bfd301f5f59249bff7c3b)

#### [9.2.29](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.27...9.2.29)

> 3 December 2017

- Release v9.2.29 [`c3e3a2e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c3e3a2ea6afb121de0271bfbd9045d88b012ce5e)
- Fixed issues with memory usage stats, added fallback code [`aa476aa`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/aa476aa5f6f04c53b21932d9d62edf6e1391d459)
- Merge tag '9.2.27' into develop [`a3d2faf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a3d2fafb03eb5f97a83e9e63dc79767acca57d3d)

#### [9.2.27](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.26...9.2.27)

> 3 December 2017

- Release v9.2.27 [`75c2b2d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/75c2b2d393166ac1e0ab98acb1f125e82d3c15fe)
- Merge tag '9.2.26' into develop [`20e3e66`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/20e3e66b81fb6f4f4277d10619c3f780f592c14f)

#### [9.2.26](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.25...9.2.26)

> 3 December 2017

- refactored xthor torrent provider [`56fe035`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/56fe035804994964d38bb6b62a2c561bf4deeeee)
- minor change [`3d55f82`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3d55f82f408746e4317fe80a2e8837d36812a8cc)
- Release v9.2.26 [`1f01aa0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1f01aa0941f633e8c4f2852fb087021da9a3bfdc)
- Fixed maximum recursion error caused my new next_aired property code [`f7963ce`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f7963ce1d7111e3c800709bb7230f06eab67d566)
- Merge tag '9.2.25' into develop [`413b876`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/413b87620ec484351de9e70df511d8735ff75818)

#### [9.2.25](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.24...9.2.25)

> 3 December 2017

- Release v9.2.25 [`5bdf6f0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5bdf6f08155887beabb091898b72b60a3d5454e8)
- refactored core variable showlist into property function [`f66447c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f66447cbba66b17aec1b907813b51b5b7c0e48bd)
- replaced database calls to show table to use core showlist reference instead, faster lookups [`38e9062`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/38e90623cb8bf38e78cd52cac4aa1e99203257ed)
- fixed issues with returning help docs for internal api [`c61c9d9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c61c9d9796db8c2bd60eb2dc3bdffce10b44e790)
- changed donation url [`4ea708b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4ea708bb706d2bd41f753f1296b420719d9e39c9)
- Merge tag '9.2.24' into develop [`e483592`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e483592bfa04fa7a12541fc4d61bcbae86deacdd)

#### [9.2.24](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.23...9.2.24)

> 2 December 2017

- Release v9.2.24 [`98f1f5f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/98f1f5f96a4c029a043b0d60a3863f3a327a47ab)
- fixed issue with downloading unrar when saving post-processing settings [`586c52a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/586c52a576221e70eb939295258bb033cba3520b)
- Merge tag '9.2.23' into develop [`6beccb8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6beccb8304f87581229094f45763e42c116b45ab)

#### [9.2.23](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.22...9.2.23)

> 2 December 2017

- Release v9.2.23 [`8a5f8c9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8a5f8c955c99eb561f321f2b515de7135665b83a)
- Merge tag '9.2.22' into develop [`aa2a24e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/aa2a24e303dba16d9fbd1d9e26a2d9c62e531dc7)
- disabled verifying private provider result urls to avoid excessive api hits [`bbd2f81`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bbd2f81376f843a1d2a56d79d0ae5e5fd4762ce1)
- disabled torrent9 provider tests [`a1d2e79`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a1d2e792aa3eef0cab66caf62a74509bca88506c)
- refactored provider test suite [`90cc105`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/90cc105fafcc84b8fdf6fa5709ea8fc5a907c5e5)
- fixed issue #138 - sessions not persisted for verifying provider results [`76c748c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/76c748c841386c7753b08e6408f0b5f8f58021c3)
- refactored docstring for api_calls function [`bfa12e5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bfa12e5dab286ef500277a498a65469723338dc3)
- fixed issues with custom newznab provider api key being saved as int when it should be str [`7470b66`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7470b66ce690c6da2174d6dc08d473cb3dc2a98d)
- refactored misc provider code [`2196912`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2196912c7ef03b4df36cbc730aae97a3b3bcb1c2)
- Changed code to set app pid of fork when daemonized [`a7a3fbe`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a7a3fbe01f57c15aa1f6f584584691e2cd41a2f7)
- Changed code to set app pid of fork when daemonized [`33496ce`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/33496ce5d0159406ff688b0d934680c802a1782c)
- Fixed unicode issues for mass show updates [`88bd49e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/88bd49e8b812c6c9e1a2e066a27571348ae2c533)
- removed code for getting torrent hash from search results, no longer needed [`3783124`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/378312477e8d7cb4d167eebeecd145a80699aa51)
- refactored api calls for built-in app api [`328e72e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/328e72e0396a3046fb59f6e16cac2220b23911c7)

#### [9.2.22](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.21...9.2.22)

> 29 November 2017

- Release v9.2.22 [`9b332e3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9b332e35ada25ed673cc57071846e2c047a3d42c)
- Updated provider urls [`92818b5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/92818b51f1941f68151a8a004c709fafaa796d9d)
- Fixed redirect 301 errors for scenetime provider [`8164abc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8164abc441c42ea37b212aab52db0e89d0651c00)
- Fixed issues with provider searches validating shows during season and episode searches [`be06534`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/be06534288d9330038307719384139431df85bcd)
- converted input box to select box for setting failed snatch age [`8f29300`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8f2930088bdb639843229800597703bcf1ea6406)
- Merge tag '9.2.21' into develop [`2926d43`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2926d43a351b84fdc979b63d0f4904aab972ba5e)

#### [9.2.21](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.20...9.2.21)

> 27 November 2017

- Release v9.2.21 [`7d0057f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7d0057f976234c81b37b0882fc479c9e2a4209ff)
- Merge tag '9.2.20' into develop [`d12d9ca`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d12d9cae32a6b0afdac1d41ad345d63b4fab9ecb)

#### [9.2.20](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.19...9.2.20)

> 27 November 2017

- Release v9.2.20 [`5ce3b85`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5ce3b85253116882cbaa37051669f93af89642a4)
- Merge tag '9.2.19' into develop [`aef462a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/aef462a5dfe87b255038a1f9656386f1fe3c09fa)

#### [9.2.19](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.18...9.2.19)

> 27 November 2017

- Release v9.2.19 [`31c5977`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/31c59779bf6f00d8c8b0849e8ecf54d90b7168a5)
- switched to using poster thumbs for poster view on shows page [`7015df3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7015df300e764b7060d5cb1508c98c4940340851)
- Merge tag '9.2.18' into develop [`ded9dac`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ded9dac21e4fc165b3e9686bb6ea65c37d3337a3)

#### [9.2.18](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.17...9.2.18)

> 27 November 2017

- Release v9.2.18 [`2028c51`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2028c51cd3248f081f5dea7b2911620cd3bbfdb2)
- Merge tag '9.2.17' into develop [`fe4ad21`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fe4ad21ae4e52d81103ff08fc8fa066f543f8ae3)

#### [9.2.17](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.16...9.2.17)

> 27 November 2017

- Release v9.2.17 [`3302be2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3302be2b45668153644dca82ac30f71fbe2d4b68)
- refactored misc function names [`0b308b8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0b308b83c85a6901367462c26a3c368fe40df22a)
- failed snatch handler now works correctly only for snatches 1hr old and no greater then 24hrs [`1554594`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1554594d834574acee065367976cc13d8da71f0f)
- check if instance is of list if not then make it [`35a929f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/35a929f9fdc7aa8a904782a887dbf98b18455856)
- fixed missing changelog_url attribute [`ba12e57`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ba12e57bf3d9cde3a1a1f89c018a50010d8cd031)
- Fixed changelog url issues [`a51d682`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a51d682633f7c4b1e35657209c08d9f8da6b918b)
- Merge tag '9.2.16' into develop [`ff39189`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ff39189d6bbedb0fa9e03a5eec06917c17e85ba4)

#### [9.2.16](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.15...9.2.16)

> 26 November 2017

- Release v9.2.16 [`f4f7da9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f4f7da9762df61f7160ce422bfa4f0e65945b0a6)
- fixed issue with associated file extensions view in post-process template [`95299aa`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/95299aaebaaae60546ab6c10d6ecdeebf58192af)
- fixed up docstrings [`044fc10`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/044fc107fc894344fec4d545b16dcdb8fb314791)
- Merge tag '9.2.15' into develop [`931b7a3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/931b7a37fbe00ef45f158d5120e785af8e7c2f19)

#### [9.2.15](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.14...9.2.15)

> 26 November 2017

- Release v9.2.15 [`a75d9c5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a75d9c51b2d1d3c393073768369268a9a5cd5cdb)
- refactored misc code [`ec6f4c1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ec6f4c1eed6ab16508e30ff899afcab4438d967b)
- refactored misc post-processing code [`8929263`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8929263068396d801beee91ae1989ca4e5f36b8d)
- refactored failed download handling to no longer be a optional feature as its a requirement for failed snatch handling to work correctly, delete on failed is defaulted to false [`e6a9b5b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e6a9b5be8804c26d24ded2b640fadc3aee015c79)
- Fixed issues with removing non release group words [`5b66f09`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5b66f09df823a89239df9b6a250deaa2bad78d9e)
- Fixed issues for air-by-date parsing [`2480e26`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2480e26e30e4c944810f1e28b5705dd04b280847)
- misc cosmetic web-ui fixes/improvements [`9b8a71a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9b8a71aa4626a632aab79b5b82459b8cd308e12f)
- removed redundant "delete failed" option from search client settings page [`b2d5c3c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b2d5c3cf0993dd0cd1778d2f74ac43f7fb12d1a0)
- refactored misc post-processing code [`7666f8a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7666f8a8f391b033825a0a423edf7d269cff4966)
- Merge tag '9.2.14' into develop [`94a6098`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/94a6098cef647e8b6eb6c6997e6c3caeebf4e8bb)

#### [9.2.14](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.13...9.2.14)

> 24 November 2017

- Release v9.2.14 [`735e12a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/735e12a1f71b078df1045a8eb6b02368f4be9350)
- Merge tag '9.2.13' into develop [`ff496c8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ff496c895636431960c33b2d03dd3905e765f649)
- Revert "refactored config class updated config to v12" [`3da7164`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3da7164edae0bdd3cab9b671c04924cffbd8ebc9)
- refactored config class [`2722ee5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2722ee56072e155b9419b3c49fc310d04818d70c)
- added code to failed snatch handler to skip paused shows [`093c597`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/093c5972999a8825d672fe1394bde3363d79a463)
- refactored config class [`630387d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/630387dea5895b445dd2c3bca560c1c7c20bfcd4)
- Refactored failed snatch handler code to use a tuple of showid, season, and episode for comparisons [`98a1036`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/98a1036052da9468fe7c95d3d366c320d29305ee)
- added code to log episode id's to history for failed snatch handler [`70755c1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/70755c182e432e5c2c9ffff20fe5e2d93c49aaad)
- disabled failed search feature temporarily [`83ccdf9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/83ccdf962936811da30b5b6746a955a361ef48e5)
- Updated url for torrent9 provider [`cf00782`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cf00782950c789241272c894c941482a91cc986e)
- reverted logging episode id's for history, no longer needed [`11a9003`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/11a90039a08b6f3ab5a7f6b2bfbd02322f00bdd1)

#### [9.2.13](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.11...9.2.13)

> 23 November 2017

- Fixed issues with tornzb results containing magnetic links and searching [`2f1d94b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2f1d94b70050226d4e4a7e982c3138a5997a3ac2)
- Fixed issues with Jackett search result downloading [`8d73c27`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8d73c275a4e2b637fc09d5af6cc8bfb1a461159e)
- Release v9.2.13 [`7132bf0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7132bf02cbb41370989cce9ca0570523be5c8b81)
- Fixed issue with IRC template [`e2a44f5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e2a44f5c5f3ac1c8193de7b22fae6911483b43c9)
- Fixed issues with Jackett search result downloading [`2e4eefd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2e4eefdc2e326b89b5fa29821057884a0618dd2f)
- Merge tag '9.2.11' into develop [`891e141`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/891e141d8fec7fffe14fba349c78d5f534bc2430)

#### [9.2.11](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.10...9.2.11)

> 22 November 2017

- Disabled validation of show names for refresh of show directories [`2c06e9a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2c06e9a1356fd5342a39a2ef0e13e6082939bdca)
- Fixed issues with custom newznab and custom torrent provider settings [`2fcac47`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2fcac47a2c1b2c7128190d1c2b768cb4b8e7da8f)
- Disabled validation of show names when loading episodes from directory [`3482813`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/348281301151e887cb24b6e500a47739056f051e)
- Release v9.2.11 [`b9a002e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b9a002e4bf861138a8bcba0885ac15587836f85d)
- Merge tag '9.2.10' into develop [`73a4826`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/73a48263d8682591ef45a0ce8c63cff9186f6d2b)

#### [9.2.10](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.9...9.2.10)

> 20 November 2017

- Release v9.2.10 [`74297b9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/74297b98d7fc0d236baf87b60fc9ae003a5d23a1)
- Fixed issue#127 - timezone issues on Windows platforms [`b8da064`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b8da064ef41d9a406696d4f9b22ab9cab6db6e2d)
- refactored backup function for app [`34ceaee`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/34ceaee9c7e8a76eb7d2ce503226a080bd8f197d)
- Merge tag '9.2.9' into develop [`a2cc0ed`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a2cc0ed1dcacb85759d7f40f7cdb871d513a87f8)

#### [9.2.9](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.8...9.2.9)

> 17 November 2017

- Release v9.2.9 [`c8d47ec`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c8d47ec3fc771fbc1f1042432f1bddcfab059cd0)
- Fixed index error during config backup on updates [`2d941ea`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2d941ea743dc322f71df5e5d72f752ef6026531c)
- Merge tag '9.2.8' into develop [`dda0777`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dda0777d578fedfdffc76473e055b95a461c5aca)

#### [9.2.8](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.5...9.2.8)

> 17 November 2017

- Release v9.2.8 [`23af894`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/23af89480751522b8ae5b6c4440243839bc1d756)
- Merge tag '9.2.5' into develop [`b4bc161`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b4bc1614cdd761fada08b491713b81943007933d)

#### [9.2.5](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.4...9.2.5)

> 15 November 2017

- Release v9.2.5 [`019c736`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/019c736ad6145550a2a97518e516eedc1d2e9e27)
- Merge tag '9.2.4' into develop [`c0c3793`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c0c37931f3164eb822eeefd42b419c0c9e4b0810)

#### [9.2.4](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.2.2...9.2.4)

> 15 November 2017

- Release v9.2.4 [`ab16911`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ab16911f83e04b00d6a9b5319a6c07df0dbf70c4)
- Cleaned up provider template for newnab providers [`0ba5a22`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0ba5a2290e0f0d0e76fecf7c90a856bd39dd337b)
- Merge tag '9.2.2' into develop [`c988625`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c988625d09e9ac5ac51388af729a443c89e915b6)

#### [9.2.2](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.78...9.2.2)

> 14 November 2017

- Release v9.2.2 [`a1f1730`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a1f17307915a82d7800701cda722a5fdd9d3a28c)
- Merge tag '9.1.78' into develop [`9d7a7d0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9d7a7d016dff6be802f569ba1ba053e9db671852)

#### [9.1.78](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.77...9.1.78)

> 14 November 2017

- Release v9.1.78 [`0505c4b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0505c4bc93756f3b37f925e50732a71688471218)
- Merge tag '9.1.77' into develop [`f5abd06`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f5abd06415cec910789728d0d49e74e4586b9fa1)

#### [9.1.77](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.76...9.1.77)

> 14 November 2017

- Release v9.1.77 [`89810e3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/89810e31b8fad58da51f8d90cf885e7cca1405ae)
- Fixed subtitle tagging for Newpct provider [`2163b57`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2163b57048a343c927cedc335e466f0277f75fed)
- Merge tag '9.1.76' into develop [`1f0c981`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1f0c981510aa113a0ef38a252b209f5dea73ce18)

#### [9.1.76](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.74...9.1.76)

> 14 November 2017

- Release v9.1.76 [`2425b4c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2425b4cdbf87029a2d71ef2123023de23a3f5be8)
- Merge tag '9.1.74' into develop [`0003335`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0003335ef52e7a07f97319b8222921f00ab7558a)

#### [9.1.74](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.72...9.1.74)

> 13 November 2017

- Release v9.1.74 [`f1a6e69`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f1a6e69144a486dd8f82c294b4f48bcfde20f758)
- Merge tag '9.1.72' into develop [`d088d31`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d088d310ef0d52ce8959358b5c437fdaefb827f4)

#### [9.1.72](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.70...9.1.72)

> 12 November 2017

- Unidecode Newpct titles to avoid unicode issues during name parsing [`0b32673`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0b32673641f0fdb300d2d6bfc16e250599f08dc2)
- Fixed search issue with Newpct torrent provider [`1c854a2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1c854a26c74310300199026846d508d84883a892)
- Disabled external caching of private search provider results [`c98575b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c98575bc3330efc1cc1df4cb23a7d12f5660a807)
- refactored providers [`342df0e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/342df0ed8e69a87031f59536e9fe79f781885a14)
- Release v9.1.72 [`15e1861`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/15e1861ed8e9d0907b978bb498fc753ab27bc8e1)
- Merge tag '9.1.70' into develop [`f6c0895`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f6c0895b708382e72387a7cc4c7eeee2ef6fecbf)

#### [9.1.70](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.69...9.1.70)

> 10 November 2017

- Fixed typo in code for daily searcher [`9498449`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9498449465805f6a5e56f75bc73c41c0cada8138)
- Release v9.1.70 [`24e1037`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/24e10375b55cb97cc30261e01b4ae6020b712977)
- Merge tag '9.1.69' into develop [`4c53c90`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4c53c90a95c69eac367333c0d7099b11535f550f)

#### [9.1.69](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.68...9.1.69)

> 9 November 2017

- Release v9.1.69 [`b26010a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b26010ab6c391967e054f35eaa437c9ef2c88f51)
- Decreased time it takes to search with Newpct torrent provider [`718179c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/718179c178a10b5d6fda2afe16298d6eccada117)
- Fixed issues with displaying correct show quality when editing a show [`9349846`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/934984677a12a730562d85ed9992459cd53483b2)
- Fixed typo for server status template [`e0c1882`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e0c188204d4067c857452267019a0f782dacc0d3)
- Removed all but itorrents bt cache provider [`725ea95`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/725ea953f8422ca8479aac7f1738783878918f57)
- Fixed typo for server status template [`fe471c0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fe471c040745244c0d411546ec55ab76a3ab08b2)
- Fixed issue with a bt cache url [`58564e1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/58564e197a04a3b4e9589cf8e4c44610e57efe72)
- Fixed issue with a bt cache url [`f2ba6fa`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f2ba6fae875dea8196c96b8d3958f65e9f41ee6b)
- Fixed issue with BitCannon torrent provider [`27af54e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/27af54e58c5ad3f4311794b5b317f276591cceaf)
- Merge tag '9.1.68' into develop [`c7de9a9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c7de9a977617be5b019d504cead78d7e18ddf550)

#### [9.1.68](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.67...9.1.68)

> 9 November 2017

- refactored Daemonize class to use os exits when forking instead of sys exits [`eaf2a97`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/eaf2a97673a2df07ce4892f0602f9eb9c333e80c)
- Release v9.1.68 [`1970e1d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1970e1dd8d29f987af9ba86edbcab548533df37c)
- Merge tag '9.1.67' into develop [`36eb27f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/36eb27f552d2380b5ca1e7b556ab9b340354dff9)

#### [9.1.67](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.66...9.1.67)

> 8 November 2017

- Release v9.1.67 [`1a61bc4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1a61bc463c3627806476294b7a1a18ca1c434536)
- Merge tag '9.1.66' into develop [`6b9969e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6b9969e3e0f50f4cc61a4189d7e48f8f895239a8)
- Updated bt cache urls and method for verifying data from them [`53aa1b8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/53aa1b8dad9e35ddfc3350b9d33c9ac7f589d63b)
- Misc typo corrections brought over from previous code refactoring [`a6240ce`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a6240ce906aa7ec0ffe53606f4932b66e7f5ec0a)
- Fixed issues with posters overlapping on show list [`5127668`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/512766899285b80bf8948d672376d2a57ec02e53)
- Decreased app startup time [`325ab75`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/325ab754a3b9633069181281bdb5a25195ac17b0)
- Fixed issue with daemonizing and pidfile's [`5cca270`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5cca270b76ff5624e45a84b9c2cffe11d18bce4c)
- Fixed bad reference [`90b402d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/90b402d83bfbee9d2b571631806617e32e429ea0)
- Fixed issues with verifying torrent metadata [`5d18ffb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5d18ffbbd124838ad6e3490a05747ecb2ef4f1f3)
- refactored core code relating to instance variables [`b407d9c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b407d9c881c1344e0e1ff8b058c3e5031ef97c96)
- refactored core code relating to providers [`30c56e0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/30c56e04f764a854a06b519cb86d428f96413b42)
- refactored core variable name srConfig to config [`e18ac02`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e18ac02bc5a400f6365340ef29fb3218bfec88e4)
- refactored core variable name srLogger to log [`cf804d2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cf804d240dbd24d5ebf2fab8e79d1ffe14f9aa6a)
- refactored core variables from main module to core class [`83efbc5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/83efbc5b23823808a985b8c968880e10384b1887)
- refactored variable name srCore to app [`bbe7773`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bbe7773e6c0d1b76b4297944a58aaa729372ef87)
- Fixed issue with Newpct torrent provider skipping first result from search results [`9221129`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9221129241b10eb7cc750938d1cc69464a421473)
- refactored core config instance variables [`73ee12e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/73ee12e595ff73c950d1955bbc7d7726038be812)

#### [9.1.66](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.65...9.1.66)

> 6 November 2017

- Fixed issue with post-processing folders and files with unicode characters in their names [`4c2676f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4c2676fd62a2966b3dbe565e881fd7209d4f31b5)
- Release v9.1.66 [`735906d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/735906d36d2c560de285b38a85b6b79bed68d9d9)
- Fixed issue with post-processing folders and files with unicode characters in their names [`aa334f6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/aa334f6ce6f4fcc81bed78606951b1cbdacaaf58)
- Fix issue with checking for latest version via git [`9b68632`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9b68632c1cf38d65398c90c2a03a58375af7dfb8)
- Fixed issue with post-processing folders and files with unicode characters in their names [`8a5d431`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8a5d43133aa5855a8f2f8e5575d2eabd0648b69e)
- Merge tag '9.1.65' into develop [`589eac2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/589eac2d5f0ce2fb8fe22c4a6b637b3bea624297)

#### [9.1.65](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.64...9.1.65)

> 6 November 2017

- Release v9.1.65 [`56217dd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/56217dd120e0e425bd27d0ae0c9b9b715222e5d3)
- Merge tag '9.1.64' into develop [`97fedde`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/97feddef20f932ce95a13a4144af04213422953c)

#### [9.1.64](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.63...9.1.64)

> 5 November 2017

- Release v9.1.64 [`a5cd4f5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a5cd4f5285c79385c820b1c7e7a399085add36b5)
- Merge tag '9.1.63' into develop [`d64aa8e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d64aa8efe78c29e5c7083955f95e080dea1f0206)
- Fixed encoding/decoding unicode issues with tuples and kludge [`394338f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/394338f4265914a3cdbeadf9a2824fa18ba713aa)
- fixed post-processor queue issues with none types [`02e5733`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/02e5733675bef5b30cf7d0bfe4fd8394e8f112c7)
- fixed post-processor queue issues with none types [`0c46c22`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0c46c22463daa604e81c3f77177ed4bc21730cb2)
- fixed post-processor queue issues with none types [`373a99f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/373a99f657f5c4193e1d4e78701bc99038a7e7a7)
- Fixed quality regex for Newpct [`ccc4dd6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ccc4dd612c98045d7f203f1796c01f1c1f40da39)
- Fixed encoding/decoding unicode issues with tuples and kludge [`68d647b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/68d647b441a6df5e9bab871a020ded27cb60e64d)
- Fixed regex's for Newpct provider and added search url for HD series [`31c2cbe`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/31c2cbedc03b9ca6b9f1eccd94d19354634bd02b)
- Fixed regex's for Newpct provider and added search url for HD series [`1260ed4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1260ed44631d1bed3a52b1a0445fba87415f38ca)
- Fixed regex's for Newpct provider and added search url for HD series [`209d748`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/209d748b29448b69af78e4354be7b93d3a8b5a5a)
- Fixed issues with Newpct provider searches [`e131756`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e13175646221fccb688408506d364d642139a760)
- Fixed issues with Newpct provider searches [`08aadb2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/08aadb21578fc5a3722015168905a5cc4f90f59d)
- added code to Newpct torrent provider to search page by page [`fd03d0c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fd03d0cb8027dfa54b1f1204302308975296dacf)
- Fixed quality regex for Newpct [`02baa59`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/02baa594ff420229799079c33a1e1a817847eb7d)

#### [9.1.63](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.62...9.1.63)

> 4 November 2017

- Release v9.1.63 [`b0b02e3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b0b02e3ec514b917ca337da416af09a809895867)
- refactored more torrent providers [`6820bf0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6820bf0759355ac419c10f9e741ce563b52dd36b)
- Refactoring search providers [`ebb2a6b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ebb2a6be83cac783f26b1860814dfbe713bf8e0d)
- Refactoring search providers [`4d52518`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4d5251888f94fd711ecf40c82c983f3edcac6ce9)
- Merge tag '9.1.62' into develop [`e7f8371`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e7f8371224bc024ef745b236893856243617e3fd)
- Refactored search providers [`ed3f92d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ed3f92dd07bbfcd1c2f0aacaaa226408c4ef4b45)
- Refactored provider proper searches [`ac96d4d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ac96d4d9b81f904c83eaf73161c484e7adaa2bb5)
- refactored minimum seeders and leechers checks [`90308f0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/90308f02bb0dd1f8e3e41cfe9ab080f85e057c72)
- refactored torrent providers [`0bf0945`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0bf09452ff481a3e32058c17bd85b0e0b7c09754)
- Fixed issue #102 - Newpct.com changed his web structure [`5cea4c4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5cea4c490ab7112fd63c432c35a53f77d204a318)
- refactored newpct provider [`00b3ffb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/00b3ffb85e347cd248180138f0330912ffdfec68)
- added download client setting for torrent clients to convert torrent file links to magnetic links, helps resolve download issues for certain clients and only works with public torrent providers [`0e2ebef`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0e2ebefd3e92e698fffecd3152ad61d18cd894fd)
- Updated grunt file to reflect repo changes [`7f450e6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7f450e6828e0cf8e03394d1855d33925175b459c)

#### [9.1.62](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.60...9.1.62)

> 29 October 2017

- Enabled caching for all providers [`7b6bbe3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7b6bbe3f1733b0d0de13825379b157e0c80cb0d8)
- Release v9.1.62 [`c174e09`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c174e098c7e250886072ba80d78212ddaf4af7b8)
- Fixed default poster size [`a90e20b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a90e20bf36bae9b1ea866be3ea309a26fd58eb48)
- Merge tag '9.1.60' into develop [`e6cbf1d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e6cbf1d411448e64352973295d4eff21f44e9ddd)

#### [9.1.60](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.59...9.1.60)

> 28 October 2017

- Release v9.1.60 [`ad2f5d9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ad2f5d9ad33c96553b61cfc7b3af91941f4d3d05)
- Merge tag '9.1.59' into develop [`2070b4d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2070b4d49b0f5febb2c4cd3d1eb70d882e1539e6)

#### [9.1.59](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.58...9.1.59)

> 28 October 2017

- Release v9.1.59 [`b30936a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b30936ab667449318c490a4a7f8c99e5402271a7)
- cleanup code [`4c26bb0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4c26bb0f2cb05279dbb412579c39928cee607711)
- Fixed issue with verifying search results [`56a04dc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/56a04dcbe8062b1a354057e77b6a3721620ae94a)
- Merge tag '9.1.58' into develop [`08eea41`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/08eea41736fed82e978b6c6f514712e1a5eabfec)

#### [9.1.58](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.57...9.1.58)

> 27 October 2017

- Release v9.1.58 [`78f6aff`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/78f6affcd9fadd8d8de6ebec0ed61e61e09dbd19)
- added code to verify all provider search results content when picking best result [`074910e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/074910e59b186d5fc1240499e77e072f3fad0743)
- public torrent trackers now added to both magnet and content if exists [`5d29937`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5d299379561a6d2501ef15b5da7b7e11b748cd44)
- Fixed issues with starting app under service in daemon mode as unprivileged user [`1f182f0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1f182f0cd63dd62544e0e1eaed988742b671b207)
- Merge tag '9.1.57' into develop [`749caeb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/749caeb69b16181328193c877181ad7c6e8e718c)

#### [9.1.57](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.56...9.1.57)

> 27 October 2017

- Release v9.1.57 [`492a3fb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/492a3fba9b1fe7eaa73753f92345781f40876e0b)
- Merge tag '9.1.56' into develop [`5371cb0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5371cb02078d27729f3b16c62394083270b487ed)

#### [9.1.56](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.55...9.1.56)

> 27 October 2017

- Release v9.1.56 [`1d4bc73`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1d4bc73fcfff52da3e5f6b40583898cd33eed5e4)
- added feature to automatically add verified public torrent trackers to both torrent files and torrent magnet links for public torrent providers to help improve download reliability and speed [`6382b2e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6382b2ed446333abf7d7e7d02c0c158baca8daa9)
- Updated docstring [`2ca0866`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2ca086670df8f109d9761e2e732a84e345b52f2f)
- Fixed url for torrent public tracker list [`ef53a1d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ef53a1d460d14cbfe5d6d307f22bb1ff95f5c865)
- Merge tag '9.1.55' into develop [`675d287`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/675d2877a34935285efc96e99fa61139a3e69410)

#### [9.1.55](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.54...9.1.55)

> 26 October 2017

- Release v9.1.55 [`8a121c7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8a121c76537a47511a6aabc1f0a0045ddd91686b)
- Fixed issue #91 - object of type 'long' has no len() for newznab providers [`043f827`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/043f82707ca5a44529f2e0f78bd9bbe8da11febb)
- Merge tag '9.1.54' into develop [`48ad850`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/48ad8507d1e0a236d7e3f34301e2cbeeb591bc30)

#### [9.1.54](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.53...9.1.54)

> 26 October 2017

- Fixed issues with clearing out stale *.pyc files [`5a73364`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5a73364c3676fef00faa1ca9fd9693991d6bfc11)
- Release v9.1.54 [`a3c8725`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a3c87254fa048573d294c9b5f9a3202b5833621a)
- Merge tag '9.1.53' into develop [`0787004`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/07870045760b37fd7c6a447819105ba38b72f47d)

#### [9.1.53](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.52...9.1.53)

> 25 October 2017

- Release v9.1.53 [`57bf43e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/57bf43edab67dd95e0946b3765eb1b1d0f1cd2b4)
- Fixed issue with wanted and missing labeling [`f90baa4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f90baa4a6b321d571b03e35ce8fc23606107465d)
- Merge tag '9.1.52' into develop [`d4650b8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d4650b8b95770c54ca7287235ad54930e075a384)

#### [9.1.52](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.51...9.1.52)

> 24 October 2017

- Release v9.1.52 [`c5143b6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c5143b6a35503d5e086dc282422ebc16d5ee2fb3)
- Fixed setup import errors for babel [`dfdaf49`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dfdaf498aae57dd05a8f8803aafe880c78ae2410)
- Refactoring requirements.txt [`c7de2b3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c7de2b363f07ce51576183dec7116338423f1b05)
- Refactoring requirements.txt [`036fc03`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/036fc0308893391103b0e8eedd13b208be56753f)
- Updated url to favicon for notifications [`68ee394`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/68ee3943a3d8af6f78fff67e6e62449c6d9bad62)
- Refactoring requirements.txt [`2a15a42`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2a15a42dd59923a93893236d832fd9ab64af9f5c)
- Updated url to favicon for notifications [`7772474`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7772474b03af4b1fb36f4e30fc328183ad6d7e8f)
- updated readme logo [`0b218f2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0b218f261e12d62beeb19be45038cdf1eede1d0e)
- Refactoring requirements.txt [`3df51c0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3df51c00882c9abcee44fef1dd6af6985f7f81c8)
- Merge tag '9.1.51' into develop [`1d4aae5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1d4aae5c331d0e2f24451229434e6d67a2d38a2e)

#### [9.1.51](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.50...9.1.51)

> 24 October 2017

- Release v9.1.51 [`9ca9dc4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9ca9dc4711ca85f0eeecdaaf9223536ee29b1620)
- Merge tag '9.1.50' into develop [`e98292c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e98292c4fe895da3f8d69f61646ec2e6dbd2c969)

#### [9.1.50](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.49...9.1.50)

> 24 October 2017

- Release v9.1.50 [`e94d370`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e94d370832df7180b315e300a4d6194240d70a4b)
- Changed urls for network timezones and scene exceptions to use our new CDN server address [`151fb91`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/151fb91124f7ffcea4cd0a67db176948469592cd)
- Changed urls for network timezones and scene exceptions to use our new CDN server address [`563f61f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/563f61ff3db1b2adaa2b3132163ad875b295ab86)
- Merge tag '9.1.49' into develop [`cc1f651`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cc1f6513064823cb1a9b94a7c97d42f69875f7ae)

#### [9.1.49](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.48...9.1.49)

> 23 October 2017

- Release v9.1.49 [`2ae8886`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2ae88860228f8cf5e3b99ec7066a14228e7db763)
- Refactored logo [`9419272`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/94192728a0f9842ce0362d6662c2ce1fea4fb24e)
- Merge tag '9.1.48' into develop [`2e3ffba`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2e3ffba75f02a0621add675a947d3c5c2b64ea33)

#### [9.1.48](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.47...9.1.48)

> 23 October 2017

- Release v9.1.48 [`b51b312`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b51b3121b0edcda4e1f0b133b992805317009e8c)
- Refactored code [`32e2fd7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/32e2fd7f905cc040afec62c40adfcfde34af0b57)
- Refactored logo [`8c12317`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8c12317aead42af053085b77b1741587973b8c55)
- Updated .gitignore file [`ec907f7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ec907f7430f0abba8e7959cc2654b4bc20283300)
- Update Bug.md [`08384bf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/08384bfc3eab8e5eb04aee5abfff6c82525094b2)
- Update Bug.md [`b29dc99`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b29dc992963493aeb5292dc670389c9a8fe9ef0b)
- Renamed template and fixed small markdown typo [`801c6a3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/801c6a326b2e0e84af2d3fab4b87e94c4c286b39)
- Merge tag '9.1.47' into develop [`19c8fc9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/19c8fc9bc36ec11ece946fb4d0a50d7db3c7ba65)

#### [9.1.47](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.46...9.1.47)

> 21 October 2017

- Release v9.1.47 [`e799d93`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e799d937a2219784f4814a6003c4e23fcd1af6fe)
- Fixed UnicodeDecodeError for retrieving messages.json data [`07fe860`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/07fe8603fd4d28d0c862573df4c6b5461726148f)
- Merge tag '9.1.46' into develop [`26f9cf3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/26f9cf3821845fa9878474d2b7392e217ca999d1)

#### [9.1.46](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.45...9.1.46)

> 19 October 2017

- Release v9.1.46 [`c470b37`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c470b376e396f3a5810fd7d9c207e8d816dd0349)
- Fixed issue #94 - manual post processing error [`b896e96`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b896e9694b8f12360cf040ce1f51cfc11957d6fc)
- Merge tag '9.1.45' into develop [`3182cdc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3182cdc2e6320240e88556d719f845d51c1b3c5d)

#### [9.1.45](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.44...9.1.45)

> 18 October 2017

- Release v9.1.45 [`b0b9201`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b0b920167ed2602cb3f48ac5c0aac8cf7b824c09)
- Refactored qBittorent [`44b2225`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/44b22256062a54377cc7309890ff6792dd991753)
- Fixed source url for login page logo [`71563bd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/71563bd3fa99fd97cc2a3e8656a1040620ee0c23)
- Fixed source url for login page logo [`d41ddae`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d41ddaef98ae7f54cbd48dc3b2c50dc9baf0574c)
- Merge tag '9.1.44' into develop [`7ddfa59`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7ddfa59fd085e53ac4506e5665f4a4b62774f858)

#### [9.1.44](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.43...9.1.44)

> 17 October 2017

- Release v9.1.44 [`59f9fbc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/59f9fbcbe6a8ab54f5bea6f0403db2c8bb072c69)
- Fixed issue with log_dir attrib missing [`08fdbad`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/08fdbad2b27b4aa1438a1940d832445993510023)
- Merge tag '9.1.43' into develop [`70b4e32`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/70b4e32172476c1a176009c3ff1d047eea133647)

#### [9.1.43](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.42...9.1.43)

> 17 October 2017

- Release v9.1.43 [`25f71bf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/25f71bfbc74e39c4c582eb42dfda7f8e2487e763)
- Merge tag '9.1.42' into develop [`6fb9cd9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6fb9cd9cb33971f9a1e803a72bb414cb58c03d00)

#### [9.1.42](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.40...9.1.42)

> 17 October 2017

- Release v9.1.42 [`f915a35`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f915a35bc723dc20fce39778d496ae1719ae5067)
- Fixed attribute error for postprocessing queue [`5563b94`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5563b946429ca1b94d977cd0c261afbfd3f04e1f)
- Merge tag '9.1.40' into develop [`5f92917`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5f9291773ffbfa6e4fcf5a6c923ae842eaa65518)

#### [9.1.40](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.39...9.1.40)

> 17 October 2017

- Release v9.1.40 [`fea50e2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fea50e214de3e228dab4cd043f309125bae742bc)
- Refactored Newznab provider code [`7aac26b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7aac26b4491f8edbd9275c1f9aceaa8e1555e0fc)
- Refactored Newznab provider code [`f45988b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f45988baf594f32258a50c814cdc563ebe73c22e)
- Merge tag '9.1.39' into develop [`871fdb7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/871fdb71e8f4432bd140d9fad9eb26b5d1ba604f)

#### [9.1.39](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.38...9.1.39)

> 17 October 2017

- Fixed issue #90 - iptorrents provider needs update [`1da0430`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1da0430d743ff333fef9cdb9d318f20fdd07b9a5)
- Fixed issue with gettext underscore being replaced when using underscore as throwaway variable [`f50a313`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f50a313c8322679fdea2b30c420d182b92398e02)
- Release v9.1.39 [`6384aab`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6384aabf545605f030f4ce04377b6116d396d70a)
- Merge tag '9.1.38' into develop [`0545329`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/05453299fd2ee292a1db80fe16ec212256506ca0)

#### [9.1.38](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.36...9.1.38)

> 16 October 2017

- Converted more templates to i18n [`2abfe11`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2abfe11c73ee3073646fe131256134cc7273de26)
- Finish i18n feature code [`51e2aae`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/51e2aaec77c76bd2fa46423cab610805f96a426d)
- Fixed 'No Content' error and added more translated languages [`372b24e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/372b24efd5444a98b016eb1358dfb5b8a4ae03d2)
- Extracted more gettext messages [`939e18f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/939e18f603603b2d0a1e498b82b994c8cc1add46)
- Fixed issues with json gettext [`a3fd581`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a3fd581b4c7a125a9b94f251cfb0e953092e6cef)
- Fixed issues with setting minimum seeders and leechers [`c1ab882`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c1ab882ef0485ac07f9dfbf6a66444bcca207d40)
- Converted more strings to i18n [`76cca85`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/76cca8516a6c795e24f627f538b6814387359842)
- Converted headers and titles to i18n [`104ae0a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/104ae0afd46e6192882ca95af62b137d76f72f4e)
- Optimized placement of gettext installation code [`7b9275f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7b9275f01a45aa193383d73fff087b242a638e80)
- Clears current user on restarts to disable header and footers and force re-login [`7927b8c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7927b8cebe2c98908ce1f192e74e9f3a6c95a33a)
- Release v9.1.38 [`8a3d08a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8a3d08a0dcd3e34f0d0be512bc35db3e9b70a283)
- Disabled header for restart page [`4f214c4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4f214c46c068c126b8206137e77e401e011c19e7)
- Fixed typo in main template [`892d3ce`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/892d3ce5b453db9fed9b24f0a9438d413144225b)
- Clears current user on restarts to disable header and footers and force re-login [`d8302b2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d8302b2c678279f39ecb07c366af6c98bc9c2961)
- Merge tag '9.1.36' into develop [`0b93540`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0b935402ea86efa9475b0c36dcb8f78d4ca968fa)

#### [9.1.36](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.35...9.1.36)

> 13 October 2017

- Cleaned up more of the provider module code [`c0bdad9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c0bdad99de81c727fae3bd3b222295c768fa4f5b)
- Misc code cleanup [`47dc9a4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/47dc9a432c2bef7b9eaced114df3b3be87441c75)
- Fixed small issue with HDBits [`a4c60fe`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a4c60feaefa2d852cfe71580484548b3b458e213)
- Fixed some typo's [`e127e2a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e127e2a11e2edb6a2c874edfcdb87d4bb7a7eae0)
- Release v9.1.36 [`7d2ff8a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7d2ff8ad476e2aaad55c85b2b3d3484012d5dafd)
- Merge tag '9.1.35' into develop [`242acae`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/242acaed544df9303360c2935dd6cd86fa7dd72e)
- Cleanup of all provider module code [`a748503`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a748503eb3ce88350697942baf34a6b2c4961eaa)

#### [9.1.35](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.34...9.1.35)

> 11 October 2017

- Release v9.1.35 [`a868e4b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a868e4b1adff33654b958e0253627dc251293af7)
- Merge tag '9.1.34' into develop [`4bad6a7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4bad6a758d89231c4c1610c99156b0d5df6a3ad3)

#### [9.1.34](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.33...9.1.34)

> 11 October 2017

- Cleaned up provider code, removed providers that where no longer working [`c2e364f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c2e364fe01372434d4e96bc908988892200cefba)
- Configs are now loaded and saved using system encoding to resolve unicode issues [`061f090`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/061f09040e931f50b2e2b25de12e5d06d67b58b7)
- Release v9.1.34 [`27f5848`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/27f5848deb3b070ebdd64b493ccd7fbb70269f20)
- Merge tag '9.1.33' into develop [`9c0fd6a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9c0fd6af17c9cbbb0575d08fa834ac42b0816af1)

#### [9.1.33](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.32...9.1.33)

> 10 October 2017

- Merged manage searches webui template into manage queues template [`54238a1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/54238a1996ff541ef0a1ff157cefb88b27b80e66)
- Fixed issues with restoring older backup files that may contain sickbeard.db file [`d9cfc11`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d9cfc11e15d97d77e7c2078b0dcb45ee3ab7163b)
- Release v9.1.33 [`819d4dc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/819d4dc813b8901b79b021bbbb067d22f22a28b6)
- Merge tag '9.1.32' into develop [`00d5ef7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/00d5ef7c20401634bffda0aa0efebdf3cd50d0d7)

#### [9.1.32](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.31...9.1.32)

> 9 October 2017

- Release v9.1.32 [`f372ab4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f372ab459a347e26505604ba93fd5fb6cb113098)
- Merge tag '9.1.31' into develop [`a086865`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a086865958f16f7c30beb35938f4138511ced0d1)

#### [9.1.31](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.30...9.1.31)

> 7 October 2017

- Release v9.1.31 [`12b6e6b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/12b6e6bc7e2669e9aaf43b700fbb01cfa5cb7f20)
- Merge tag '9.1.30' into develop [`f34d160`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f34d1605ff79566f9328df75b2e87cabe3ef7fe5)

#### [9.1.30](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.29...9.1.30)

> 7 October 2017

- Updated general advanced settings to allow setting of PIP path [`b8786d6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b8786d6fc18433223dc429a40501b14c0457b0ee)
- Release v9.1.30 [`cd9041d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cd9041dd75cbd87a114a7875bd9d0e79c7dc4469)
- Merge tag '9.1.29' into develop [`55eb7f7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/55eb7f7aa6dc6f292bf62260e699b4b46eeb2794)

#### [9.1.29](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.28...9.1.29)

> 7 October 2017

- Updated requirements [`8562a7d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8562a7d9d0a99322fe85cda9d1330dfc003c8b5c)
- Release v9.1.29 [`1b67369`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1b67369966e056a0c8f5b6c80907bc21b44e3839)
- Merge tag '9.1.28' into develop [`1d56992`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1d569920cb937fdc30c2c0ada64380101ea76820)

#### [9.1.28](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.27...9.1.28)

> 6 October 2017

- Release v9.1.28 [`d06862a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d06862aec0d52e1fea0d9cdca9db03cee7584058)
- Merge tag '9.1.27' into develop [`b04d8fb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b04d8fb042cd86b15508167dbbd1440bced68b36)

#### [9.1.27](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.26...9.1.27)

> 4 October 2017

- Removed async for login handler [`c4277b5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c4277b5177f86cbe8bd9fbc4f995c5e15af4edc7)
- Release v9.1.27 [`3732ce2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3732ce2428667fb4496491db435d592205d40ebf)
- Removed async for login handler [`4a81426`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4a814260f71aa97bb14ff01708217a550bd3bcd1)
- Merge tag '9.1.26' into develop [`3b7e618`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3b7e618c280bf50e9d9d22dca9d88f2125f9175c)

#### [9.1.26](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.25...9.1.26)

> 4 October 2017

- Release v9.1.26 [`4070c4c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4070c4ce5ae64da1510e95861e498afb4864b3f2)
- Fixed issues with saving settings [`156c0f3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/156c0f312b30446190c82af28b2f936cfdb52b9d)
- Merge tag '9.1.25' into develop [`f040ea3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f040ea3f93dca4cfcb29df1db92f401d6ac4e0e1)

#### [9.1.25](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.24...9.1.25)

> 3 October 2017

- Improved censorship of sensitive data in logs [`e1c6cdc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e1c6cdc50522f95da75391f833642d0fd22ebd8d)
- Release v9.1.25 [`3ec56ef`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3ec56ef046bea47cbdb38070bbd964425c047ec5)
- Merge tag '9.1.24' into develop [`25e6f80`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/25e6f80bf11ffa3c545edcf1eaa1d2fa69d3d94b)

#### [9.1.24](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.23...9.1.24)

> 1 October 2017

- Metadata for actors is now pulled from indexers using a function [`8c581c5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8c581c5aa57434a6de18c048c468f3dcd8523932)
- Release v9.1.24 [`077a85c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/077a85c5e8eb97677ba515de3ca20ea9c409c00c)
- Merge tag '9.1.23' into develop [`dd7415e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dd7415eb783c00e9971148f9c74ee601b83d51b1)

#### [9.1.23](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.20...9.1.23)

> 30 September 2017

- Fixed issues with login function for webui [`7c63227`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7c632274d72174d5a2dd244cb8d17ecf84f3f63d)
- Release v9.1.23 [`a99f625`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a99f625f2c84baeb558365c351ef68d851f4a709)
- Fixed issues with login handler [`0bb6c69`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0bb6c69f8d4730deba704df4da06c58172f8896c)
- Removed code that manually sorted trakt shows by votes before display on page [`85812da`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/85812da783e0fa4e4a3a73fe3ba70e922366c98d)
- Checks current user before attempting to auth for login [`257d1f9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/257d1f90c9ae5f8ccbe9d95b26a8de48d82615ec)
- Fixed typo [`4295e55`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4295e5535d0b1ae2afa83dff2439d1add4fc8bec)
- Merge tag '9.1.20' into develop [`dd84f3d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dd84f3d9544562137329f48d4d4dadec9d152b04)

#### [9.1.20](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.19...9.1.20)

> 29 September 2017

- Release v9.1.20 [`cd6f0fe`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cd6f0fe603d1d7ebd146f46983863dfc8976666f)
- Merge tag '9.1.19' into develop [`c3eb23a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c3eb23affabcc12a84474582d63c89d1f9914b46)

#### [9.1.19](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.18...9.1.19)

> 29 September 2017

- Fixed duplicate issue with configure provider select box [`b8adf84`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b8adf846451989d69eced4291fc164704b8837bd)
- Release v9.1.19 [`f0c8cbe`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f0c8cbefc84c78db119d962e7e4b323322c3fd8e)
- Merge tag '9.1.18' into develop [`31830ff`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/31830ffa2600df9a18b63aad6a90741bc751678c)

#### [9.1.18](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.17...9.1.18)

> 18 September 2017

- Fix for issue #71 - removes format metadata from video file [`1e5bd13`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1e5bd13558db30556d5ecad4a55c3097c4bae208)
- Release v9.1.18 [`4b1e431`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4b1e431d56867da0c1b0d04a2c0d3855389573c2)
- Fixed issue with retrieving cached results for searches when performing a provider search [`a6a84d4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a6a84d4f65c31525062429515db22344fe4ee44c)
- Merge tag '9.1.17' into develop [`138478d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/138478d07ebf19edfc5c385a27e4f803cbb99846)

#### [9.1.17](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.16...9.1.17)

> 10 September 2017

- Release v9.1.17 [`489ea29`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/489ea29d4815bfe968502a2158497d0d4b180b31)
- Fixed issue #77 - strips whitespaces if show airs property is blank [`d3cf02c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d3cf02cf6f880ff1edae90da58cf4123ec066ed6)
- Merge tag '9.1.16' into develop [`a4dbe5f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a4dbe5fc74bcdf3ff930e76b8024966f05c38ee2)

#### [9.1.16](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.15...9.1.16)

> 5 September 2017

- Cleanup of subtitle mako templates [`fe775d7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fe775d7c25222a7abb50790dc8b10877dd3cd1b4)
- Fixed issues with scene numbering functions [`bb4adb8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bb4adb836ef1c8dd8f5d989e82f531af4a611ce6)
- Removed next episode scheduler [`18bf4b5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/18bf4b5072bb3320c91bf18cbf4e78158caa459f)
- Fixed issue #71 - missed subtitles search [`e10fec6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e10fec636ba615b1645b7b74b62d1d4e9ac2f551)
- Changed minimum allowed python version to 2.7.8 [`0a0ff73`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0a0ff7330d8dc49f6e1068635168b2a3de241798)
- Removed shutting down scheduler, may be causing restarts to lock up [`2b006c0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2b006c04caa82aaa49a6a9e61e08e68e2b90feb5)
- Release v9.1.16 [`1a64092`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1a64092428dde8fdc2106ca2191ab309fa8388ca)
- Merge tag '9.1.15' into develop [`3cc59c1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3cc59c113201b21d545579c161c0d5cc488e91a9)

#### [9.1.15](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.14...9.1.15)

> 30 August 2017

- Fixed failed download handling [`ff9dbcb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ff9dbcb48aad90636f36c329faf5f7054eb5ad22)
- Fixed EOF issue related to pickled settings with new configs [`f9f02ff`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f9f02ff41ea4a489954504625e4a450d3082f0d9)
- Release v9.1.15 [`39ca900`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/39ca900647edaf4d80a77affcae509653b2db603)
- Merge tag '9.1.14' into develop [`59f8199`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/59f8199aeab7371fa586562ee5cc34c6e4e4114b)

#### [9.1.14](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.13...9.1.14)

> 28 August 2017

- Using pickle instead of json for storing config settings when needed, retains integers for dict keys. [`d9b6217`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d9b62176f517219bc312cb2d1baed68c5dfd9ba7)
- Corrected trakt data generator code [`9d2b9de`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9d2b9de7ae75397335d067b1941dd94d892b2d22)
- Convert results back from indexers into integers before comparison. [`900c785`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/900c7858471581bcc5702f4ca7bf84d115f57db8)
- Release v9.1.14 [`1e1a90b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1e1a90b432add08d905581fd0e98a3a2184f55c1)
- Updated network logos [`be50e92`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/be50e924fbc4b33b710d22e99f420e2692d75631)
- Merge tag '9.1.13' into develop [`d309e8b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d309e8be05fcd1b54429b24a4dd8fca48bfddf03)

#### [9.1.13](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.10...9.1.13)

> 27 August 2017

- Fixed startup issue do to unicode decode on os.walk [`b6172d5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b6172d587d185167326a7698c740b8848abe980c)
- Moved code to core for removing stale .pyc files [`27326ca`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/27326cade41c435d731c30b90d4a46072880c876)
- Release v9.1.13 [`81ac249`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/81ac249f732a150500458566f5451d85eebece7d)
- Fixed fanart lib issues [`dcfdc7f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dcfdc7f87719116f07331a79348680190ca19e09)
- Removed LXML warning as we've replaced that with html5lib [`b2b3a7b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b2b3a7bd7ee8ba73d2ba579907e587ef40012096)
- Fixed shutdown issues with queues [`eba1be4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/eba1be42600519e694828cfb90acac53f722e05b)
- Merge tag '9.1.10' into develop [`d98d592`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d98d5921e9f88057fff6475113d670237444677e)

#### [9.1.10](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.9...9.1.10)

> 22 August 2017

- Fixed app restart issues [`b5ad47a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b5ad47a40bd08137eb664e1602e38fc9f8b7f16b)
- Release v9.1.10 [`1662bb7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1662bb7275009159c9924a541bd2ce00d1a61cfe)
- Merge tag '9.1.9' into develop [`f793d98`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f793d98a5f12352090a3e97e46732fd303e35c21)

#### [9.1.9](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.8...9.1.9)

> 22 August 2017

- Removed shutting down scheduler [`36c64f2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/36c64f28f5ba5d01b0a8d207a745c7f0ce47e486)
- Release v9.1.9 [`ba560dc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ba560dc27bed35631cf539b30174c94d491f174f)
- Merge tag '9.1.8' into develop [`087dd9f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/087dd9f26e9c5c9fca2d8efe6543d71de1bc8681)

#### [9.1.8](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.7...9.1.8)

> 21 August 2017

- Release v9.1.8 [`730db3d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/730db3d3fcd84ea4083fe08be48fc6f37ae1be25)
- Downgraded cfscrape to v1.7.1 [`ad759ad`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ad759adeeca6f0fa19db9f2fdee5bbb5600db616)
- Merge tag '9.1.7' into develop [`171dcf4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/171dcf4f9127a682ee5c7c2968ead8f2aa79b8a2)

#### [9.1.7](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.6...9.1.7)

> 21 August 2017

- Release v9.1.7 [`a3012f9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a3012f955537198cd0eef65a56b4ffd74cc06937)
- Merge tag '9.1.6' into develop [`b282bdd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b282bdd27d3b707239dfb78a603b6be3bcd227d1)

#### [9.1.6](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.5...9.1.6)

> 20 August 2017

- Manual re-scan of files will force populate show images and overwrite existing image files [`22a13d3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/22a13d3c57d0a3d339129f94168d700a6a7dd23f)
- Downloading from torrent cache urls is now retried twice to make sure its a invalid download [`f518e6a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f518e6a02f664e0c6130945d571d85aac90bb68c)
- Removed allow_redirects [`12fd7b5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/12fd7b5ba2a35d14da5f771b02a4ddd6dda78aac)
- Release v9.1.6 [`2cf9098`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2cf9098ab6dddd53e0e9ac2d7db2fb44027d5215)
- Disabled verifying ssl certs and cache for downloading torrent files from torrent cache sites [`385b6f1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/385b6f105cee0bcc57ef055284709e4e4fc7a87e)
- Merge tag '9.1.5' into develop [`8415597`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/84155976be67d1b026da87510dd133509427de3c)

#### [9.1.5](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.4...9.1.5)

> 17 August 2017

- Release v9.1.5 [`13231a1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/13231a19588974247ed2f17fa20f8e173b6e2026)
- Merge tag '9.1.4' into develop [`107e2c6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/107e2c6818b846e945c8d7dc921711f3e42c81c0)

#### [9.1.4](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.3...9.1.4)

> 17 August 2017

- Misc template code cleanup [`eca5647`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/eca564775e8de34cba39cab4e42d99ddef706a0c)
- Release v9.1.4 [`c055429`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c055429519ee343e93273206d6a654755674ae30)
- Fixed issues with adding a new show [`306d6b0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/306d6b03cfa5d536b4a3fe187d867754027152ad)
- Merge tag '9.1.3' into develop [`64b0779`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/64b07790cdecc947697b2ba625245f4fe3dbe31d)

#### [9.1.3](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.1.1...9.1.3)

> 15 August 2017

- Cleaned up bower installs [`a162a88`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a162a885a9e618f1c6456179f292b9942c687ed1)
- Release v9.1.3 [`4794c94`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4794c94bddbfae366cd0aa1cd9077cae83d6736e)
- Merge tag '9.1.1' into develop [`f077c2c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f077c2cca473d658bf475f26ecd7a9fc93fea587)

#### [9.1.1](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.0.90...9.1.1)

> 15 August 2017

- Fixed show/hide of content based on enabling a feature [`c071aec`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c071aec5a7645806130b6e8cd1dc5896ede55621)
- Updated logo [`6501a74`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6501a74ddf20a9e4fc97157fc1e8c6f280eb1e8a)
- Release v9.1.1 [`ea1a3e5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ea1a3e549df8974c2f850985469616cec235fa4b)
- Merge tag '9.0.90' into develop [`7928a75`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7928a754f69015291b5ac222f0e8e72225107a53)

#### [9.0.90](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.0.89...9.0.90)

> 14 August 2017

- Fixed tooltip issues and invalid number of columns issue with display show page [`399f86c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/399f86ca9b35e1c625336df3f0a3e08af3b02bdd)
- Fixed issue with display show title row [`fc35b2d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fc35b2d372ac6cdd28b7b69c3f5ed8ac7e4fb66a)
- Fixed tooltip issues for episode descriptions [`201c6eb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/201c6ebe55bba0ca63942d5a71e7c46013304545)
- Release v9.0.90 [`0178d4b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0178d4b44bf4bba022353bb8685b5828118dcf70)
- Merge tag '9.0.89' into develop [`d78a55e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d78a55e9ba92abaec5c6794e126723d0372a153d)

#### [9.0.89](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.0.88...9.0.89)

> 13 August 2017

- Updated IMDB popular shows template [`34d0e15`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/34d0e15b1b4fbce0c76181fb988bd9d688a83a4f)
- Fixed issues with displaying show images on IMDB popular template [`c92a212`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c92a212ee9c2c5217beb15e0bb6ec15d9304f3df)
- Fixed change size function for popular shows [`aa835da`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/aa835da69335fad7bf3045dd09d972a91d9f3da7)
- Release v9.0.89 [`12bbf4b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/12bbf4b1fc3ec11f5e90e7ae6a20c4a861183209)
- Merge tag '9.0.88' into develop [`9ff2395`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9ff23952c986b6f9f7a4febd276fd928cef8ba4e)

#### [9.0.88](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.0.87...9.0.88)

> 13 August 2017

- Changed placement arrow icons [`8fcbf4a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8fcbf4ab0720ab827162de10631c827fe9acb40e)
- Fixes issue #47 - File air date stamping failed [`f0735a3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f0735a3b22093b85056fad1d7c1416fd8dcd145c)
- Updated non-release group names [`9389c56`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9389c5697aa3fa3f6f6fdb252a28e179ace96a4e)
- Updated main navbar icons [`6c71133`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6c7113392cb615497efbec7f87e0d74dea55ca7b)
- Fixed formatting of season and episode numbers to be 2 digits [`e355b98`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e355b98136b92428b73becff3e79c5cf078eebe8)
- Release v9.0.88 [`07d2ef9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/07d2ef90f9f421d277deeba7e323c8927fb5dc9f)
- Merge tag '9.0.87' into develop [`c1a1208`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c1a12085678077140ed19c92cf4d46e572d0f84b)

#### [9.0.87](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.0.85...9.0.87)

> 12 August 2017

- Release v9.0.87 [`4901a6e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4901a6e7648b955ce2604f78d70105eb21746272)
- Merge tag '9.0.85' into develop [`932302b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/932302bdc653e33b1a812801fbc26bbb0a720ce0)

#### [9.0.85](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.0.84...9.0.85)

> 12 August 2017

- Release v9.0.85 [`720826d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/720826d12cb6e5d012b4f936ba13200ff7cd4b65)
- Fixed typo in dailysearcher code [`baa2a29`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/baa2a29c1d47122d069f079e8ed34b384a7edabc)
- Merge tag '9.0.84' into develop [`c337cbb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c337cbb35e83af4ecbdad982baff30d8adc43832)

#### [9.0.84](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.0.83...9.0.84)

> 12 August 2017

- Misc code changes to startup and shutdown of app [`70902cd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/70902cda526c1c1c21576af0bb7d1245e100d057)
- Moved io loop to main thread [`32eabe0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/32eabe03169b2e5d4ff33176717d1a0cee1de421)
- Release v9.0.84 [`c803d2d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c803d2d839b1f0953a3573c164e7ec20355cd7b8)
- Merge tag '9.0.83' into develop [`6eff8cf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6eff8cf7f23bbb8863eed92bb6f15e57c00a7a36)

#### [9.0.83](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.0.82...9.0.83)

> 12 August 2017

- Updated regexes for nameparser [`1105065`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/11050656e34bef5978caf455fc63c5a6e099a6af)
- testing ioloop threaded [`cf2c0b3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cf2c0b3165d376dfd2ca88283d5f1bb417869b6d)
- Revert "testing ioloop threaded" [`43ede21`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/43ede2116c2c0f4ae15d36d48f4eef6997310aa9)
- Misc fixes [`e7fdcba`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e7fdcbaeba4fdd44cecc058f599cc81727ae78f0)
- Changed shutdown sequence [`6f7c227`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6f7c227b14ebd6225115d83320f741d33741b747)
- Fixed restarting issue [`736cbfc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/736cbfcc1d6e584d699ce09a8b6a1d1c8e7ed56c)
- Release v9.0.83 [`318669b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/318669bc0eacfee21a8448faf45e7b5f3edf8ef0)
- fixed typo [`e7cdb57`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e7cdb5767893a815ce6eb872a5e943ab8880fd54)
- Merge tag '9.0.82' into develop [`829ae1a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/829ae1a7a3612f3eea46169a68f8a6059a02376a)

#### [9.0.82](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.0.81...9.0.82)

> 11 August 2017

- Updated selectboxes in display show page template with class input350 [`b009b72`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b009b722a8fec82eecca8e723e8e76f62e58ec78)
- Release v9.0.82 [`6ffa4d0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6ffa4d0b8d8dc7baef49a1a0e0688b393e4835b4)
- Merge tag '9.0.81' into develop [`75be423`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/75be423b9d4ee2404758b9a39e834c66fa9852c1)

#### [9.0.81](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.0.78...9.0.81)

> 11 August 2017

- Fix #53 - unicode issue during post-processing [`#53`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/53)
- Removed size restrictions on selectboxes to make them more responsive. [`6ffa3ba`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6ffa3ba5524d9e1cd7c6f1ecda32818ad22d0af4)
- arguements passed from web views are now unicode encoded to resolve unicode decode issues within app [`b2b56f4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b2b56f4f6db3f08ab115194b5b0fe0d088501aad)
- Release v9.0.81 [`4bc0209`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4bc0209d3e5fa991e4c1002d5a991f18d520edc6)
- Release v9.0.80 [`4a2fa3a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4a2fa3ad47c223b2d24830e0d886cb283865cc11)
- Merge tag '9.0.78' into develop [`4aacae4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4aacae4a3f2d4dc19f59b1314b68f0c549fec22a)

#### [9.0.78](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.0.77...9.0.78)

> 11 August 2017

- Changed layout for display show page and made it more responsive [`a888753`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a88875353ffab88e2ebe285aa40219f16b72ff58)
- Release v9.0.78 [`352fe0b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/352fe0bdd9a7d95116659f151ad84853e983d6f8)
- Merge tag '9.0.77' into develop [`c0f58db`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c0f58db070d1040cac1973df41b72f57e6301d7e)

#### [9.0.77](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.0.75...9.0.77)

> 11 August 2017

- Updated jquery-confirm bower package [`523b62a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/523b62a03e0ba214aaac3d04c2cd99c1db4960b9)
- Updated responsive code in templates [`35e0ad2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/35e0ad24b70cc8727cfd3114cd4a513b920e8be5)
- Fixed slow show adding to database issues [`677399e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/677399eb7d70e315e57243d04d753b3593913236)
- Cleaned up add show options and backlog templates [`9445b55`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9445b55610c8a7f1b51ab4595c2a7b3790e073fb)
- Fixed unicode decode issue [`f159260`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f15926053bd82de815e1f715d5d92ffeb5fa2536)
- Updated requirements [`ecabf80`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ecabf8037fe18aae69b877a90944eac829494a02)
- Release v9.0.77 [`15a7a0d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/15a7a0d9a75cf85e1212e39b242617944340fe3d)
- Merge tag '9.0.75' into develop [`becb5ee`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/becb5eec09b542aa9125444472ba7d31324d7f40)

#### [9.0.75](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.0.74...9.0.75)

> 10 August 2017

- Notifications config template is now responsive [`93f109e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/93f109ec350f93c5045fdbdec08f9da5c6da6b84)
- Misc template cleanup [`668a726`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/668a72625107ba3a06032a612d319a619a4da02a)
- Providers config template is now responsive [`b681895`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b6818954b39a3cb04a38b73850f5e2b30ba3bf86)
- Updating post-processing template responsive code [`738d613`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/738d613268c3d83149520ac21822c0fcaaeb5497)
- Config -&gt; General is now responsive [`3d2c071`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3d2c071bb4622e5a0997e5526fcd4b5a86fd57c6)
- Edit show template is now responsive [`d32f7e7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d32f7e794bf4631a96b7053c45a2ecaf82039dda)
- Core config code changes [`bdcebe1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bdcebe1cd4b73bd805f74f025ed0ac66e1a8c151)
- Post-processing config template is now responsive [`ea63857`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ea63857b9907929eddea8b6cf29de056550196a6)
- Misc template code cleanup [`bd9752f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bd9752f95886d25fe511b1036ff32ed51a04b9e0)
- Centered submenu buttons to top of page [`08a6479`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/08a64795ee3bcbd4cd5a01fb2e5da9452137a677)
- Post-processing template is now responsive [`869ff4e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/869ff4e2b7d59e8da5031c3da183033b1ab96921)
- Backlog Overview template is now responsive [`7c23adc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7c23adc369db901b4f5a6c433265cf0c0b04280a)
- Misc responsive code cleanup [`c6b39cc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c6b39cc2c8971e19a586ab6e2bd9a20599db71db)
- Updated general config template to be responsive [`d0b1f6b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d0b1f6bf0f75bace0e244b230518fd0cfb23911c)
- Config info page is now responsive [`9db243e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9db243e81fa04e9bc7fd308f955f118abe955732)
- Manage searches template is now responisve [`1717a0a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1717a0a33ef58d497b197b23094fa8e4eed24ebe)
- Quality sizes config template is now responsive [`80bda17`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/80bda17eca1b865e11ee4217b49c548dbf994a85)
- Misc template tweaks [`92b7582`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/92b75822256515bbc454588c52d2a0ab805de80a)
- Misc template code cleanups [`d20f497`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d20f49758229f420cf0348cbb38a6f2cb16a347e)
- Misc code changes [`2409d7a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2409d7a1324c88684ff6be05c460b779d3ec0fc2)
- Misc changes [`ff3dca8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ff3dca8c8e78c4af469fd0ecd56c2a0e5db26db9)
- Web views are async now [`0f42df7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0f42df76c901826c8697e4c6fc0fc2e4f8578648)
- Merge tag '9.0.74' into develop [`6dfeb92`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6dfeb92d86153164071cc5a5c08229fdb6400831)
- Web File Browser dialog box is now centered to screen correctly [`fabbf63`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fabbf63ea91af7bf08bb8df60d7baf066481bdf8)
- Misc code changes [`b7cbeba`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b7cbebaf42e28aa6e7cfc90f54ad2ada3a7c791b)
- Fixed issue displaying show banner [`c41008e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c41008e61421f49e9a9b0415a040b8bf0532d009)
- Edit show template is now responsive [`0543be7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0543be731746eb6c1f70096fce6e974da25dbcc6)
- Misc code changes [`3a9ae65`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3a9ae6590a919041be5116be8894bb958e3251df)
- Misc code changes [`fdd5acd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fdd5acde6d0e1208d07f05af83cbef526da0430b)
- Misc code changes [`e0d1e84`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e0d1e84d0e7ac4668a830cf2e841e15632e051da)
- Release v9.0.75 [`9d2ba37`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9d2ba37ee2c3cc3a47839643035a0042f5e55c6b)
- Misc code changes [`9078909`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9078909622d37a45b9fcedbb4e71125c8fd65841)

#### [9.0.74](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.0.73...9.0.74)

> 9 August 2017

- Misc version updater code cleanup [`69b26f4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/69b26f4bee2fc38b443f8b59240b1543ff3e796e)
- Fixed issue #47 - File air date stamping failed [`580ccdb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/580ccdbcf1e26e706431bed1ff041f2b1e91019d)
- #46 - Updated Nyatorrent provider url to nyaa.si [`194d14e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/194d14e16f9778af13207e9918ace64418a0b7d0)
- Release v9.0.74 [`25ba84f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/25ba84fd4f0879f9be02d58a43cb681f74f623ab)
- Merge tag '9.0.73' into develop [`9545030`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9545030dd9004c9b4ce0abf2db90f226c503b441)

#### [9.0.73](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.0.72...9.0.73)

> 8 August 2017

- Release v9.0.73 [`277d303`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/277d303965f0c6a4f6c4358d7086bf2a7e2e67b3)
- Merge tag '9.0.72' into develop [`262bb00`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/262bb00d707e089afe6cb31bdbf422cbebb6f70f)

#### [9.0.72](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.0.71...9.0.72)

> 8 August 2017

- Release v9.0.72 [`e679b10`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e679b106c4d70f211645328704a837fe54f4f886)
- Merge tag '9.0.71' into develop [`284aa43`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/284aa430514a421adaecdebcd947c807fe453531)

#### [9.0.71](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.0.70...9.0.71)

> 7 August 2017

- Fixed issues with retrieving show and episode images from indexer when show is not english [`c8dbc4b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c8dbc4b7278bf8885fa16016a2f5d855981dfc14)
- Release v9.0.71 [`adb6543`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/adb654383cf3609290c6b85fbcf1c106c1e2ae95)
- Merge tag '9.0.70' into develop [`e0172c9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e0172c9a55da8c93c00d10beb2f318cea72b73ec)

#### [9.0.70](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.0.69...9.0.70)

> 7 August 2017

- Release v9.0.70 [`062834a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/062834afbb4a60eb655c7463548a72a057b3abb3)
- Merge tag '9.0.69' into develop [`95ab385`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/95ab38577ed55446dddf920700de7e97a05f2568)

#### [9.0.69](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.0.68...9.0.69)

> 7 August 2017

- Release v9.0.69 [`24e488c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/24e488cc15ba401a677fbca768cb8f6103c007d3)
- Merge tag '9.0.68' into develop [`9d7801e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9d7801e00f32204400dc9e3ab5b95ef05cda696d)

#### [9.0.68](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.0.67...9.0.68)

> 6 August 2017

- Release v9.0.68 [`0cea9ef`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0cea9ef49b1bdf06351ff887cb3e32fd18f45ae5)
- Merge tag '9.0.67' into develop [`5dd254e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5dd254e02eef67e57892ca9a5eb74d2f0e5a8fd9)

#### [9.0.67](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.0.66...9.0.67)

> 5 August 2017

- Fixed issue #20 - rar not working [`1d7b71a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1d7b71ab1cbabec7dd5ae292a80fc7041c4243e7)
- Release v9.0.67 [`6774207`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6774207b7a641a14028743885f665d3284854b40)
- Merge tag '9.0.66' into develop [`779a7c9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/779a7c947f2f95e3e2a97b62f4047d0e7f56e1e6)

#### [9.0.66](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.0.65...9.0.66)

> 5 August 2017

- Release v9.0.66 [`859f714`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/859f71487e2e5b8458a6f39c05cefedec9f165f0)
- Merge tag '9.0.65' into develop [`5e98653`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5e986539deb34a9f5e08f03732467d3b9eff6852)

#### [9.0.65](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.0.63...9.0.65)

> 4 August 2017

- Release v9.0.65 [`0c55c51`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0c55c5172a34957029f4f6b537f959ea46b53498)
- Release v9.0.64 [`d96697c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d96697cd26478137af7faa208ad8fa5e7caea4dd)
- Merge tag '9.0.63' into develop [`c6c56e9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c6c56e95ac07f94d5a8c1833859e669d14ca9ec9)

#### [9.0.63](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.0.62...9.0.63)

> 4 August 2017

- Fixed issue #42 - Pushbullet Notifications Not Working [`6775391`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/677539109dd37bbf8e8bff551ed9c551fcb424cf)
- Release v9.0.63 [`a1277cf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a1277cfe9bf82a9ddf3817a22d6b68ba1f8264ab)
- Merge tag '9.0.62' into develop [`92af9e4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/92af9e4cd480edf597cee752f41a5a892614ac58)

#### [9.0.62](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.0.61...9.0.62)

> 4 August 2017

- Release v9.0.62 [`15f720a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/15f720a19fea206c6ac67633ea23ec0c739e496a)
- Merge tag '9.0.61' into develop [`a137310`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a1373100f973e394ffbfc5a7bfa93b6a61ba9ee5)

#### [9.0.61](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.0.44...9.0.61)

> 4 August 2017

- grunt tasks [`1735eaf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1735eafea29fc5fa2f80d4c4bfb2a51f8350b9e4)
- Release v9.0.60 [`5e8e772`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5e8e7722a439322f581f9e6114086c4bcc7f6af6)
- Release v9.0.61 [`4effd2c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4effd2cb6eac5739e5fff4403fc9bf0ebdf34084)
- Merge tag '9.0.44' into develop [`8daaa26`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8daaa2680794adb1bd93fa9475cb4173a5f32fbc)

#### [9.0.44](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.0.43...9.0.44)

> 4 August 2017

- Fixed issue #33 with adding existing shows not detecting status of episode files on disk [`a3316de`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a3316dee3738ac3aa35e72f2663dcf368800fa48)
- Fixed issue with retrieving metadata for existing shows when adding them [`9d3fd0e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9d3fd0ed165425a8af674acb6b91325a3d0b65ab)
- Merge tag '9.0.43' into develop [`1c4ed45`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1c4ed4565288cbc06423a5fecafa64141b71abe7)

#### [9.0.43](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.0.42...9.0.43)

> 3 August 2017

- set indexer searching for indexer ID is optional in nameparser [`f5ba588`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f5ba588e1910e6d534f20da844cef0e148e53402)
- Removed IMDB caching, not thread safe [`8d7f2e2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8d7f2e22786256abb4d4582fa44958e412674667)
- Removed IMDB caching, not thread safe [`a43028f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a43028f1e1504884355b9f8b33a2f278bc67d2b5)
- Merge tag '9.0.42' into develop [`32ecd10`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/32ecd10be53be4acf708f1892f598e8debbe7235)

#### [9.0.42](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.0.41...9.0.42)

> 3 August 2017

- Removed toggle switches from mako pages [`bec0c7c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bec0c7c268b69c9c457d29f4a9bdd079ca714c3a)
- fonts and images now use directory refs instead of url refs, resolves issues when using web_root option [`0c50d02`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0c50d022045e58fba767ab1c5ada69ef957c3571)
- Fix for issue #39 [`39b65eb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/39b65eb391551abfbd94f8cb210d95cd8f8d7e2d)
- Merge tag '9.0.41' into develop [`2f79837`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2f798371933ae6edf29086d77c9627cc250f42af)

#### [9.0.41](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.0.40...9.0.41)

> 1 August 2017

- Fixed symlinks for synology devices when returning show image paths [`ba6f47b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ba6f47bd0727ba7629ef14328b674d2578fd6d47)
- "performing episodes search for showname" message to only be displayed in log if there are actual episodes to be searched for [`8b294f8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8b294f80dbc7de6e4ab58f96636be1ac226f4335)
- Merge tag '9.0.40' into develop [`8a22c30`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8a22c30ee3df2c07621179efc05816fc5ebd4f5e)

#### [9.0.40](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.0.39...9.0.40)

> 31 July 2017

- Fixed incorrect refs in rtorrentlib module [`512bfcc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/512bfcce82ea5e4a93ce6e422cc662b3d607dd45)
- renamed rtorrent libs to rtorrentlib [`dfc5dbd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dfc5dbd4047c46226467b27a5b8ea786dc4e771c)
- added absolute import for rtorrent client [`961db5c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/961db5ca219c964ef3a64b060ca5f7dfe724c3de)
- Merge tag '9.0.39' into develop [`ea576f3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ea576f3e9e33d0e9b10b18e0fdced0c74d7b6c54)

#### [9.0.39](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/9.0.38...9.0.39)

> 31 July 2017

- Fixed issue with nameparser get_show function [`227ac22`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/227ac22fe49b348f181de3baf2b836c63e99be09)
- Merge tag '9.0.38' into develop [`a68d142`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a68d1426b9b2546943bbc49552a0a63f7bf88e5a)

#### [9.0.38](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v9.0.37...9.0.38)

> 30 July 2017

- Merge tag 'v9.0.37' into develop [`3e3ed86`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3e3ed8650f25b4ffe540662fe38073ff26b2b794)

#### [v9.0.37](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v9.0.36...v9.0.37)

> 30 July 2017

- Merge tag 'v9.0.36' into develop [`820d256`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/820d25657daa68cc5e0939888ad3baad9fac6f6a)

#### [v9.0.36](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v9.0.35...v9.0.36)

> 29 July 2017

#### [v9.0.35](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v9.0.34...v9.0.35)

> 29 July 2017

- Fixed issue with caching rss feed items not in tv library [`3ebc420`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3ebc420d77eecfbf39e3126dc3e5f89e951fb4da)

#### [v9.0.34](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v9.0.33...v9.0.34)

> 29 July 2017

- Fixed code for unpacking rar files [`3b3085c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3b3085c8ee19fd80205cc61bfd9e61f38fc8a026)

#### [v9.0.33](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v9.0.32...v9.0.33)

> 27 July 2017

- Fixed typo causing issue with log filtering for post-processing [`77457f8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/77457f83660542ad1234028b5ef1ca1c0295d1d4)

#### [v9.0.32](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v9.0.31...v9.0.32)

> 27 July 2017

- Misc code improvements [`1898db7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1898db76c996ce90d9c515ae2cb11e206416e649)
- Fixed typo [`6ac10bd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6ac10bde9de6f3c4eb2c80cacdcc214d8a08df07)

#### [v9.0.31](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v9.0.29...v9.0.31)

> 25 July 2017

- Fixed issue with selecting too many shows when adding existing shows [`bf579c6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bf579c677cf99e410e3f2caaa3d770fccebf85a0)
- Fixed show image scraping issues [`a492e7f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a492e7fcce5e39a918b1f232670456b030301456)
- Removed lxml from requirements [`564f31b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/564f31b756b4e5f2ac95596e7e3cf51c3d16ad90)

#### [v9.0.29](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v9.0.28...v9.0.29)

> 23 July 2017

- Fixed issues with connecting Deluged clients [`fdea81f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fdea81fc17119595989777f9f538f0c9d9be36cb)
- Fixed issues with Deluge WebUI client [`8539ec9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8539ec948780b0214ca1d357e069da7ec53af694)
- Fixed issues with provider url's [`02a28f7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/02a28f7d59357283e5ad72f84f9fb1efc6c84a99)
- Cleaned up morethan.tv provider code [`3543398`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3543398a9816d9e9a6a8522c7ffc22ac7ad9cfe8)
- Fixes session issues with cloudflare scraper and web client session request function [`341a7eb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/341a7eb4c94e5aaba30c474248d0a16145f4c59a)
- Fixed issues with sessions and cookies for providers [`5e99b21`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5e99b21701ca7bbfb2e407eff55b8e90d7f823de)
- Fixed Unicode issues with general config page [`45170ac`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/45170acb582f1bc7cc330e8fa9de2278afc6ff62)
- Fixed issues with scene exception downloading and name cache [`7f1bc8f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7f1bc8f9df430203f04a1eb4991e1f4cdd2e8ec7)
- Fixed unicode issue for displayshow template [`761353a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/761353a35dbab96b65f780390574dc9dc7d07a5e)
- Fixed issues with web client sessions not being persistent [`47afef8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/47afef8b3f7946f57805e56ba82b095aeb3462a5)
- Fixed torrentday url [`32ed9c7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/32ed9c74a9ee7bd3467f9a9cd4eb678993767f0e)
- Fixed torrentday url [`22ffaa3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/22ffaa3e159dee5a8e5caad9b8367a03c2e0c9a3)

#### [v9.0.28](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v9.0.26...v9.0.28)

> 14 July 2017

- Moved location of libs folder [`4731b6a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4731b6ac96c3d79a5418b78861d62c8e8ae481bc)

#### [v9.0.26](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v9.0.25...v9.0.26)

> 14 July 2017

- Cleaned up filtering for mass update page [`672730d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/672730de49fe83ac807e58dcb2806786c8a97fe1)
- Cleaned up filtering for mass update page [`765d71f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/765d71f7c98185488c83362204d4c19432a2ef77)
- Misc improvements to show queue functions [`28e9e8b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/28e9e8be1255fab83b438fabc0052715b58f2db3)
- Updated manifest [`abac6ed`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/abac6ed97b75eb1c4a2503b1f1db6c58524795f5)
- Updated bittorrent cache urls to use secure links [`f712802`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f71280279c37a84daf8ffec54dfbd50413146355)
- Download size filter now displays size of download and quality size when throwing exception to ignore [`6687cd7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6687cd7fb1d34742a3095c991d32eb98ce60a538)
- Updated setup file cleanup code [`4be05b1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4be05b14121b9c47b358249d67b89f806ec1eb27)
- Changed network timezones url [`1be8b99`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1be8b9998800f643c80ab47aaa9629ca4000f9eb)
- Fixed exception error for filtering sizes of download results [`b0c4125`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b0c4125607322a340532ce7224ac5082d2888c2f)
- Changed scene exceptions url [`1efad19`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1efad195815cf883c06b00e3f175fb4e0337419b)
- Changed anonymous referrer to nullrefer.com [`8eed07c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8eed07cac3e8d847595ca53bb389b7b13acf7428)

#### [v9.0.25](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v9.0.24...v9.0.25)

> 14 May 2017

- Fixed issues with post-processing air-by-date episodes [`1d137a2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1d137a252f92e8bd3bd168e4c82d9b05205b9411)
- Fixed issues with web sessions [`537e7e4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/537e7e473eb2c0838362e6d7ffd93f26cf96d75d)
- Fixed unicode issue when deleting shows [`8a3edc5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8a3edc51f19bebb5e8244c2acf7629acd1dca8f2)
- Fixed template issues with manually searching previously snatched/downloaded episodes [`8af7715`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8af77150fbda4a930a02b1017b52db28c56e4fdb)
- Fixed web session caching issues [`ffe7b30`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ffe7b3043fb03d14d57157a87f8be2508f7544c3)
- Fixed web session caching issues [`3ff85b7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3ff85b70af8d992efe2cbdea884325174da41b6d)
- Fixed typo in scheduled job name [`461c001`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/461c001575226fc4fce57011e213d4395803e5bc)
- Removed obsolete images [`ec4bc83`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ec4bc830816007f215a0c34e8263818698bcb1db)

#### [v9.0.24](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v9.0.23...v9.0.24)

> 9 May 2017

- Updated readme files and gitignore file [`d40b187`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d40b18790122b8f9f96d4cda66361b32d72f3ad8)
- Disabled web session caching for provider searches to ensure all data returned is current [`7c4bf39`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7c4bf3930c93bac7275310a29be317fea76fb755)
- Removed 7 day cache for web sessions [`ec347b0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ec347b0da197a63845be06affb5f0f2b6553e991)

#### [v9.0.23](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v9.0.22...v9.0.23)

> 8 May 2017

#### [v9.0.22](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v9.0.21...v9.0.22)

> 8 May 2017

#### [v9.0.21](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v9.0.20...v9.0.21)

> 8 May 2017

#### [v9.0.20](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v9.0.19...v9.0.20)

> 7 May 2017

- Cleaned up next episode function code [`7269f08`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7269f08ab4bc83d339298f781ea8ec1a016a1d8d)
- Fixed view log search issues by adjusting regex opts [`f9f2cd7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f9f2cd74b9ac80246e18f675e5c183c274629f63)
- Moved nextEpisode function call for daily searcher to searchForNeededEpisodes function [`4721bb5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4721bb5c3a2e659b111ebbb7b73c0e1f68eb881b)
- Removed news from list of default homepage choices [`e412510`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e4125104d587e8b9bed89ca1db637d479877f5ba)
- Fixed view log text alignment issue [`bc5f92a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bc5f92a9a5064ec79c186c0cf5134e8ae0caee50)

#### [v9.0.19](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v9.0.18...v9.0.19)

> 7 May 2017

- Fixed issues with buttons being hidden on log viewer [`39e1a19`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/39e1a19556cf6f0eb3df71a35fff50b0958be25c)
- Fixed issues with launching browser on incorrect ip address [`112d3a9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/112d3a946522ce1f69972fc5d57c780c10df4aaa)
- Fixed downloading of torrent files from hanging when issue with connecting server [`3e87d84`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3e87d84d962e2670b89b5b7eed18e49c4ca03bc2)
- Fixed issues with daily searches and episodes without a name causing pattern match errors [`da83091`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/da83091b857347c247959767f330fee911fb41b5)
- Fixed width issues with display show page [`6f7f317`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6f7f3174f27eaaa70d4b86bd4bfa7a0c6cce567d)

#### [v9.0.18](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v9.0.17...v9.0.18)

> 6 May 2017

- Fixed misc unicode issues [`71d381a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/71d381a4c2147fedc3b69faddf6e65d19c6910a5)
- Misc code cleanup [`49359c4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/49359c4afbb5a0af8ef22c9e88f970faab66f383)
- Fixed update notifications for source updates [`4924eca`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4924eca60da0c0cd1249c37b41022e20dc58b499)
- Fixed update notifications for notifiers to display new version [`85bd7d7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/85bd7d72339da971f4e3316e64ca3e87b9cd957c)
- Fixed global name 'get_lan_ip' is not defined error [`4c9b49d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4c9b49d3a1a55127348f726f92da29c0ceb7a16d)

#### [v9.0.17](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v9.0.16...v9.0.17)

> 1 May 2017

- Fixed issues with qtip js code [`6a10c8e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6a10c8e397f11a29659d6ef769dbbe86b1afb8d4)

#### [v9.0.16](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v9.0.14...v9.0.16)

> 1 May 2017

- Fixed display show table layout and column selector [`bbab0a7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bbab0a773b8e9ff4650353ac05105bf13bd66584)
- Updated tablesorter to latest version [`88ace11`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/88ace11b32b1b210247f01b6304a80818a788a01)
- Make upgrade notifications to be 90% of width and responsive [`f2e439d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f2e439daccd7b8dfffef5a3cdb808cd96abf50bb)
- Fixed season checkboxes in display shows [`58b2dae`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/58b2dae46feb27832d1db648da38ab39d3a13f7a)
- Fixed issue with 'prev episode' on main show page [`63ba9db`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/63ba9db32be931f5900400ad5ae50c0cf1e5fe23)
- Moved upgrade alerts to be positioned below submenu if exists [`ec48add`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ec48add932e3050e093f3fc6e52497e2acc4eb07)
- Moved update notifications code to views updateCheck function [`2ff8f73`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2ff8f73becd1a337a1d81ad8843ac2988da97599)
- Clears newest version text variable before redirecting to restart page on updates [`9446ad4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9446ad4cc585b89514de0b41acb1c90c2aad4bcb)
- Fixed column selection issues for display show web view [`1c72547`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1c725479da7633cd7ef2f604a8bda0b3a180b5a9)
- Fixed forced update checks to display new update text even when autoupdates are turned on [`410c93f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/410c93fad94497f24231c57de8a19f8b47f28be6)
- Released v9.0.15 [`c111307`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c111307c54fc8589b380cd5ffb6ef013490fa3c4)
- Clears newest version text variable before redirecting to restart page on updates [`69f604d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/69f604d4e1f2bbc160d44025c794ea09e96d174b)
- Clears newest version text variable before redirecting to restart page on updates [`7d2d7d8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7d2d7d8c313dbfb43198b58ac74f7148ca9a8949)

#### [v9.0.14](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v9.0.11...v9.0.14)

> 26 April 2017

- Fixed tabs for notifications config template [`c2983f8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c2983f89e75a8719a2068cf79b21bbd858f31f84)
- Fixed tabs in templates, reformtted templates [`02d0a89`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/02d0a89a917df1aeb524673ccbd7af9ab24b6b3f)
- Fixed tabs for post-processing config template [`e9f3913`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e9f3913ede32994cdad52c65b24990bbb13ecc38)
- Fixed tabs for search provider config template [`4e4ad23`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4e4ad23ebcfcf38b638ca0f6096564c172f0b9bd)
- Fixed issues with subtitle config template and adding languages [`b1a5276`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b1a527624deba8a9f54e7ca1c0b2c4bc41a994ba)
- Fixed issues with editing show info and saving it [`cfd1b33`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cfd1b33011687f8d113261d32231d8cb37d81f38)
- Removed news functions [`c603415`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c6034157bdbedc91ebce6a5d799cfed6e6910ea1)
- Fixed tabs for search provider config template [`9eb7122`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9eb71220630e5ad10c01581a9bd819d5f81088b1)
- Fixed issues with returning the wrong interface ip address [`2c722b7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2c722b760c4cfbb4ae75ac5bad194c9bfc932099)
- testing new restart code [`71d7bdb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/71d7bdb0b8823b30dea62d010a1f29ad3ba4aa58)
- testing new restart code [`7cf729d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7cf729db6d41ffd84adb16750989aa798ab71886)
- Fixed issues with enzyme exceptions [`2f73691`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2f7369100eb2709f726b90c719cfc2b7ea631e44)
- testing [`256b107`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/256b107dcb178523b7ddd35ed1a4ec68d0514180)
- Fixed version updater issues [`c96a482`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c96a482fea5ba222ab511c20f5a1e61da5f660c0)
- testing new restart code [`14cf887`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/14cf8875fee561ef6ebe47710999da12dd1bed26)
- Released v9.0.13 [`b1eeac6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b1eeac63c558d1f8eb0c7709d70331527ede0d30)
- Fixed version updater issues [`62dfd77`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/62dfd7765b90cf45d3b74a8a01237433fe4b2100)

#### [v9.0.11](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v9.0.9...v9.0.11)

> 18 April 2017

- Misc changes [`01b56d9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/01b56d966d525270c704f3253ae914e7c8c8b1a8)
- Changed layout of display shows template [`4a93dfb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4a93dfb05faed7990ea5f40c976c14f626486f4e)
- Fixed layout for history template [`c4825da`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c4825da992c5a02893afcc2062f38dab60830d4c)
- Fixed issues with navbar and anchors [`46a6106`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/46a610668718abd89de8a2f6000b5947099760ac)
- Misc changes [`245f6bf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/245f6bfcd30af2a4a8d1b096a2c03f23455fcb7a)
- Released v9.0.11 [`1259eb2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1259eb237e58a780d2b8c3bba7fc007488e6a176)
- Released v9.0.10 [`6822e6d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6822e6d1fcefe15ae476fe3252962e31da6ab380)
- Changed display shows background from poster to banner [`3771cf2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3771cf28b679603ce7c23316cebc50fa165faf82)
- Fixed show overview attribute error [`4a4538b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4a4538b708d3608726a78ca978fec7b7fc895c2c)
- Fixed show overview attribute error [`e12ff3e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e12ff3edb9705773dd29e831a92f477a32846eba)

#### [v9.0.9](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v9.0.7...v9.0.9)

> 15 April 2017

- Converting display shows to popup modal [`f9ad610`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f9ad61047cef12fc8505d544b7c39dcd9be2e342)
- Converted display show template to be responsive [`6f8a986`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6f8a986481ccce539120029fcd9728d402720e5b)
- Removed FancyBox [`572ada6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/572ada681a780287e3f7468392d847cee3af5d39)
- Removed unrequires loop continues in templates [`46d5408`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/46d5408eded50aa907200d102c7fc1d77c47dce2)
- Removed unrequires loop continues in templates [`8b9b81a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8b9b81a22f19d9430139a09b9cdb0e68ab4169b2)
- Removed FancyBox [`ef7074c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ef7074c17da56320f363b2183732c2485b343ed7)
- Fixed issues with web root variable and reverse proxies [`02bcefa`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/02bcefa67b685c40921ece6940d79f98fed77a0a)
- Updated responsiveness for display show template [`681aee3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/681aee3ad3f88fe0d0dbd98e0a08c28dddced7de)
- Removed unrequires loop continues in templates [`19fe437`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/19fe43792a40126f58629a874be54f44e8884066)
- Performed grunt tasks [`34fd2d5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/34fd2d58223640b69d7e9b2979125f4fc589a5ce)
- Released v9.0.9 [`e126a23`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e126a23606bafa254dc46dc34b65ec8f5fafbaf7)
- Fixed url paths to image files [`2f7163b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2f7163bcc61706e6ab8c6fed3058b734b549a8fc)
- Performed grunt tasks [`9941ce1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9941ce1d043d6f24036c652cf96ccc7954db291a)
- Removed showing imdb runtime/year info, uses show runtime/year instead [`010345a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/010345af90bd51acd348ef274b14763ebfef12ed)
- Performed grunt tasks [`8b0193a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8b0193a61b8653df238a969d249b8fac63406482)
- Changed notification icon size from 32x32 to 96x96 [`6c7b3cc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6c7b3cc7656ef157a295d773e95fe16f6662261c)
- Removed showing imdb runtime/year info, uses show runtime/year instead [`4f851b3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4f851b306b6f965b236c7d4b368e406e701a588a)

#### [v9.0.7](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v9.0.6...v9.0.7)

> 14 April 2017

- Updated favicon's for all devices [`b1edb65`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b1edb65414fddd6f00d98400ae93c3d35acc6895)

#### [v9.0.6](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v9.0.5...v9.0.6)

> 14 April 2017

- Removed unrequires loop continues in templates [`73e78d3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/73e78d336cfb6ea06a6467862623cab41281196d)
- Fixed issue with quality chooser template [`0ab30ee`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0ab30eea4ecd2adaaef89bd5307443ec1a69af2f)
- Use showObj when referencing indexerid [`4a8fc9c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4a8fc9c94d6c8019cce01e3245504d6bbd6a7bd1)
- Fixed issue with quality chooser template [`d0aebf1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d0aebf139614b0a0bdcb3e730badcc56ce8967bb)
- Grunt tasks performed [`53076ab`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/53076ab3dbe7f7c91431785491ed591b8ee462d2)
- Fixed regex for web server images path [`a16c75e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a16c75e0814d454386fd8d272edf01626bd109f2)
- Fixed issue with quality chooser template [`eba7fc2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/eba7fc2d3b8633ab20190b871c9cc17539ac1b31)

#### [v9.0.5](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v9.0.4...v9.0.5)

> 14 April 2017

#### [v9.0.4](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v9.0.3...v9.0.4)

> 14 April 2017

- Released v9.0.4 [`1aecdce`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1aecdceebd6901b099380faa6a78047d9439075f)

### [v9.0.3](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.8.4...v9.0.3)

> 14 April 2017

- Misc code updates and cleanups [`dbafd0b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dbafd0b1e3584839c8698d9cd8c3366fa2772508)
- Moved custom libs folder and added in code to add to python libs path [`cf5506f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cf5506f59ba76e9f8880b6e341bb0fcd8b2b9afb)
- Cleaned up subtitles code [`17f64bc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/17f64bcc6d3a2a079312d83a708c32b10cd4d360)
- Migrated to new-style settings for metadata provider objects [`ab88a54`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ab88a5484bcf157d15d5c9ee162f9ca8e2f089bd)
- Reformatted and rearranged code [`e4d8300`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e4d8300d49676e125b7eebb013a2238347007cc8)
- Cleaned up home and scheduler views [`13dea70`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/13dea70334639a886a9dff60b0a603396810f155)
- Updated provider URL [`b8fce94`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b8fce948bd124c8dcfd2bd2c4b4b70d33f571f71)
- Migrated old-style notifiers code to new-style with generators [`4658201`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/46582019d69682313e8de08a947808eb3202d00e)
- Fixed issues with web root variable and reverse proxies [`5d0de31`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5d0de3105c1e75df1072715a88e7e9842e97c66a)
- Updated subtitles downloader [`40ddccc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/40ddccc8b365acc3fdbfdb7e97e681584634a1c0)
- Improved daemon handling code [`80e464b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/80e464b7969f526c0c68199871c00e194559967e)
- Misc code cleanup [`ef6fc73`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ef6fc73ad61f60719d4172fc64c6c7f1d362a221)
- Misc code cleanup [`338f1e5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/338f1e533feaf6a9339da5b58206961bdef1b2f7)
- NEW Release v8.9.8 [`64be91c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/64be91ced953ad24fd9da1a0125aac95c4942938)
- Improved daemon handling code [`05db96b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/05db96b0f0205e9ccadb555bcb8c8f5fd26ea722)
- Updated code to help debug issues with metadata downloading issues [`033ca62`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/033ca62c7d85cf389d031e978581ec0200d2597b)
- Fixed misc bugs with web session handling/exceptions [`e29e5bf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e29e5bfb50abfd1c73f206bf0c1a4bc875a069ba)
- Fixed issues with startup delays related to compacting main database [`f042119`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f04211961c9cb886c4a4ae219ac7a5c325ec5d4b)
- Migrated from os.rmdir to shutil.rmtree [`c77b996`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c77b9960ef563d9882b3c74f245676065373702c)
- Cleaned up web server init code [`fbb3999`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fbb39992eab7b14612a966b5f35ef670ec1a8359)
- Released v9.0.3 [`5c1022e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5c1022ef6a39cb46cdbcb80193d91d6a70fb81c4)
- Developer mode disables scheduled jobs [`8ab1894`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8ab18941e5bc4e8d3bea137aceb27872f98644f6)
- Fixed issues with core session download function [`31d5fe9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/31d5fe91a34d292b6e675819b373f17af1b933f7)
- Removed misc stale code [`d4061cf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d4061cf2efb5c70cb43115ba65ae8f6afbad801f)
- Cache directory is now automatically placed in data directory [`bf1768c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bf1768c3e5d32b6257ce930835f2fbbdc8662c8f)
- Cleaned up version updater code to reduce memory usage [`639ce93`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/639ce93bdffad0fcd2efd8e555ef7fe38b6c5ffb)
- Fixes issues for corrupted thetvdb api cache [`b27f5fe`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b27f5fefdb3a01981e6d106aa3f01433492fa96b)
- Updated thetvdb api url [`6086b26`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6086b26a751afc63f6d989448718fe8a1bd872d0)
- Fixed issues displaying episode end date/time in schedule view [`59d69d0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/59d69d096fcf24cc03f35e119dfc40c3b7d29452)
- Corrected some code violations [`7c1e6b2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7c1e6b233eacea7353641f2c2500d3df0e36baa2)
- Fixed issues with new subtitles code [`417d5e2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/417d5e2e09aea3181b4ae6c160786d035e28caa3)
- Fixed import errors [`04dd3ef`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/04dd3ef2ec855db3ec2fa2ab4c4a435230feeb4e)
- Fixed issue with metadata view template code [`3f87196`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3f871960c871252bb7ea423bb939459344fe9d29)
- Fixed queue currentItem ref's [`d669135`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d66913531d5db29dd60128c999863ecdc0a6e901)
- Updated requirements [`7f2b8cf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7f2b8cf96790bc8b85052f05f2c1b556c4783796)
- Fix for failed downloads [`39b7cd5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/39b7cd5fc8e56871a89ab4d8a9a0c014204f8480)
- Fixed template error for app status [`e1e541f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e1e541f6a510320c4f700e0743fcc7cc53f2f50f)
- Increased indexer api timeout to 120s [`a7d9214`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a7d9214fe0c8a00569822fe10a588601f9615364)
- Optimized Imports [`40fd11e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/40fd11e345e061e214e620822c0f19c29cb400f5)
- Improved daemon handling code [`5e0d292`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5e0d2923da0b5dd1d693377faa9722855f25f685)
- Changed threading lock to rlock [`5ab4758`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5ab47583e2e3b84e9289b84b1ebb92a3a70889b4)
- Fixed issues when trying to retrieve images and actor info from thetvdb api [`b278192`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b27819244d82ca3653bfed79a8a3866e46e29a18)
- Removed the ability to change the log directory location and log file name [`9ee5c8c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9ee5c8cf4dce2f2b8ec4ba1281d897e8395529cb)
- Fixed pushbullet notifications [`e563457`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e563457d6de23108ead408e6cd13d48105855359)
- Fixed db backups to save correct path names [`ce5ff24`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ce5ff24e52208c9f1616c9956e1f89483366f97d)
- Updated code to help debug issues with metadata downloading issues [`e530100`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e53010038bf5661f6086d532f5db580b9bda67b7)
- Updated contributing guide [`b2af322`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b2af322771c22ca6f88973d2e7258f06e9760e7f)
- Improved daemon handling code [`785ccca`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/785ccca8a897e1990b7f49056f1fc4c1eced6dab)
- Fixed queuing priorities [`1a863e5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1a863e5b55ee8a4ec1810a3ea3be50c54fa0bdf4)
- Updated code to help debug issues with metadata downloading issues [`b5633b2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b5633b2057111d5a20d526ec32884f9cc2c53b07)
- Fix for pushbullet configuration in webserver [`49648be`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/49648be184e3d81404933789fb288d90227b6e47)
- Fixed issues with version updater [`5e2dd84`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5e2dd843c6fd8b2d4d836823eef8917be71f3f50)
- Fixed args passed when in daemon mode for browser window launching and quite [`13ef587`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/13ef587b49336271eb6a99055e50dfe17540d5b0)
- Fixed issue with parsing show airing info from thetvdb api [`ae89023`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ae89023c180e157a8c654fa4c445a1cecfeaf46c)
- Improved daemon handling code [`55d69f7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/55d69f7d5d66da1349534ff189bdfff28ff8a83d)
- Fixed issues with next_ep and prev_ep airdates for home view [`3a1a2f5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3a1a2f5db74f8176337c6e4a1c693b37719432bf)
- Fixed issue with season pack searches/downloading [`5dfb0b1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5dfb0b16b16500b49b7e861836acf4676146b094)
- Fixed issue with saving metadata provider settings [`d791a3a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d791a3a853b5555344f6a765bdeaa694c11c90f7)
- Fixed issues with displaying providers [`2694d7b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2694d7b8ee9a386cbed32828f0c7a1b9269ab168)
- Fixed issue with parsing show airing info from thetvdb api [`0e3cda5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0e3cda58d6148c15ad0ed5c13f680f4127af6402)
- Fixed issues related to renaming episodes and subtitles [`82d5a2d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/82d5a2d759fb3784a88c6cbb26d84d227b3d4682)
- Corrected some code violations [`5e53d4a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5e53d4a0de4e99212fc8bb0e226a42328193ec8e)
- Updated requirements [`6a75c06`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6a75c06b0151f0264ff8335b70c1818185ba79aa)
- Fixed issue with episode status manager and snatched. [`613f601`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/613f6015cc3cf37a52320851ad72c5e0f8276eff)
- Fixed pushbullet notifier web sessions [`5459e37`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5459e3732b3921d2fa4cd3dc7fb486311bf12271)
- Fixed issues with automated show updates [`8be82eb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8be82eb4966b1329acd8e6e22646219b35f19312)
- Fixed restart issues during updates [`873a209`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/873a209c87878f7898d7252ec33f8340a4ccf6d0)
- Fixed login redirection issues [`c60690a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c60690af661406ab48bf6329f2c266ee07a24e1e)
- Fixed issue with version updater and safety checks [`45a38c8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/45a38c873467d6e13d603e3cbdbc06ba34502ec3)
- Misc code reference cleanups [`d2d7244`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d2d724480bfcabbd9a412f5c3ab9b62286a7a203)
- Fixed issue with provider objects and ordering [`6d06475`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6d0647571916ece9b18fb97878ed548b04d9f3be)
- Updated to v8.9.4 [`10d0371`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/10d0371b32eeba07919346f1ead69b4c1d0cb5b8)
- Fixed insecure url [`7f4b642`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7f4b64248b11eaf84c1960680e415562bca5026b)
- Updated to v8.8.6 [`1594ffe`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1594ffe94b162f998bda61f08061477fd9eba574)
- Updated to v8.8.9 [`70aa230`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/70aa230393302a910d3063a98c6995c425ecb799)
- Removed startup message for daemoning pid [`3edf433`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3edf4331528b20629ba453faf4c2ae016cefbf4c)
- Queue threads joined on shutdown [`14ce167`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/14ce167d4017e0a1715eef52b469dc991d60a622)
- Version updated to v8.8.7 [`fb84609`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fb84609c7ad76bae5fe5c6f9b12a155a6c9ef9df)
- Updated to v8.9.1 [`76a3681`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/76a3681b05ef3309544a2203106e6385e390fe63)
- Updated to v8.9.0 [`11deea3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/11deea3bff269fb660f57e64163250d715f98947)
- Released v9.0.1 [`fb0e818`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fb0e8189081041cbb09eb03a227e660f0fed1e75)
- Fixed provider URL [`50fe40a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/50fe40aa88a5256a88224431bebfc9405286c3ee)
- Improved daemon handling code [`0333c4c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0333c4c2d3d06da95ee5d009d3f9f9a3dcb4ba47)
- Fixed issues with next_ep and prev_ep airdates for home view [`8456556`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8456556b804d2f61e421d4d3a887c358135fb675)

#### [v8.8.4](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.8.3...v8.8.4)

> 15 November 2016

#### [v8.8.3](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.8.2...v8.8.3)

> 13 November 2016

#### [v8.8.2](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.8.1...v8.8.2)

> 13 November 2016

- Fixes issues with Newznab providers and dict key errors for feedparser [`2a0f78f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2a0f78f2c633729c23d4e7eb3b531cfa746320a0)

#### [v8.8.1](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.8.0...v8.8.1)

> 13 November 2016

#### [v8.8.0](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.7.9...v8.8.0)

> 12 November 2016

- Fixed issues with omgwtfnzbs newznab provider searches [`671670d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/671670d811592de5d10bcf3bb3644f66089c87fe)

#### [v8.7.9](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.7.8...v8.7.9)

> 12 November 2016

- Fixed show display template code [`45d8ad2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/45d8ad23aee15f65c166e98b006ee4b6de3a9bcb)
- Fixed issues with find propers searches [`1f80a6f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1f80a6f3cb52331effc763fbd5cebcd7afffd291)
- Fixed show display template code [`f153e72`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f153e720a63901a08e40ad89435039bf2fd55eb7)
- Fixed issues with find propers routines [`5726d5f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5726d5f6c7251250f62ea519835899ecef6e189c)
- Fixed issues with database and too many files open error [`bc7184c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bc7184cb9bbf3ade8c2a71a4c78c07b3f3c7d762)
- Fixed issues with database and too many files open error [`7ad7d01`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7ad7d010d40749e7e674de01994036fae6b47933)
- Fixed show display template code [`bde3888`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bde3888c068482f57a81bd292373add9cb563941)
- Fixed show display template code [`8acf7b3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8acf7b33ced8d64a354217880370a01da9d61576)

#### [v8.7.8](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.7.7...v8.7.8)

> 7 November 2016

- Updated logo [`a546517`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a54651757b24f23bb9f41c7ab795cf9f442499c9)

#### [v8.7.7](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.7.6...v8.7.7)

> 7 November 2016

#### [v8.7.6](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.7.5...v8.7.6)

> 5 November 2016

- new: v8.7.6 [`35db11d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/35db11d7a3dd34572f6c72fdec6da40f88c3a841)

#### [v8.7.5](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.7.4...v8.7.5)

> 4 November 2016

- new: v8.7.5 [`eabff6e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/eabff6e8ec8c61dce13ac20670b111f97fe318b2)

#### [v8.7.4](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.7.3...v8.7.4)

> 1 November 2016

- new: v8.7.4 [`1140fde`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1140fde8270118a0a8047e6293d485c429766dec)

#### [v8.7.3](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.7.2...v8.7.3)

> 1 November 2016

- new: v8.7.3 [`7df9a11`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7df9a1187b39229d5c6d17db5d1af1d9aacc51ad)

#### [v8.7.2](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.7.1...v8.7.2)

> 31 October 2016

- fix: Cleaned up version updater module code [`2af3779`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2af3779d5b9fc283f1fe3d3d6b8953e59f4becb8)
- fix: Cleaned up nzbGet module [`cdc56b9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cdc56b9d57862478ebbca292f394281a2fd7e144)
- new: v8.7.2 [`25c7e45`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/25c7e455d1fa830a2f69ce8166ae819cd2f51e5a)
- fix: Cleaned up code for finding shows in show list [`2f74a8b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2f74a8b48f2e9f02465d6c230d0d3cda8c7f9f6e)
- fix: Database backups now done for each database, 5 backups per [`5b4ae73`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5b4ae7369053f5bd6cec9fb5476db61999256fb5)
- fix: Cleaned up template for new shows [`ca9a483`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ca9a483494882fc5c02a4341264bedb0b9e08ab2)

#### [v8.7.1](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.7.0...v8.7.1)

> 25 October 2016

- new: v8.7.1 [`15d2930`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/15d2930614366657db26191ca77503a7271fec8d)

#### [v8.7.0](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.6.9...v8.7.0)

> 25 October 2016

- new: v8.7.0 [`f385fce`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f385fceb4fb30defd5cf009ad43150da6e95ffd6)

#### [v8.6.9](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.6.8...v8.6.9)

> 25 October 2016

- new: v8.6.9 [`862a810`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/862a810a34c5381f930ca9cc5a0a591983e29d85)

#### [v8.6.8](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.6.7...v8.6.8)

> 25 October 2016

- new: v8.6.8 [`d0d9a70`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d0d9a70e9684d752be8c911747c4af4041c4138b)
- fix: misc url changes/cleanups [`179d46b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/179d46bfb28430488b02b55e621080252726e98c)
- fix: misc url changes/cleanups [`850f2be`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/850f2bee57e909ea50566909841a166f1df566bb)

#### [v8.6.7](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.6.6...v8.6.7)

> 23 October 2016

- new: v8.6.7 [`a6bdbdb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a6bdbdb51d7786da9abba8faed5cb7b6a534b32c)

#### [v8.6.6](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.6.5...v8.6.6)

> 23 October 2016

- new: v8.6.6 [`3405193`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/340519363a27bc4a30bc8c8ace453c2ecefe5791)

#### [v8.6.5](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.6.4...v8.6.5)

> 23 October 2016

- fix: Misc cleanup of code and headers including url updates [`99fb372`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/99fb37277daf8bce54273b3128347117081745b7)
- new: v8.6.5 [`437e2be`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/437e2bee6a0ef0a1c0611b1ba4803daa6cfc9ed8)

#### [v8.6.4](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.6.1...v8.6.4)

> 22 October 2016

- fix: Fixed issues with saving providers then having incorrect attributes showing [`002de48`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/002de486dd56cb00e14e98419303b458dd0328ac)
- new: v8.6.3 [`e5f0fae`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e5f0fae1bdfb6c501460547f4a0de6f4f08a4624)
- new: v8.6.2 [`c888b11`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c888b11c9debf58534ac32b8c913f398dc2d9e3a)
- new: v8.6.4 [`4031902`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/403190298d0b71f098d24abcd85bf463903c7dae)
- fix: corrected issue with checking for enable_cookies attribute [`3db5ed7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3db5ed77236faca97410cf9f87b38d3265cd42d7)

#### [v8.6.1](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.5.8...v8.6.1)

> 15 October 2016

- new: v8.6.1 [`c96cfe6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c96cfe6164472b384b51f88ffa51b71a61ccf7cd)
- fix: Fixed proper searcher [`33db42e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/33db42e8a8172d7c665ac73d597450b650fd9dc6)
- new: v8.6.0 [`7fe3d84`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7fe3d847859812097e475f2d52585c544b527039)

#### [v8.5.8](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.5.6...v8.5.8)

> 15 October 2016

- fix: Misc small fixes [`a0f0484`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a0f0484c9c32a7797c1691cb2638748b4e0e715e)
- fix: Minor change (testing) [`5ba5063`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5ba50638d9f177c606dd5f240adee6d5b84248f3)
- new: v8.5.7 [`74e09f1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/74e09f1da87566b45931ea85acb82d86cf19422b)
- new: v8.5.8 [`b1a92a3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b1a92a34e72b7299dcbec8a97c2027bd62883b2d)

#### [v8.5.6](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.5.4...v8.5.6)

> 13 October 2016

- fix: Misc code corrections [`5e7f7ac`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5e7f7ac748ca332c1fbfc16b0724692c5456fa4a)
- fix: Post-Processing [`c724b64`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c724b6446ae74d63806213f6c99bad4d40541f05)
- new: v8.5.5 [`416b349`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/416b349f888dad2b03cdedcd54249362c73ede6f)
- new: v8.5.6 [`f7d7168`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f7d716868aa2635d3ed99b8500d5fc9d186ce65a)

#### [v8.5.4](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.5.3...v8.5.4)

> 13 October 2016

- new: v8.5.4 [`1c30b91`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1c30b91c0f08c11fda6d54f86591d085a03fe917)

#### [v8.5.3](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.5.2...v8.5.3)

> 13 October 2016

- fix: RevConflict issue during updating of shows and imdb info was caused by mistakenly storing previous rev info to class object [`c519929`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c519929a98dd4091cbcbf7ff1fd1f71dbd96c25c)
- fix: Changed web session handling of error messages to send to debugger instead of creating a error [`1c7a1ba`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1c7a1baf8c621ca58614f38be39fa7a2cc3fe768)
- new: v8.5.3 [`a337fb8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a337fb8c0a1ae600a1e8a2f3cd64c70b8c08347c)

#### [v8.5.2](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.5.1...v8.5.2)

> 13 October 2016

- fix: Issues with web client sessions due to premature error handling, now returns response object [`9207d6f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9207d6f47ceea5d417e2b750b006f9c1264cca52)
- fix: Fixes issues with git and checkout of new branches [`5a8c514`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5a8c51484f3bb84b08e74fbffbd346409d0b8b25)
- new: v8.5.2 [`5934241`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/59342415116923ce854ed9c1241c1f8524140efc)

#### [v8.5.1](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.5.0...v8.5.1)

> 13 October 2016

- new: v8.5.1 [`d4bc818`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d4bc8186e91537d6f000d9c2ee781e9a0f0c2423)

#### [v8.5.0](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.4.7...v8.5.0)

> 12 October 2016

- fix: Provider code cleanups [`de5b544`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/de5b544c77917fc08832a38bc93e1ae5eb7de0b8)
- fix: performed several PEP8 changes [`462c9e2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/462c9e286ea9bb9283a6fdc2ea9fad0494183142)
- fix: Minor code changes [`edf7875`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/edf7875cf420ff90a93f0f348b31532d188771df)
- fix: Corrected typo in function name [`984f4d9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/984f4d98ee58adb3a3c554e66a182f156b7c28de)
- fix: Minor code placement change [`45a8004`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/45a80046e19aa05719f5924c99de74a24ecbc41d)
- fix: Queue tasks are now put into the background to prevent blocking tornado web calls [`ad6760a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ad6760a697c7651cee5c634b8cd839735cc0ccbc)
- fix: request session handling returned resp at wrong section of code, corrected [`2cbd54c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2cbd54c480ba51556836c4f1a7819cce1a3faebd)
- new: v8.5.0 [`47fe22b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/47fe22b85421cae1149229f3b7f119dce78d77dc)

#### [v8.4.7](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.4.6...v8.4.7)

> 11 October 2016

- new: v8.4.7 [`0b6a95b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0b6a95bd33eed54b21583390a27ffa87289e91c2)

#### [v8.4.6](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.4.5...v8.4.6)

> 10 October 2016

- fix: Fixed issues with deleting shows and mapping of indexer's to show id's [`257902e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/257902e8e417fb337ae0ef232a1ef390848dfcaa)
- fix: Misc fixes [`bae6ef2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bae6ef2981646081db8bdebc6c320c1fc956fe27)
- new: v8.4.6 [`baa41ea`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/baa41ea031c7c394568927e770464659d188bfa5)

#### [v8.4.5](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.4.3...v8.4.5)

> 10 October 2016

- new: v8.4.5 [`a42520e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a42520ebcc32d7e5909418fdbe3d533fd2dea18c)

#### [v8.4.3](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.4.2...v8.4.3)

> 10 October 2016

- new: v8.4.3 [`3ca1781`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3ca1781263d4f4bd35d3f6efd705163989f6dec5)

#### [v8.4.2](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.4.0...v8.4.2)

> 10 October 2016

- new: v8.4.2 [`525d3ae`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/525d3ae8ff63920ad16a601003da391cec47603f)
- fix: Backlogs start earlier now [`eb09f3d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/eb09f3d97217a880f019882e6c0301830fe10663)
- fix: Converted returned epInfo values to integers, resolves episode renaming issues [`3a87341`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3a87341c5f680bffbc1fd2e67a93ab85204ccd6b)
- new: v8.4.1 [`4df3c2c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4df3c2c83cdbf47dc41482c9ab0d7efa661dfa1b)

#### [v8.4.0](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.3.9...v8.4.0)

> 9 October 2016

- fix: Misc minor fixes [`2754b45`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2754b45452652372a36350a833e417aff89a8ce1)
- fix: Revamped network timezone code, gained overall app performance from this fix [`fee55aa`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fee55aa1e7c7e44ba24b9a3bdf2c5feacdb781f1)
- fix: Backup/Restore functions now work with new database and database backups [`3c45ed8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3c45ed80a93b59a46bc5797796018922a621cb83)
- new: v8.4.0 [`927d3fb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/927d3fb6fc84e454e6a87c18fd3b238467a65f65)

#### [v8.3.9](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.3.8...v8.3.9)

> 9 October 2016

- fix: Fixed issues with episode renamer [`8ff771b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8ff771bcfbd6b7e47d1bbe18ed8afecbb209dd34)
- fix: Fixed issues with episode renamer [`af04c02`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/af04c02f8758150af088bcb8a136e488b2e30700)
- new: v8.3.9 [`2476793`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/24767932f2b280e0ea20c5190945b725008ff0ad)
- new: v8.3.9 [`bbf088b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bbf088b2591ba47600ae389c78955365a7a9dfa9)

#### [v8.3.8](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.3.7...v8.3.8)

> 8 October 2016

- new: v8.3.8 [`9e46f05`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9e46f05418462f598e322571e2a5aecd76f17393)

#### [v8.3.7](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.3.4...v8.3.7)

> 8 October 2016

- fix: Minor code changes [`920455d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/920455d59e6681e3de14c06686c187ba3b6b09c7)
- fix: Fixed issues with retrieval and saving of IMDb info [`f4e899b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f4e899bb92c73592f652c56ac2f814099654faf8)
- new: v8.3.6 [`122bd10`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/122bd10874d9a5d8eb5ab9d85cd3f78214e0c644)
- new: v8.3.5 [`63db473`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/63db47348cab0646acfa16cf4ea2f1369b491d76)
- new: v8.3.6 [`2424afc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2424afc6348ab0470feb4711e9f6c1abade733bf)

#### [v8.3.4](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.3.3...v8.3.4)

> 8 October 2016

- fix: Minor edit_show.mako fixes [`#3269`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3269)
- fix: Removed dbFilename from mako template code [`b90acf0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b90acf04ed8d7153487c54b1f1692a62e7620ae3)
- fix: Corrected typo to resolve key error [`7d4cd4a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7d4cd4a0ec4fd2e4558068345967c2be1d13f86e)

#### [v8.3.3](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.3.2...v8.3.3)

> 8 October 2016

- new: v8.3.3 [`1c5c697`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1c5c69745256cc5c31fb37579d167614d5c4030d)

#### [v8.3.2](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.3.1...v8.3.2)

> 8 October 2016

- new: Version 8.3.2 [`6022bb3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6022bb3cfbd9395f6b10ea92fccbdff234edfb41)

#### [v8.3.1](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.3.0...v8.3.1)

> 8 October 2016

- fix: Issues with image query params resolved [`2eeb509`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2eeb509260d00e2ecf0f60b3c81caeaced859fcb)
- new: Version 8.3.1 [`4b278f6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4b278f62f49f1ecaf52edf47b01227df11a2871d)

#### [v8.3.0](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.2.4...v8.3.0)

> 7 October 2016

- fix: Fixed IMDB Popular shows page [`4244405`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/42444052415defab343c278a939e214f04f2da79)
- fix: Core queue is now multi-threaded as well as queue items [`2d9625e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2d9625e13815075c59387bd20a29b2a06ec9e3a1)
- fix: Corrected missing DOC variable indexes [`2363878`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2363878233372ccb4959366c440426ba4f3d28da)
- fix: Fixed core queue code thread naming [`1f4bfc0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1f4bfc0a1ed2de8f0dc75f891c7c965175b1f959)
- fix: Misc code corrections and fixes [`cdf2d4a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cdf2d4a996a8e2e2b40f4517f1529ab03bc2961a)
- fix: Core queue is now multi-threaded as well as queue items [`60d2c66`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/60d2c66dae95b5f78d073f812f52bbf0f967181b)
- fix: Using get calls for loading episode values from database to prevent key errors [`1e41339`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1e41339c594777365b95f0cb9007db988ef998b5)
- fix: Fixed scene time provider search [`f425aca`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f425acaa6f275547799871f9ada004bd1c694307)
- fix: Corrected search queue code for putting search items into queue [`1d4be98`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1d4be987d81d76f34afbeb0c315fde46290fd3a1)
- fix: Ctrl+C now performs proper shutdowns [`c8a3b77`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c8a3b77b643ddb6c7443ff3647af3be5acc81e76)
- fix: Corrected old code for show location to new-style [`ad28896`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ad28896ba1d067eda9db1e7205b2a524afdf0f46)
- fix: Corrected name cache code for clearing cache and properly loading database items into dict [`9101f35`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9101f3561b311ffce9997a403d8b478b2bcab4b5)
- fix: Core queue is now multi-threaded as well as queue items [`c22d84d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c22d84d6f2fdae309ccfe5c004671303db40d74c)
- fix: Fixed issues with scene season, episode, and absolute numbering for database [`d4c2bb7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d4c2bb7c67ec2be12343cb6c8dea188e4202bcc8)
- fix: Check result returned for dailyer searches to prevent issues with adding to results list [`dd02f40`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dd02f409862784152be26a06ef72b1a1982a20b9)
- fix: Corrected missing DOC variable indexes [`987c3ee`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/987c3ee3f519a4c75e49ada1a641f24c9e34b294)
- fix: Fixed core queue code thread naming [`cde2043`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cde2043c204f3ebf69a9ab16328d6e5910de1e29)
- new: Version 8.3.0 [`8dad800`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8dad800ae93e7ac77f1a7f77ab9a55672de041f0)
- new: Updated network logos [`9eb4be1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9eb4be1748a5d8666049118bbd11564d1344c054)
- fix: Lowered sleep timer [`c3fbb84`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c3fbb844c1cdd91f98382f6b5e76116da78b9ad8)
- new: Updated images [`7d3fbea`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7d3fbea1304ffd29d862143ed1fcebfeb7bae4e0)

#### [v8.2.4](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.2.3...v8.2.4)

> 23 September 2016

- new: Version 8.2.4 [`7115c4e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7115c4e4ca266b989eabdc3a57b6b5f8989d85f0)

#### [v8.2.3](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.2.2...v8.2.3)

> 23 September 2016

- new: Version 8.2.3 [`d988a71`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d988a71912d51f2da40276b64d95f208686b320f)

#### [v8.2.2](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.2.1...v8.2.2)

> 23 September 2016

- fix: Revamped core queue code [`b8b6d0b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b8b6d0b0e294a4ca5fdbe29d30082ec839d93f92)
- fix: Changed code for restarts and shutdowns [`6b4c6f5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6b4c6f5522e8c534f56021d341b75ee4fce5277b)
- new: Version 8.2.2 [`29d7d25`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/29d7d25aef05810e3a85374f26697130140edc3c)
- fix: moved shutdown of web server to last before ioloop closing [`9617086`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/961708673c9b8dc83969123968ca9e4e987eb30d)
- fix: removed clearing of ioloop, caused fd value errors [`329f2ef`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/329f2efebf11b8f9bb1a55c6a29f4319461a7859)
- fix: clear ioloop instance instead of current [`405ea0e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/405ea0eb1e2c0b7cd67ffb95162dff29a1761e08)
- update: Updated tornado requirement to version 4.4.1 [`2a49dbc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2a49dbc2a2a7ddc9ec3607019199eb5aa3747a1f)
- fix: Corrected core queue code shutdown function [`d968bf8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d968bf870bb44095dd1829413fa7a16a6953c0e3)

#### [v8.2.1](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.2.0...v8.2.1)

> 21 September 2016

- fix: Removed un-needed return statement in code [`258e91d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/258e91d46ab3e8d6a614c4f49a83875d4d351a2d)

#### [v8.2.0](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.1.9...v8.2.0)

> 20 September 2016

- new: Version 8.2.0 [`4f6c1d6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4f6c1d62cd244f0170415ef46fce091daa8c22e2)

#### [v8.1.9](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.1.8...v8.1.9)

> 18 September 2016

- fix: Changed routing code for web view methods to return None if unable to locate correct route and skip rendering web view [`436b17f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/436b17f1fbe7f7e62afd85f747ce3ddde931138b)
- new: Version 8.1.9 [`3e79a8f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3e79a8f121e2b95e9ed67899a8816da349f879ea)

#### [v8.1.8](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.1.7...v8.1.8)

> 18 September 2016

#### [v8.1.7](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.1.6...v8.1.7)

> 18 September 2016

- fix: Correct column span for display shows to fix background [`b773e6d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b773e6d86b7958706b9eb22f96bda520c337acc5)
- fix: Removed error logging during automatic daily show updates [`cdc9e5a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cdc9e5a47a45a664f35945504c7b90189af9eb11)
- fix: mapped parsed json data from XEM to integer, helps checking for indexer id [`d088fcc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d088fccabfddeb15e00ed0089514ee8000d6bc6a)
- new: Version 8.1.7 [`37e526d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/37e526d89d04d887212a69c29c676d6d725248b9)
- fix: Corrected query variable [`e87deb5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e87deb56fd5c77d0eef6135829b786ca13077b1a)

#### [v8.1.6](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.1.5...v8.1.6)

> 17 September 2016

- fix: Changed show refreshes to not be forced during automatic show updates [`6021a02`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6021a027037a7683b589439016d41ade1e263acd)
- new: Version 8.1.6 [`f34195f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f34195f44ba432c81d8668f520d686e00fe56673)

#### [v8.1.5](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.1.4...v8.1.5)

> 14 September 2016

- fix: Removed redirect routine override [`cf2b15d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cf2b15d8ae9191ae96a0e06f5310814c10dc4f53)
- new: Version 8.1.5 [`84f1285`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/84f12859db7b7b3a3bc11d15532defdafdb0c32e)

#### [v8.1.4](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.1.3...v8.1.4)

> 14 September 2016

- fix: Fixed issue with IMDb during adding and updating of shows [`93c2b78`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/93c2b789bbb4327feb1005cf559d1807d9d47630)
- new: Version 8.1.4 [`d6bb6ea`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d6bb6ea63b94b874326657883f8437e32730c194)

#### [v8.1.3](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.1.2...v8.1.3)

> 10 September 2016

- new: Version 8.1.3 [`2dbae19`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2dbae19408db4c05d29769ebcc60506ae703785b)
- Updated changelog grunt task to append to changelog [`15fe75d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/15fe75db9f40fcd7b5ac803bc42963733ba51169)
- fix: Bumped DB version to 44 to be compatible with other forks [`b1d4247`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b1d4247621bd5dac1ea744c0b0fb425cc6ed892c)
- Updated url for torrentz torrent provider [`201af10`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/201af10c231cfb7097c0136917ffb0609b2288b8)

#### [v8.1.2](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.1.1...v8.1.2)

> 9 September 2016

- Fixed core queue minimum priority checking code [`e57cb6a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e57cb6a07d913850149a7df48ac627848834ccd0)
- Fixed core queue minimum priority checking code [`d9d2ce0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d9d2ce0d1db8d8f123c80c13848c07cdde180f40)
- Fixed core queue minimum priority checking code [`aa14dc0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/aa14dc0071909407e62f05170e9eff7ae8dc4a2a)
- Fixed core queue minimum priority checking code [`eb9f718`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/eb9f71853d42b75cb88c35fb141e411a1cc399db)
- Fixed core queue minimum priority checking code [`e0300f1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e0300f1415a0d6fbc4c364de4a291feb30ec5eb0)
- Fixed core queue minimum priority checking code [`ce154cb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ce154cb15364924528f5f7196f995fa4d1ff968a)
- Changed queue interval timers from 5s to 1s [`d3106ff`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d3106ffad3b097f85df1739be0256a2d1f1ad26c)
- Fixed core queue minimum priority checking code [`1d630dc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1d630dc8c585fe97db254a1a9e3ec50e43a1b9cb)
- Fixed core queue minimum priority checking code [`dc6f6d2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dc6f6d2bc92eab72421662584d2fc09bf6200986)
- Updated to version 8.1.2 [`3942052`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/394205291912b37c924d7c1004bf6a28d0cb713a)
- Removed version check from web gui footer mako code [`5772348`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5772348f3093ae12d2c94339da20e1c6751844fb)

#### [v8.1.1](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.1.0...v8.1.1)

> 9 September 2016

- Fixed core queue code issues related to adding of shows [`e0a1420`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e0a1420dce12d1e2b2821524005c8d5bfa59b404)

#### [v8.1.0](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.0.11...v8.1.0)

> 8 September 2016

- Fixed several issues relating to NZB/Newznab providers and searches [`a04f1d9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a04f1d963146344e4373c4352d73246f35fa0280)
- Fixed several issues relating to NZB/Newznab providers and searches [`2d06621`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2d0662158d179caf9414c90d914b2a39dcc5d2ba)
- Cleaned up search code. [`3f513cf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3f513cf2026f0d4ac214505b6f0d5682acb726eb)
- Fixed issues with getting overall size of search results. [`cd19664`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cd196648c2bdc7f84ce52a29906baea3d4111650)
- Fixed issues with core queue code [`321616e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/321616e8ab4bf4a18e50e1ebfa27a6a10801c5eb)
- Fixed code in queue's for handling currentItem [`a2e97e8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a2e97e8769e41c0770a82955fc3ca8db902856b4)
- Fixed code in queue's for handling currentItem [`06f398c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/06f398caa431046672bf2168e5ce2a99a44202ad)
- Fixed code in queue's for handling currentItem [`3663dd7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3663dd786d87368c2a6bc3ab7f3d6642ec6972b3)
- Fixed code in queue's for handling currentItem [`3904a3c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3904a3c25e77b4d8f037a142105048906fdc1e66)
- Fixed code in queue's for handling currentItem [`dfa5e99`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dfa5e99b45e7c2690f0d2882b9515cd05be5d337)
- Disabled raising exceptions for getting file sizes during provider searches [`5494ed7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5494ed7125d16edcdefee8d4235db0c8db2b7442)
- Updated auto-install of requirements to use '--user' flag [`c04c0a7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c04c0a7685518e0e762bb9d131f31f25da14efee)
- Fixed code in queue's for handling currentItem [`6ea6a06`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6ea6a06df01eb65b3f83effe7a698e723b7f69cf)
- Fixed code in queue's for handling currentItem [`577c75a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/577c75a9e59f3ad43402abf707f1eaac7c30f3f0)
- Updated version to 8.1.0 [`4ded8bb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4ded8bb64209b21e416ecf934b401ccebc5a0307)

#### [v8.0.11](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.0.9...v8.0.11)

> 28 August 2016

- Fixed issues with NZB searches and params [`e2793c2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e2793c21c02680034ecebb5f6ee82fd630d31a51)
- Updated version to 8.0.11 [`dbf8ac3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dbf8ac346580f62ee6f0dbb06cc3b531d4f539ff)

#### [v8.0.9](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.0.8...v8.0.9)

> 27 August 2016

- Corrected fixing of unaired statuses on startup [`dd2394b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dd2394b4a0e0473e61057ba952b21437b2abe3e3)
- Updated to version 8.0.9 [`9809565`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/980956586ef6b4851da85c36dc1a22d276985287)

#### [v8.0.8](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.0.7...v8.0.8)

> 27 August 2016

- Updated Regexes. [`cb62854`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cb6285490afae229981f2b2ad4dec56310f72984)
- Corrected session exception handler code. [`aa02f47`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/aa02f47f9565881f56fdc47194f8796cb9772f62)
- Fixed some issues with formatting of error messages [`ed27f96`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ed27f96c732b99674ac291e9289ced1e27c2fc6f)
- Fixed issues with NZB providers and retrieving categories [`11e2e41`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/11e2e41fdb46f2710cd38f0eee385c48b3b04dda)
- Version updated to 8.0.8 [`10acd0e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/10acd0e46702834baa9c4bc01341a7010801f74a)
- Fixed issue with mainDB code for fixing unaired statuses on episodes. [`9fa8f46`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9fa8f46677396d9c1749a47c3433a94b8d2bd76b)
- Fixed issue with mainDB code for fixing unaired statuses on episodes. [`b96c56b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b96c56bb1be5090bf4228c94b160b538ca21e22a)
- Fixed issue with mainDB code for fixing unaired statuses on episodes. [`22d9c40`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/22d9c404fff2825423c75227ee7dce74af8dc5e9)
- Using error instead of exception for session wrapper [`f4d6cd0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f4d6cd05051efa807bb013bcdf29e05147a61530)
- Updated regexes file encoding [`bb5489d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bb5489d2c61cb31de16631b45c5dbc6f997493ef)

#### [v8.0.7](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.0.6...v8.0.7)

> 15 August 2016

- FIXED: Corrected search url for kickass torrents [`a65d191`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a65d191c24ab789b81dd0fced2de04a0c8080784)
- FIXED: Corrected search url for kickass torrents [`0037fd9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0037fd900c967859ae61a31a5530833dfa253e3b)

#### [v8.0.6](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.0.4...v8.0.6)

> 27 July 2016

- FIXED: Language selector for add new shows page [`a6a399a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a6a399a0cea41238942c49193600ebd82e487274)
- FIXED: Placement of dropdown boxes on home page for listing shows centered properly [`55ce7cb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/55ce7cb29da4d9f6bd0253274d73dbaa2dd11738)
- FIXED: Outlines around jquery tab panels removed [`d2669af`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d2669afe4eac0e93d75c5cfaaaabc51e629e60c5)
- FIXED: Requirement issues with setup.py when using git links [`80f7ca7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/80f7ca7a40d2a720cf16a8ecc006dfbe25c82040)
- FIXED: Displaying/Editing shows with missing or invalid show directories is now possible [`13dc799`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/13dc7994c20355c456b3d44d0ea7a3bd119dc76b)
- FIXED: Removed border around ui widgets [`2fc2d22`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2fc2d229eed499526a946775a0da68317c6eb7fc)
- FIXED: Placement of dropdown boxes on home page for listing shows centered properly [`4f1d53e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4f1d53e14cc39f22e91e374bb391e76c0ae74168)
- FIXED: References to old code changed to reflect new code, handling of provider urls [`d3044d3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d3044d3e282a315ae54628efc41eac75fc19c5c0)
- FIXED: Placement of dropdown boxes on home page for listing shows centered properly [`a249f72`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a249f72f83ee171ed2611a1ef73c9472daf5035a)
- FIXED: Issue with displaying episode location in display_show template [`824464f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/824464f5223c1524b5243388fc5a25098477646c)

#### [v8.0.4](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.0.3...v8.0.4)

> 3 July 2016

- FIXED: Config file argument when passed in is now checked to be absolute or not and corrected accordingly [`e06dee3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e06dee3efa239c7efbf86fed52b62be1b4603bef)

#### [v8.0.3](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v8.0.0...v8.0.3)

> 30 June 2016

- FIXED: Requirements slimmed down and replaced python-fanart with updated version using newer requests [`099e0ad`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/099e0ad08d621f434af836cbd80493bfb643b825)
- FIXED: Issues with daemonizing and unicode resolved. [`9f53481`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9f5348184c5e85f7f18a56e2a1c7ba6f2c41f3cb)
- FIXED: Issues with daemonizing and unicode resolved. [`ecb16e1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ecb16e12c2a028eb2cca3f4c5242fb3c1e0e1658)

### [v8.0.0](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/7.0.22...v8.0.0)

> 20 June 2016

- Fixed issue with anon_url whereby if the URI began with https:// it ... [`#3264`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3264)
- Restruct of javascript routines and imports. [`cb6ecf1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cb6ecf1c5a0594306d554fd45445be03ba1a3e25)
- Fixed WebUI issues with threads being blocked when heavy tasks are executed in the background. [`ce1e345`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ce1e3459dc5c344476050fb7cf845c3ef5492e06)
- Misc fixes for anidb connection code, removed setup function from helpers. [`2a5dfad`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2a5dfadefe47d16b794b7d14cef451e14f57dc93)
- Provider settings are now pickled. [`11011b5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/11011b56cc43e1ab4685d807157d0809c8d2d763)
- Fixed file browser js code. [`715ae67`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/715ae678ab3090947b842d2d9c21e43864b5d93d)
- Misc small fixes for provider classes. [`f33bc7a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f33bc7abfc3e612b32786a63d6256558a31f208c)
- Fixed issue with git mako code template. [`13f9245`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/13f9245f4c08efd1dd2fa183b5db47e59bb9bd69)
- Fixed add new shows js code and mako templates [`8fc3fea`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8fc3feae2111a1429ae744cfa4da25cf45f7794d)
- FIX: Corrected minor issues with backup and restore of config/db files for app when porting backups from other forks [`57240f6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/57240f690271097b228cc8f83b0d4ff0918a7d5c)
- Converted all "from datetime" imports to relevant imports. [`c1879b3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c1879b30662cf462f47271f0f84b8b598f5ccbf9)
- FIXED: Disabled same-thread checks for databases to fix issues with more then one thread opening the database files [`6c82baf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6c82bafdeb31994b60e4a5ac66aea48cf16f4f30)
- Fixed issue with ioloop exception caused by sleeping being called from different thread then main. [`0d52dc9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0d52dc9f78da321e3adbb27767078e8ad8f9eddd)
- Fixed issues with custom requests session class code to properly handle kwargs and updating of them when required. [`34a558a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/34a558a29041d36394093e44109ec2154f0d4901)
- Misc WebUI changes. [`f4b88ac`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f4b88ac18e2929847eb1642ae1a73c503d0e450b)
- Moved WebUI notification queue instance to core instance. [`eef41d3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/eef41d3ea42a3d93a9d585f4154c9e219eaa6c79)
- Fixed responsive mobile layout. [`4ca63b4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4ca63b461704b7f835d837ef75bc79fefdc609aa)
- Fixed issues with git branch checkouts. [`22911d3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/22911d3a7f222c4797c4f4b9d6b77437ae305e86)
- Update git ignores [`c3536f3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c3536f3ee296a9df265d50384f8e8accc0a8333b)
- Updated WebUI via Grunt [`e74e982`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e74e98274c7f779eb8be3b51950cb8ba9d8d33a8)
- FIXED: Expand/Collaspe button for episode status manager [`b5caac0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b5caac04de59eb182384cc6bbc5722e0e42fc65a)
- Corrected code issues with new indexer persistent show cache, works now! [`b053953`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b053953308a6c4c9a06515ff3fec5a7d93741bb1)
- Grunt updates. [`4cadf49`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4cadf4956646c08fa68b4cf23324652bd35659a0)
- FIX: Updated web site url [`3e4a7ca`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3e4a7caa83c28b5ba00e76ab484c8e7d88578b08)
- Improved updater checker code. [`89180e2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/89180e252671db58b709b07d9f13de5f51bda1dd)
- FIXED: Detects VirtualEnv properly during pip and requirements installations [`580b217`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/580b217c1f58cb7f836369540611c390abc86edc)
- FIXED: Detects VirtualEnv properly during pip and requirements installations [`5bf6fc9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5bf6fc9849cc06516c1c6199dcb2fa060b711581)
- Fixed issues with show updates/refreshes both auto and forced, enforced to skip grabbing info from DB to ensure new data takes properly and repairs damaged shows/episodes. [`4239c9e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4239c9e9a43f9dfe6a036d3da9e1f78d41187849)
- Update web views code for restarting, added 5 sec timer for restarts. [`1a428b2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1a428b29a9b446060f9e8d53dc1d3fb2ad8e3586)
- Fixed issue with stale pidfiles, checks if proc exists then removes from filesystem. [`9005b83`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9005b83841913cdd14d921919971730cba5da85b)
- Converted all "from datetime" imports to relevant imports. [`cb52ac7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cb52ac7ebf778a07b820d61449ee3f583de0b6e9)
- FIXED: Email notification erros [`8cae227`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8cae227ffc548c24bcb393d4a0735414652837a2)
- Fixed incorrect refences to srConfig class in mako templates. [`3edf3b8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3edf3b861ec1781bdf4d52accc4e395b6842c888)
- FIXED: When disabling torrent or nzb functionality for searches but not disabling individual providers under those categories the non-disabled providers were still being used for searches even if the main classification of them was disabled [`6fd10db`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6fd10dbb1e1de352492f6b71cbfccb3591f52fb0)
- Updated bower requirements and core js code. [`a4f17c3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a4f17c30244ec02f3fb9744da988497cfb3209cc)
- Changed code for pip installation of requirements. [`bce2784`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bce2784751d921eb5fddcb7bf899017d08a155e5)
- Fixed several code issues relating to restarts of sickrage app. [`db8e33c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/db8e33cf595cfb442cffd4d45d66530712c05e98)
- More responsive-ui fixes applied [`9bd21fc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9bd21fcfd6fcb0d4c90355fd5328053ab101389f)
- Updated repo readme file [`4b81746`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4b817462810348c8cb93647c4218f264b41855f7)
- Updated readme [`4e28dee`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4e28dee8f40513b437f0143171608a7472a060fd)
- Updated repo readme file [`a81b7cb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a81b7cb29e6e25b88624fdf9cb0bd2f62107c789)
- FIXED: Requests exceptional handler can optionally be turned off to allow custom handling of certain exceptions [`d293d32`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d293d32347408d01b8fbc629ba62a899591da30b)
- Grunt updates to core js files. [`358bd5c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/358bd5c3770033b79c1d9fe218c7520f2d8713ce)
- FIXED: Queue was not properly looping through tasks, corrected by adding a while statement [`13b9977`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/13b9977bd053f935e260e830acfbd590a9d86364)
- Fixed issue with daemonizing app to background on linux. [`6bbb744`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6bbb744a5150a16ec425ac6eb9dabb76def9a96a)
- FIXED: Daily searches now set shows airing on the day of the performed search to wanted instead of including hours and mintues as a deciding factor [`c46fbc6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c46fbc67dd7ecb7a457f01fa6d0b03461f3fd16d)
- FIXED: General settings during save was missing new stale shows variable causing settings not to be saved. [`9418082`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9418082e7a6b23edb273476c6537af4c67f480a9)
- FIXED: Issue with new pip upgrades and requirements installations [`0a6a028`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0a6a02882a03116262617a0a924773af2581d7d7)
- FIXED: Queue was to slow with previous shutdown implementation so added a new improved stop event [`082c883`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/082c8830e7a7bc43e07d1ebb0f0eb1343044eddd)
- Fixed issues with sys.stdout during installation of requirements. [`d5b3d69`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d5b3d69a63fcd2806a6a2e8a559fa6822cc43816)
- Fixed issue with auto-detecting git executable path. [`15f2dd5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/15f2dd5f8c6b6c3befc816533cc3e9d1fcf01a57)
- Fixed several small issues in version updater class. [`df6068f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/df6068fb808f11aaed000eb1df62c812e0613870)
- Misc fixes for version updater [`ee11333`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ee11333d3bcaf260a653fb59b10859936a70cf0d)
- Updated changelog [`ef60c54`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ef60c54ebeb8db4f9e3f872670ddba57ea93360c)
- FIXED: References to sleep in some modules where incorrectly specified [`ba14b9d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ba14b9d673d25f59b7f1bb212fc192ab6057a3df)
- Fixed issue with version updater not properly determining install type. [`85fe032`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/85fe03227f17e70a83f8f4784bb2affea5e3ab2d)
- Fixed redundant loading of network timezone data from database. [`0d2e6e0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0d2e6e07599f67b64fc159525565104cdc83981e)
- Updated name cache to re-load saved data from database and save to database on successful builds. [`3de2a0e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3de2a0edca8b0a69d91a75d633aad3de3d103e9b)
- Updated name cache to save show to db when building internal cache. [`8845cff`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8845cff7c7354d75d2ef094533199db12e73c217)
- Updated resources for checking if pid exists. [`0848dd4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0848dd4a0d71be882d78251535059b55934d9153)
- More updates made to version checker [`7b8d27b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7b8d27b8154398b67b91ba9b9014f1b2e6164607)
- Removed gitlab-ci runner config, moved to pages branch [`9fdf493`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9fdf4939dce1a3233b6a624443f5ab16b704b8fe)
- Corrected exception messaging handling for refreshing shows from folders. [`28641dc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/28641dc1a776ac7042a12513eec5589dcb092907)
- FIXED: Requirements installation now recursive [`f1919a1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f1919a1cf65bb67c1cb7f8119dd9bd2b72f46516)
- Fixed more issues with git mako code template. [`5f896e3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5f896e3e12b2b8175fd2015687c9b8301cfd7aa5)
- Fixed str type error in version updater. [`4c00838`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4c00838603122dc55228e875f0f7fdadc08145b2)
- Fixed issue with anon_url whereby if the URI began with https:// it added [`e83d29a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e83d29a05d8bcfc47fbf2205162c11202733c66e)
- Corrected standard_absolute regex [`2b3eb60`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2b3eb6051aa06cec298fce45ef6b4dafb55b0d78)
- Fixed several issues with database operations including upgrading of database versions. [`f5a81d7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f5a81d70f762ca4da4da2e1febfb1b496ce5bfc9)
- FIXED: Removed PyDrive from requirements and constraints files, using custom internal methods instead [`a8568d4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a8568d4e8f5e7e81175da7c0e22ba8c693fa3125)
- Updated pip manifest. [`1508342`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1508342fb2177410e24e581a7351188ce88526a3)
- Removed "publish" cmd from setup.py [`04059de`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/04059decb695af946e0e0123ef3815a01d7fd871)
- FIXED: Incorrect filename specified for constraints if performing a install via setup.py [`e7e7340`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e7e73406f3ef5fc2a8369d155a1af370e9b4f6f7)
- FIXED: Web client exception handling now logs via exception not error [`fa6a00d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fa6a00dc3056a5bac9516cd24714609137a98f23)
- Restruct of javascript routines and imports. [`504865f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/504865fe4546e3b45ff48b7d899ddec91ef1a5de)
- FIX: Corrected issue with email notifier and unicoded username/passwords [`9b07c19`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9b07c19917bb51961dd1d911b909023e97cae1c3)
- Fixed a type error issue in version updater. [`690343c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/690343cd1d521ea3896ebbe6f6c67ca6c171d71c)
- Fixed issue with snatching torrent magnet links. [`1866bfa`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1866bfa7b99063d96e9eb1c48ca3d3324e0371f5)
- FIXED: Issue with shutdowns and queues resolved. [`553cd75`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/553cd75d76074824de0a9355f47126723c528267)
- Fixed issue with transmission torrent client ratio feature, confirms ratio is a integer or long. [`24224c2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/24224c213b59c21a185d3dbd456b7fe3705ad1ec)
- Updated setup.cfg [`782dd7c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/782dd7c6fba3312eafb2e29de5118e868ea09d4e)
- Updated donation link in templates. [`f73c439`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f73c439dcb47e6ca69a80dd3f73648187efcb0a0)
- Updated readme.md [`8aa69f5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8aa69f54989ad9b469f14f0c6f397c833196d433)
- Updated permissions, set executable bit [`e97d758`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e97d7582e600eb369224e8718592524ca25ffb10)
- updated permissions [`c76c77b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c76c77b518465ec1ed8cd19fc4364d035fd19ef3)

#### [7.0.22](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/7.0.21...7.0.22)

> 8 February 2016

- Fixed issues with running as a daemon, moved logging calls to start after daemonizing. [`a58ca53`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a58ca539dd9864ffaafcca5dcb037cd408988aca)

#### [7.0.21](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/7.0.18...7.0.21)

> 8 February 2016

#### [7.0.18](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/7.0.17...7.0.18)

> 8 February 2016

- Replaced IMDBPy with imdbpie to avoid requirement of lxml. [`9e1c098`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9e1c09809626a84ddfc1d1dd1ebe15012923eb09)

#### [7.0.17](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/7.0.16...7.0.17)

> 8 February 2016

- Removed requirements module and moved code into main module for startup. [`146ad83`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/146ad834956b386573cb63d3af405775a3296eeb)

#### [7.0.16](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/7.0.12...7.0.16)

> 7 February 2016

#### [7.0.12](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/7.0.10...7.0.12)

> 7 February 2016

- Reverted all tornado gen.sleep calls to time.sleep calls. [`f352ff9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f352ff901417dcfcbda79fa9fc774f1e4680ddc1)

#### [7.0.10](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/7.0.5...7.0.10)

> 7 February 2016

- Reverted database back to using concurrent futures for multithreading. [`db8ad5b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/db8ad5b2e20b70f91ff6eb8dcfe138c29e543be2)

#### [7.0.5](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/7.0.3...7.0.5)

> 6 February 2016

- Changed database queries and upserts to use multithreading correctly so to not block the web-ui. [`fd1f005`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fd1f005ae7dd5898503aeaacbe31fc25c81a122f)

#### [7.0.3](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/7.0.2...7.0.3)

> 6 February 2016

- Moved a few constants to the top-level of main module. [`5adef32`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5adef324e68b82ea4b10ac4ad629ce3171b9cea2)

#### [7.0.2](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/7.0.0...7.0.2)

> 6 February 2016

- Fixed issues viewing schedules regarding datetime problems. [`832840a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/832840ae06c0220cb3b377ccbb2237137d1bc392)

### [7.0.0](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/6.0.59...7.0.0)

> 6 February 2016

- Release version 7.0.0 [`a6e82cb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a6e82cb66e71309ccef6ce9edbc194f68c4b8ad1)

#### [6.0.59](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/6.0.58...6.0.59)

> 6 February 2016

#### [6.0.58](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/6.0.57...6.0.58)

> 6 February 2016

- New daemonizing code added [`1edbb2a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1edbb2a2293fd50b2ce496602c5ceec3190c3d66)

#### [6.0.57](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/6.0.56...6.0.57)

> 6 February 2016

- Corrected issues with daemonizing sickrage on startup [`e00e5f0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e00e5f054c9131c1d79cf6525072eb687ea04ed7)

#### [6.0.56](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/6.0.55...6.0.56)

> 6 February 2016

- Fixed more issues found with startup and pip installs/upgrades of required packages when running as a non-root/admin user [`13be08c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/13be08cfb6ea4f6c985c28326bac83fb3d1ef2c0)
- Fixed issue that was causing logger to duplicate log messages. [`991c4d4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/991c4d44a0a56cf99b313c627147cb630f05c2bf)
- Corrected path issue for tests and travis-cl [`35607d0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/35607d06486c234ec395dbde1c903129d4dfac5a)
- Updated travis-cl run script for tests. [`c5e4a38`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c5e4a38f21b7ddb837c1320a9d44da432b776582)
- Version bump to 6.0.56 [`9f8f618`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9f8f618f1066a7d6964ac94c6198f04e75999f52)

#### [6.0.55](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/6.0.52...6.0.55)

> 5 February 2016

#### [6.0.52](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/6.0.50...6.0.52)

> 5 February 2016

#### [6.0.50](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/6.0.45...6.0.50)

> 5 February 2016

- Fixed issues with pip updates on startup. [`23a7f73`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/23a7f73e6cf076b070f2ec91d55071e04c4ee5a7)

#### [6.0.45](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/6.0.30...6.0.45)

> 3 February 2016

- Restructured folder layout to conform to pip install standards and fix startup issues. [`7c4d0f0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7c4d0f0889cac1f41c02a3b3e64c12875c4fa64b)
- Fixed issues with installed/upgraded packages not being detected properly and re-installed anyways. [`dbb0550`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dbb05507bfab8b63872029ab9c961ad25072c02d)
- Fixed module import error on startup files. [`7a522f1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7a522f1d47ec309caf81ac586865997afcc6e8a2)

#### [6.0.30](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/6.0.27...6.0.30)

> 19 January 2016

- Pip installs now use Install class for installs/upgrades during startup, this fixes more startup related issues. [`3ae3625`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3ae36256459a8468e6847e2ca2a071cb3753516b)
- Fixed issues with setup.py for pip installs. [`38df002`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/38df0020156a2b188c0649a042dd721e21060301)
- Fixed issue with thread naming and instances not being classes [`de05f45`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/de05f45971fc86f3f5dfbeb625cbe16c4b72cf71)
- Bump to version v6.0.29 [`f49d861`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f49d8613cdfa4e36b44836877a79380dfeeada5f)
- Bumped version to v6.0.28 [`19c425a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/19c425a5b858e326ae671b8fdfc330d7c9b25e6e)

#### [6.0.27](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/6.0.25...6.0.27)

> 18 January 2016

- Fixed beautifulsoup issues with html5lib and parser, resolves several issues in relation to torrent providers [`22a357a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/22a357a68354f89463b7becbbb980d25b8f342ba)
- Fixed startup issue related to pip installs [`b6ab8a3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b6ab8a3e198600dd503c05332aaae9a0ebdcc79f)
- Fixed 2 more bs4 issues [`57149b3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/57149b30f249d2d44e569556cae8660a3270fcf9)
- Fixed issue with privs checker at startup [`015e69f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/015e69ffecfc94059b1fd5f04cc36d789b17a9f3)
- Correct path mistake for travis-ci builds. [`ededc5f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ededc5fa43233e3b80ba7737397ef0d8320d5cf6)
- Bumped version to v6.0.26 [`22bb3b6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/22bb3b63ba8a8e4a5a5ab0bb8721c2dc6d17c15b)
- Need more coffee [`f75ba3f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f75ba3f97b2f1404a7b9ff272ef5435b05d85ede)
- Changed executable bit on install.sh [`d2cc69a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d2cc69aa62872797ef829354fe92b3f8cca2ae3c)

#### [6.0.25](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/6.0.24...6.0.25)

> 18 January 2016

- Changed executable bit on install.sh [`0bed0df`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0bed0dfd9ed0763ce8ec0a1f918c1d0ff78ba237)

#### [6.0.24](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/6.0.23...6.0.24)

> 18 January 2016

- Fixed database call issues for daily searches [`2a73bc9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2a73bc99e9818156d039e6dbb853409f577e99c6)
- Updated travis-ci tests to install requirements via pip before performing tests. [`fdef5c7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fdef5c782d00e46bde2a593539e2c00e4967289a)
- Fixed issue with pip installs being unable to locate get-pip.py [`8d71dbb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8d71dbb25c2030f28472b544a0e7e2e530e5a5cb)
- Fixed issues with status view [`b911bf7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b911bf796731cec83aa2fdf24dc54a20d5907831)
- Fixed issues with detailed history views [`e2067d7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e2067d71b1edfbae630ab162dd22ef2408e9f926)

#### [6.0.23](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/6.0.22...6.0.23)

> 18 January 2016

- Version bumped to v6.0.23 [`ef7facd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ef7facd5aae34565b54645aec60fd3ef5d19d942)

### [6.0.22](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/4.2.5...6.0.22)

> 18 January 2016

- NEW: Rewrote the startup/restat/shutdown of the app to utilize tornado's ioloop and autoreload features. [`f1f73a4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f1f73a40c9ef5f79a58092ca2a2ef0d4789d80fc)
- Complete restructuring of modules and code and changed all sickbeard references to sickrage [`0be25da`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0be25da39ae5a7cfc41af43e3c046b9bdc1a7a7f)
- Complete restructuring of modules and code and changed all sickbeard references to sickrage [`3fd9dbd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3fd9dbd708500776bb055ab1cbf7a36e72cfb368)
- Fixed all unresolved references to imports. [`c36f208`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c36f208c13384c80ecfd634f9dc3b3b154a68da9)
- NEW: Rewrote the startup/restat/shutdown of the app to utilize tornado's ioloop and autoreload features. [`c0892e4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c0892e4d1241d66ba07d84a298fcca2aa744157f)
- Updated to version 6.0.0, restructing completed. [`3238b91`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3238b91ae43afe1b0c8496d81d25720b84239187)
- Updated templates [`ac85744`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ac85744fbf4c5d111c3521588f04de13bae5535b)
- Fixed more unresolved references to imports and more issues revolving around naming of episodes and setting of qualities. [`e74d2c4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e74d2c4c7e8b49eb34bea6edbefc4eea9d900a23)
- Further fixes for restart/shutown of app. [`9a8d283`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9a8d28302c655ab0a5edff9669a9dfde2605fc75)
- FIX: Corrected several cyclic depends. [`f8621be`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f8621bea39d8333d4713a9386363196967daa103)
- Fixed startup issues related to patching of ssl sni contexts for pip install of required library files. [`7c81090`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7c810905087c8ecde0896fe9787c42ea6115d551)
- FIX: Corrected DB code to handle list instances when performing fetchall and fetchone. [`8237e9f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8237e9f085567eddd30016e9c326a71bded9c76e)
- Fixed timezone issue for windows users causing a mako exception. [`b60ad73`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b60ad73096d1f4eea855f896b124625ec616cf2f)
- FIX: Corrected status web view [`4ee4a0f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4ee4a0fe8445a3c566122c35121dd7b6d4b893b3)
- Fixed several bugs with sql database calls and connectors. [`0107af8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0107af88d9f18e881e17204af52b567cd398a395)
- Fixed startup to automatically install and upgrade pip to latest version. [`f4a2533`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f4a2533e346c0513536acb93e8fcb79c74ed4592)
- Fixed issue with queues by switching from apscheduler to ioloop events, [`e538324`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e5383241bf793dc813026e2d87a9c6336ef7de14)
- FIX: Corrected several more bugs in notifiers including plex [`4a62a6f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4a62a6f0183e9def35e722ec444c566da6924b37)
- Fixed startup issues relating to version checks [`3005b23`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3005b23670fe9ab622b0e59f7e249fde5ef4a1e5)
- Updated init scripts. [`94d6d35`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/94d6d3514dab0cbb10f2f9a80ea79a1c67f0a05e)
- FIX: Corrected DB code to handle list instances when performing fetchall and fetchone. [`853668b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/853668b5c10c70b441aaca580644ce2ad19a364e)
- FIX: removed logger calls that were to early in the code [`ad6f7ba`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ad6f7ba9f46fb995f5f045860e797d8ae7cee9e1)
- Complete restructuring of modules and code and changed all sickbeard references to sickrage [`b4c4aad`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b4c4aad68f12660fb7c70cc83c985f173d834adb)
- Fixed class naming issue between validator and tv classes [`6bf50fe`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6bf50fea7d32b726d7efd192dda060a5507529c6)
- Updated git ignore file [`505022f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/505022f75d9cb89bdad2c4400b160e5f73da93b8)
- Fixed paths for requirements [`bda28a2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bda28a2a7f8d55b865099378ed095c1ca8cb7800)
- Version bump to v6.0.3 [`747734e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/747734ec7f10164084346004921f66d3a2e9d4f9)
- FIX: Bug in login template corrected. [`234ec95`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/234ec959e6cf6a079ca2b1b4478588c532774b63)
- FIX: Made lxml a optional requirement [`0957c98`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0957c987cf6a80ab55093def6a92651780e78523)
- Fixed issue with adding shows and quality presets [`c2cb8e1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c2cb8e1648072554038c4a3017b8081cd064fc0c)
- Fixed setup.cfg [`3c89ae4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3c89ae45b50923acdbb75dc932aa21d344a9efba)
- Corrected a startup issue with installation/upgrade of pip [`d3761be`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d3761be201c03e8c54f53ae63135cfed70ac7ca2)
- FIX: Corrected logfile name for tests. [`eac348d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/eac348dc35271d7c6c50db9d8614d9284a3167c5)
- FIX: Corrected namecache freq [`b583a6e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b583a6ebe2c33b8f7696594605958d7cf88db6b7)
- FIX: synoindex_notifier code correction that was preventing post-processing from working [`67e09f6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/67e09f63ac3071438a05209892ef8a21d75d0e3f)
- FIX: Corrected provider result bug [`1c39d11`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1c39d11b058f329c16c4a909f900d15404a1eaf5)
- FIX: Corrected issue in requirements.txt file [`ee97067`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ee97067af22dda3fc5a97fbec3b85262de372e78)
- FIX: Missing import in common [`b19e4d1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b19e4d1b41228ad0b293bf08015cfae100bf6fd6)
- FIX: Corrected missing seedratio attribute for provider results [`0b201a9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0b201a9d5b725c69e7cea17c41a662949cd601bc)
- FIX: Fixed issue with parsing air-by-date shows and displaying results. [`ef72b4e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ef72b4e916f45205eaade0bc4cfedd2df0601db5)
- Fixed issues with removing a show via mass edit when show variable is None [`279374c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/279374cc9eb47aa239d1861a1906d1f857295595)
- Version bump to v6.0.12 [`cca222e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cca222efa24266c20b11f0dd8419a52758b003c2)
- Fixed requirements file [`22693cc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/22693cc1f62649b903419c6b8b4354acd87d46ea)
- Version bump to v6.0.13 [`e0333fc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e0333fc7e5be3b898ffdf810f6166bad3905fe1d)
- Fixed restart issues [`168db6b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/168db6bee18f3efdaad30049e907e87f9ffedb7d)
- Rename History.py to history.py [`f589e49`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f589e4907ab438312b41cf56348ab72db516ec99)
- Fixed issues with history view [`ece5ec8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ece5ec88a5e9badaf182354d59ca9cb522246de1)
- Version bump to v6.0.5 [`d75b834`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d75b834af1aa131bf21a6efcdc133f540c74f583)
- Fixed date issues with scheduler [`9567b1c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9567b1c21be2480dbb0a1250dc1218e94a8699a7)
- Version bump to v6.0.4 [`45b38cb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/45b38cb0f372fb76aee7cca7ba9d9cc92c0911de)
- FIX: Corrected path for requirements.txt [`76d19ed`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/76d19ed1f272482fbe8c508fdfc37b6f42b02842)
- Version bump to v6.0.22 [`0ad39f2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0ad39f2500819cf78cb896c206f6a72b719ec119)
- FIX: permissions on main executables. [`dac5b49`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dac5b49a53063fcce487d3faea1c7d379df14d6d)
- FIXED: permissions on init scripts [`6bd2f45`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6bd2f45646b4444c657fcbbd252343894c285ece)

#### [4.2.5](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/4.2.4...4.2.5)

> 22 December 2015

#### [4.2.4](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/4.2.3...4.2.4)

> 22 December 2015

#### [4.2.3](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/4.2.2...4.2.3)

> 22 December 2015

#### [4.2.2](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/4.2.1...4.2.2)

> 20 December 2015

#### [4.2.1](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/4.2.0...4.2.1)

> 20 December 2015

#### [4.2.0](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.1.0...4.2.0)

> 20 December 2015

- Removed nxtgn provider [`#3203`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3203)
- Add RSS to Strike [`#3191`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3191)
- Fix readme.md warning typo on develop branch [`#3193`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3193)
- Added autocapitalize="off" to login form and text fields throughout c… [`#3196`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3196)
- Miibug fix [`#3194`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3194)
- Add RSS to BTDigg [`#3186`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3186)
- Save multiple plex servers [`#3184`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3184)
- fix bluetiger auth [`#3185`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3185)
- Unicode fix [`#3178`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3178)
- Revert "Fix post processing non-ascii" [`#3177`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3177)
- update user information on anime Black- and Whitelisting behaviour [`#3172`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3172)
- Remove FTDB provider [`#3174`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3174)
- Fix post processing non-ascii [`#3176`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3176)
- Use login on initial Github request if defined. [`#3175`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3175)
- Add real to proper strings [`#3171`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3171)
- Only use the exception logger for ERROR level (maybe we should use lo… [`#3170`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3170)
- Remove unused imports in mako [`#3168`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3168)
- Fix history layout caching issue (cant define mutables inside &lt;%!) [`#3167`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3167)
- Fix synoindex calls in helpers [`#3165`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3165)
- Encode long type as int [`#3164`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3164)
- Fixes extra scripts for subtitles [`#3163`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3163)
- Added DVD parsing for %SQN, making sure group is not included in parsing [`#3159`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3159)
- Fix displayshow, shcedule, history encoding problems. Still a few que… [`#3161`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3161)
- Fix forgotten import in webapi [`#3160`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3160)
- Fix missing episodes in displayShow [`#3158`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3158)
- Fix displaying non ascii in log/error viewer [`#3157`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3157)
- Multiple fixes [`#3156`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3156)
- Hella lint errors and some actual bugs fixed [`#3154`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3154)
- lint js [`#3152`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3152)
- Use names parameters when adding a show from the API [`#3153`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3153)
- Convert StatusStrings to a dict subclass [`#3108`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3108)
- Fix unicode in nfo's, clean up some log spam [`#3151`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3151)
- Io open [`#3150`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3150)
- Update parser.py for PEPs 8 and 263 [`#3148`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3148)
- Update regexes.py for PEPs 8 and 263 [`#3147`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3147)
- make sure images and nzb data is downloaded as bytes instead of unicode [`#3149`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3149)
- General cleanup [`#3146`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3146)
- Update tivo.py for PEPs 8 and 263 [`#3145`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3145)
- Update wdtv.py for PEP 263 [`#3144`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3144)
- Update kodi_12plus.py for PEPs 8 and 263 [`#3143`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3143)
- Update mede8er.py for PEPs 8 and 263 [`#3142`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3142)
- Update mediabrowser.py for PEPs 8 and 263 [`#3141`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3141)
- PEP 263: Add encoding declaration to kodi.py [`#3140`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3140)
- Update metadata/__init__.py for PEPs 8 and 263 [`#3139`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3139)
- Update generic.py for PEPs 8 and 263 and remove unreachable code [`#3138`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3138)
- Update helpers.py for PEPs 8 and 263 [`#3137`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3137)
- Update ps3.py for PEP 263 [`#3136`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3136)
- fix indentation [`#3134`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3134)
- update old br tags to HTML5 standards [`#3135`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3135)
- fix typo [`#3133`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3133)
- Update indexers_config.py for PEPs 203 and 263 [`#3132`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3132)
- PEP 8: Move module level imports to top of file in indexers_exceptions.py [`#3131`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3131)
- PEP 263: Add encoding declaration to indexers_api.py [`#3130`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3130)
- PEP 263: Add encoding declaration to indexers/__init__.py [`#3129`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3129)
- Add param to getURL "needBytes" for when we need bytes instead of uni… [`#3128`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3128)
- Update maindb.py for PEPs 8, 203 and 263 [`#3124`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3124)
- PEP 263: Add encoding declaration to databases/__init__.py [`#3123`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3123)
- PEP 263: Add encoding declaration to utorrent_client.py [`#3126`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3126)
- Update transmission_client.py for PEPs 203 and 263 [`#3127`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3127)
- PEP 263: Add encoding declaration to failed_db.py [`#3122`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3122)
- Update cache_db.py for PEPs 8 and 263 [`#3121`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3121)
- Should probably check if it exists first, doh [`#3125`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3125)
- Update deluged_client.py for PEPs 8 and 263 and streamline conditional [`#3114`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3114)
- Update download_station_client.py for PEPs 8 and 263 [`#3116`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3116)
- Update clients/generic.py for PEPs 8 and 263 [`#3117`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3117)
- Update mlnet_client.py for PEPs 8 and 263 [`#3118`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3118)
- Update rtorrent client for PEPs 8 and 263 [`#3119`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3119)
- Fix daemon startup [`#3120`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3120)
- Linting frontend [`#3115`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3115)
- Update deulge_client.py for PEPs 8 and 263 [`#3113`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3113)
- Update clients/__init__.py for PEPs 8 and 263 [`#3112`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3112)
- Update tntvillage.py for PEPs 8 and 263 [`#3111`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3111)
- Remove the reload of sys and setdefaultencoding hack that is frowned … [`#3057`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3057)
- Added MLDonkey basic client [`#3107`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3107)
- Remove glype [`#3102`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3102)
- Fixes https://github.com/SiCKRAGETV/sickrage-issues/issues/3580 [`#3109`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3109)
- Updated subliminal (develop) to newest version [`#3106`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3106)
- Add missing CF error codes - fix SiCKRAGETV/sickrage-issues/issues/3577 [`#3105`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3105)
- Update webserve.py for PEPs 8, 203, 257 and 263 and streamline dict/list creation [`#3099`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3099)
- Fixes https://github.com/SiCKRAGETV/sickrage-issues/issues/3569 [`#3100`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3100)
- Update helpers.py for PEPs 8, 257 and 263 and streamline datetime call [`#3094`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3094)
- Update sickbeard.py for PEPs 8, 263 and streamline datetime call [`#3087`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3087)
- Allow user to submit 'Unknown error code' message [`#3097`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3097)
- add aria-haspopup to force ie11/edge to emulate hover on these elemen… [`#3098`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3098)
- make sure the caret is in the right place on -xs (mobile) layout [`#3096`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3096)
- Update traktChecker.py for PEPs 8, 263 [`#3090`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3090)
- Update blackandwhitelist.py for PEPs 8, 257, and 263 [`#3088`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3088)
- PEP8: comments should start with '# ' (rebased for @labrys) [`#3085`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3085)
- Added quality string to newpct (rebased for @CristianBB) [`#3084`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3084)
- Allow bare anime results without release group if no black ir white list [`#3083`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3083)
- Update CPasbian URL [`#3082`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3082)
- No normal regex anime [`#3081`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3081)
- Remove feedcache [`#3076`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3076)
- Fix show download statistics (downloaded, snatched, totals) cache issue [`#3074`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3074)
- Fix setting home layout. Will be more issues popping up now that mako… [`#3073`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3073)
- Make sure airdates are &gt; 1 (really 693595) in webapi to stop erroring… [`#3070`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3070)
- Remove "append_identifier" feature introduced with newpct, as it brea… [`#3069`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3069)
- Make "newpct" configs more n00b friendly [`#3067`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3067)
- Import datetime to fix undefined errors with sabnzbd [`#3065`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3065)
- Added support for Calendar Icons in Google Calendar (Develop branch) [`#3064`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3064)
- add category options to nzbget and sabnzb for backlog episodes [`#3056`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3056)
- Maliciamrg kat develop category [`#3062`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3062)
- Don't log as error when TVDB info is returning bad series name or id.… [`#3061`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3061)
- Lint sickbeard/__init__.py [`#3060`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3060)
- Clean up metadata providers a bit more. [`#3059`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3059)
- Remove roman numberal matching from "no season" regexes [`#3058`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3058)
- Please dont use funkym provider names, if someone wants to use it the… [`#3054`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3054)
- Linting webapi and fixing a few problems [`#3021`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3021)
- Cristian bb develop [`#3053`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3053)
- Lint postProcessor [`#3051`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3051)
- Some fixes [`#3050`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3050)
- Fix issue #3491 [`#3049`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3049)
- Only use the exception logger for ERROR level (maybe we should use logger.warn() too xD) [`#3609`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3609)
- Fixes https://github.com/SiCKRAGETV/sickrage-issues/issues/3580 [`#3580`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3580)
- Merge pull request #3109 from duramato/patch-6 [`#3580`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3580)
- Fixes https://github.com/SiCKRAGETV/sickrage-issues/issues/3580 [`#3580`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3580)
- Fixes https://github.com/SiCKRAGETV/sickrage-issues/issues/3569 [`#3569`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3569)
- Merge pull request #3100 from SiCKRAGETV/bugfix-3569 [`#3569`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3569)
- Fixes https://github.com/SiCKRAGETV/sickrage-issues/issues/3569 [`#3569`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3569)
- Fix Shomin Sample [`#3564`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3564)
- Dont try normal regexes when we know the show is anime (still might need to flip the order on line 87) [`#2834`](https://github.com/SiCKRAGETV/sickrage-issues/issues/2834) [`#3562`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3562) [`#946`](https://github.com/SiCKRAGETV/sickrage-issues/issues/946)
- Decode the data back to unicode! [`#3527`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3527) [`#3527`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3527)
- Make sure airdates are &gt; 1 (really 693595) in webapi to stop erroring when unaired episodes are asked for info [`#3512`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3512)
- Make sure airdates are &gt; 1 (really 693595) in webapi to stop erroring when unaired episodes are asked for info [`#3512`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3512)
- Don't log as error when TVDB info is returning bad series name or id. Just notify with INFO. Sometimes this just happens. [`#3545`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3545)
- Use a lookbehind to not match roman numberals if they immediately follow an e [`#3544`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3544)
- Use a lookbehind to not match roman numberals if they immediately follow an e [`#3544`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3544)
- Lint postProcessor [`#3527`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3527)
- Match all torrent_row classes on libertalia, not just new [`#3543`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3543)
- Match all torrent_row classes on libertalia, not just new [`#3543`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3543)
- Remove feedcache, update feedparser [`bda03f4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bda03f4af8ff08ccd61697fb07cee137055bbe40)
- FIX: Fixed a bug that was causing anime settings page to detour to subtitles instead [`8384e29`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8384e29ef1f95a36a70a916b1373e92f290d92ba)
- Code changes to correct flow of ascii &lt;-&gt; unicode issues brought in by previous code updates. [`425aa9c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/425aa9c025e157c6ae4bc190735d8c52f938676d)
- lint old *.js && update views [`32bad59`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/32bad593424746caa92489a735b36845e16e8114)
- Fixed bug in db connector, was not closing db after commit. [`64e7572`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/64e75724d48d7e4936b721028e47d5401c73ed63)
- Remove unused lib/futures [`7b289da`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7b289dacd04c9247eecfc10e4b08cdfd58310f46)
- PEP8: comments should start with '# ' [`eed6610`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/eed661038b390693930974dafc78c44a0864b07c)
- Remove the reload of sys and setdefaultencoding hack that is frowned upon and unpythonic [`99d4707`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/99d4707478e31c11d84dfea6baded9e525499f7c)
- Fixed more unicode decode/encode bugs. [`fcc4fb8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fcc4fb882cf566b96a4f908a72856e26cb73cbe2)
- FIX: Corrected code for log viewer that was preventing proper display of logs and log levels. [`9a0f85e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9a0f85e44aae5895624f4f5997d97d59464ded2e)
- lint new/*.js [`ae5b8b5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ae5b8b5da3dbd8861969c1ce88f42f7d6aaaf03a)
- linted js files [`03a781c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/03a781c52eae9e2fb5f9df23422ce024aed55385)
- Flake sickbeard module, lint clients [`5acef40`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5acef4058934adbd3456dcf9a729fbe72ae3c5e7)
- Fixed unicode handling issues for generatortypes and revamped the encoding module source code. [`f14764e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f14764ef4a6a77baecab46db5ef697633e879605)
- New provider: www.newpct.com [`c220ff2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c220ff2621737b1a472fc173d4ff17ec37024219)
- Remove glype proxy support [`012c0be`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/012c0be2b006696afc3b9ad2ba31f77f6a96049a)
- FIX: Converted last of the old-style logging calls to work with new-style logging module code. [`8836404`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8836404571df13fecb365dbc4dd7a9fc705202a7)
- FIXED: Issues relating to restarts from web app corrected. [`1a98807`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1a988072fb7115b85b81e695baf6507bf506c3a4)
- Fixed unicode issues with web views in app. [`f12bfb1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f12bfb1368bd7edb670ea26b412fb103c49067af)
- Fixed unicode issues relating to encoding checks at startup of app. [`ce5f000`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ce5f000721260d3deeb0e418367a2cf11602a0f6)
- Fixed issue caused by nextgen removal. [`2df5dee`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2df5deeaedb4f0c5a3cc490efbb1d7059e6e01b2)
- Corrected issues with shutil_custom imports [`e1645e2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e1645e210e14b7fc954b75ebb93b5c96ccfa3835)
- Fixed unicode and logging issues with config module. [`81e7779`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/81e7779094a5e1f19faf72d61353e0340a4f0b6c)
- New feature: User can select episodes and delete them both from show and hard drive. [`ed5d3a1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ed5d3a188e5bc6a3a1139adf42ed01cbb848b6dd)
- Fix up code and build testing [`21c75ee`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/21c75ee53d187b574aef8724aa08f7f684b67e86)
- Fixed bug in shutil patch preventing post-processing from completing. [`f77cdb3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f77cdb3a10de071d2eb353204b56373222fb74b3)
- Converted more os calls to use ek wrapper to prevent unicode issues. [`cde0cfd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cde0cfd78fd1e7417731d1b51ab8452514a72e31)
- FIX: Fixed bugs causing undefines when trying to display or edit a show. [`e9e4d71`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e9e4d71c08dd75c30c580a93270c551f4a19d8de)
- add category options to nzbget and szbnzb for backlog episodes [`fccc3f3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fccc3f3522b5a59a4ead5e1e16f239410ccfe9b9)
- PEP 8: Fix indentation and add/remove blank lines for consistency [`de1cae3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/de1cae3029cb81c3b5bb34ba6c88425454d77704)
- PEP 203: Replace dict creation with dict literal [`251493f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/251493f400c458b31033ccd653dc326b6747b374)
- Code changes to support not using feedcache and new feedparser [`4f83679`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4f83679cd0ff6be0ca88a33cc9b502e31e959674)
- Remove proxy setting from r/w of config, and in gui/webserve [`56b7f57`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/56b7f573cc1736fe31e4fd9aff6c053bdf43af0d)
- FIxed bug preventing shutdown signal from being caught correctly. [`99ea156`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/99ea15617bfe34e4585b10adae777a6716747f1f)
- Fixed issue with unicode handling of generator objects, resolves issues for post-processing [`9fd5f8f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9fd5f8f9c4b5caee031d0e76c11e24f93bf5eddc)
- FIXED: Corrected stdin/stdout to properly handle unicode encoding/decoding [`64badf3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/64badf3b10ec1dc770357088d38b3c7b10692ebe)
- Converted shutil calls to use ek [`456bdde`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/456bdde8a0385c16e8363fa085235fb262338e39)
- Fix setting home layout. Will be more issues popping up now that mako cache is working! [`3ee22fe`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3ee22fe9711cd9a4641a49140268ebf18e7cb134)
- Fix setting home layout. Will be more issues popping up now that mako cache is working! [`fea3f1e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fea3f1e21ceba437f2cb0958dadb021485ac9c7d)
- FIX: Better handling of bozo errors on rss feeds [`4595b79`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4595b79fe116ad9c5e81f80fd52a5387379e1c10)
- PEP 8: Convert tabbedindents to spaces [`4566d2c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4566d2c8eb37d10d17ef36518fb822bf8f7b126d)
- PEP 8: Fix indentation and remove excess blank lines [`b0ba95e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b0ba95e57d7565badb033c245021e3d95bbbf5a3)
- Clean up old tornado location before it is imported [`16f3118`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/16f3118e8338651d1d730d42ff4c052af7a1ecf2)
- Re-add womble feed parser test, and make it work [`18056a2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/18056a265f866fc0352761cccd1777e8287985ae)
- add base .jshintrc for js linting [`2984dc5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2984dc51f6d7e1c01187308899cdf2e3576a396f)
- Remove "append_identifier" feature introduced with newpct, as it breaks multiple other features such as history, failed download handling, proper finder, removeWords, etc. [`b83170f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b83170f9ccba718df48ab3ba052202895c195169)
- Fixed bug in shutil patch preventing post-processing from completing. [`0496b1f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0496b1f7b3320027e96788de48501dacaa467186)
- Corrected spelling for post-processor class name. [`8b2eeaa`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8b2eeaa52263a216949cf615408d67a94736a085)
- PEP 8: Convert membership test from 'not x in y' to 'x not in y' [`d7202f5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d7202f554a9fe0b32e190d2f9d7f057b7e479bc4)
- linted js [`baa20ef`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/baa20ef23b6e2a8190dc0c50833c4224c316c907)
- Further unicode issues corrected regarding post-processing [`7ce84f5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7ce84f51f1b184eb7460448a47ea17a2e31ded27)
- Deleted _get_episode_search strings [`3c25f0a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3c25f0aee885e42c6e5872fc53f492ac9d26da15)
- Fix bug when opening the postprocessing config [`0d27120`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0d27120235460cff0f7979e1fee3b3fdcbb79c94)
- PEP 8: Refactor variables that shadow built-in names [`0111c52`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0111c52efc360613d16b4b11bb35f3c876ab6e96)
- Fixed copy/move functions to not remove the source file if a error occures [`2022dce`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2022dce0b6a3afaf7de7533e78bbf36b07e08b13)
- Minor code correction for github api [`2d8c058`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2d8c0588532d924af5807938a000529cfb07cfea)
- FIxed unicode issue with os.stat calls [`de5b2f1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/de5b2f112552c87b2e361081a77def8050e403b5)
- Fixed bug in shutil patch preventing post-processing from completing. [`fbc8960`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fbc8960a2f39991300fa2a8b6c50b1128334ef8a)
- PEP 8: Convert None comparisons from operators to 'is / is not None' [`3257c71`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3257c713d32d6e59b97db5f6536294352569ad94)
- linted mako [`8c60b69`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8c60b698794ae7feeb828c2c8eebb326d5df7855)
- PEP 257: Convert docstrings to triple double-quoted docstrings [`0fcb652`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0fcb652db77ea3f9e8b7786f227e637505a8f7cc)
- Remove redundant parentheses [`8d68fb9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8d68fb947ddb20b7826f18698ca67c42088fc4d9)
- PEP 203: Replace assignment with augmented assignment [`e1d2e95`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e1d2e95ac09373e5e68ab10cf9c2830fd8e6d338)
- Fixed unicode bug relating to os.path.getsize, resolves issues for setting episode statues and related functions. [`2c750c1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2c750c13b327627f44626686effb2e3f09461bff)
- Fix another stdout error [`9120677`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9120677d54d85e874a19ce9da5b98c0f9ee16e20)
- PEP 8: Move module level imports to top of file [`20393c4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/20393c4854cb8509efd77d14582ac1d72d251e1d)
- PEP 8: Fix under-indented continuation lines [`b0f531c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b0f531cba0990be886cdb4ceb2fa96eb8f565ed0)
- PEP 203: Replace dict creation with dict literal [`ff7907f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ff7907fc78ee6ad5bf0c50f8f9d908c5e2c469bb)
- PEP 8: Remove excess blank lines [`9a76b25`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9a76b2559432cdafd4d5cbf19d84a47b609c1a5b)
- PEP 203: Replace list creation with list literal [`8589490`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/85894908e13df8c29f5fc9edda49db973f209a81)
- Remove errant spaces [`f90e9fe`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f90e9fe2bed09bc7228096316076c06be3a405e1)
- Remove redundant parentheses [`3e0c7cc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3e0c7cc6426239ce9d99dde2e4a92aeaa0b3376d)
- Remove errant spaces [`57b043b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/57b043be95f462fa39296de970e0070d6307455d)
- fix unused imports and misspeled name [`31c1e45`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/31c1e4545c1aa23e4ce6916b63a5a852490ecbd6)
- PEP 8: Convert None comparisons from operators to 'is / is not None' [`3824491`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/38244917caa09601dfcd3c81926ffed3ff2c9b62)
- Fixed issue for post-processing on *nix systems [`22fcae6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/22fcae6dbbc1deca5f237098725ae25d0a57cb35)
- add aria-haspopup to force ie11/edge to emulate hover on these elements, also add superfluous span so that bootstrap-hover-dropdown correctly attaches the events [`0a8ec34`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0a8ec34a21fb649d790ae3d288594306ab49b418)
- kat provider choice between anime or tv based on search type [`63866b6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/63866b6d6d13d6cbc0740d56d44210e16855e19f)
- FIX: Corrected code for log viewer to display when first accessing it. [`0066b61`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0066b6146d187183c2a8daa4d283f90dc5a73077)
- FIX: Corrected code for log viewer to display when first accessing it. [`22b003d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/22b003d0ed7d1533478c38e8c0d00411848e380e)
- FIX: Corrected bug that was causing to many redirects when using a username/password [`a40fe0a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a40fe0accc8eba5333a23edd9739dd93425e7105)
- Fix starting as a daemon when running in unicode mode =P [`92fa0be`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/92fa0bedfac753d1480c1bc917cafd00f1a39015)
- Updated readme [`5fce328`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5fce328af3dfa1dcf2873ce1ef42db8b61d2c16e)
- Update package.json [`379fad8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/379fad84bdc635685b8e20d437321a111df5860a)
- Update package.json [`f62dc65`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f62dc65bef699a151f3d2892c61cc4fa6026e84b)
- Remove redundant parentheses [`9e53168`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9e531684f6e0a51ee2af63fd18f97bb901205407)
- PEP 8: Convert comparisons [`63f96e4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/63f96e461b8d3158d02d3761a131527895c04587)
- PEP 8: Fix indentation [`8cd170c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8cd170c077fe219e4326fe8d9f97f536374271b6)
- PEP 8: Convert None comparisons from operators to 'is / is not None' [`922f763`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/922f763a5b38b8da1f28765997164f941e43e766)
- PEP 8: Refactor variables that shadow built-in names [`d0702c0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d0702c002441376cfd4ad39d3525dd77e4f043c6)
- add extra globals [`641754c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/641754cc91329954c339403ac8db9039ec1c11d0)
- Revert force local timezone [`adb3058`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/adb3058cd64c4977fdf71c9d1b6dd67e81708560)
- Whitelisted develop for travis-ci builds [`b41a8a6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b41a8a64e827a2465bfac26cab1b2c1e790ccc2c)
- PEP 8: Convert membership test from 'not x in y' to 'x not in y' [`c12733b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c12733b81fc3ef285267a071a0dacb12a0d77f39)
- Remove unreachable code [`4b1d6a0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4b1d6a06b7966a180569791613085686a56292c2)
- Updated readme [`4a5fae4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4a5fae4719485b11e7c1eb7e9aa3dfb1f3534763)
- PEP 8: Convert lambda expression to a def [`5d9cbdf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5d9cbdf7838544c49e2d674cf0961acbc5f37444)
- PEP 8: Move module level imports to top of file [`91009f7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/91009f7555d3b5ecf3fe0d62532b8e3ee0472f34)
- update kat to use a mirror [`df86983`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/df86983f2040ca5f3ec15fb2f8d0be596813ca22)
- update kat to use a mirror [`2d82a34`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2d82a34d7ef442872ffac93e9c25597d40aa2732)
- FIx: wrapped os calls with ek calls for proper unicode decode/encode [`3a9ff9a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3a9ff9adcbbb1249626b30325726ba119865df92)
- Remove redundant parentheses [`c675674`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c675674cea4bf6a7d2f72cfaa376369ca9bde19b)
- PEP 257: Convert docstrings to triple double-quoted docstrings [`6d8b748`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6d8b748b9fad5d7182bcba1c65e126d96e9c1f3b)
- Update readme.md [`74500a2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/74500a248a39754624dc58170a86d5c398df72c7)
- Update readme.md [`d294e9f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d294e9faf48d45051a50d4e2cf3a0252c28d5b17)
- PEP 8: Convert lambda expression to a def [`f273b45`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f273b45e5673fa3adefccb504d9739852d4fcc99)
- Fixed issue with browse button missing on post-proc config view. [`9385abc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9385abc7624d1614662720965dd486f842e1f990)
- Combine duplicate conditional check [`fc62243`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fc62243ff54e4320fd08e954028364ac83e0ce72)
- Fixed missing reference to remove test cache db files when running unit tests. [`7c91a80`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7c91a806818befa296c929697cdbb3c2844ae591)
- PEP 8: Convert None comparisons from operators to 'is / is not None' [`a9ff03a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a9ff03aae3077899d9e59499ad99527dfa5c1bae)
- FIX: Corrected url routing parser code that was causing misc web items/services to not function correctly [`83ef6e0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/83ef6e09c754699db30afa77c45a8b6fdb083942)
- oops [`5f49688`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5f496885827bf88e4b24a4c94dc163dd016b2bca)
- fix indent [`d58c59b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d58c59b7c50f91b2199c93c6b4884a38c97a45af)
- PEP 8: Convert None comparisons from operators to 'is / is not None' [`ca2b8a0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ca2b8a07a1ab92ea48cf11b2a400c4361b6074c0)
- PEP 203: Replace assignment with augmented assignment [`ea5ffde`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ea5ffdeece4140e84e223f51437795b4c50ece7c)
- Convert to new style classes [`792ff3b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/792ff3bd9619254711192c3258631ee042f66ed8)
- Fixed bug in shutil patch preventing post-processing from completing. [`22ea241`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/22ea2414307d67de020bf208c1af9766b351f9b7)
- Fix typo [`e8c5912`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e8c5912099a266dd7006a3ed65ed4678c58d5b2e)
- PEP 257: Convert docstrings to triple quoted docstrings [`1ae38ce`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1ae38cec6ac9ec59a211a8bfd7d10ecbaa662596)
- PEP 8: Convert membership test from 'not x in y' to 'x not in y' [`c4cc2ea`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c4cc2ea7d778030d7f13b485c2d8cc48adab60dd)
- Fixed issue in shutil patch regarding missing ek reference [`2376d2c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2376d2c6719c37ed9d71b5888896f13554401f23)
- New feature: User can select episodes and delete them both from show and hard drive. [`b3da8d9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b3da8d931510a82cd42149b002bd40b10d3571f0)
- Passing the showObj here is matching wrong shows! NameParser may be broken somewhere? [`ab64122`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ab641225e040e077bddc778b6a0c45c602cda118)
- PEP 8: Remove unused variable [`e51ec7a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e51ec7aba475078b24ec2a6cb0118ada7ffa9431)
- Corrected travis-cl branch reference. [`f82cc3e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f82cc3eeda571015d35a3f1cefb2115877173c0d)
- Corrected travis-cl branch logfile reference. [`ee20635`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ee20635b5ea02b55a166ebe9e357d206bd85fb18)
- PEP 8: Fix indentation [`54edd29`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/54edd2923589b40cc2df2babe0e49bac29a2df6b)
- Corrected travis-cl branch logfile reference. [`4c670ff`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4c670ff419dd56425bf0dc243dcdac5a0cff56e9)
- Whitelisted master for travis-ci builds [`d134454`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d134454b978467ac62c576e735f243090c7d7d28)
- PEP 8: Convert None comparisons from operators to 'is / is not None' [`48c5c76`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/48c5c76ab56bcd2a590d6a2f51ca07920662dbd7)
- Make ,only download spanish results disabled by default aka n00b proof... [`6c1b489`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6c1b489e0057c3fbb482c5a685c5f33eca7dbf4a)
- PEP 8: Convert membership test from 'not x in y' to 'x not in y' [`8e1a17c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8e1a17caebb54d255e2822ac3d4076b42415d11c)
- change sbLogin to srLogin [`8c9515e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8c9515e66a26f46c2ddf4aa6df9547b5017e70ca)
- PEP 203: Replace assignment with augmented assignment [`4767c90`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4767c90a0b13ca2bbacc6f1c2e45f6998a8772a0)
- Remove redundant parentheses [`fa1c8fe`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fa1c8fe3558cc18fd4509fbdf33c243ee5398150)
- Remove redundant parentheses [`f4f5f55`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f4f5f55ebeac9b3d2b645e5033ecb5fe8cb77d65)
- Please dont use funkym provider names, if someone wants to use it they will know what language it is for [`1b2062f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1b2062f90beace148ad735dbea3e5236f3da7cb4)
- Have to replace _ in the key check for imdb info also [`1352557`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1352557216703b982a0468ad33ef522004831b80)
- Have to replace _ in the key check for imdb info also [`307d1a6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/307d1a6559767bef4ce4989631b23958367c7e29)
- Remove redundant parentheses [`bce75e5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bce75e5adacca952c15813c5754c310cdbb05ff8)
- Remove redundant parentheses [`609e6d3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/609e6d329b1314c5de4d761cdbcfc3523dc6b3b7)
- oops [`0bfddc9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0bfddc9faa87b78cb5f04f01eaf40d753d4c11c9)
- PEP 8: Remove blank lines for consistency [`13794b2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/13794b2edfa7060df2f3e7730cefa9edbf541209)

#### [v4.1.0](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.76...v4.1.0)

> 1 November 2015

- Intialize providers correctly [`#3048`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3048)
- Remove autoProcessTV scripts (NOT post-processor!) from the repo [`#3047`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3047)
- wantEpisode was totally broken (may partially still be) [`#3046`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3046)
- fix propsal for 1097 - dropdowns not working on touchscreen [`#3045`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3045)
- fix several front end bugs with initial setup [`#3043`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3043)
- Make sure news var is defined before finditer on it. [`#3044`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3044)
- Fix updating imdb info for shows [`#3039`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3039)
- Fix mako cache bug [`#3038`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3038)
- Added Musique Plus Network Logo. [`#3034`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3034)
- Improved BDRip recognition and indentation, removed WEBRip support (a… [`#3035`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3035)
- Update mako from 1.0.1 to 1.0.3 [`#3033`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3033)
- Make sure data is xml before trying to parse it with xmltodict [`#3032`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3032)
- Added hd-space.org support [`#3031`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3031)
- Missed specifying the parameter to replace in the datetime object, sh… [`#3030`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3030)
- Need to convert from datetime to ordinal and make sure is &gt; 0!  [`#3029`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3029)
- Always check scene exceptions when parsing files or names to shows/ep… [`#3024`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3024)
- Replacing tabs with spaces before giving data to soup. [`#3027`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3027)
- Don't use | for air_by_date or sports, especially if provider doesnt … [`#3026`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3026)
- Fix almost all of the name_parser tests [`#3025`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3025)
- Check scene exceptions while PostProcessing [`#3023`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3023)
- Dont allow "downCurQuality" after reverting a failed episode, should … [`#3020`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3020)
- Lint sbdatetime and fix some problems where returning within finally … [`#3019`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3019)
- A lot of linting in tv.py, rework the modify file timestamp method, f… [`#3018`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3018)
- Make massEdit UI consistent with other pages. [`#3012`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3012)
- Added GFTracker.org as torrent provider [`#3016`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3016)
- Avoid open mako cache issues and warn user to delete cache folder [`#3015`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3015)
- Hide pin from the UI [`#3014`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3014)
- Add "[PublicHD]" to removewordlist [`#3013`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3013)
- Lint helpers.py and fix some problems [`#3010`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3010)
- Use tzwinlocal for sb_timezone on windows. [`#3009`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3009)
- There isnt any Freelech torrents on tracker nor implementation [`#3008`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3008)
- Hotfix-3450: Fix airdate of 'Never' while avoiding Windows dateutil issues [`#2997`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2997)
- Fix Trakt message log levels [`#3002`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3002)
- Do not make torrent labels lower case for rtorrent client [`#3007`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3007)
- Fix listing associated files when folder name has [ or ] and confuses… [`#3006`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3006)
- Provider for Pretome tracker added [`#3005`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3005)
- Fix a bug where file would not PP a better quality when existing qual… [`#3000`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3000)
- Fix issue filter - prevent issue SPAM [`#2996`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2996)
- Fixed scene quality auto pp not renaming, added bdrip, dvdrip, webrip… [`#2993`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2993)
- Fix link to rarbg from readme :) [`#2992`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2992)
- Fix Season folders [`#2971`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2971)
- Display show names while massEditing [`#2990`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2990)
- MTV provider fixes/improvements [`#2987`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2987)
- Add missing traceback import to hdt [`#2989`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2989)
- Add torrentz provider (May need work) [`#2988`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2988)
- NextGen provider domain change - again [`#2984`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2984)
- Add Ratio to TorrentProject [`#2985`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2985)
- Add Ratio to Strike [`#2986`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2986)
- Add "-[SpastikusTV]" to removewordlist [`#2983`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2983)
- Add Ratio to BTDigg [`#2982`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2982)
- Fixed MTV provider specific issue with search [`#2981`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2981)
- Fix HDT AttributeError [`#2980`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2980)
- Make sure news var is defined before finditer on it. [`#2089`](https://github.com/SiCKRAGETV/sickrage-issues/issues/2089)
- Make sure news var is defined before finditer on it. [`#2089`](https://github.com/SiCKRAGETV/sickrage-issues/issues/2089)
- Make sure data is xml before trying to parse it with xmltodict [`#3507`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3507)
- Make sure data is xml before trying to parse it with xmltodict [`#3507`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3507)
- Don't use | for air_by_date or sports, especially if provider doesnt support | [`#3406`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3406)
- Dont allow "downCurQuality" after reverting a failed episode, should fix failed handling issue of replacing existing good files [`#1994`](https://github.com/SiCKRAGETV/sickrage-issues/issues/1994)
- Fix problem where anything that was not SD was being detected as SDDVD if it included "dvd(rip|mux)|b[rd](rip|mux)|blue?-?ray" or "xvid|divx|[xh].?26[45]" [`#3494`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3494)
- Do not make torrent labels lower case for rtorrent client [`#3004`](https://github.com/SiCKRAGETV/SickRage/pull/3004)
- Fix listing associated files when folder name has [ or ] and confuses glob [`#1571`](https://github.com/SiCKRAGETV/sickrage-issues/issues/1571)
- Ignore RARBG release intro videos [`#3477`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3477)
- Ignore RARBG release intro videos [`#3477`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3477)
- Fixes https://github.com/SiCKRAGETV/sickrage-issues/issues/3404 [`#3404`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3404)
- Fixes https://github.com/SiCKRAGETV/sickrage-issues/issues/3404 [`#3404`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3404)
- Return False if no data was returned from getURL in NextGen login [`#2203`](https://github.com/SiCKRAGETV/sickrage-issues/issues/2203)
- Lint sbdatetime and fix some problems where returning within finally block can swallow exceptions [`51b058c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/51b058c62569202e2908a518f543e585ce0ab915)
- Fixed scene quality auto pp not renaming, added bdrip, dvdrip, webrip detection, fixed encoder detection with multiple codecs in file name [`42afe02`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/42afe02425a783dcc851b0f597e21faa1eebab79)
- enlarge the clickable area for toggle drop-downs on touchscreens, but retain hover and click-to-link behavior for non-touchscreens [`dadfdca`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dadfdca95c77c3a040777f38c3dd9ed748e077dd)
- Remove BOM @ncksol please change your editor settings [`100a2dd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/100a2ddf1fdd1731a16d90fbc36cc587781c7309)
- Remove BOM @ncksol please change your editor settings [`15b3150`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/15b3150bd4735ff76e86b44038c956f500e362f2)
- Fixed session timeout issues [`8cdb0e9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8cdb0e9b9c9cfd74fc41755a935239137bd6cf54)
- Remove all occurrences of  since it is not needed on Python 2.7+ [`9bdd070`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9bdd070a5bc6e122862eb25c531606f9e09507d2)
- Fix situation where category is not defined for an item in torrentz. [`900ec53`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/900ec53a865c2bfd0c0bf69f7ab2ee42a4f60a79)
- No need to import each provider in sickbeard/__init__.py [`ded601a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ded601a1277af2f918dfed173e8d2b4a8e875476)
- fix bug where if you update using autocomplete first, then the file browser is out of sync [`d9f62a4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d9f62a49c9d8d59265f4b60b722c131e8e134f8b)
- Fix log filter [`4258d06`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4258d06a14ac2633da66d77db787e3a1d8663162)
- Need to convert from datetime to ordinal and make sure is &gt; 0! @duramato' [`6d24e4b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6d24e4b54eaa64c72425d849e7496bf0f4551f56)
- Fixup [`ef75a59`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ef75a599deda39b46a432a99323c440744c4c016)
- Fixup [`2613a73`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2613a73dad353a127d35876e7a4d5e5bbef8c202)
- Hotfix-3450: Fix airdate of 'Never' while avoiding dateutil issues on Windows [`0a6e4e7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0a6e4e70306a9a4612d1b0c54f471adda8c7e60e)
- Update helpers.py [`0c906ac`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0c906acdf2bc98fb565d27dda2a3efb65ce42309)
- do not cache notifications or file browser calls, fixes lots of weird UI quirks on IE/Edge [`ebf5527`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ebf552704b8df0b17dc14bbf5964508bf5d744a3)
- Fix a bug where file would not PP a better quality when existing quality was unknown. [`9ba5154`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9ba51541da1d9be67c1bb3f84ae4be2dc14b5c6c)
- zzz [`e61aaf3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e61aaf37645e360e5527b4d0b44a532dea63976c)
- Missed specifying the parameter to replace in the datetime object, should have tested it better [`44651ae`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/44651ae4004a5ca289532380d3a8a6780e16b1b7)
- zzz [`5e38535`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5e38535bc59d877f01562e38abb00b9e0e0804db)
- Updated description [`2e17e67`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2e17e6787a152ecfe65f8cc93ca50782af7c13d0)
- remove unnecessary init causing error on search settings screeen [`442e9c7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/442e9c72ab5c58e1da0bd1ea4a59eb78207febcd)
- Move tornado into lib [`618737a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/618737a3b52e11866f20e76f1ee272cf16351aac)

#### [v4.0.76](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.75...v4.0.76)

> 24 October 2015

- Temporary change TPB URL [`#2979`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2979)
- Do not interfere with the dateutil timezone info when updating networ… [`#2977`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2977)
- Fix bad encoding in hdt [`#2976`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2976)
- Try to fix encode/decode in HDT title [`#2975`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2975)
- Update dateutil to 9645c3d [`#2974`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2974)
- Added support for freeleech only torrents to Torrentbytes [`#2973`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2973)
- Torrentbytes provider fixes [`#2972`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2972)
- Missed a place to remove non-release groups [`#2970`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2970)
- We are not checking for propers when snached_best [`#2969`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2969)
- Fixed #3432 [`#2968`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2968)
- Added Scene Quality naming pattern and capitalized release groups opt… [`#2967`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2967)
- Add [cttv] to removewordlist [`#2966`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2966)
- Handle server maintenance mode on TorrentProject [`#2965`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2965)
- Removed forced encoding, changed log warning to info, fixed some logs [`#2964`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2964)
- Fix broken flags in subtile settings and in missed subtitles [`#2963`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2963)
- Change line from error to warning [`#2962`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2962)
- Fix SiCKRAGETV/sickrage-issues/issues/3418  [`#2961`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2961)
- Fix SiCKRAGETV/sickrage-issues/issues/3418 [`#2960`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2960)
- Fixed pt-BR not recognized, fixed flags in subtitles settings, remove… [`#2959`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2959)
- Fix SiCKRAGETV/sickrage-issues#3416 [`#2957`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2957)
- Cleanup logging in kodi notifier more. Don't log when not sickbeard.K… [`#2956`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2956)
- Add option to subtitle settings for selecting hearing impaired subtitles [`#2955`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2955)
- Schedule/ComingEpisodes was not considering snatched_best and snatche… [`#2953`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2953)
- Add login fields for opensubtitles, addic7ed, and legendas.tv [`#2952`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2952)
- Add size to SCC [`#2951`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2951)
- Reorganize and normalize name quality detection a bit [`#2950`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2950)
- Upped RARBG's cache checking interval to 10min [`#2949`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2949)
- Added legendastv subs provider, added login for subs (python), many b… [`#2945`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2945)
- SCC search improvements [`#2948`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2948)
- Add subtitle provider login variables to config [`#2`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2)
- Add TorrentProject link [`#2941`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2941)
- Ups forgot import on TorrentProject [`#2947`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2947)
- Fix typo in log message [`#2946`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2946)
- Add RSS to TorrentProject [`#2944`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2944)
- Fix missing code when exception and pylint [`#2942`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2942)
- Fix multiple snatches when 'snatch notification' fails [`#2940`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2940)
- Should fix SiCKRAGETV/sickrage-issues/issues/3273 [`#2919`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2919)
- Change loglines to be SickRage [`#2939`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2939)
- Catch URLError when Kodi cant be reached for notifications [`#2938`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2938)
- Allow user to Ignore subbed releases based on language names. Used to be hardcoded [`#2935`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2935)
- Fix wrong search string in scc cache/rss update [`#2937`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2937)
- Fix HDTorrents findPropers and others. [`#2936`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2936)
- Let user choose which timezone to timestamp file [`#2934`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2934)
- Display free space in human readable numbers [`#2933`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2933)
- Remove findPropers override from HDTorrents [`#2932`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2932)
- Update to Tornado 4.2.1 [`#2931`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2931)
- Fix custom quality alignment in Edit Show [`#2926`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2926)
- Update TorrentProject default trackers as some are dead [`#2929`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2929)
- Search only TV category on TorrentProject [`#2928`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2928)
- Providers cleaning like a boss [`#2925`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2925)
- Ignore .AppleDouble [`#2924`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2924)
- Move findPropers into generic.TorrentProvider (Only needs overridden … [`#2923`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2923)
- Add WebHD quality detection [`#2922`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2922)
- We have no requirements other than Python 2.7.10 [`#2921`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2921)
- We have no requirements other than Python 2.7.10 [`#2920`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2920)
- Make Edit Show page style consistent with other UI. [`#2911`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2911)
- Should fix #2894 [`#2918`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2918)
- Fix SiCKRAGETV/sickrage-issues/issues/3370 traceback [`#2914`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2914)
- Fix SiCKRAGETV/sickrage-issues/issues/3347 [`#2905`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2905)
- Update libertalia.py [`#2917`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2917)
- Use common code to compute the shows statistics [`#2898`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2898)
- Fix SiCKRAGETV/sickrage-issues/issues/3357 [`#2912`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2912)
- Temp Solution for SR DDOSing TorrentProject [`#2915`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2915)
- Clean up, fix, and improve metadata creation for all metadata types [`#2910`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2910)
- Revert "Add NzbIndex ,update xem icon & add torrentz icon" [`#2909`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2909)
- Reorganize and reword PP settings page. [`#2908`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2908)
- Revert "Fix SiCKRAGETV/sickrage-issues/issues/3286" [`#2907`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2907)
- Add NzbIndex ,update xem icon & add torrentz icon [`#2904`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2904)
- Added Super Écran network logo. [`#2903`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2903)
- Fix SiCKRAGETV/sickrage-issues/issues/3342 [`#2900`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2900)
- Remove some unused imports in webserve [`#2899`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2899)
- Remove archive first match check from displayShow [`#2901`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2901)
- Fix SiCKRAGETV/sickrage-issues/issues/1638 [`#2895`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2895)
- SiCKRAGETV/sickrage-issues/issues/3335 [`#2897`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2897)
- No point show Logs & Errors [WARNING] when log show only warnings [`#2896`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2896)
- SiCKRAGETV/sickrage-issues/issues/700 [`#2893`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2893)
- Saving downloaded subtitles with utf-8 encoding [`#2894`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2894)
- Provider domain change - again [`#2846`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2846)
- Fix SiCKRAGETV/sickrage-issues/issues/3177 [`#2892`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2892)
- Fix SiCKRAGETV/sickrage-issues/issues/3319 [`#2889`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2889)
- Fix SiCKRAGETV/sickrage-issues/issues/2383 [`#2891`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2891)
- Fix SiCKRAGETV/sickrage-issues/issues/3286 [`#2886`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2886)
- NextGen returns different data in browser vs SR? [`#2887`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2887)
- Add size parsing and freeleech option for nextgen [`#2882`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2882)
- Hotfix Kat [`#2879`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2879)
- Hotfix TBP [`#2878`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2878)
- Try to fix HDT 503 error [`#2877`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2877)
- Try to fix https://github.com/SiCKRAGETV/sickrage-issues/issues/700 [`#2876`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2876)
- Fix SiCKRAGETV/sickrage-issues/issues/3297 [`#2875`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2875)
- Added 2 network logos (TV5 & TV5 Monde) [`#2873`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2873)
- Fix SiCKRAGETV/sickrage-issues/issues/3296 [`#2874`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2874)
- Change "Authentication Failed" to warning [`#2872`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2872)
- Revert "Handle ConnectionError" [`#2871`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2871)
- Fixes #3282 [`#2870`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2870)
- Handle ConnectionError [`#2868`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2868)
- Added w network logo [`#2869`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2869)
- Fix SiCKRAGETV/sickrage-issues/issues/3219 [`#2859`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2859)
- Change default values for new install [`#2867`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2867)
- Hide enable_backlog for dailysearch providers only. [`#2865`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2865)
- Handle jackett/torznab in client direct connect as well [`#2864`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2864)
- Make default timezone as local. Force 'local' for existing users [`#2863`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2863)
- Add support for Jackett/TorzNab. Add them as custom NZB providers. [`#2862`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2862)
- Fixes SiCKRAGETV/sickrage-issues/issues/3274 [`#2860`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2860)
- Added missing Canal D network logo. [`#2856`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2856)
- Don't WARN about miseed sync files on PP. [`#2855`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2855)
- Temporary fix for shazbat.tv (and possibly other rss only torrent pro… [`#2854`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2854)
- Temporarily make generic.TorrentProvider accessors forgiving [`#2853`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2853)
- Handle unicode titles better in bitcannon [`#2852`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2852)
- Fixed relative paths [`#2850`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2850)
- Finished implementation of checkbox, fixed #3263 [`#2847`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2847)
- Added support for subtitles without country codes, added checkbox des… [`#2844`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2844)
- Change ' Refusing to change status of' to WARNING [`#2845`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2845)
- Hotfix hdbits [`#2842`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2842)
- Add bitcannon support [`#2843`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2843)
- Fix SiCKRAGETV/sickrage-issues/issues/3229 [`#2841`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2841)
- Added some missing network logos [`#2840`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2840)
- Replace SSL Error with a url with information. Disable issue submissi… [`#2838`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2838)
- Dont stop PP if any notifications fails [`#2839`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2839)
- Just format to minimum 2 digits in episode search strings for anime, … [`#2837`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2837)
- Check that the file being processed exists after unrar. [`#2835`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2835)
- Updated subliminal to 1.1.0.dev0, added no_setup patch, added napipro… [`#2834`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2834)
- Lower words while comparing with title [`#2832`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2832)
- Fix SiCKRAGETV/sickrage-issues/issues/3248 [`#2833`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2833)
- Add option to only download english releases on TNTVillage [`#2830`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2830)
- Fix NyaaTorrents [`#2827`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2827)
- Disable logging with print in hachoir_core so pythonw.exe isnt failing. [`#2826`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2826)
- Merge pull request #2968 from medariox/develop [`#3432`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/3432)
- Fixed #3432 [`#3432`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/3432)
- Check that show has a network and air time before trying to convert airdate/time [`#3007`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3007)
- Wrong var name in mede8er [`#3398`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3398)
- Display free space in human readable numbers [`#2930`](https://github.com/SiCKRAGETV/SickRage/pull/2930)
- Limit twitter messages to 140 chars [`#3388`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3388)
- Error was already formatted [`#3386`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3386)
- Ignore .AppleDouble [`#3330`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3330)
- Move findPropers into generic.TorrentProvider (Only needs overridden now if provider doesnt use the new search strings types!) [`#3348`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3348)
- Add WebHD quality detection [`#3287`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3287)
- Merge pull request #2918 from medariox/develop [`#2894`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/2894)
- Should fix #2894 [`#2894`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/2894)
- Encode search string in Kat [`#3351`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3351)
- Guess that was that way for a reason. TVDB sending wrong encoding in headers? [`#3339`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3339)
- Fix https://github.com/SiCKRAGETV/sickrage-issues/issues/3319 [`#3319`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3319)
- Try to fix https://github.com/SiCKRAGETV/sickrage-issues/issues/700 [`#700`](https://github.com/SiCKRAGETV/sickrage-issues/issues/700)
- Merge pull request #2876 from fernandog/skipping_char [`#700`](https://github.com/SiCKRAGETV/sickrage-issues/issues/700)
- Try to fix https://github.com/SiCKRAGETV/sickrage-issues/issues/700 [`#700`](https://github.com/SiCKRAGETV/sickrage-issues/issues/700)
- Merge pull request #2870 from medariox/develop [`#3282`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/3282)
- Fixes #3282 [`#3282`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/3282)
- Merge pull request #2847 from medariox/develop [`#3263`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/3263)
- Finished implementation of checkbox, fixed #3263 [`#3263`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/3263)
- Check that the file being processed exists after unrar. [`#3252`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3252)
- Updated subliminal to 1.1.0.dev0, added no_setup patch, added napiprojekt subtitles provider, fixed #3251 [`#3251`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/3251)
- Renamed variable _save_subtitles [`e25aa88`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e25aa88275ee1b16a5851a20608d9bd05b8cf5ea)
- Do not interfere with the dateutil timezone info when updating network timezones [`9e5af4b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9e5af4b275cc6ef6c5b63c7e27ab3d77ef045b5f)
- Remove findProper override from frenchtorrentDB provider\nRemove self.enabled redefinition in all providers [`5e580fb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5e580fbd6e0c285ac3de122dfbccbd05f2b081bc)
- Remove code redundancy [`97a323c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/97a323c9d7af1d5ffdbdf53c9b74dc5f4643b6ed)
- Remove findProper override from fnt provider [`69676c8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/69676c8fb80c75bcee67eb4bab82fa2beef09c7f)
- Clean up unused imports in alpharatio [`a96404f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a96404fc18f07ac1325c9093e6b2ded893664be3)
- Remove findProper override from cpasbian provider [`4337752`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/43377523400f2d58cb5231757156e7eb42cbba1a)
- Remove findProper override from bluetigers provider [`4a6918a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4a6918a8458e078e5879b0ec815f83e1bcf2d1b7)
- resolved conflict in nextgen provider [`1e9a23f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1e9a23fb057f7b9527765979730f413342d78be7)
- Remove findProper override from bitsoup provider [`7e1cdb2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7e1cdb23b7e0c26779beb0619f2bb75038785b5c)
- Remove findProper override from extratorrent provider [`d32b2cb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d32b2cb7d86391b0b4f73542c00aefd309555175)
- Fix bad indent for btdig. Clean up unused imports. [`6898d78`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6898d78eaae9ee897d4967d94cfe386db339ba6a)
- Remove findProper override from bitcannon provider. Remove unnecessary encode/decode [`8937ea1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8937ea152243c1aed3629b05852cea8da1f00937)
- Move nzb item parsing into the nzb provider class and handle exception better [`dbddd3e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dbddd3e69473b372ccd6d49e6b177f0dea8e85f5)
- Fix nextgen, allow setting minseed and minleech [`08e7e59`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/08e7e594de40fa4286a7345a1801913010fa4bc1)
- Remove getQuality override from hdbits provider, some linting [`676f999`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/676f999dcf192b3c4e5cc8b97cd9c0be7f301939)
- PR#2911 - move archive setting to "Main" tab. [`a14a390`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a14a39018d33fb784c245ef290ce0aa6d0349f03)
- Update readme.md [`a78b842`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a78b842dcdfcee16cabd6401b86b4d93a558d61d)
- Fixed pt-BR not recognized, fixed flags in subtitles settings, removed useless code [`a5a15a6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a5a15a68ceaa676ac163bb1d64c2dea8a3ffb1fa)
- change domain for provider NextGn [`d7fb443`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d7fb443f1eaf711ef754336bb8939beddef1d141)
- PR#2911 - fix custom quality alignment [`588060e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/588060e53f2b66e7e21af39221f72fd934010c0e)
- Comment out useless log spam [`199d3b5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/199d3b5f358649899e638b5ec92572652eed15d2)
- fixup [`363cc4c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/363cc4c6f49b176be23aa0a4c0367e21e6eec403)
- Opps again... [`34e418c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/34e418ceb9ebb54e38a7fb686ff628dcf42742b7)
- Just format to minimum 2 digits in episode search strings for anime, follows scene [`3270086`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/32700860f23ce61c08c9c089501bf9fddd904b07)
- Opps, committed an error. Fixes tvdb searching [`d09ca17`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d09ca1705c776f3a8ef6697775b53095153a205e)
- Fix Extratorrent encoding [`d41574c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d41574c9ae34be69267160dcd2fdc1563dc653cf)
- Revert adding all_tests.py [`32973f4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/32973f480d0a78c13fb1d18de601c1b19855824e)
- Fix typo [`7f61f16`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7f61f16695c4b6bba549a3adb5f573ef3efddaae)
- Revert "Fix magnets from torznab/jackett not registering as multiple trackers in receiving client" [`8024143`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8024143e9e1cd1c6a4c300ca2c4633d7984547c4)
- Change hardlink line to warning [`1704872`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1704872b8ee23c7adaa35a46dee3b3d509785b25)
- Fix magnets from torznab/jackett not registering as multiple trackers in receiving client [`fb3c81d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fb3c81d4d86af905a1887675f5ba3e91836ea946)
- Ups forgot import [`b14e4d0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b14e4d08b9c9e5ddfa9852caaaceee4f234c3c9e)
- Return when no trackers in bitcannon [`60f5c2b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/60f5c2b101c400b3afeaeb5a0708cd22d094386c)

#### [v4.0.75](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.74...v4.0.75)

> 10 October 2015

- Removed silly feature [`#2825`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2825)
- Fixed bug with empty path, make sure path exists on refresh [`#2821`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2821)
- Fix kodi 12+ metadata more. Eliminate an error, and stop overwriting … [`#2824`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2824)
- Make sure to replace &nbsp;, and make sure _cleanData in tvdbapi is o… [`#2823`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2823)
- Added the RDI network logo. [`#2822`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2822)
- Hotfix xmltodict issue [`#2820`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2820)
- Revert "Update xmltodict to v 0.9.2" [`#2814`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2814)
- Fix SiCKRAGETV/sickrage-issues/issues/3242 [`#2815`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2815)
- Fix tokyotoshokan [`#2816`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2816)
- Update sublimnal to 1.0.1, subtitle logic in subtitles.py, much more [`#2812`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2812)
- Check sockets timeout and fix log messages [`#2804`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2804)
- Fix SiCKRAGETV/sickrage-issues/issues/3231 [`#2808`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2808)
- Fixed a corner case issue where scene exceptions can't be found for some animes [`#2813`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2813)
- Fix an issue with quality pill title [`#2809`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2809)
- Fix boolean values in API [`#2805`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2805)
- fix typo : downloadURL should be download_url [`#2803`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2803)
- Added back all network logos... :( [`#2801`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2801)
- Fixes SiCKRAGETV/sickrage-issues/issues/3215 [`#2800`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2800)
- Fix SiCKRAGETV/sickrage-issues/issues/3223 [`#2799`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2799)
- Replace &nbsp; with &#xA0; in xml data before partsing with xmltodict, or even etree, or it will choke. [`#3240`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3240)
- Fix RSS for T11 [`#3226`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3226)
- Switch to mode format for searches in SCC, and add sorting each mode by seeders [`#3220`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3220)
- Missing size def in IPT [`#3216`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3216)
- Fix kodi 12+ metadata more. Eliminate an error, and stop overwriting watched state. [`75f1466`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/75f14668b73e07b0cf64ed28c9bd72430c5208f8)
- Fix nonetype error on torrentproject, by checking if there was data returned from getURL [`caa7915`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/caa79156e5cb27ba400d7a1587f0d5f93139929d)
- Revert "Revert "Update xmltodict to v 0.9.2"" [`4b0584d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4b0584d10e966397c1f1079b3351a4aee44c0f15)
- Make sure to replace &nbsp;, and make sure _cleanData in tvdbapi is operating on a string! It was trying to replace chars in a datetime object that was not formatted to string yet. [`e2f6b1b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e2f6b1b925d37f8d69899e944378c5206e013f01)
- Fix search/snatch for btn (still needs a rewrite though) [`40670c6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/40670c6efcafec342433b77e030406008c9cd2e2)
- Removed language restriction from xem allNames call and ensures the search string generator can return searchstrings for anime shows even if the whitelist and blacklist is empty [`e8c4d88`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e8c4d88d32be934ebcdbf374d3af88269be88bb0)
- Fix incomplete format in omgwtfnzbs [`a315f2f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a315f2fb71c71fd98d2d13d03a3d8f505d858946)
- Fix mismatched variable name in libertalia [`483ccd9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/483ccd9ace838439f4d541f8029be6e9b41ef883)

#### [v4.0.74](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.73...v4.0.74)

> 8 October 2015

- Make new nfo actually write the actors. updates of existing nfo still… [`#2797`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2797)
- etree.ElementTree was failing to set the &lt;id&gt; correctly because we we… [`#2796`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2796)
- Add try|except for trakt_api.traktRequest and fix log messages in  [`#2792`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2792)
- Fix some of the log messages from tv.py [`#2793`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2793)
- Filter another recurrent issue [`#2795`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2795)
- Add "searchURL" log message to KAT/TPB [`#2791`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2791)
- Cleaner code for issue submitter notifications. Also use ui.notificat… [`#2790`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2790)
- Added srRoot to apibuilder [`#2789`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2789)
- Added code guidelines to contributing.md [`#2786`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2786)
- Refactor /comingEpisodes/ to /schedule/ in GUI and save sort [`#2784`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2784)
- Moved js to new directory [`#2787`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2787)
- Parse size from RARBG results [`#2785`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2785)
- Added underscore.js and fixed viewlog search [`#2788`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2788)
- Temp patch tpb kat [`#2783`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2783)
- Add result sorting for providers [`#2776`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2776)
- Removed one logo to many. [`#2782`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2782)
- Added missing Belgien network logos. [`#2781`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2781)
- Removed TVRage network and unused logos. [`#2779`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2779)
- Avoid submit mutliple ascii errors [`#2777`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2777)
- Fix Strike NameError: global name 'items' is not defined and parse si… [`#2775`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2775)
- Fix BTdigg NameError: global name 'results' is not defined [`#2774`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2774)
- Fix Torrentproject: ValueError: too many values to unpack [`#2773`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2773)
- Allows scrolling on error pages [`#2772`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2772)
- Fixes SiCKRAGETV/sickrage-issues/issues/3176 [`#2770`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2770)
- Split thread name and time from error title before attempting to matc… [`#2771`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2771)
- Hide filter row on Schedule page [`#2769`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2769)
- Fix "Select Columns" button on Schedule page [`#2768`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2768)
- Fix comingEpisodes sorting [`#2767`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2767)
- Mass change providers [`#2754`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2754)
- Fix bug causing redownload of download episode if quality is below th… [`#2764`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2764)
- Add column filter widget to schedule table [`#2763`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2763)
- Don't wrap quality pills [`#2762`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2762)
- Add more history page limits [`#2748`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2748)
- Remove line between text and caret for split items [`#2761`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2761)
- Don't show logout option when auth is disabled [`#2760`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2760)
- Only show appropriate error submenus [`#2759`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2759)
- More updater changes... [`#2758`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2758)
- Update PyGithub, fix issue submitter, news and updater. [`#2757`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2757)
- Update PyGithub [`1f4f611`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1f4f611bcda1d54c8bfcbf43bafc449ca8064a37)
- Fix log messages [`ee72b0f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ee72b0f40131b2239accbf5c58936a60cbb41847)
- Clean providers [`ff9d636`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ff9d636104a86efd91cce3fce315549bac40fa49)
- More changes [`a6e23cb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a6e23cbb2e8e08897da675c2a1445f6fba76f9d0)
- Reorganize imports so tests work individually [`70a6da1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/70a6da11f9029653d5045ea79fbcedb30422544c)
- Refactor /comingEpisodes/ to /schedule/ in GUI [`5e90804`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5e90804da5d5d734f914b9809b85ae8852bc3ced)
- Check xmldict exception [`b18b66a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b18b66ac95fa9a37833377fa339d58f7bdedbba0)
- Make sure the dir exists when checking for free space in root dirs and tv download dir. If it doesnt exist display "Missing" [`b8db289`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b8db289dd5b08811661f9208858db3163a1229ac)
- Fix bug causing redownload of download episode if quality is below the highest possible quality (even if archive on first match) [`f70e72c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f70e72cb865d9751539035a40913e47617b6d1c6)
- Update contributing.md [`c542698`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c5426984a148e00e4af4b6dcc0054c4ac913e1ed)
- Use regex to detect and match mako errors in issue submitter, temporarily [`49dfc22`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/49dfc22ec0c4a8e1ba4b3bd6f674df44cab54d6b)
- Make new nfo actually write the actors. updates of existing nfo still doesnt work. [`2e9005e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2e9005e0673ffd2d6012e2a8a0a468e6758b42e3)
- fix build second error [`1c57cce`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1c57cce2d73d9775acb01f256e07d22a93f4c1f4)
- Only show non-proper log as debug [`3d6ba28`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3d6ba285824d41e8bca392383a88852d5a335379)
- No wrap Ends column [`c1dc7ec`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c1dc7ec4b45e252acb99dd1c4152e9c711f7c146)
- Fix syntax error breaking build [`39f4c8f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/39f4c8fdf5738f7bd4d132a125922d1048129ba0)
- pushurl error on some installs? strange. [`c92f56c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c92f56ccfcbbdb22b5098113e0ec95a0cb6fccbf)
- Fix provider images [`b59169e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b59169e66ef9553b39fb4f6d3bb87dbe403e65dc)
- Changed torrentbytes icon [`416b27a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/416b27a8f756eef7897c7e34447460cd381dca7c)

#### [v4.0.73](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.72...v4.0.73)

> 5 October 2015

- Add [EtHD] to removewordlist [`#2752`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2752)
- Clear cache/sessions and cache/indexers on restore [`#2753`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2753)
- Add SATRip to SDTV [`#2751`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2751)
- Fixup .gitignore [`#2750`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2750)
- Add pnotify back since it might be used [`#2749`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2749)
- Clean warning logs for t411 [`#2746`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2746)
- Removed unused code [`#2747`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2747)
- Fixes _bower.js being tracked [`#2745`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2745)
- Added bower support [`#2742`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2742)
- Handle locked issues in issue submitter, better logging and ui notifi… [`#2743`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2743)
- Move 'Archive on first match' closer to 'Quality' in editShow [`#2739`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2739)
- Added isitmaintained buttons [`#2740`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2740)
- Redirect to /errorlogs/viewlog/ when clearing errors [`#2741`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2741)
- Moved to .build [`eb54f65`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/eb54f6503aa2b85f1946e3971302cd0730cfaf00)
- Handle locked issues in issue submitter, better logging and ui notifications for submitter [`582b594`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/582b594a4f054a190e4927e20a573f627296832f)
- Clean warning logs [`320aa08`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/320aa080b6df17ccbed4bdae84731fee0c7c1b7a)

#### [v4.0.72](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.71...v4.0.72)

> 4 October 2015

- Wrap time calls with try/except to fix #3095 [`#2738`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2738)
- Fix title and header on missed subtitles page. [`#2737`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2737)
- Remove manage submenu. Only use submenu when it is something not in nav. [`#2736`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2736)
- SDTV was not part of the sdtv tag? Fixes SiCKRAGETV/sickrage-issues#3089 [`#2735`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2735)
- Fixes viewlog disabling inputs till refresh [`#2734`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2734)
- Fix typo and grammatical error [`#2733`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2733)
- Added bootstrap-achor and made history goto displayShow SXEX [`#2732`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2732)
- Add 5 most recently accessed shows to Shows menu [`#2731`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2731)
- Fixes broken table sorter [`#2730`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2730)
- Merge pull request #2738 from VinceVal/fix-issue-3095 [`#3095`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/3095)
- Wrap time calls with try/except to fix #3095 [`#3095`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/3095)
- Removed push header fix [`1700c06`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1700c060c3fc528af09f9693822101290e8c958e)

#### [v4.0.71](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.70...v4.0.71)

> 3 October 2015

- All should be good and matching airdates now. [`#2729`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2729)
- Updated isotope [`#2728`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2728)
- Rename 'Coming Episodes' to 'Schedule' [`#2726`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2726)
- Navbar non-dropdown background hover [`#2727`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2727)
- Move log menu to tools menu and update tools badge [`#2725`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2725)
- Render a badge with error count on Logs & Errors [`#2715`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2715)
- Add support for x264 and h264 [`#2667`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2667)
- Added warning to meta.js [`#2724`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2724)
- fixes SiCKRAGETV/sickrage-issues/issues/3079 [`#2723`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2723)
- Revert "Respect timezone setting in displayShow, backlogOverview" [`#2722`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2722)
- Respect timezone setting in displayShow, backlogOverview [`#2721`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2721)
- Fix the topmenu for News and IRC [`#2720`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2720)
- News notify and tools menu [`#2717`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2717)
- Fix airdates in displayShow and backlogOverview, so they all match wi… [`#2719`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2719)
- episode can be None when using abs number. No need for this log line … [`#2718`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2718)
- Change default log menu href [`#2716`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2716)
- Update readme.md [`#2714`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2714)
- Notify user when new news exists [`925075d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/925075d5b30e40eceb18d0d8d8b69e0812d6b677)
- Update isotope [`f542e17`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f542e17117472dbb29762fab211e9bfa2fc76840)
- Fix build, rawHD wasnt matching [`06d4866`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/06d48664c0c8d933e5d838f2a0957ebaccfe9504)
- episode can be None when using abs number. No need for this log line anyways. [`26307a7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/26307a7c3fc9f1b50f882946eb56749e1779bcf8)
- Missed try/except on a date format in unrar2 [`8d6431c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8d6431cf3cc6336bb7867184cbcebb9409ced009)
- Last fix to unrar2 [`1f0e30e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1f0e30ef55d3c865ce81c49bb66bafc0482a8140)
- Didnt mean to commit this [`09b7131`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/09b7131d595c0c5c71b8bd87abcfa9319a4969ce)

#### [v4.0.70](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.69...v4.0.70)

> 3 October 2015

- Remove redundant buttons from various pages [`#2675`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2675)
- Create split navbar dropdowns [`#2713`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2713)
- Fixes SiCKRAGETV/sickrage-issues/issues/2368 [`#2712`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2712)
- Update unrar2 to 2fe1e98 and patch it to accept both date formats. [`#2711`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2711)
- Attempt to fix SiCKRAGETV/sickrage-issues/issues/2781 by not restorin… [`#2710`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2710)
- Typo [`#2709`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2709)
- Updated jQuery, added bootbox back [`#2707`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2707)
- Removed fancybox [`#2706`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2706)
- Linted formwizard [`#2705`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2705)
- Converted to meta function && removed unneeded comments [`#2704`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2704)
- Fixes SiCKRAGETV/sickrage-issues/issues/3007 [`#2702`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2702)
- TTN: Fix category & search_string [`#2703`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2703)
- Added config.js back [`#2699`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2699)
- Fix Chrome rendering issue on episode status page [`#2698`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2698)
- Syncthing uses prefix for sync files, not extension/suffix [`#2697`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2697)
- Revert "Check if is safe to update when user click "update" in UI" [`#2696`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2696)
- Duramato patch 2 [`#2695`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2695)
- Revert "Change default DATA_DIR to PROG_DIR/data" [`#2694`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2694)
- Change default DATA_DIR to PROG_DIR/data [`#2561`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2561)
- Deduplicated metas [`#2692`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2692)
- Add back downloaded status' to episode status management, prevent mak… [`#2691`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2691)
- General code cleanup [`#2690`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2690)
- Fixes cursor not changing back to default after logs load [`#2689`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2689)
- Removed auto refresh [`#2688`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2688)
- Fixes missing SORT_ARTICLE [`#2687`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2687)
- Fixes https://github.com/SiCKRAGETV/sickrage-issues/issues/3041 [`#2686`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2686)
- Update six lib to 1.9.0 [`#2685`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2685)
- Update xmltodict to v 0.9.2 [`#2683`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2683)
- Fixes SiCKRAGETV/sickrage-issues/issues/3056 [`#2684`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2684)
- Auto convert bare archived episodes to compound status. If file exist… [`#2682`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2682)
- Fixes #3049 and #3024 [`#2681`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2681)
- Fix SKIP_REMOVED_FILES not saving [`#2680`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2680)
- Fixes SiCKRAGETV/sickrage-issues/issues/3039 [`#2679`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2679)
- Fix ET cloudflare issue [`#2678`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2678)
- Make navbar dropdowns clickable links [`#2674`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2674)
- Make the "Select Columns" buttons consistent [`#2676`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2676)
- Fixes class attribute on navbar items [`#2677`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2677)
- Show season dir in File Name column on show page [`#2673`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2673)
- Fix .seasonheader on rename page with light theme [`#2672`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2672)
- Convert "Shows" back into a submenu [`#2671`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2671)
- Fix typo [`#2669`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2669)
- Check if is safe to update when user click "update" in UI [`#2668`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2668)
- Change comingEpisodes keys to be aligned with API [`#2665`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2665)
- Add archive first match to 'Manage' [`#2664`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2664)
- Add TVMux ,WebMux and BRMux [`#2663`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2663)
- show_queue remove Was passing an int instead of tuple, and now checks… [`#2662`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2662)
- Restores support to ignore embedded subs, '?' will now be replaced by… [`#2661`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2661)
- Fix SiCKRAGETV/sickrage-issues/issues/2905 [`#2659`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2659)
- Fix SiCKRAGETV/sickrage-issues/issues/2769 [`#2658`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2658)
- Improve the way quality class is generated [`#2660`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2660)
- Add DVDMux & BDMux as valid SDDVD qualities [`#2652`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2652)
- Add missing config settings to UI [`#2657`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2657)
- Fix for when seeders/Leechers is "---" instead of a number [`#2655`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2655)
- Fix issue #2988 [`#2653`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2653)
- Use enzyme to detect embedded subtitles instead of subliminal [`#2650`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2650)
- Merge pull request #2686 from OmgImAlexis/fix-sorting-shows [`#3041`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3041)
- Fixes https://github.com/SiCKRAGETV/sickrage-issues/issues/3041 [`#3041`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3041)
- Merge pull request #2681 from medariox/develop [`#3049`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/3049)
- Fixes #3049 and #3024 [`#3049`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/3049)
- Converted to meta function [`3e8cba7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3e8cba7cc1e82755a8d3d67be7eec52f82f6ae22)
- Update unrar2 to 2fe1e98 [`f458db7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f458db75892ea31712426221956b1f1ecb379fff)
- Restores support to ignore embedded subs, '?' will now be replaced by default langauge (see conditions) [`e9a4b4a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e9a4b4a08f20a9625704b4e856db45b5c28a49ed)
- Remove skip remove from PP. Not PP setting [`d600f76`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d600f76226b09b3f51f6e1d774ba9313d5cc7e65)
- Removed old jQuery and momentjs [`c1fdb0f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c1fdb0f17726bfa30b7e566fc9e75948dcb89ac3)
- Check if is safe to update when user  click "update" in UI [`c08c1e5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c08c1e57bb942fa1bf778a1349506130064c5d70)
- Moving all data files in a seperate data/ dir [`bed33d6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bed33d600ae551ce8bcf1345d2f3f4dbf578d090)
- Removed unneeded comments [`04a2d79`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/04a2d79f4498b04096d8b6e91305195013720ee8)
- Use os.path.join instead [`617204f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/617204f55626ee278ce4e6332f69e7629babbb29)
- Fix cloudflare issue [`1d18d4b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1d18d4b264ec7c7f56e5b2adbc1e5069789572d1)
- Moved form wizard to main libs [`328c392`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/328c39288ca73c7caaf94bd9a1f9e602a021268e)
- Moved formwizard [`6b1b643`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6b1b643c6a6ac0744102f921f89a884622a6173b)

#### [v4.0.69](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.68...v4.0.69)

> 29 September 2015

- Rework ThePirateBay provider. Now supports getting sizes, proper cach… [`#2649`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2649)
- Also ignore thumbnail dirs on syno when processing a folder [`#2648`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2648)
- Tempfix TPB (cloudflare) [`#2647`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2647)
- Add missing check for auth to _doSearch [`#2646`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2646)
- Fix urlsearch [`#2645`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2645)
- Fixes https://github.com/SiCKRAGETV/sickrage-issues/issues/3010 [`#2643`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2643)
- Finalize extratorrent provider [`#2642`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2642)
- Add ExtraTorrent provider [`#2641`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2641)
- Redo most of kat provider, Also make it use params so cachecontrol wo… [`#2640`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2640)
- Ignore .@__thumb on qnap, and dont log it. [`#2639`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2639)
- Fix hashbangs in autoProcessTV, tests, and indexer_exceptions. Also f… [`#2638`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2638)
- Fixes displayShow date format [`#2637`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2637)
- Dynamically get torrent trackers instead of hard coded ones [`#2636`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2636)
- Fixes [`#2634`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2634)
- Merge pull request #2643 from OmgImAlexis/fix-config_backuprestorejs [`#3010`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3010)
- Fixes https://github.com/SiCKRAGETV/sickrage-issues/issues/3010 [`#3010`](https://github.com/SiCKRAGETV/sickrage-issues/issues/3010)
- Update readme and contributing about feathub [`36df8b3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/36df8b3314dfcbf8a1b5e44f6caeda95c8400a33)
- typo, in a comment (i know silly commit, right?) [`8030d38`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8030d385ea4d52be870f2a7a276cc1d5892c7c0f)

#### [v4.0.68](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.67...v4.0.68)

> 27 September 2015

- error-&gt;warning for not enough enabled services in subtitles. [`#2633`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2633)
- Update pylockfile to 4a7a20d91c44d2be6396be5fc64d27b0b5afa4e2 [`#2632`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2632)
- Missing import in webapi, fixes SiCKRAGETV/sickrage-issues#2991 [`#2629`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2629)
- Fix for wrong subtitle language codes [`#2626`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2626)
- sbRoot is no longer used anywhere [`#2628`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2628)
- Fixed qualityChooser not expanding custom qualities fields [`#2625`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2625)
- Add TorrentProject provider [`#2621`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2621)
- Temp fix for config_subtitles [`#2624`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2624)
- Fixes config_subtitles [`#2622`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2622)
- Lint new API Builder [`#2623`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2623)
- New API builder [`#2581`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2581)
- merge #2620 [`#2620`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2620)
- Removed fuzzydate and library [`#2618`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2618)
- Multiple JS fixes and refactoring [`#2615`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2615)
- Add id= to header tags in markdown2 [`#2617`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2617)
- Daemons should always be umask 0. Fixes SiCKRAGETV/sickrage-issues/is… [`#2616`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2616)
- Updated 6box logos & added ALL brazilian networks logos [`#2614`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2614)
- Fixes subtitle recognition with sigle language [`#2613`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2613)
- Added 'archive on first match' option when adding a show [`#2612`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2612)
- Add "srRoot" template variable [`#2611`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2611)
- merge #2609 [`#2609`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2609)
- merge #2610 [`#2610`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2610)
- Moved more js to own files [`#2602`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2602)
- Fix not being able to set status to compound archived qualities [`#2607`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2607)
- Some linting on helpers.py [`#2606`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2606)
- Add webrip properly in guessing quality for SiCKRAGETV/sickrage-issue… [`#2604`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2604)
- Fixes with ARCHIVED Qualities, we will only use compound ARCHIVED qua… [`#2605`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2605)
- Unused logos and add missing ones [`#2601`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2601)
- Fix info icon on custom naming legend [`#2603`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2603)
- Preliminary support for tvdbid search on indexers. [`#2600`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2600)
- Linted [`20b78fc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/20b78fc5414fd48ff96d7cff69645ad8e73fb675)
- Moved from sbRoot to srRoot [`c2fa507`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c2fa50773424d7dab34b74e75550cf87d0138564)
- Remove fuzzydate and library [`247489c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/247489c5b3e405c832fa0816a883100c161c4c09)
- Fixed isodate [`d42c7fe`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d42c7fe20711bd81c69ef3e93bce2e1ca4627657)
- Linted config and qualityChooser [`06b6f0c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/06b6f0cc0c3c9ee36c5f803b7deb26cc850dbec0)
- Moved js from files to own [`e303308`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e303308c14102ce1da079e8056ed2b3e39f9ac73)
- Implemented saving as default archive on first match option [`4943b78`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4943b78b8e9a595c404dad6bda1e45bfb5029428)
- Fix subfolder not created for new shows [`ec5c7ec`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ec5c7ec1f57d02d2d1cefcd126111977a8cf9874)
- Update pkg_resources.py [`139b3f5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/139b3f5f145f0ad3553e4f6a4a4a8d63ed56c39b)
- Fixed two bugs introduced int PR #2612 [`04caa3d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/04caa3d489ea6fa985dc28fd21778757b40d7941)
- Force CacheControl to use MkdirLockFile. [`7b584bc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7b584bc9702a03b922a515f4eeb405384c1ed624)

#### [v4.0.67](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.66...v4.0.67)

> 25 September 2015

- Sic Logos & TVcabo logo [`#2599`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2599)
- Add log message about discarded torrent [`#2598`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2598)
- Fix "Initial page" option [`#2593`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2593)
- Add RTP networks logos [`#2594`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2594)
- API images fix [`#2596`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2596)
- Fixes SiCKRAGETV/sickrage-issues/issues/2954 [`#2597`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2597)
- Fix history limit and save on change limit [`#2592`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2592)
- ntpath is windows only. Some systems override this module and it will… [`#2590`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2590)
- Add more values to history limit [`#2591`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2591)
- Image API commands now return the correct Content-Type [`#2589`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2589)
- Improved API docs #2588 [`#2588`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2588)
- Fixes ${sbRoot}  in js [`#2587`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2587)
- Fixes https://github.com/SiCKRAGETV/sickrage-issues/issues/2942 [`#2586`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2586)
- Don't format JSON before sending the response [`#2582`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2582)
- Fix page url on shazbat.tv [`#2579`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2579)
- Show SR datetime in the bottom of page [`#2584`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2584)
- Add tip to timezone setting [`#2583`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2583)
- Fix webpage url for BTN [`#2580`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2580)
- Move js and lint [`#2576`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2576)
- libertalia login unsuccessful warning [`#2575`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2575)
- Fixes "Snatched (Proper) 1080p WEB-DL" not fitting on a single line [`#2574`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2574)
- Don't show 'add' button in imdb popular if user already have the show [`#2577`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2577)
- Fix dailysearch not respecting timezone setting [`#2570`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2570)
- Add webage url to btdigg [`#2573`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2573)
- Show timezone setting in the 'Airdate' column in comingEpisodes [`#2571`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2571)
- Really fixes SiCKRAGETV/sickrage-issues#2774 [`#2569`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2569)
- Fix SiCKRAGETV/sickrage-issues/issues/2910 [`#2567`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2567)
- update xthor add quotes to search string [`#2565`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2565)
- Move the js from mako to .js files [`#2566`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2566)
- Merge pull request #2586 from OmgImAlexis/fix-viewlogs-root [`#2942`](https://github.com/SiCKRAGETV/sickrage-issues/issues/2942)
- Fixes https://github.com/SiCKRAGETV/sickrage-issues/issues/2942 [`#2942`](https://github.com/SiCKRAGETV/sickrage-issues/issues/2942)
- Use a single tablesorter function for both anime and normal [`aed837a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/aed837aa407994ceaa14971bc20d27210dfcafb9)
- Fix lint issues in home and history js [`4fb2c51`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4fb2c5104e8659c78de716487225f69413525691)
- Restore was only processed when console logging was enabled! [`070e1ba`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/070e1ba55b74f2d5cbf41602c690cdf55fb0576c)
- Restore was only processed when console logging was enabled! [`acb6a81`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/acb6a817a32477781e53b48686d1dfa6b2a7e1a4)
- Fix funky url [`1331981`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1331981df3a721c301fe7c64734611c0423e9f42)
- Move metas to their own block [`97c28bc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/97c28bc4a5d8d0e46fec7dcd5e99e47838f5511f)
- funky url [`2e73a22`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2e73a22b445c023e4351f88b371142573f2b394e)
- Don't show 'add' button if user already has the show [`5144fc5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5144fc503dea4f097695326546f4d914a875cedc)
- Fixes  in js [`cd956e0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cd956e05dde948d592e03de2ec7cbc00c9106b8b)

#### [v4.0.66](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.65...v4.0.66)

> 22 September 2015

- Fixes blackwhite list loading before jQuery [`#2563`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2563)
- Use timestamp for sorting data [`#2564`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2564)
- Fix some out of order paramters in calls to private pushover notifier… [`#2560`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2560)
- Add locked icon for private providers, and unlocked icon for public. [`#2559`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2559)
- Fix linting in newznab.py [`0736f58`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0736f58383357abac1fda1b61a3f18b4ff9d46ad)
- Fix some out of order paramters in calls to private pushover notifier methods [`657ffd7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/657ffd7c4e61d32cecde009541cd25476579b254)
- Fix some out of order paramters in calls to private pushover notifier methods [`561dde9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/561dde9012910234700f5abf54f99cead3079b1b)
- Update style.css [`ea2c482`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ea2c482832a1e7a01bba799025b15472c37461f1)
- Make providers list cleaner with white color for torrents [`5c4c084`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5c4c0849d2db1f8619f9622170d691a99df9aab8)

#### [v4.0.65](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.64...v4.0.65)

> 21 September 2015

- Fix linting errors in logger.py [`#2556`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2556)
- Change imdb url in imdbPopular to akas.imdb.com (same as used in imdb… [`#2555`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2555)
- Change quality regex from hdtv to hd.?tv for source matching [`#2554`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2554)
- Fix SiCKRAGETV/sickrage-issues/issues/2877 [`#2553`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2553)
- Pylint fixes in SickBeard.py, fix redefined class in mainDB.py [`#2552`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2552)
- Proper selective imports for etree, sometimes cElementTree is not ava… [`#2551`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2551)
- Added public/private class to provider list [`#2549`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2549)
- Finished lint of js files [`#2550`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2550)
- Add public-private var to providers [`#2548`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2548)
- Move exceptions to sickrage module [`#2529`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2529)
- Fix undefined FULLHDWEBDL, make common.py lintable by fixing a few pr… [`#2546`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2546)
- Fix "Jump to Season* dropdrown [`#2543`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2543)
- Update t411 domain name [`#2544`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2544)
- Added WiKi to the config/info page. [`#2539`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2539)
- Clear up some linting errors in name_parser [`#2540`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2540)
- Remove leading slash from folders in gitignore [`#2541`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2541)
- Try to fix SiCKRAGETV/sickrage-issues/issues/2841 [`#2542`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2542)
- Move `ex` from `sickrage.helper.common` to `sickrage.helper.exceptions` [`e917a89`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e917a8999c24b5ba49f76cf3125e1e662aa499d5)
- Fix undefined FULLHDWEBDL, make common.py lintable by fixing a few problems and disabling some lint checks [`a91513f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a91513fde738481ee43782fc15a4d460d09a236c)
- Change imdb url in imdbPopular to akas.imdb.com (same as used in imdb lib) [`5639ab3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5639ab3056d48ab6c430d589e85784449a8b7d4e)
- Open the selected season [`2f7b93c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2f7b93c92d503b6c5b7f9173d1e5192e9e8ba525)
- Fix redefined class in mainDB.py [`9103354`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9103354b6ef14754f39b968ae915f9953f7b8742)

#### [v4.0.64](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.63...v4.0.64)

> 20 September 2015

- Make coming episodes results mutable [`#2538`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2538)
- Use full name of `showQueueScheduler` to delete a show [`#2537`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2537)
- merge #2536 [`#2536`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2536)
- merge #2535 [`#2535`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2535)
- Provider domain change [`#2531`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2531)
- Alpharatio does not respond to the SSL version [`#2532`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2532)
- changed domain name for NextGen provider. [`042362f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/042362fe4ccfd53e9137f9b92677d99efcda30da)

#### [v4.0.63](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.62...v4.0.63)

> 19 September 2015

- Adds missing docstrings / some minor fixes [`#2527`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2527)
- Add license info to all the files in the sickrage module [`#2525`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2525)
- Enhance quality pills [`#2528`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2528)
- Move encodingKludge to sickrage module [`#2522`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2522)
- Make Series packs work for TVChaosUK, Fix episode searches [`#2524`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2524)
- Adds missing docstrings / some minor fixes [`#2523`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2523)
- Use common code to refresh a show [`#2521`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2521)
- Remove file [`#2520`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2520)
- Return exception as error message if deleting a show fails [`#2516`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2516)
- Add TVChaosUK Provider [`#2519`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2519)
- Add TransmitTheNet provider [`#2517`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2517)
- Use common code to pause/resume a show [`#2515`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2515)
- merge 2567 [`#2513`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2513)
- merge 2512 [`#2512`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2512)
- Fixes airdate on comingEpisodes [`#2511`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2511)
- Use common code to delete a show [`5952418`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5952418a742bfbe66c89eb55466fd74ae7a1145c)
- Fix Confirmation Dialogue for removing shows and make class more unique [`e88c11f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e88c11fae04b6fca232df2b0cbcd21b84d4f4a3a)

#### [v4.0.62](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.61...v4.0.62)

> 18 September 2015

- No git clean [`#2510`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2510)
- Hide upgrade div on restart [`#2509`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2509)
- Moved comingEpisodes js to own file, added metas block to main [`#2508`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2508)
- Move "Coming episodes" logic into a dedicated class [`#2438`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2438)
- Fixes fuzzydates being used & fixes if checks in js [`#2507`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2507)
- Only select required field in history [`#2506`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2506)
- Clean fix for SiCKRAGETV/sickrage-issues/issues/2793 ?? Sets referer … [`#2503`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2503)
- Fixes https://github.com/SiCKRAGETV/sickrage-issues/issues/2774 [`#2502`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2502)
- Try to fix db version checks in updater, by checking that found hash … [`#2501`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2501)
- Fix imdb popular setting [`#2500`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2500)
- BitSoup: Change searchURL to search_string [`#2498`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2498)
- move js from home.mako to home.js, switch from fuzzydate to timeago, and remove size column [`#2492`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2492)
- Merge pull request #2502 from medariox/develop [`#2774`](https://github.com/SiCKRAGETV/sickrage-issues/issues/2774)
- Fixes https://github.com/SiCKRAGETV/sickrage-issues/issues/2774 [`#2774`](https://github.com/SiCKRAGETV/sickrage-issues/issues/2774)
- Move home.js into file and remove show size column [`373aba4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/373aba468b14bfbe60a9c2ed7c1a11c730e76575)
- Changed home from fuzzydate to timeago [`d105605`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d1056059c94316352d760439d146e268f75c82b0)
- Move "Coming episodes" logic into a dedicated class [Web UI] [`4f1a581`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4f1a581307e5b5d49c949e9fc87c9f66619a93a2)
- Fixes not showing dialog for removing shows [`23c1a61`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/23c1a61c0f2a3ff85279ee25e808828f05d67f4e)
- Remove use_imdb_popular setting, unnecessary [`ee01230`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ee01230a725a53b2dc296265ae4b94b843504c0a)
- Fix use_imdb_popular setting getting set to 0 [`91c4d09`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/91c4d098bfdbfd9d90801ac999d87f061baab43d)
- Hide git reset option in config/general since it is forced true [`9075788`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9075788d7785144646255ac63bb8c8f2365d7cb4)
- Change searchURL to search_string [`0055a42`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0055a42498e26043d5654d946e735ce8f9bf7bfa)

#### [v4.0.61](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.60...v4.0.61)

> 12 September 2015

- Missed space in git submodule command [`#2491`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2491)
- Fix typo [`#2490`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2490)
- Add Strike Provider [`#2488`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2488)
- Update submodules as well when we update SR [`#2486`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2486)
- merge #2485 [`#2485`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2485)
- Fixes viewlogs not keeping url state [`#2484`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2484)
- Remove size column js as it doesn't exist anymore. [`#2483`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2483)
- Adding mako cache cleaner upon startup of new version [`#2482`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2482)
- Added missing Colors network logo [`#2481`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2481)
- Fixed bug in pickBestResult [`e65f319`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e65f319252637d4376aefff4b11b142baf75936e)
- Fixed bug in pickBestResult [`9d4506f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9d4506f5bc8df76c8a552e8e81eb42be6b49d8af)

#### [v4.0.60](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.59...v4.0.60)

> 11 September 2015

- Dont prefix imports with lib [`#2480`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2480)
- Fix confirmation dialogues not showing. [`#2479`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2479)
- Fixed loading network logos when using custom data directory [`#2477`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2477)
- Fix HDT: use bs3 instead of bs4 [`#2478`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2478)
- Removes size column [`#2476`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2476)
- Images are binary files [`#2475`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2475)
- Fix for https://github.com/SiCKRAGETV/sickrage-issues/issues/2719 [`#2474`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2474)
- Fix for blank options Deluge [`#2472`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2472)
- Trying to fix broken images [`#2473`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2473)
- Remove jQuery image loading and size checking [`#2470`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2470)
- Fix options for blank options. [`2132ef6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2132ef671a61b2c7f7c2ec9d94ba7c526e71f43e)
- hide size column [`30c4e0e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/30c4e0ed9419279ea463285a8540e396773e3f65)
- Change metadata message about not finding image to info [`a8c3828`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a8c3828ece5f88d8b096750e872586a4584e4992)
- Don't erase cache folders backups like 'cache-20150910_190504/' [`c15e60a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c15e60a56c773d13dd774c903e2ad183cda44ffb)

#### [v4.0.59](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.58...v4.0.59)

> 9 September 2015

- Fix header problem with torrent providers. Many need a real browser a… [`#2469`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2469)
- Fixed Popular shows page title [`#2468`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2468)
- Show mako loading times for all [`#2466`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2466)
- Add temp log lines to HDT [`#2467`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2467)
- Start making providers use params correctly, to fix cachecontrol (cac… [`#2441`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2441)
- Fix header problem with torrent providers. Many need a real browser agent [`89d328b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/89d328bfd6603fa0595fb550c0f6bc79407297f7)
- Fix mako load times for all [`f15adac`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f15adac877b6f4c7f434f734ecf6824e87675ddc)

#### [v4.0.58](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.57...v4.0.58)

> 9 September 2015

- Fix recursion depth error in _doLogin [`#2465`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2465)
- Bad indent maybe caused recursion depth error? [`#2463`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2463)
- Display "Add anime" after the anime table [`#2464`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2464)

#### [v4.0.57](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.56...v4.0.57)

> 9 September 2015

- Remove show if no mapping (use addExisting then), pause dupe and remo… [`#2461`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2461)
- Fixes massEdit and trendingShows [`#2460`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2460)
- Fixes Page Title for Trending Shows [`#2462`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2462)
- Fix tntvillage match [`#2459`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2459)
- Restore support for relative, absolute and empty paths [`#2453`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2453)
- Revert "tntvillage: Fix torrents searching" [`#2458`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2458)
- tntvillage: Fix torrents searching [`#2457`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2457)
- Should be using cached imports [`#2456`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2456)
- Fixes [`#2455`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2455)
- Fixes https://github.com/SiCKRAGETV/sickrage-issues/issues/2696 [`#2696`](https://github.com/SiCKRAGETV/sickrage-issues/issues/2696)
- Fixes https://github.com/SiCKRAGETV/sickrage-issues/issues/2704 [`#2704`](https://github.com/SiCKRAGETV/sickrage-issues/issues/2704)
- Remove show if no mapping (use addExisting then), pause dupe and remove tvrage show in case of dupe (move seasons from tvrage version into other manually and rescan before unpausing) [`28e007f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/28e007fb5cef4a0f8ae43ab224a9fb856013442c)
- Fixes massEdit [`edc4981`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/edc4981e73e1c47b5c2f7350a42c8bbe2ea2696e)

#### [v4.0.56](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.55...v4.0.56)

> 8 September 2015

- Fixes https://github.com/SiCKRAGETV/sickrage-issues/issues/2689 [`#2452`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2452)
- Last one? [`#2450`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2450)
- Swap mapped indexer ids, I had those backwards [`#2449`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2449)
- Import fix for config_postProcessing [`#2447`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2447)
- Fixes broken imports in SABnzb [`#2446`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2446)
- Missed imports, fixup conditions [`#2445`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2445)
- Added missing developer info to footer [`#2444`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2444)
- Fix SiCKRAGETV/sickrage-issues/issues/2683 [`#2442`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2442)
- Adding nzbToMedia as submodule and deprecating autoProcessTV [`#2440`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2440)
- Add tensiontorrent.com to removewords [`#2439`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2439)
- Add tensiontorrent to removewordlist [`#2436`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2436)
- Temporarily disable show updates from TVRage since it's down [`#2437`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2437)
- Move logic to shutdown and restart SickRage into reusable classes [`#2429`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2429)
- Missed sort var [`#2435`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2435)
- Fixes https://github.com/SiCKRAGETV/sickrage-issues/issues/2677 [`#2434`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2434)
- response is content already, cant check status or text. TorrentLeech … [`#2433`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2433)
- Oops, i broke that. [`#2432`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2432)
- Try to fix SiCKRAGETV/sickrage-issues/issues/2568 [`#2431`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2431)
- Move history logic into a reusable class [`#2430`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2430)
- Fix images loading [`#2428`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2428)
- Fixes https://github.com/SiCKRAGETV/sickrage-issues/issues/2675 [`#2427`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2427)
- restart_bare.mako isn't used [`#2426`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2426)
- Fixes newShow scripts [`#2425`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2425)
- Only cached imports work on the whole file [`#2424`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2424)
- Shutdown/Restart have wrong reference [`#2423`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2423)
- Shutdown/Restart have wrong reference [`#2422`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2422)
- Fix SiCKRAGETV/sickrage-issues#2671 [`#2421`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2421)
- Move logic to load images (fanart/banner/poster/network logo) into reusable classes [`#2414`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2414)
- Fix status column for shows in home.mako [`#2420`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2420)
- Forgot renderQualityPill in displayShow [`#2419`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2419)
- Fixes https://github.com/SiCKRAGETV/sickrage-issues/issues/2669 [`#2418`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2418)
- Fix for SiCKRAGETV/sickrage-issues#2578: Add a "Size" column on shows list [`#2356`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2356)
- Revert "Only keep /cache/images. Delete everything else..." [`#2416`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2416)
- OmgImAlexis inheritance model [`#2415`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2415)
- Fixes [`#2413`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2413)
- Change libnotify import.  [`#2411`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2411)
- Use get instead of refreshing the page [`#2412`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2412)
- Fix typo that prevents pushover sound from saving [`#2410`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2410)
- Only keep /cache/images. Delete everything else... [`#2409`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2409)
- Fix bug by gborri latest PR for removing shows with invalid ID. [`#2408`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2408)
- Bug in emby notifier [`#2407`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2407)
- Update jQuery and use cdn [`#2406`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2406)
- Override some jQuery-UI values [`#2405`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2405)
- Fix some undefined names, thanks flake8 [`#2404`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2404)
- Fix history limit [`#2401`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2401)
- Display debug data [`#2386`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2386)
- Added handling of seed ratio and high priority for new releases. [`#2400`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2400)
- Add support for non-ASCII chars in search string [`#2390`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2390)
- Update guessit to 0.11.0 commit 2516111ea7bf910df32d1b0c11a3e8e64490aaab [`#2399`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2399)
- Update guessit to 9c1e689b115bd641ffdb1dee69e0bfd0773f1d22 [`#2398`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2398)
- Fix for https://github.com/SiCKRAGETV/sickrage-issues/issues/2616 [`#2397`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2397)
- Fix for https://github.com/SiCKRAGETV/sickrage-issues/issues/2618 [`#2396`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2396)
- Dont allow setting to bare archived status, dont allow setting failed… [`#2394`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2394)
- Remove failed status if feature not enabled [`#2391`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2391)
- Updating guessit to wackou/guessit@8ec4d7b642 [`#2393`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2393)
- Use getURL to do post requests, so cache control is used, sessions pe… [`#2392`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2392)
- Show "Add Anime" at the bottom of the anime tables [`#2389`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2389)
- Move submenu js to webserve [`#2388`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2388)
- Added missing spotweb.be provider icons. [`#2387`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2387)
- Added missing S4/C network logo [`#2385`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2385)
- Added missing network logos [`#2384`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2384)
- Update guessit to f7c067f161e3a937c972745a62321c73c8fa07bb [`#2383`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2383)
- Merge pull request #2452 from OmgImAlexis/develop [`#2689`](https://github.com/SiCKRAGETV/sickrage-issues/issues/2689)
- Fixes https://github.com/SiCKRAGETV/sickrage-issues/issues/2689 [`#2689`](https://github.com/SiCKRAGETV/sickrage-issues/issues/2689)
- Merge pull request #2434 from OmgImAlexis/develop [`#2677`](https://github.com/SiCKRAGETV/sickrage-issues/issues/2677)
- Fixes https://github.com/SiCKRAGETV/sickrage-issues/issues/2677 [`#2677`](https://github.com/SiCKRAGETV/sickrage-issues/issues/2677)
- Merge pull request #2427 from OmgImAlexis/develop [`#2675`](https://github.com/SiCKRAGETV/sickrage-issues/issues/2675)
- Fixes https://github.com/SiCKRAGETV/sickrage-issues/issues/2675 [`#2675`](https://github.com/SiCKRAGETV/sickrage-issues/issues/2675)
- Merge pull request #2418 from OmgImAlexis/develop [`#2669`](https://github.com/SiCKRAGETV/sickrage-issues/issues/2669)
- Fixes https://github.com/SiCKRAGETV/sickrage-issues/issues/2669 [`#2669`](https://github.com/SiCKRAGETV/sickrage-issues/issues/2669)
- Fixed home [`5bfd5d9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5bfd5d9fa6b9e7a1afd819904347064d54a8f5ce)
- Move old files to views dir [`570e5a7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/570e5a7209916e528d70df0c27799a41ab8fb44e)
- Move logic to get show banner/fan art/network logo/poster into reusable classes [`6539420`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6539420dd15f758958f1a73f1448ef78c5f15418)
- autoflake [`7a4ffd5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7a4ffd519aebda2b09ead1fdc71a128a54b4e7b7)
- Move "Get history" action [`9dfa173`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9dfa173314c78790efb7404570cddb7ff013b76d)
- Dont allow setting to bare archived status, dont allow setting failed status in webapi if FDH is disabled. [`e56b434`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e56b434c40213a79afbdc4dd7edf5b8a9e5646ec)
- pylint doesnt like relative imports in __init__ [`b47de6c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b47de6c779c4a01c8f801445c205aaec665a85e6)
- Update file size computation [`8d91331`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8d91331fdd81c78902b92d2f15640b9d32869c0e)
- Update sickrage.media.* classes [`20212e7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/20212e79156502d1ca3bae20ba746813eb957517)
- Fix some pylint errors in providers [`8a56a91`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8a56a91d99d5eeb7b68f7146c14b22b5e81aa6e8)
- Fix image loading [`c1e24bd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c1e24bd7d02dc7a317024244bf13e45d49d564ad)
- Move "Clear history" action [`2e19f6a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2e19f6afa55003f0f3bb8376ce96fef6c4c525af)
- Remove my futile attempt for setting ca bundle path and sni checking. It doesnt work and pyflakes barfs [`01eedce`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/01eedce1552bdd158b6ab261322ec10e45bfdb1b)
- Remove json selective import from sickbeard.browser, and make the getDrive cleaner [`ef02fe8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ef02fe8b6516755873001093cc188fc09b2bb793)
- Fix metadata/generic and mede8er, not sure how these could have worked before [`6dac7b7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6dac7b7d614ce503b4dd523f900a0275d38da6b2)
- Remove 'freeze_support' since we dont compile EXE's anymore [`6cbe56e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6cbe56e156d84372e94a119e813e8db514aba699)
- Fix default sorted columns index [`7bcc79d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7bcc79ded6e51f8152dbc1c59d48bb88ad2303cb)
- Fix setting GObject in libnotify [`67c637f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/67c637ffdb8da6ffa19c89f2221c67ef12bec295)
- Fix for PP not moving subtitles [`17bb919`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/17bb9194713d8a7709d3987d97ff40f460328cf9)
- Fix Boxcar test notification [`9b017ba`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9b017ba090abec59e01cd0889c560583cbdb04a2)
- Fix undefined in webserve.py [`ebb4ddb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ebb4ddb354682edff3eaee596c9e661f6be0ac2d)
- Fix twitter DM notifier [`67f62d7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/67f62d703c84d1a1cf800fe53b58b621ace1c004)
- Fix typo that prevents sound from saving [`a6a3f89`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a6a3f89af5cf8930e22677b15087fb96246edaeb)
- Import fix [`dc55b73`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dc55b73be46d47b9c75285793ca30a9f3a8c90ce)
- Remove archived [`41db28c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/41db28c00ae28a1f05c98165c0167723c0e2077f)

#### [v4.0.55](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.54...v4.0.55)

> 31 August 2015

- Try to fix SiCKRAGETV/sickrage-issues/issues/2534 [`#2382`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2382)
- Add ".[BT]" to removewordlist [`#2381`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2381)
- Remove from trakt right in the queue item, as there were multiple pla… [`#2380`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2380)
- Add missing jQuery-UI sortable widget [`#2379`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2379)
- Update dependencies and use minified resources [`#2375`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2375)
- Make removeShow action double-high priority [`#2378`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2378)
- Use show_queue to remove shows [`#2377`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2377)
- Load images after page finishes [`#2376`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2376)
- Remove show from trakt watchlist that are not on tvdb [`#2374`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2374)
- Vince val more specific quality pills [`#2373`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2373)
- CSS optimizations [`#2372`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2372)
- Display episodes list of collapsed season when select all is checked [`#2371`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2371)
- Fix CSS after #2336 [`#2370`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2370)
- Sort the appropriate value in the "Downloads" column [`#2368`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2368)
- Fixes progressbar sorting [`#2365`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2365)
- Added missing Yorin network logo [`#2364`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2364)
- Fixes SiCKRAGETV/sickrage-issues#2584 [`#2361`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2361)
- Providers cleanup [`#2358`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2358)
- Re-apply x265 patch, so they don't get detected as unknown [`#2363`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2363)
- If file does not exist, don't allow SB quality names. If it DOES exis… [`#2362`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2362)
- Update guessit to f25e1b30c60f334ad378d1146a900797e8f76240 [`#2360`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2360)
- Remove duplicate CSS rules [`#2336`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2336)
- Try and clean up hachoir objects better, need to patch the lib and op… [`#2357`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2357)
- Fix for SiCKRAGETV/sickrage-issues#2498: Include a print "Shows list" feature [`#2335`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2335)
- Crackle network logo update [`#2355`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2355)
- Fixed up deluge daemon handling of torrents that are already added. [`#2353`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2353)
- Remove obsolete Google Code and Windows binary distributions [`#2350`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2350)
- Remove unused files [`79e0094`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/79e0094ffd0dfd2c84ecc29b2ce70d9af47db816)
- Use minified version of Bootstrap and remove unminified version [`fcf5486`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fcf548626e68feac0eb82ff4adc1cf947aedfece)
- Use minified version of jQuery-UI [`3201494`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3201494eea100404cba272c7b124c53995938028)
- Update Bootstrap to 3.3.5 [`44a16e4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/44a16e45756a9475472224906b8ea5678ad7d4ed)
- Remove trailing spaces [`8e552e6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8e552e612853c95960a09693837e46124d5d218d)
- Render more specific quality pills on show list [`8e7d7a1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8e7d7a156e113fcec700e9d1606de2ac240f70a9)
- Fix menu icons [`9f6339d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9f6339da8f39c9f91acfdd9db2880ac211176ef5)
- Remove duplicated rules [`30ba6a9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/30ba6a97d2d88d0255a4ae7041fa35f8ada0fa18)
- Cleanup on silly call in most providers [`9f4558c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9f4558cbeacee833cbc29d13b3b70529e391e426)
- Remove from trakt right in the queue item, as there were multiple places shows could be removed and they werent removed from trakt. [`afe5252`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/afe5252cd52d6fd49ca3f29db943e95b5b8898e1)
- Fix progress style [`c0e7900`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c0e7900fe4d256c6ea2e817fff3e5cff9ab627b8)
- Fixes 80 - 100 always being set as 100 [`cbd0948`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cbd09480cc4a4a72c0b904e1714d61004baacc4d)
- Fix file permissions [`1b1e387`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1b1e38783ed200f27c9765edb8ba52be955844cf)

#### [v4.0.54](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.53...v4.0.54)

> 25 August 2015

- Initialize amActive for SubtitlesFinder [`#2346`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2346)
- Can't use str() builtin anymore unless absolutely necessary! we are m… [`#2345`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2345)
- Fix NoneType not iterable in t411, and clean it up while I was there,… [`#2342`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2342)
- Added Vimeo network logo. [`#2341`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2341)
- Add AmActive to schedulers [`#2339`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2339)
- Add archived for composite status' [`#2337`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2337)
- SNATCHED_BEST should not be included in these places [`#2334`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2334)
- Dont allow forcing daily/backlog search on startup [`#2322`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2322)
- Let tornado handle etags for browser caching~ [`#2333`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2333)
- Revert "Set up cache control for static content (images)" [`#2332`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2332)
- Revert "Fix bugs when using banner or small poster view with cache im… [`#2331`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2331)
- Fix bugs when using banner or small poster view with cache images [`#2330`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2330)
- Set up cache control for static content (images) [`#2323`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2323)
- Add option to not forcibly send sound in Pushover [`#2328`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2328)
- Fix for SiCKRAGETV/sickrage-issues#2538 [`#2329`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2329)
- Added icon for Xbox Video [`#2327`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2327)
- Modified deluged_client.py to allow move to folder to be set. [`2686562`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/26865623e799aada4e294d0cd6d72e545673a1de)
- Revert "Fix bugs when using banner or small poster view with cache images" [`4b97901`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4b9790173a132f4485c0c30d0265d87c6ad02a86)
- Make posters and network logos permanent redirects so they cache browser-side [`2cb7667`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2cb7667fc1865a1578e85466bd021f16856a0340)
- Remove raise from newznab. Change to ERROR [`5ac5073`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5ac50733382995128bd2e1dca3821697ee5c1aab)

#### [v4.0.53](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.52...v4.0.53)

> 19 August 2015

- status command should not always return 0  [`#2325`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2325)
- Add ".Renc" to removewordlist [`#2319`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2319)
- Remove update on start and update on snatch options, always update on… [`#2321`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2321)
- Update imdbpy to 5.1dev20150705 [`#2320`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2320)
- Fixes error when saving config [`#2317`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2317)
- Remove update on start and update on snatch options, always update on boot, to prepare for new api show updating [`4d56699`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4d56699742abac74a7e8168d38a7c1f1bb844a9e)
- Fix commit hash in updater [`2034443`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2034443f36c11a7abf927bbd5e4fca4694883516)
- Remove branchdest from getDBcompare [`4238c5d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4238c5d7a845fe57e9cb01dee7694b55ad856824)
- Fix issue getDBcompare() takes exactly 1 argument (2 given) [`06b9304`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/06b9304cebc84e978f6a92ddde99813b1ffe5c67)
- Fix broken debug checkbox [`919b69c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/919b69caf5427f39595988487df78b00baea4487)

#### [v4.0.52](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.51...v4.0.52)

> 17 August 2015

- Updating after Cheetah &gt; Mako change [`#2318`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2318)
- Some fixes and optimizations for mako [`#2316`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2316)
- Remove Trakt Rolling [`#2314`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2314)
- Cheetah &gt; Mako [`2945d7b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2945d7bcb8f0ab4586ceae575f082cb9ab0945ed)
- Fix homepage with fuzzydate [`ac28f04`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ac28f04070ac131fbfd52a1887ad297e84bb6037)

#### [v4.0.51](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.50...v4.0.51)

> 16 August 2015

- Support for notification sounds in Pushover [`#2311`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2311)
- Corrected faulty filesystem freespace check on non-Windows [`#2312`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2312)
- Don't search backlog on show update! Save episodes from memory to db! [`#2313`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2313)
- Committing on behalf of @Greg0rz in SiCKRAGETV/sickrage-issues#256 [`#2310`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2310)
- Added missing NFL Network logo. [`#2309`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2309)
- Add "Amazon Prime Instant Video" network image [`#2305`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2305)
- Adding logo for NBCSN [`#2306`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2306)
- Adding missing variables to notifications [`#2307`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2307)
- Fixing typo recepients &gt; recipients [`#2308`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2308)
- Remove animezb.com provider, domain up for sale [`#2302`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2302)
- Added missing network logos. [`#2298`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2298)
- FIX: Subtitles Extra Scripts [`#2297`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2297)
- Add new Deluge Daemon Client [`#2300`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2300)
- Update pynma to 1.0 [`#2295`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2295)
- Temp fix for navbar overlapping submenu and hiding add-show, etc. [`#2294`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2294)
- Adds overview of free diskspace in /home/status [`#2290`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2290)
- Adds possibility to send tweets via DM as well as normal update [`#2291`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2291)
- Remove trailing '/' from torrent path because some clients don't like it [`#2292`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2292)
- Revert "Moved closing div tag to fix layout issue when a show doesn't… [`#2289`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2289)
- Moved closing div tag to fix layout issue when a show doesn't have any seasons [`#2288`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2288)
- Adding a new step to make sure that develop is up to date. [`#2286`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2286)
- Fix version checker ssl error [`#2278`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2278)
- Revert "Added support for support HEVC (x265)" [`#2285`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2285)
- Added support for support HEVC (x265) [`#2283`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2283)
- Hachoir [`#2282`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2282)
- Update hachoir libs [`#2281`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2281)
- Start converting templates for Mako, and replacement of Cheetah [`#2192`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2192)
- More bool for tuple index [`#2276`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2276)
- Some topmenu [`#2275`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2275)
- Mako more [`#2273`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2273)
- Big mako pull [`#2269`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2269)
- Mako pt11 [`#2267`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2267)
- Mako pt9 [`#2264`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2264)
- Mako lib [`#2265`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2265)
- Fix backlog overview [`#2260`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2260)
- Fix manage_subtitleMissed [`#2259`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2259)
- Fix coming episodes [`#2258`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2258)
- Starting subtitleMissed [`#2253`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2253)
- Mako8 [`#2257`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2257)
- Mako conversion pt3 [`#2250`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2250)
- Finish manage_episodeStatuses, Finish restart and restart_bare [`#2248`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2248)
- Switch cheetah reference in SickBeard.py [`#2247`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2247)
- Mako6 [`#2246`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2246)
- Fix history page for mako [`#2242`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2242)
- Fix column selectors, progress bars, help&info page, small poster layout [`#2241`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2241)
- Mako3 [`#2240`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2240)
- Mako2 [`#2239`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2239)
- Fix conflicts [`#2235`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2235)
- Mako switch webserve3 [`#2234`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2234)
- Mako switch webserve2 [`#2233`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2233)
- Mako - Start switch webserve [`#2232`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2232)
- Mako [`#2222`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2222)
- Create all .mako files [`08343e7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/08343e7e0ee2791b877b91316e8e13dfa6b1049e)
- Reset templates [`c1e994c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c1e994c826374f4fc1a9f1ace2eb39436f184453)
- Replace tabs with spaces and trim trailing in templates [`6c5fe55`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6c5fe553a8d84b1fd5053e7e53db755255b03ec4)
- Re-apply patched mako templates [`5fee0b0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5fee0b0d46ac4dc111856caee6c36960267186b1)
- Removed some tmpl files thatve got "working" mako files [`7a6a090`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7a6a0902dddc45e92c00325b7ef70a57c9c6888c)
- comingEpisodes mako pt3 [`e920212`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e920212af5d416f0111fa99500cea996af9d25ae)
- config_providers mako [`2ba561c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2ba561cef11f33028e3737eb056be8a815a5f9c0)
- Don't break it again [`b0df89b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b0df89b4ec8537790a4b0a43bc66360f0d0b2b16)
- Oops?? [`ded3fbf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ded3fbf07059637cde652129fc8b31ed161d0d4b)
- comingEpisodes mako [`9008b45`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9008b45936fdba67853d16364dc034cb6e80811e)
- Removed unneeded tmpl & fixed config mako [`9d5bb95`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9d5bb953802f7e8d5f5e6527eaba82a359eef163)
- Create apiBuilder.mako [`ef8dd99`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ef8dd99ef7a9a8dcd498b8d615e5f0be309cbd74)
- Fix js in all mako templates [`1f90988`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1f90988f4bb1970b8d661b641048f05b4793578f)
- manage mako [`9dfc4a3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9dfc4a3a996081f504f60ab52a62e75faf795189)
- fix much missed conversions, use bool in true/false tuple index [`bea805b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bea805bd0d25f45ba6b97cfa95ae461b6cdf58fb)
- home mako pt2 [`7af4dc6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7af4dc60949704033741d8ef9be922feaf64a5bc)
- use bool for checkbox tuples also [`b5355f7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b5355f721b127c6ac41a9146dd0c312f40adf8b2)
- status mako [`ec69683`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ec696834c5f6dcb7af67588cea07e600cfd56451)
- Removed inc_top.tmpl [`2928016`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2928016c9f6cb5c67685b52e2d4bada3ea0c2087)
- Convert most of inc_top.mako [`08ea0ec`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/08ea0ec030c64b2a479604747e4f7016c14d7a57)
- Convert most of inc_top.mako [`bbccc38`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bbccc38ebbe3baa288d0fe698a75419ec5dcb508)
- ___ [`d42f96b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d42f96b8f321521bbd027e7d3c554201f0fba2e5)
- config_providers and config_subtitles mako [`549d685`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/549d6859f0ddf35362a53e2d0bec250f417debec)
- Working on status [`aa2a137`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/aa2a137f274434c72c78146f5e83371b23d597d2)
- Fixup home.mako [`15d60fd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/15d60fdb1f45eccd2af6a204c0e2f1be76b4cc07)
- removed more tmpls [`35a4cb0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/35a4cb0a0f65c8ed4070852f16a857a28063c112)
- config_notifications done [`f0842ca`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f0842ca2578faa85ef208010ce0d26100749cf6c)
- home mako pt3 [`6935dad`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6935dada2738d5201ed99ef055cb04bff74dc2fd)
- home mako pt1 [`b2285f8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b2285f81768758fe8da57ff752e77424d7fe7226)
- Mako version of imdb_popular feature [`9e4a29f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9e4a29f3a4e61f22c4ec81737996b2a4cc39d0ab)
- config_search mako [`48ab1d2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/48ab1d2a97a169ecbb65a116434b616a0fd1d32f)
- history mako [`1a58060`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1a580608dddfe4fbff4fd3669e97c596a97ada38)
- config_search pt2 [`73c7416`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/73c74163a11d88a44e6bbafc3a83aea72045ff08)
- config_general mako pt2 [`cacac7a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cacac7aa3a0390bccb3f50096ddaca127452436a)
- manage_subtitleMissed mako [`a47c3a5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a47c3a5e7149cfd208b1090afb9029ac9cb1b070)
- Mako conversion of webserve.py [`dabd08f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dabd08f07cd90c45d784a466047fab65eace07c4)
- config_providers mako pt1 [`c1077a0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c1077a04b9bbdd6a33b88be2a9fcfa563488ccc2)
- config_general mako pt1 [`e544ddf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e544ddf877c65942d2aebece55bfe83fe18a34a4)
- Convert apiBuilder.mako to Mako [`ee03e01`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ee03e01f6bbda5182cf69935d99751036aeb1f2b)
- Normalize more true/false indexed tuples, fix a few out of order [`90503bb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/90503bb8d8318ca08460048e3b3a6a7419389549)
- manage_backlogOverview mako [`b872e2c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b872e2cde9b8f0c535c0ed667e512474dc5ec01e)
- Removed tmpl and markdown mako [`a4dbb8f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a4dbb8f06b8ae44609f3ddaba3c8e350bd00ccfd)
- manage_massEdit mako [`0a078d7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0a078d7acb4326ae0a35268d888016cbd585ac49)
- Config fix and postprocessing pt1 [`dc1edb1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dc1edb1ca4eaeac0618f7a19f4ea52fbc1bdae18)
- manage and manage_massedit [`c51c322`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c51c3220bda85a9e81a229f89da6fabbb2969851)
- manage and manage_massedit [`c72db16`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c72db163e9305fa168a027a55c0011c50d5ad3ea)
- config_notifications mako pt1 [`844de1e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/844de1eff98c33bb5a82692c9f1fcf2c34fbd70a)
- status done [`5a77163`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5a77163dfe747fbe235f7523dee1ebadb8d21790)
- config_postProcessing done [`18612e9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/18612e94ceb0a8e1a16742fb314ac8af242af34b)
- webserve semi-working for mako [`a04ffa2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a04ffa2fa7ffacc091570d78db87799fc438b595)
- inc_bottom mako [`e5a60af`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e5a60af92d6e1d61fdb02cf0997fb3c9cf13f30e)
- manage done [`89bd797`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/89bd7974ddb3c814f75175f5a3c14e77edf96542)
- comingEpisodes mako pt4 [`5e2f443`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5e2f443a170e17d0bfedb02969afc628411a1fe0)
- Fall back to using video height to guess a video quality if video is not in snatch history and quality cannot be found from file name [`5ef77b3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5ef77b35fa935ff8fa1c5f2dfbf115de15d9344a)
- config_general almost done [`fade1a8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fade1a8f1002ac6a3b258fcca6fec88e09664567)
- Don't need config.tmpl [`e4b756a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e4b756a14d5990732e620eb02fa7de73a132a98b)
- comingEpisodes mako just needs if statments fixed [`db28612`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/db286128c09feca29e90706289071869d81e7b33)
- inc_qualityChooser mako and tmpl removed [`56548c9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/56548c96366c18301a54c40318dd29af4e272a97)
- errorlogs mako [`8403651`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8403651fc7786def2f1fd27c6d9b46cf5863e088)
- home mako [`3360b5d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3360b5dd8fe3749276eb2b809d3fe27a40651363)
- manage_failedDownloads mako [`659ce46`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/659ce46ae924f2ea8ced397806829fc930902b79)
- config mako [`035501a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/035501aec00a3f53e9f0cbd378346b2bd01dde4f)
- postProcessing mako pt2 [`9b5e881`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9b5e881c65230db07221a01730205447e440471b)
- manage and backlog [`1a0c299`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1a0c299d44d9c9b67b402d13005c2d54cffbf485)
- most of config is done [`2bd744c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2bd744cdf24391dbde66a764d1375bfb5498a04c)
- config_general mako pt3 [`2792629`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2792629e370fe3bab35e64835abd8c45536c436a)
- too tired to finish [`8dbda68`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8dbda682a8c7b91a77ac473f110fe20d7717b079)
- viewlogs mako [`e5546a9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e5546a9a4ee5b1b486a6f7528336fa5fc367bfbb)
- config_backuprestore mako [`8244ebc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8244ebc8a2e5dc56dbf076da4bbcf04c7d589836)
- More mako [`9d92840`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9d92840c8da6cb049b1d8c1b28ec338f6117a56d)
- Fixed merge? [`4ce1955`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4ce1955bae414a07b59f4a34f399848b436dae9e)
- More mako [`8ba2301`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8ba2301af82c5003d3989f48391eb0f0b8636354)
- Merge develop, breaks inc_top [`9f1004d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9f1004dd944f958d7e96d90fb8772fe172328b62)
- config_general should be done [`1606e94`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1606e9415abcf4a0c94817149b6d06bad009cab8)
- home_postprocess mako [`d8655ea`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d8655ea92966628e70daed849bb14cd0edf4c74b)
- manage_backlogOverview, manage_failedDownloads and comingEpisodes done? [`174ce67`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/174ce675c4a46501de65a0b254d832cfe2796fef)
- restart_bare make [`624dfcf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/624dfcf05dee5d4128a40126fa635e7c0b9100ee)
- manage_backlogOverview, manage_failedDownloads and comingEpisodes done? [`3c0ef08`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3c0ef086015892e900314c409ae056e615359bf0)
- config_general mako pt5 [`e3e79d8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e3e79d849419ef032352c1b2f9aece6656d7d4f1)
- config_anime mako [`e20cb96`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e20cb96c0d3c6ff98d737ddbddae529422d9400c)
- config_providers and config_search done [`ea2418a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ea2418aaa1071d17e1666c4220aff1a7da2c8405)
- manage_backlogOverview [`19d8005`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/19d800588c99db1e8e88f2986335ea3b8e73e592)
- manage_backlogOverview [`b7c2a71`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b7c2a713a54ea3b690564bd6e6187c489562216c)
- Fix config/postProcessing and genericMessage [`2647466`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/26474664b746159368237072841c55c40b8371ec)
- config_subtitles [`0308427`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0308427daf61326ca95ca73f1cbbc3bb524d5ff0)
- config mako pt3 [`4348f6f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4348f6f8d429237f79ec97a5428cc7a28795f929)
- manage_torrents mako [`fc4abba`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fc4abba822f9f42ac9a07f0be82a3745434022f8)
- new style imports in sickbeard/__init__.py [`5c0ed9a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5c0ed9af9a59cd0517ed6956d00952a9b029065d)
- comingEpisodes pt1 [`ac93418`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ac93418169f59735537649b4348d6d2c6f90be1e)
- history mako [`feaa50e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/feaa50e515f886beb0a2a3f6abf0a642e533130e)
- inc_rootDirs mako [`9a56e97`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9a56e9722b20022c84fd61cdf1303e8f3a6869ad)
- Fix all sbRoot/sbPID [`e794c64`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e794c6497511fd9990730ff040b3ce08eb2b9a44)
- More fix for preview rename [`f03a513`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f03a513869c8a0cfa36b227f571009cc2982bc0e)
- Don't import tmpl as they should be removed [`4ed23e9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4ed23e9abb84d467afe2d441daa5387f9c24c0da)
- comingEpisodes should be done [`45948a6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/45948a64937443345198c335e5244c455643c7ad)
- Inherit inc_top, include inc_bottom [`6945832`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/694583288a3eacbf000430dc1e229f985dc4d550)
- comingEpisodes done [`2d9688b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2d9688b71c1676f7f14a627afde4ede443f68a63)
- Fix edit show [`52ef491`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/52ef491757a6c780e5a6bee8e9a34af8848a1654)
- broken mako [`22b9575`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/22b9575e309ab23a9139a8aea38621510ff7e259)
- config_notifications mako pt2 [`cbe7688`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cbe7688b504227786ea4715e7e177a2459a996cc)
- restart mako [`088cf97`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/088cf971b34db69eef6a96cb90473579f511c08c)
- history should be done [`d604a3e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d604a3e7c38702bde23bea2ac3ce8625559a076d)
- Yawn [`26a4c95`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/26a4c9596e7bccfc352a4e774b7b7a3f63a7c466)
- swapped ifs [`10bbe99`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/10bbe99609f8a994c83f3edbc84bf54084ddfe1f)
- IRC mako [`9b9eafd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9b9eafd16ccf3f82a429b9603710772f6d050f0c)
- Finish apibuilder conversion to mako [`3003dbd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3003dbda8c75a420208b255b1ba0fe3a32a106de)
- config_anime should be done [`8737d2d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8737d2da1c7378dbd450998d109a063fb587c04f)
- genericMessage mako [`c53eecd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c53eecde7d9f2aaf14377249fcd0e1e601afdf8f)
- inc_bottom should be done [`053afa3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/053afa321b5c978ccc7f5e88c189ccaebcf3f13f)
- Fix addExisting, snatched count in footer, and curDelete in manage [`91a37e7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/91a37e7a9b059237b86d6ee7b15248b8c2174cba)
- swapped ifs [`75159a5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/75159a5a06c5d4b56a7c8a43fc171c483fc1c5a0)
- config_general pt1 [`e0397ba`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e0397bab31e570ae35da554c0f96d3984bc73072)
- login mako [`221de9b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/221de9b8a127646657fd8e4745fbc7efd7cbdcf6)
- config_general mako pt4 [`5cd1092`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5cd109211011eca56304c96c42def35d5a0e9dbe)
- No need to check for mako, it's in lib/, bump python check to 2.7 [`b6be881`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b6be881fd3b3a3aafc499b137f8bd56908c7bf9e)
- history fix for } char [`108919e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/108919ee1854d6191d8e679ea1ec0362892d548e)
- history fix for } char [`aaefe3b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/aaefe3b33df3f509365aa9287243ce80d66ab767)
- Cleanup [`532baf6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/532baf6e0805ba419c9bb235be41d55c9dddc2de)
- backupandrestore done but needs imports touched [`5076608`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/50766080d765c4732b6c7afc6906dc122d49bf2a)
- Quality chooser fix [`1673b7d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1673b7d6e2508e7a171ff6fe9e03f94c3c636528)
- fixes subtitle page not showing selected subtitles [`c6b6224`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c6b6224ac931fa6dc1c91b35d750f4c4d5845fb8)
- User iteritems instead of items [`4f6171c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4f6171c7cfc4978c6a7ae191962731575fbfdc9e)
- General and backlog done [`a4f060c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a4f060c2c7b8256dc20acf7f2341138b0be82c17)
- config_postProcessing mako pt3 [`a70f0af`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a70f0af027013c8edac2832d0b71892f86a345bd)
- home should be done [`fe6a553`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fe6a553207b358463d53cbba61e75f1dbfac5460)
- Header exists mako fix [`e7449c8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e7449c8dc14148049ac09a65a85997ced069fe88)
- Let's hope they're meant to go there [`981965a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/981965ac18901a99c8051965cbef0e474a992690)
- subtitleMissed done [`bfee64a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bfee64a2ddb63f3bf8aa850d6293a04a136fcc22)
- subtitleMissed done [`8bd54f2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8bd54f201431a66d2098c3657dbda5c921a23b67)
- http instead of https for rarbg torrentapi [`60238b2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/60238b25ba29708a71fe3813a4abbe352d6511ca)
- config_backuprestore should be done [`deb66e5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/deb66e542ca63e478f3a177e3f684a27a84d10f7)
- Fixed missing $ [`d1af927`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d1af9279faaf1c4cb7c176e132aa2cd83f799529)
- Fix exception when obj is null in generating meta images [`f58bc28`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f58bc28189fc7aa54f1262da6f9557285a742900)
- managesearches done [`dfd3798`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dfd3798ced66b894a4c0e530dda4ba029bc45e74)
- inc_top mako [`2a4ad7e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2a4ad7e3f556ebcfa465cb5fa6cebf3ec3f67cf0)
- Fix mako apibuilder [`2a298dc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2a298dc8a35de06b71ae60dff0397ec212165586)
- apiBuilder should be done [`3d52c3a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3d52c3ae6fc2b300c65f2fe35fbb2eee4c87dd65)
- comingEpisodes and manage_backlogOverview done? [`1f4f5e7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1f4f5e7f990e5c1093bc7bfcaf32666c81f523d5)
- fixes L269 weird line on inc_top [`463c579`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/463c5796a61828cb02a3bfa6abc66477488f8afe)
- comingEpisodes and manage_backlogOverview done? [`5d4995b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5d4995b9ff95c56c957a57d43120a5363224106e)
- managesearches done [`ac5e11c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ac5e11ca14eddb0edba286211d59a615ca435d02)
- tmpl -&gt; mako reference [`9bab171`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9bab171ff279f2022a3c763192183e8c26da2d17)
- IRC should be done [`292ce21`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/292ce21546bf1cac72e9266e36e29a2add7e1b0e)
- Fix mako compile error not recognizing backslash as new line filter [`8155d40`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8155d40eab485c72f2bc1cb1f7c67ac6829d1972)
- Forgot a few # from home [`960cf87`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/960cf872b38b80a431bb67628e7aa7af6098e648)
- Reversed active/inactive images on home page [`bf48058`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bf48058420d7339d24a4f58dc47c1d6cadaec2c4)
- history using mako imports [`e94abde`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e94abde340c5dcb7ef5144b8a290caef6dddb916)
- Revert "Moved closing div tag to fix layout issue when a show doesn't have any seasons" [`43ac198`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/43ac1981f1de32354478d498e752cb00ee84f3e0)
- Fixes syntax highlighting in editor [`7fa2765`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7fa27656238f4eeafcf8dec871841e9994531951)
- swapped ifs [`0e285ef`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0e285ef0197792e2542f364f6a26d04a40020942)
- Change requirements.txt to install mako, change readme to say mako [`b08fb91`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b08fb914d6fc8135976415b92952a46dda513728)
- Fix loglevel and logfilter dropdowns in viewlogs [`fba2943`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fba294395ebcee645a287573a8d1bdab7808ceaf)
- Fix for double dropdown date style selection [`937c095`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/937c0951dd1dfd5aec353905460b51bfa48025bb)
- Fix not being able to enable/disable subtitles/flat folders in edit show [`c4916f2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c4916f2e65d47e5ef7101b1637c8656907960410)
- Wrong variable name for setting attrs in newznab [`19d19c4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/19d19c4ac68a76975b84694956edb8d423f7e1e0)
- Rev [`360bb2d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/360bb2db72b5a169aa34f3822874816db677c7bf)
- match fix for subtitle providers [`8f35907`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8f359078037f7273679b33fb25c2f5fcce47d6e5)
- Removed #&gt; [`b754a67`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b754a67f3a379b350cc18482bc030264d6b9960f)
- Fixed banner issue on comingEpisodes [`111b4fc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/111b4fce6e51c7c0b1d543f7f7116cf85acda144)
- Rev [`bbaac56`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bbaac5603d4b99842e9141f1501594cad7d33b38)
- test rename fix [`d3c2057`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d3c2057008f6132158bcd0a9333888005e02eb47)
- match fix for subtitle providers [`29adce0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/29adce0c288c7ab9d3507aa714186e5dcf933a55)
- Update wiki URL in PP [`992c82f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/992c82ffb1ecb175bbf96a0c692d7cca6f56cdb1)
- Fix history -1 and fail img [`4fdb8fe`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4fdb8fe41069029656d3584a1bcfb2eaaca15622)
- Missed $, need to go over this as I don't know the url to test the page [`6136fad`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6136fad9a0a4bff759bd2ad4cd87496d071b1295)
- Fixed banner issue on comingEpisodes [`e1bf8f1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e1bf8f1b0fc54c972914ddc149b13563f14006b8)
- Header and title for test rename -&gt; Preview Rename [`9ec727a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9ec727a00be94146e96061a42791e8ef6c3d0338)
- errorlogs done [`5344697`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5344697bb10cd5ad413cf3f490e1c1302adbedb9)
- Update Wiki URL [`6a545ff`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6a545ff45d808180569b5718ce58fbf593f33307)
- Nofolow for robots [`abd7d9f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/abd7d9ffce60195c175b7f91fee989b27fced618)
- sickbeard.layout in 'poster' fix [`a967db2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a967db21e104476b1a809b949aed63759520e059)
- Fix login page on mako [`ad226c5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ad226c51a10a56e5c69bea9b9e8f0316cce75f70)
- Missed $, need to go over this as I don't know the url to test the page [`a1bfabf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a1bfabfa162596a9eed5d1d1b4ee515a23ba5b87)
- Missed t. removal [`e6fe095`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e6fe095d0d9ea8fb65c81d0b240a86e58824b64e)
- inc_top should be done [`c43e1a9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c43e1a9555931ed1569df09c8b91bbc3ffb1bd4d)
- Rename tmpl to mako [`c5a7b6a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c5a7b6a7904704ca873494a9348e16cd8aaf4546)

#### [v4.0.50](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.49...v4.0.50)

> 5 August 2015

- Don't accept results for episodes that have not aired yet [`#2272`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2272)
- Changed name of provider icon abbeygirl.co.uk to new anonzbs.com. [`#2270`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2270)
- Newznab: Only have rid in first query, no string query when rid searc… [`#2271`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2271)
- Display show/episode which image was unable to download [`#2268`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2268)
- -Siklopentan to removewordslist [`#2266`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2266)
- Missing session for nzbsplitter [`#2263`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2263)
- Add [1044] [`#2251`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2251)
- Fixing indentation on emby notifier [`#2249`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2249)
- Newznab: Only have rid in first query, no string query when rid search,  and skip string queries if rid search had results [`89f2ce3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/89f2ce3c7f2271eb5d35b4dbfd99a1d5ed5a1efa)
- Newznab: Only have rid in first query, no string query when rid search,  and skip string queries if rid search had results [`8abd29b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8abd29b2968b240990cae4c65cdddf8dad1bd01d)
- [1044] [`ffd1d74`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ffd1d740230f30d023dbf9f594d7e2c92ea64b61)
- Change PLEX Identifier to user agent [`3c2e42d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3c2e42da647e6dc52be0c0ec2ce8fcc9d3b3aff7)

#### [v4.0.49](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.48...v4.0.49)

> 1 August 2015

- Change 'unable to obtain cookie' to warning messages [`#2231`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2231)
- Added Piratennzb provider icon. [`#2243`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2243)
- Add Emby notifications [`#2237`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2237)
- Paused Shows are Showing in webapi Backlog Query [`#2236`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2236)
- Add variable in init.fedora to allow changing the Python path [`#2230`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2230)
- Only email committer if build fails in travis [`#2228`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2228)
- Fix equality vs identity problem in catching requests status codes fo… [`#2225`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2225)
- Fix provider column in history for archived items, fix subtitles flag… [`#2224`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2224)
- Replace tabs with spaces in templates [`11bd12f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/11bd12f7d0d3d6c99026590cd844bed566cde874)
- Update guessit to 15bb35b885b94c6494fbfbdf872890d0717dfabf [`b387dc9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b387dc9741697259d87abd3ffb741522fc4ed68d)
- Can't do a season pack search in manual search [`97b1469`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/97b1469441a113b8007172d88be532b2ed6799c0)
- Fix equality vs identity problem in catching requests status codes for trakt [`8fa7a4b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8fa7a4bb777c9192bd706115579e540eed8461b2)
- Fix equality vs identity problem in catching requests status codes for trakt [`7227f4a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7227f4a101ef5fc8abb6f326aaf77dd963cc1a03)
- Fix thread naming not showing up [`6cba297`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6cba2974684ea5663b748a9b4c5606ddbbef7545)
- Update torrentday.py [`64b6bb4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/64b6bb40907bd57a0fcafc893d16f69de8ce8406)
- Fix missing " [`051c99c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/051c99c5773d1b824b18227ffcc02d8f80112d17)
- Change time out error to warning [`be8026b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/be8026b8cc7148a5c3dd6024a3671113fb6415d4)
- Dont fix episode status for special episodes [`23b3a18`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/23b3a183e4705d8be35b8340f78178514d0e631f)

#### [v4.0.48](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.47...v4.0.48)

> 29 July 2015

- Also need zip64 for other methods, and to extract! [`#2223`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2223)
- Update guessit to 15bb35b885b94c6494fbfbdf872890d0717dfabf [`#2221`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2221)
- Templates formatting [`#2220`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2220)
- Check if SR is updated before submitting an issue [`#2217`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2217)
- Fix SiCKRAGETV/sickrage-issues#2377 [`#2219`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2219)
- Add note that SickRage should be updated before submitting errors [`#2218`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2218)
- Fixes SiCKRAGETV/sickrage-issues#2370 [`#2216`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2216)
- Fixes SiCKRAGETV/sickrage-issues#2373 [`#2215`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2215)
- Replace tabs with spaces in templates [`0db61e2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0db61e2eb4fcd4ab7556950b436759e6876fe205)
- Need to make sure data is big enough before decompressing [`7b8963e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7b8963edfd7dc9f02fe52e7433620c24168123f1)
- Dont fix episode status for special episodes [`eea739f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/eea739fc4f6ea527be5e817389b3345f108d159a)

#### [v4.0.47](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.46...v4.0.47)

> 27 July 2015

- Missed a bad return [`#2214`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2214)
- Revert text factory to may19, until we can fix unicode [`#2213`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2213)
- Fix KAT and TPB via proxy (need direct client connection, no black hole!) [`#2212`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2212)
- Feature: Popup confirmation before submitting errors. Fixes SiCKRAGET… [`#2211`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2211)

#### [v4.0.46](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.45...v4.0.46)

> 27 July 2015

- Skip non propers before snatching them, and log which provider is ret… [`#2210`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2210)
- Remove headURL and see how it works out. bt-cache sites are only nece… [`#2209`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2209)
- Fix Xem refresh [`#2208`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2208)
- Show skipped files in log INFO, not DEBUG [`#2207`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2207)
- Fix returns in xthor and ftdb [`#2206`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2206)
- Added missing provider icons. [`#2205`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2205)
- Wrong return in libertalia _doSearch, fixes SiCKRAGETV/sickrage-issue… [`#2204`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2204)
- fix xthor crash (ratio) [`#2203`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2203)
- Hdts cleanup [`#2201`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2201)
- Fix for SiCKRAGETV/sickrage-issues#2337 [`#2200`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2200)
- Use issues even if they are closed for issue submitter [`#2199`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2199)
- Fix bug preventing torrents with 0 leechers from being downloaded [`#2198`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2198)
- Remove headURL and see how it works out. bt-cache sites are only necessary for blackhole now [`02f14a6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/02f14a655f11ed0e5ab12d6183683f2ef3e56ff0)
- Cleanup hdtorrents a bit and fix a small bug [`558068c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/558068cd30e9f8dcdff026e56ca86fe37a993512)
- Don't search eponly in sponly mode, just gives errors about it not being a valid season pack [`57e3173`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/57e3173e9ee8bf7efc009a5c801cd93ef12c4391)

#### [v4.0.45](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.44...v4.0.45)

> 26 July 2015

- searchRSS returning episodes for paused shows? - TEST [`#2197`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2197)
- Changed .col-status to make it fit larger statuses [`#2194`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2194)
- Clean up some code in kat.py [`#2191`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2191)
- Paused shows [`#2190`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2190)
- Adds option to save history limit selection [`#2188`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2188)
- Disable text factory on DB for tests, read line comments [`#2189`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2189)
- Adds saving history limit, fixes https://github.com/SiCKRAGETV/sickrage-issues/issues/1812 [`#1812`](https://github.com/SiCKRAGETV/sickrage-issues/issues/1812)
- Update light.css [`4f8ae57`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4f8ae57ead01efe7f69639ffbd063e5397e8447e)
- Update style.css [`8e37af5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8e37af50befa8e775b066f426d8c39ebe963e57d)
- What was I looking at? [`ee1e4c8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ee1e4c8db6a3e04837c46e1ed4be09b5e6b33f78)

#### [v4.0.44](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.43...v4.0.44)

> 24 July 2015

- Text factory decoding order change - Fixes SiCKRAGETV/sickrage-issues… [`#2187`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2187)
- [www.frenchtorrentdb.com] to removeWordsList [`#2186`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2186)
- Develop [`#9`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/9)
- Fix restart default page [`#2185`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2185)
- Try to fix SiCKRAGETV/sickrage-issues#2207 by adding delay between ap… [`#2184`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2184)
- Missing select in manage_episodeStatuses, also fix SiCKRAGETV/sickrag… [`#2183`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2183)
- Reorder other decoding methods also [`a47d396`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a47d396f1857f17e48bda8bea6641028efc3da87)
- Force git reset in user settings. Will fix some issues. [`26b51e1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/26b51e102b21afa49bd0c74b44744ab28e7abf00)
- Remove some log lines to avoid spam log [`d6b06ce`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d6b06ce13da98e509684534386d3626ad5631984)
- Revert "If user has debug enable set DEBUG as min log view" [`fdd4ec6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fdd4ec6b149a9e1a4ab95bea083af237ea2e8e4e)
- If user has debug enable set DEBUG as min log view [`b33ef8f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b33ef8fddcf310869cfab13ae6db2834c1a1068c)
- Update template to show "Loading the default page" and not home page [`abb31e4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/abb31e4fd48997723ea08252ff9e3ad695899fc7)

#### [v4.0.43](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.42...v4.0.43)

> 24 July 2015

- Some cleanup [`#2182`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2182)
- [www.Cpasbien.pe] to removeWordsList [`#2181`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2181)
- New word ,to removewordlist [`#2178`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2178)
- Take single/multi subs into account when changing permissions - fixes… [`#2180`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2180)
- Handle xem_refresh better [`#2179`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2179)
- Update TODO [`#2177`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2177)
- Add "Collapse" button on subtitles management [`#2176`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2176)
- Crop support image [`#2174`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2174)
- Adds default page option [`#2173`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2173)
- Add Xthor provider [`#2172`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2172)
- Develop [`#8`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/8)
- Fix log lines and add log lines for URL when code is 200 [`#2170`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2170)
- Add GITUSER to IRC [`#2168`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2168)
- Multi-Ep results were not checked for qualities, ignored/required wor… [`#2167`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2167)
- Added some missing network logos. [`#2166`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2166)
- Don't log IP when successful connection to SR [`#2201`](https://github.com/SiCKRAGETV/sickrage-issues/issues/2201)
- Multi-Ep results were not checked for qualities, ignored/required words, bad releases, anime white/blacklist, and were using getURL instead of headURL [`17eb849`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/17eb849cddbb13bb3e74540174a508eb848c68c0)
- Bad log formatting [`719b270`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/719b27082c2ae9ece0ecf048656c51da17a6e27d)
- Remove useless vars [`1d008f7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1d008f7480196fc176cc168c01d3bdd4478dc33f)
- Missed import [`335c911`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/335c91134ee92a0f3a4b4cfcc365665781f34fbd)
- new word [`67eb54a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/67eb54a8a2ac314a18fff945c9f5d14450533d5f)
- Fix newznab global name 'params' is not defined [`ec69423`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ec6942375bf6c401d35539b1a0db654c44abe18d)
- Change IRC username prefix to know its an user from UI [`3dc1fa9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3dc1fa9fee1a00147b7effd9e1b8e3cb8f3cf41c)
- Don't remove generic.py [`2de60e2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2de60e26b20094fe4199212269d0ba4b2618b5dd)

#### [v4.0.42](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.41...v4.0.42)

> 21 July 2015

- Remove old clients files [`#2165`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2165)
- Adds IRC to SickRage [`#2161`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2161)
- Added missing fyi & soho network logos. [`#2164`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2164)
- Added missing Arena network logo. [`#2163`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2163)
- Missing Recommended Shows [`#2162`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2162)
- Fix default argument when not provided. [`#2160`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2160)
- Fix TRAKT log message to use pattern SXXEXX [`#2154`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2154)
-  Nonsense Fix SiCKRAGETV/sickrage-issues#2206 [`#2159`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2159)
- Add post subtitle download scripts [`#2139`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2139)
- Fix SiCKRAGETV/sickrage-issues#2126 [`#2158`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2158)
- Stop building for 2.6, and set readme requirements to 2.7.x [`#2157`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2157)
- Bugfix tv [`#2156`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2156)
- Check free space of show folder instead of it's parent - fixes SiCKRA… [`#2155`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2155)
- Show only basename of filename in display show [`#2152`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2152)
- Add an API command to get the fan art of a show [`#2150`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2150)
- Migrate travis to a container-based infrastructure [`#2151`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2151)
- Added missing subtitle flag for Afrikaans. [`#2153`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2153)
- New fixes for log pattern SxxExx [`#2149`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2149)
- Make SxxExx pattern as default in log messages [`#2148`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2148)
- test [`a8041fe`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a8041fe7b47f1466025ad70e2e99cede8fc31df5)
- Disable auto set as "air-by-date" as it's not a proper code. Let user set it [`dd99b5b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dd99b5bcd96d6fa1888decf7fa63cad01fe2c94f)
- Fix notification when searchin subtitles through web api [`bb196f3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bb196f36019baa9b923e9cc5ed170b84c94db762)
- Fix max title length for issues [`4fac9d2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4fac9d21f35698446c49400ac89d261d64d8c763)
- New log improvements [`2dbd47c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2dbd47c8c01f1a5c00780ea0bd9ac1efc8553495)
- Make "Filter Row" in shows page enabled by default [`999ad6e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/999ad6e833c26f7912da8b44906698796dcc0d12)

#### [v4.0.41](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.40...v4.0.41)

> 19 July 2015

- Add NZBGeek to newznab providers (Thanks NZBGeek for dev apikey) +fix [`#2146`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2146)
- Add Default Ep Status to WebAPI CMD_ShowAddNew [`#2142`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2142)
- Remove zoink.ch [`#2145`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2145)
- More network logos [`#2144`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2144)
- Added missing bravo (us) network logo. [`#2140`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2140)
- Several network logos [`#2141`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2141)
- Don't allow chained call with command show.getnetworklogo [`#2143`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2143)
- Fix Cpasbien provider [`#2136`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2136)
- Fix error: Filesize would require ZIP64 extensions [`#2138`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2138)
- Develop [`#6`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/6)
- Simplify status in tv.py [`#2135`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2135)
- Fix WANTED episodes that haven't aired, less log spam [`#2134`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2134)
- Add missing api commands to apibuilder [`#2127`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2127)
- Fix search indexers api [`#2128`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2128)
- Ñew word to removedWordList [`#2132`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2132)
- Fix https://github.com/SiCKRAGETV/sickrage-issues/issues/2203 [`#2203`](https://github.com/SiCKRAGETV/sickrage-issues/issues/2203)
- Update helpers.py [`efebf85`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/efebf855f5109e71ff08e25f93cda970063dccd2)
- chiba tv,sun-tv & teletama [`3c82b7a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3c82b7a1267bb51cd7b14e8db9faa980360e49af)
- we_tv logo [`b111a79`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b111a797ac83eb2b9841126193a6a1335500fccc)
- several logos [`dabfdce`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dabfdce27c1ce703ac8c3d5653ac1e21c15ecba7)

#### [v4.0.40](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.39...v4.0.40)

> 18 July 2015

- Don not consider episodes with airdate = 1 as aired [`#2133`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2133)
- Add TitansOfTV provider [`#2129`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2129)
- Updated CHANGES.md `till 4.0.39 [`#2130`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2130)
- Develop [`#5`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/5)
- Added missing global & abc (ja) network logos. [`#2126`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2126)
- Develop [`#3`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/3)

#### [v4.0.39](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.38...v4.0.39)

> 17 July 2015

- Revert "Set episodes with airdate as 'never' to UNAIRED status" [`#2123`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2123)
- Set episodes with airdate as 'never' to UNAIRED status [`#2122`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2122)
- Rename clients py files to avoid conflicts with libs [`53ce36a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/53ce36a9dc336907f81d63e2d0d455c27d11b299)
- Update tv.py [`92e299e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/92e299e31cec13c31504d8dfc74b066389e8a37f)
- Update search.py [`e38274d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e38274d6f33bc2e15092367a8e2aa6bee5e4da5f)
- Update search.py [`95ac7be`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/95ac7be53e318d79033c886deb26b04a5a05903f)

#### [v4.0.38](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.37...v4.0.38)

> 17 July 2015

- Update readme.md a little [`#2120`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2120)
- Added Fox Crime network logo. [`#2121`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2121)
- Remove lib from import lines. Save memory and always have the same object for vars and exceptions [`#2119`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2119)
- Added Fox Crime network logo. [`#2181`](https://github.com/SiCKRAGETV/sickrage-issues/issues/2181)
- from lib.module and from module return different objects [`762a0e4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/762a0e4d8c14b0a2947adbfa72c91f4151966a5f)
- Revert local scene exceptions to use gh repo [`4eb123a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4eb123ac1973be1b573f78b4491682bfbf90fa2e)
- Revert network timezones to use repo again [`2d1aaba`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2d1aabadcffe4e9362b088bfb58ea0d144bd3960)
- Update news.md [`fc3b1c7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fc3b1c79c7ac7a73c6ff7e7d9cf1410665a06620)
- Update news.md [`358f683`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/358f683d40dd15518ae782fe50784dc376a896d0)
- Fix bug with scene exceptions, and build [`0657d64`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0657d64e2d0d3feb159d0a41e9b3a407cf520618)
- Fix bug with scene exceptions, and build [`7a542ec`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7a542ece2e6c758868804126c6eb9fdeb3f8a25d)
- Better log message when error downloading subs [`9ebb446`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9ebb446756950aae64d09e2a4d934a5b93571322)
- Change show names cache to DEBUG [`47e4021`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/47e40213ec48c53ab160af44c4685ca9f229b890)
- Fix URL with double http:// [`d6aedae`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d6aedaef6148d90a14e20710c23e20a27333c948)
- Fix bullets in markdown [`c25e0d7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c25e0d7f30d0f072d08c249552e36b3772b1322a)

#### [v4.0.37](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.36...v4.0.37)

> 17 July 2015

- Changelog [`#2118`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2118)
- We need to figure out a better way to handle this [`ef12cae`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ef12cae3dd6aa790bd5574ba246d223507b0305a)
- Rename news.tmpl to markdown.tmpl so it can be reusable [`280ddfb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/280ddfb8e3cdf1a5832bdb7480f7f76b7ad474c8)

#### [v4.0.36](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.35...v4.0.36)

> 16 July 2015

- Fix detection of already downloaded subtitles when using a custom sub… [`#2116`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2116)
- Fix detection of already downloaded subtitles when using a custom subtitle dir [`ef3278d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ef3278d777a45b164795a7a8853e63ec3d0a6df2)

#### [v4.0.35](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.34...v4.0.35)

> 16 July 2015

- Updated subtitle flags. [`#2112`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2112)
- Small Typo [`#2115`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2115)
- Add Cpasbien provider, update Libertalia [`#2114`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2114)
- Develop [`#2`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2)
- Update Libertalia not to use urllib2 anymore [`c5d579a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c5d579af7d3476fd267b84c4639cbb51d450b34f)
- Update news.md [`19dae7d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/19dae7d8e995af4664edecb0be578fee7b6bf5e2)
- Fix flags on history page and info lang [`0ebb1bd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0ebb1bd8ca7c88d3c517e0eb0a7d7c9ea3b11e77)
- Update news.md [`9de06c4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9de06c41ce60153175ee79c08a0cc5bc62a3c6b0)
- Update news URL [`a62f64d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a62f64d7a1c0dee3542b42f68a12905a506bf3d3)
- Update news.md [`2312f65`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2312f6567d5338077d6ab0396da1e8e44cd6085c)

#### [v4.0.34](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.33...v4.0.34)

> 16 July 2015

- Add news [`#2086`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2086)
- Bug in PP where scene numbers always used [`#2110`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2110)
- Add FrenchTorrentDB and Libertalia providers [`#2106`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2106)
- Use markdown2 to parse github markdown pages [`ba1babf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ba1babf427ec021637af1cb5b917dbf73f58152a)
- Move and improve subtitles codes check [`4d9663c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4d9663c13fa520287aa351fad1a508a14fbd1f26)
- Move and improve subtitles codes check [`9c373c2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9c373c2d5fae6656fd44eb98b74aa46036520e17)
- Create news.md [`281fb27`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/281fb27691be4416451e174f83c1d56f481c2ad1)
- Update webserve.py [`ec4e3ec`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ec4e3ec0e8793bfa84613773396568c60d81c5e8)
- Create news.tmpl [`3ad822a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3ad822a094e5146d0006dcd1dd026e428e0db06c)
- Fix flags on history page and info lang [`1e2bcad`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1e2bcad2f1d668deb6257ae698b45a8bad0e3769)
- Performance improvement in subtitles code check [`8e38759`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8e38759d53db01998426e0add03e089be5076007)
- Performance improvement in subtitles code check [`f3b5727`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f3b57275d6b43c019a4513e4461f6a7a96d7ffde)
- Update inc_top.tmpl [`5dd7732`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5dd77326422d30546fac32d9c8a47a83ea6ac87b)
- fix-donate [`921c111`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/921c111d05700e27a1a626184ac25d27c9e68b09)
- Changes spaces [`6305bbd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6305bbd4c3ce103c8135fc81ce3e7a5c0c0d8932)

#### [v4.0.33](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.32...v4.0.33)

> 15 July 2015

- Fix old subtitles codes in DB [`#2109`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2109)
- Added missing subtitle flags. [`#2107`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2107)
- Add setting for future episode status [`#2108`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2108)
- Fix trakt return [`#2105`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2105)
- Fix trakt exceptions when connection timed out [`#2104`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2104)
- Fix html tags [`df8b042`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/df8b0428a12845aded67ecf96071ad40006419f4)
- Updated subtitle flags. #2 [`88c3fa8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/88c3fa8e40a8cf33178ed473d320d4daf2a6c950)
- Updated subtitle flags. [`0b91408`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0b91408daec1131222631fa14099668e0268d2b8)

#### [v4.0.32](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.31...v4.0.32)

> 14 July 2015

- Re-add namecache creation to SickBeard.py [`#2102`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2102)
- Hack around failing TokyoToshoKan - Should fix SiCKRAGETV/sickrage-is… [`#2101`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2101)
- Use only absolute path for SUBTITLES_DIR - Fixes SiCKRAGETV/sickrage-… [`#2100`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2100)
- Subtitles - Use opensubtitles codes [`#2096`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2096)
- Reorder encoding/decoding attempts, update chardet [`#2099`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2099)
- Fix SR not auto exiting if another instance is running [`#2098`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2098)
- NEW OPTION in config/general advanced settings (SSL Verify) - Disable this for QNAP SSL problems. [`#2097`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2097)
- Fix for SiCKRAGETV/sickrage-issues#2079 [`#2095`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2095)
- Add an API method to get a network logo [`#2090`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2090)
- Updated the provider icons. [`#2092`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2092)
- More sufixes and prefixes [`#2093`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2093)
- Better integration in Chrome for Android [`#2089`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2089)
- Small visual improvement in server status [`#2091`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2091)
- Fix for SiCKRAGETV/sickrage-issues#1927 [`#2088`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2088)
- Update chardet hoping to improve guesses [`4c87b84`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4c87b84664f8ae7198b980f322079e56d7984fe7)
- enum34 dependancy for chardet [`b06dfaa`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b06dfaaf8a2817fb77b419c3ca5630cf1f298b93)
- Missing guessit test files [`13347b4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/13347b4a071bee5c4e90e5845ba02487bd8add15)
- Correct a problem where name was reassined as a list in tntvillage, resulting in error on second iteration. [`1e95c08`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1e95c084ed3faa55ac0db8f1bcecf24906b7475e)
- Encode freemobile msg and title with utf-8 [`bbe5aa2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bbe5aa2cf2eeff261503602eea393e3460389dea)
- Fix parser log [`27ab189`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/27ab189b43b9fd38747dd89d0f7f314f4f22e194)
- Fix log message showing 'no released episodes' when It shouldn't [`7146315`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7146315fef7d097aa8ee78753cd90ff003b8f688)
- Only notify plex if there's title and update_text [`4a69012`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4a69012f67f7e3bca8babaee0c4638b390429a9f)
- Fix cache log message [`fe8a85f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fe8a85fa92682d188f7fa7028a42828d6341afce)
- libs are already at the start of sys.path, importing from lib or lib. causes import issues within previously imported objects [`ad31d9e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ad31d9ee9812d1215cc7032601cbbeead8cc923d)
- Paused shows: unaired episodes should honor default ep status [`ff58945`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ff5894546bae22ae6f5bb8b4a767472628fb0062)
- Make botton "backlog search" as timeleft [`c2e5344`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c2e5344469b9a02174f5447df04ae74213bf6944)
- Move subtitles flags to their own directory [`76e4670`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/76e46708b538065df56e6d7e1d46e8087f7082b8)

#### [v4.0.31](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.30...v4.0.31)

> 12 July 2015

- Fix provider sorting, enabled are always at the top now. [`#2087`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2087)
- Scene exceptions list overwite results in multiple identical search url's [`#2084`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2084)
- Update removed words [`#2083`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2083)
- Update changes.md util 4.0.30 [`#2082`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2082)
- Better path control for scene_exceptions [`#2081`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2081)
- Fix some incorrect permissions [`#2080`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2080)
- Fix TypeError on tntvillage provider [`#2066`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2066)
- Remove the hard linking for subtitles search - too many problems. Fix ui notification for subtitle downloads [`6b98cc6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6b98cc65a679ca7e3670b545fc884c793fafc882)
- fix scene exception update using mass memory and missing a bunch of exceptions, stop hdd thrashing [`5ee5c00`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5ee5c003ed42adcc67f011967a3aaca58ba6fd1a)
- use .iteritems() instead of .items() - everywhere, to save processing and memory. [`9880d06`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9880d06f76c7078e40e19b16fd0cc64e7f6f6434)
- Only warn if kodi is unreachable [`1832ecc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1832ecc4bfec200d1600264e5a8f48408c1dc745)
- Loopy import??? [`c2436b4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c2436b4f76029bfe903ba4a4bb0792a1d2f6c6aa)
- Fix status string in dailysearcher [`232069a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/232069a0a027e1f2bef562e1515beaccc7540b61)
- Change donation page url to wiki page [`1b3ec33`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1b3ec33cc3be32606f090a93d33f4cdb39547257)
- hotfix - Need https not ssh for github (accepting github key issues) [`5e47d9f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5e47d9f4b34567c241e19c1a8edb37e5248c8036)
- Update remove words [`f487290`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f487290c0f5db75314b4f1466c6b31036acf138a)

#### [v4.0.30](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.29...v4.0.30)

> 9 July 2015

- Missed this change [`#2079`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2079)
- Fix default episode status. Shows are added with set initial default … [`#2078`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2078)
- Add device parameter for pushover - SiCKRAGETV/sickrage-issues#1965 [`#2077`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2077)
- Try unicode bare first in case of empty string, then try chardet [`#2076`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2076)
- Fix for SiCKRAGETV/sickrage-issues#1927 [`#2074`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2074)
- Add main TV category to newznab categories [`#2075`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2075)
- Fix log messages with chars like \xc3\xa7o [`#2073`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2073)
- Make sure to remove hardlink and return if scan_video fails [`#2071`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2071)
- Reorder if/else to make readable [`#2070`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2070)
- Fix manage of unaired episode according to trakt rolling download enabled [`#2068`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2068)
- Fix release_name extension detection for subtitle downloads [`#2069`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2069)
- Wrong module for method - subliminal.subtitle.get_subtitle_path [`#2067`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2067)
- Remove Show from SickRage if ended and full watched [`#2011`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2011)
- Unicode conversion before SQL actions iot needed, custom text_factory… [`#2065`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2065)
- Fix possible filename encoding problem [`#2064`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2064)
- Add API methods to check for update and perform update [`#1958`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1958)
- FNT & BLUETIGERS PROVIDERS [`#2063`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2063)
- Use a temp hard link to get better subs matches [`#2058`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2058)
- itorrents.org caching website [`#2059`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2059)
- Fixup HDTorrents provider [`#2062`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2062)
- Revert "FNT & BLUETIGERS PROVIDERS" [`#2060`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2060)
- FNT & BLUETIGERS PROVIDERS [`#2057`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2057)
- Need to use real path, or subs also get saved in wrong path [`#2055`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2055)
- Revert "Comedy Central Updated Icons" [`#2053`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2053)
- Various fixes for subtitles [`#2054`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2054)
- Subtitles continuing [`#2051`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2051)
- Remove www from HDT [`#2052`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2052)
- Comedy Central Updated Icons [`#1909`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1909)
- Updated provider icons. [`#2048`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2048)
- Change message about unable to find show [`#2049`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2049)
- Rewrite BTDigg provider [`#2050`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2050)
- Add provider BTDIGG [`#2045`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2045)
- Updated subtitle provider icons. [`#2043`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2043)
- Add log message when ignoring result from provider [`#2044`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2044)
- Add exception handling to sql commands [`#2042`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2042)
- Add new exception handle to avoid break loop th files [`#2041`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2041)
- Add more debug log message to showrefresh [`#2039`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2039)
- Subtitles download now, only error checking and Language code convers… [`#2040`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2040)
- Temporary remove torcache due to JS timer [`#2038`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2038)
- Glob still wrong -.- [`#2037`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2037)
- Icon for podnapisi.net was missing in the new Subliminal. [`#2035`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2035)
- Cosmetic change and disabled add paused if trakt rolling enabled [`#2036`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2036)
- Add guessit dependancy stevedore [`#2034`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2034)
- Subliminal continue [`#2033`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2033)
- Fix italian language recognition for tntvillage provider [`#1963`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1963)
- Add timeout to Boxcar2 [`#2024`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2024)
- Added 4.0.29 to the changes [`#2027`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2027)
- Fix SiCKRAGETV/sickrage-issues#1930 [`#2026`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2026)
- Missed requests import zzz [`#2025`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2025)
- Metadata needs a session too! [`#2023`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2023)
- Wrong import [`#2022`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2022)
- Fixes to subtitles, none enabled for now but close! [`#2021`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2021)
- Fix a logline string formatting error in SCC. [`#2020`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2020)
- Honor usenet retention setting. Fixes SiCKRAGETV/sickrage-issues#1910 [`#2019`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2019)
- Fix for PP issue and [ or ] in folder names. Fixes SiCKRAGETV/sickrag… [`#2018`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2018)
- Update subliminal [`#2017`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2017)
- Add babelfish dependancy for new guessit, update guessit [`#2015`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2015)
- Update cachecontrol, don't clear it's cache, dont build nameCache or … [`#2016`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2016)
- Updated search stings with airdate [`#2014`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2014)
- Added/redone some provider icons. [`#2013`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2013)
- Pass headers through also, better exception log [`#2012`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2012)
- Check if user needs to add token to PLEX [`#1969`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1969)
- Change Trakt genre url [`#2010`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2010)
- Updated Changelog [`#2007`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2007)
- Forgot indexer scene_loc change [`#2009`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2009)
- Update enzyme to work with subliminal [`112ac3c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/112ac3c7e8d74fc4650a892f9b87f65f8622d1bc)
- Proxy and session fixes: [`ddffe65`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ddffe6516fe448c27f5b357f784e4a54ff9f1daf)
- More subtitles changes [`fae8a12`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fae8a12d21fe159cef3df372c89f289175a80e83)
- Updated changelog with changes from 4.0.20 `till .28 [`1193418`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/11934183cf095c950625122c3ab0c3fccff74fde)
- Various fixes to subtitles. [`360392c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/360392cb145d9a5a21a93f34b681972590ddf654)
- Don't raise exception when no token set or server unavailable [`15a76f2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/15a76f27ced027e21fb62fdac77e6ba3c1fa4388)
- Cosmetic change and disabled add paused [`8cf5410`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8cf541027ec6ba278e4d5f6dc632bf7b7475467b)
- Fix build with new cachecontrol, must have a session now - cc wont create it! [`35ebfba`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/35ebfbab66d103d6038f32a282aea34d9aab2a45)
- More work on subtitles [`ae336d8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ae336d8579f1029154b5ae985ded405ef1255988)
- Fix manage of unaired episode according to trakt rolling download if enabled [`5d39b05`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5d39b05d0b4062ce1eea52b336228411ce827b42)
- fnt.png =&gt; 16x16 & seeder and leechers support [`56f5b6d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/56f5b6d271246084c9b7f7f23a56cf01122b9dec)
- Cannot add lib in import calls for subliminal [`08bf6b3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/08bf6b3078ce86e10621568fabd8c10ab6cd9233)
- Monkey patch new subliminal to run on py2.6 [`fdb7ca1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fdb7ca1936c1c3c21b5e3025ade691c2c3e1f742)
- Disable second guesses, but wrap in try/except incase we need them [`7d3a239`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7d3a2396663be51f4173e10b1376b9c25e4b62ab)
- Use configured remote when setting repo url [`7fd5a63`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7fd5a63f2bcaaaea477fbcc3cd20e3865bad8d29)
- Change some errors to warnings in updater, when commit is newer than master or network unavailable [`029dd7b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/029dd7bff9d4fc99b0ed6587a1a24f51dfab36e0)
- Commit after massaction/action to reduce memory consumption 2-3k queries in memory?? and remove Locking. isolation level is non/deferred by default [`3ab23bf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3ab23bfc94d54244e24b00c34b7b6cad981f6d32)
- NullHandler [`fe5d4a4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fe5d4a484de2c8d38c7425987bca2d59b63ebff0)
- Use travis on all non-master branches [`c386f24`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c386f24ebe3fbb1f7afc83fe74bcc463d4ff4c25)
- Monkey patch guessit to work on 2.6 again, might be more patches needed if issues pop up [`06b0303`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/06b0303b6300e93ba158a6b47f85d30af0a27c4a)
- Don't fail ssl test if response is ok! [`edab960`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/edab96071fcc92703318e287bdde8e34d30a24c7)
- Missed a session for cachecontrol [`2a333c3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2a333c3fc95ee8ab199dd9dddfa1bdc4c0ddfdd0)
- Forgot myself [`4311ff4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4311ff464d71d7b65bedcc86e01a6179b10563ac)
- Missed import [`aa9c1bf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/aa9c1bf1ca2bf3df9cd33fe4e798c8247dfe1881)

#### [v4.0.29](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.28...v4.0.29)

> 25 June 2015

- Fix scene exceptions and network timezones paths to be absolute [`#2008`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2008)
- Fix resultType not in class Proper, use head instead of get request w… [`#2005`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2005)
- Fix and clean SCC, don't spam them with faulty queries, and process e… [`#2004`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2004)
- Remove submodules and use subtree instead, submodule isnt prepopulated [`#2003`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2003)
- Why use requests if we arent going to verify anyways? Maybe requests … [`#1992`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1992)
- Try again with the name_cache lock. there was a deadlock. Add submodules for scene_exceptions and network_timezones [`#2002`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2002)
- Move name_cache lock to fix error of list modified during iteration [`#2001`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2001)
- Missed import! [`#1998`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1998)
- Change so travis can cache pip installs between builds [`#1999`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1999)
- Remove https from rarbg token [`#1997`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1997)
- Sleep in SCC, move torrent content download to after all checks to make sure we want it. [`#1996`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1996)
- Try #2 on Failed to load url error [`#1995`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1995)
- Failed to load URL? This section needs debugged hard [`#1994`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1994)
- Add NZB.Cat to providers, per KingCat request [`#1993`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1993)
- Merge commit 'dc627a9ac4886be728aaaa7403b78924f30850ce' as 'lib/scene_exceptions/tvdb' [`4f63ea3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4f63ea3b512e3126ffbfc939552d4ffd5185a825)
- Bad encoding [`94d9e7f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/94d9e7fc46dda37544db2cae0ee8dbd75f15b644)
- Merge commit '35e6e584b5b316f57a9b4f6a874b8807fa36931d' as 'lib/network_timezones' [`30142f6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/30142f6b89f76529714ebcc935b11acf0e4352a3)
- Merge commit '08555d15cb2bab1c66aa5e8048db8c580c3a1c4b' as 'lib/scene_exceptions/tvrage' [`56d40f9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/56d40f973d4f21748b0b2516d7bf720f7becb8db)
- Why use requests if we arent going to verify anyways? Maybe requests is broken with verify off [`f8d4e26`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f8d4e264ae27d3eecab5f61e3ebf9b006d98b26b)
- Network timezones loaded from git submodule [`059e4cc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/059e4cc8a809090fba695cd60e9822fdcfedc612)
- Use exceptions from submodules, so we don't need to grab from github [`349e72b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/349e72b5dd855bee852e8fc64ac7c0527b9a1146)
- Remove submodules [`c00c6fc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c00c6fc58807f9a93537cf7d03f3ab38a8d15aff)

#### [v4.0.28](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.27...v4.0.28)

> 23 June 2015

- Change USER_AGENT back to SR now that problems are fixed. Hopefully w… [`#1991`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1991)
- More fixes 2 [`#1990`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1990)
- If these are too high, they are being used in places they don't belon… [`#1989`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1989)
- Test for write/permissions problems and warn [`#1988`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1988)
- Update tornado to 4.1.0 from 4.1.0dev1 [`#1987`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1987)
- Set maxage to today-airdate to limit results to relevant results, and… [`#1986`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1986)
- Missing import for show_name_helpers, Fixes SiCKRAGETV/sickrage-issue… [`#1985`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1985)
- Missed import [`#1984`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1984)
- More fixes [`#1983`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1983)
- Oops [`#1982`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1982)
- Multiple fixes [`#1981`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1981)
- Fix torrentday [`#1978`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1978)
- Remove html tags from ui.notifications [`#1973`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1973)
- Fixes SiCKRAGETV/sickrage-issues#1747 [`#1976`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1976)
- Add Trakt empty token error message [`#1972`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1972)
- Change propers code for newznab, hopefully fixes it [`998d26c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/998d26c9b25ce4fca55dfd634d0ec27937d57dab)
- More newznab limitting/fixes [`01770bd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/01770bdf6eab3284a6e90b89495782377e4fe979)
- Name cache cleanup [`dc9bad3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dc9bad3a976e2099c3f60cfa33396ed342b2f8a9)
- Fix group sometimes not showing in compact history [`a7ca5a8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a7ca5a8d10ff8c8f0bfd5db96ad6cf65a38a0fdd)
- Catch exceptions from providers in daily searches [`b6f913e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b6f913eb8984ebb2127a5e84604fa5bc4671bbd4)
- Use womble for feedparser test [`e953a87`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e953a8740c538aa06533d1f33cc37a3e737f120c)
- Fix results from cache not honoring ignored/required words [`ddeaf99`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ddeaf996786635ca05af497e68b5591a2474b0b0)
- Filter .torrent and .nzb from pp list of files [`e9fd2e5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e9fd2e564cf078229380013deab3f1f98be5053b)
- If these are too high, they are being used in places they don't belong! Don't change them [`09e5ec3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/09e5ec3f1ddf481462ae6b4f1d6226d5ac7d0c5f)
- make sure we are cleaning up destination filenames before renaming [`3dbb738`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3dbb738d8b56b9946ae056ef576a58c9e3f52c83)
- Update webserve.py [`b84ad2c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b84ad2ca826af5c2897baeed97bbe5983affa55d)
- Disable feedparser test again. [`5a1869b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5a1869b21bcf980b64676294f57c5dd3310ac926)

#### [v4.0.27](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.26...v4.0.27)

> 17 June 2015

- Fixes /SiCKRAGETV/sickrage-issues#1814 Fixes /SiCKRAGETV/sickrage-iss… [`#1971`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1971)
- Fix remove default ep status [`#1970`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1970)
- Remove "Default Episode Status" from editshow [`#1968`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1968)
- Remove Oldpiratebay provider [`#1967`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1967)
- webapi CMD_ShowPause doesn't update database [`#1947`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1947)
- Properly import sickbeard.exceptions.ex [`#1966`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1966)
- Update RARBG to new API (v2) [`#1964`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1964)
- Warn on bad gzip header response, instead of error [`#1965`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1965)
- Oops, searches weren't ran at all [`#1962`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1962)
- Limit newznab searches to 400 results, clean up logging [`#1961`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1961)
- Fix HDT removing first letter of the file [`#1959`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1959)
- Remove eztv and ezrss due to general scene skepticism about the shady… [`#1956`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1956)
- Try to get the best quality from the best/archived list on first snat… [`#1957`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1957)
- Add alt.binaries.teevee [`#1955`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1955)
- Remove eztv and ezrss due to general scene skepticism about the shady nature of their takeover [`be1528e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/be1528e5f19b9a5f846ad2110f32a2f06ce688f4)
- Remove OldPirateBay provider [`e6129a4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e6129a4a423e87a2c1aaffdf37cbb7b8ef66e1b8)

#### [v4.0.26](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.25...v4.0.26)

> 13 June 2015

- WindowsError undefined on linux, but WindowsError and IOError are jus… [`#1953`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1953)
- Allow select SDTV for Best/Archive quality in MassEdit [`#1951`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1951)
- Strip [vtv] and -20-40 From release group. [`#1950`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1950)
- Fix removeWords, ignoreWords, requiredWords..... [`#1949`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1949)
- Allow SD as archive quality in custom qualities, SD is better than Unknown, and some of us want to use smaller files for 'archived', meaning "we wanted an episode as soon as it was available, but we want a specific quality once it is available" . Works if there is only 1 quality is set in archived quality for now. [`#1948`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1948)

#### [v4.0.25](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.24...v4.0.25)

> 11 June 2015

- Add ranked and sorting options to RARBG settings [`#1946`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1946)
- Sort rarbg results by seeders, not by newest. Newest torrents tend to… [`#1945`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1945)
- Unranked rarbg and pp logfix [`#1944`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1944)
- Fix torrage and zoink.ch, because torcache has a timer and returns ht… [`#1943`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1943)
- Show scene exception help info even when no exceptions are set [`#1940`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1940)
- Fix SiCKRAGETV/sickrage-issues#1554 [`#1942`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1942)
- Revert "Update RARBG category to 'tv'" [`#1941`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1941)
- Check file lock [`#1821`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1821)
- Update RARBG category to 'tv' [`#1939`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1939)
- Fixed verify_freespace check and return False on isFileLocked check [`bdadba3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bdadba3f21aec0193bdfc1e490e00a410e61e0b5)
- Log regex mode only on error, disable unnecessary pp messages [`af7bbac`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/af7bbac7f07b0f6a8b9ba9b18359a9971acf46ba)
- Fix torrage and zoink.ch, because torcache has a timer and returns html instead of a torrent [`b9ec121`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b9ec121df04ee8048c052af654615cf1696b38a1)
- We want all results from rarbg, not only internal right? [`6b816ad`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6b816adfe5ef3a1315cd40791bf67ef9966050df)
- Update thepiratebay url [`43d10cb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/43d10cba2fe91166825907a352a3d6091ca8befe)

#### [v4.0.24](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.23...v4.0.24)

> 7 June 2015

- Fix for potential bad episode airdates preventing SR from starting. [`#1936`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1936)
- Nice and clean info now. Need to disable some of the debug logs compl… [`#1935`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1935)
- More log cleanup and fixes. Move lower level actions to debug [`#1934`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1934)
- Logging changes and improvements. [`#1933`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1933)
- Update initial schema for failed.db and cache.db, Big clean up of log… [`#1932`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1932)
- No need for the dropdown, the extra items appear on the right under t… [`#1931`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1931)
- Small change for additional layout. [`#1922`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1922)
- Update initial schema for failed.db and cache.db, Big clean up of logging on startup by moving some INFO-&gt;DEBUG. [`c2d334b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c2d334b59e7053524005561d63881d916ee3f9de)
- Mod kodi log messages for updates and notifications, warn on errors, debug on actions. Less log clutter pl0x [`5d8a014`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5d8a0140774a49233d9cdde07b4f9d7f1d752be6)
- Nice and clean info now. Need to disable some of the debug logs completly to clean up debug logs! [`54e5197`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/54e5197749f8139c8d1cb7c8fd0854b59f1e5d17)
- Clean up some more logging, especially when using hard links [`0e986b3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0e986b3e33f7bfa77fe5ac7aaac44284ddd4be92)
- No need for the dropdown, the extra items appear on the right under the navbar [`cf3aabb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cf3aabb975a6a41c195b4fb0bcb9a07e25b96c30)

#### [v4.0.23](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.22...v4.0.23)

> 1 June 2015

- Update regexes.py for the web site ISLAND FANSUB (ANIME) [`#1925`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1925)
- Change urls to use http github.io pages from our repos [`#1930`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1930)
- Change image download issue from error to warning [`#1929`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1929)
- Update regexes.py [`626da7d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/626da7d2fd52658bc5e20c304a8d6ad267ab6675)

#### [v4.0.22](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.21...v4.0.22)

> 27 May 2015

- Update both requests to 2.6.0 [`#1928`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1928)
- Change check scene exceptions from error to warning [`#1921`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1921)
- Fix for issue #1691 [`#1927`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1927)
- Fix name of attribute in providers.newsznab.NewznabCache._parseItem() [`#1919`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1919)
- Feature: Trakt PIN Auth [`#1731`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1731)
- Revert "Update template" [`#1920`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1920)
- Failed Download Handler: Size Fix [`#1918`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1918)
- Try to fix 'utf8' codec can't decode byte [`#1916`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1916)
- Uppercase 'in' and 'a' in fuzzy dates. [`#1917`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1917)
- Lowercase date fuzzies were ugly, and the 'last' keyword suggests &gt; 7… [`#1914`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1914)
- Add failed option to PP API [`#1887`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1887)
- Also catch BadStatusLine [`#1913`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1913)
- Lowercase date fuzzies were ugly, and the 'last' keyword suggests &gt; 7 days ago. ie: this past sunday (2 days ago) is not the same as last sunday, as last sunday was 9 days ago if today is tuesday. [`b525eea`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b525eea3ab63a55b3056714d4ae3dce51db4e883)
- Fix name of attribute that newsznab returns [`016c646`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/016c646bf360b1883e24862797398ad36b503f5c)

#### [v4.0.21](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.20...v4.0.21)

> 17 May 2015

- EZTV Provider: save all possible links found in the homepage [`#1910`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1910)
- Fix#1603 - Manual add to Black / White list failed [`#1912`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1912)
- FR#1585 - Add Fanart to local image cache [`#1911`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1911)
- Added missing funimation channel network logo. [`#1902`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1902)
- Network Logos [`#1904`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1904)
- Fix#1558 Fix Quality Colors on History and displayShow pages [`#1897`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1897)
- Added and Corrected several Network icons [`#1898`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1898)
- Updated Discovery Channel logos to current one [`8a78d72`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8a78d729c0e4b741508120290ec63ce750dad6ba)

#### [v4.0.20](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.19...v4.0.20)

> 10 May 2015

- Fix#1453 - Fix 'NoneType' object has no attribute 'whitelist [`#1889`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1889)
- torrage.com domain expired, zoink.ch nginx misconfigured or service s… [`#1896`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1896)
- Fixes due to html changes in http://eztv.ch [`#1884`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1884)
- Fix funky Quality Names. Fixes SiCKRAGETV/sickrage-issues#1508 [`#1885`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1885)
- Fix#1450 - Update Regex to be more specific to for replacement [`#1888`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1888)
- Added missing "The Anime Network" logo. [`#1890`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1890)
- re-enable feedparser test, as lolo.sickbeard.com is operational again. [`#1891`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1891)
- Change sr_tvrage_scene_exceptions to use SiCKRAGETV repo instead of e… [`#1892`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1892)
- Add flexibility when determine title from link in eztvapi.re: [`#1858`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1858)
- Remove pyopenssl from libs. use pyopenssl==0.13.1 if you cant get cryptography installed. [`#1886`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1886)
- SCC doesn't support searching dates with pipe characters. Use '.' [`#1873`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1873)
- Fix webapi error when show search returns 0 results. [`#1870`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1870)
- Replace SSL Error with a url with information. Disable issue submission of the infamous SSL errors. [`#1880`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1880)
- Move init/upstart scripts to their own folder to organize and clean up the source. [`#1879`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1879)
- Add flexibility when determine title from link in eztvapi.re: [`#1437`](https://github.com/SiCKRAGETV/sickrage-issues/issues/1437)
- torrage.com domain expired, zoink.ch nginx misconfigured or service stopped. [`544664f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/544664faa06f3c221d25dd33e931eaae881b5424)
- Update Regex to be more specific to for replacement [`1f94101`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1f94101d0acaae6702f28634533d5087eb69c6f5)
- Didn't rewrite the message in the log. Oops. [`7558355`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/75583553ced342e90c2b985f2b81d9fe8dc533e8)

#### [v4.0.19](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.18...v4.0.19)

> 4 May 2015

- Bump Milestone, fix autoProcessTV scripts. [`#1878`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1878)
- Add __init__.py to autoProcessTV/libs so absolute lib paths work. [`#1877`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1877)
- Merge develop into master. [`#1876`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1876)
- Add pyopenssl libs, and a inittest [`#1872`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1872)
- Center Search icon on displayShowTable [`#1874`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1874)
- Upstart expects you to start things in the foreground. Simplify script, ... [`#1875`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1875)
- Update mainDB.InitialSchema to v42 to prevent db upgrades on a fresh DB [`#1868`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1868)
- Added some missing Network logos. [`#1869`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1869)
- Revert "Update requests library from v2.5.1 to v2.6.2 ff71b25e" [`#1867`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1867)
- Update certifi certificates [`#1862`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1862)
- Make sure we are using our included libs, and not system libs, by provid... [`#1864`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1864)
- Remove unused libs, Thanks SickGear [`#1865`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1865)
- Fix build status, feedparser uses lol.sickbeard.com and they no longer e... [`#1866`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1866)
- Fix travis reporting failed builds as successful [`#1861`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1861)
- Update requests library from v2.5.1 to v2.6.2 ff71b25e [`#1860`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1860)
- Remove reference to readme-FailedDownloads.md, which doesnt exist. [`#1854`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1854)
- if re.search returns None due to no match, .group() will cause an exception [`#1856`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1856)
- Update requests library from v2.5.1 to v2.6.2 ff71b25e, possibly fixing some ssl errors [`b08b1c5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b08b1c58f3341f34fc36ae5f673552305f3297e0)
- Make sure we are using our included libs, and not system libs, by providing the full path [`c16b2c1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c16b2c1c769a2c7c8d93707ff44ac00894501c6f)
- Fix build status, feedparser uses lol.sickbeard.com and they no longer even have a feedparser test, and have changed the api. [`4aac134`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4aac134c741e6c84324f06d258d26a0d953f2a8b)

#### [v4.0.18](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.17...v4.0.18)

> 26 April 2015

- Update changes [`#1853`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1853)
- Update template [`#1852`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1852)
- FR#1419: Add Persistent Collapse Expand Buttons on Episode management [`#1851`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1851)
- Make check_setting_int understand True/False from settings [`#1850`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1850)
- Fix upstart multi pid [`#1846`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1846)
- Missing chmod [`#1847`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1847)
- FR#1364: Seperate Plex Media Server and Plex Media Client [`#1849`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1849)
- HOTFIX: convert the bool to int for default web_use_gzip config [`#1848`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1848)
- FIX#1406 - Plex Notifier change ERROR to WARNING [`#1837`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1837)
- FR: SaveFilter [`#1838`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1838)
- add multi-search IPT [`#1765`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1765)
- FR#1409  Recommended Shows Update [`#1839`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1839)
- FIX#1292 Masking NZB API Keys in logs [`#1842`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1842)
- FIX#1226 - Confirm Show Delete for Mass Edit [`#1843`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1843)
- Updated and New logo's [`#1845`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1845)
- FIX: Add anime to new show page [`#1844`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1844)
- Add anime release groups to add new show page [`#1749`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1749)
- Enable trending shows only if Trakt is enabled [`#1836`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1836)
- Use 'WARNING' logger for 'No NZB/Torrent providers found or enabled in the ... [`#1835`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1835)
- Block issue submitter from running more than once at a time. Fixes #1305 [`#1833`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1833)
- Fix BTN [`#1832`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1832)
- BTN - Show warning instead of error for api call exceeded [`#1818`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1818)
- Build tests [`#1812`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1812)
- Cat sickrage.log generated by unit testing if travis build fails. [`#1813`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1813)
- New KAT domain page [`#1822`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1822)
- Fixup regex for issue submitter, Dont allow dupe app submitted issues. More [`#1820`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1820)
- Match "bluray, blueray, blu-ray, and blue-ray" for determining qualities [`#1831`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1831)
- Fixes #1401 - SD Blueray not matching [`#1830`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1830)
- Updated the network logos. [`#1829`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1829)
- FR#1078 Update Specific Plex Sections [`#1825`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1825)
- FR#574 - Home Page - Show List Filtering [`#1826`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1826)
- FR#1040 - Collapse passed seasons [`#1827`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1827)
- FIX#1397 - updateKODI showObje error [`#1824`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1824)
- Fix Morethantv (http to https) [`#1823`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1823)
- Fix scenetime index bug (sickrage-issues/#1354) [`#1828`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1828)
- Fix SeasonPack searchstrings for episode search on multiple ep search [`#1815`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1815)
- Fix missin amActive [`#1817`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1817)
- Fix missing import traceback [`#1816`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1816)
- Unit test: change journal mode when in unit test [`#1807`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1807)
- Fix Plex notification status check [`#1810`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1810)
- Fix Plex Authentication Token [`#1808`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1808)
- Fix TypeError: cannot concatenate 'str' and 'int' objects [`#1811`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1811)
- Build tests fix, replaces #1525 [`#1750`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1750)
- Remove indexer from tvshow.nfo and series.xml [`#1804`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1804)
- T411: Catch invalid data, log, and continue [`#1802`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1802)
- Merge pull request #1833 from miigotu/block_submitter_spam [`#1305`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/1305)
- Block issue submitter from running more than once at a time. Fixes #1305 [`#1305`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/1305)
- Merge pull request #1830 from miigotu/fix_#1401_sd_blurary [`#1401`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/1401)
- Fixes #1401 - SD Blueray not matching [`#1401`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/1401)
- HotFix for: local variable 'subtitles' referenced before assignment [`#1359`](https://github.com/SiCKRAGETV/sickrage-issues/issues/1359)
- Fix TypeError: cannot concatenate 'str' and 'int' objects [`#1349`](https://github.com/SiCKRAGETV/sickrage-issues/issues/1349)
- Fix Plex Authentication Token [`#1348`](https://github.com/SiCKRAGETV/sickrage-issues/issues/1348)
- Fixup regex for issue submitter. [`2791e33`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2791e33ab0e99b7b0fbd954f859661d162d54ff7)
- Fixed scenetime index bug (sickrage-issues/#1354) [`6d5a998`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6d5a99872122a8ff65762a914adef325dea197d4)
- Replace error title submitted to issues with the error message if title is missing [`3dd3a70`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3dd3a70eda3d9d9a0a3d089ffddcfc07c0fc559a)
- Fix epsearch only searching first wanted episode when multi-ep search [`09e8ca0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/09e8ca0988695b27b4da5d97fb49f983021f8f25)
- upstart script was broken, spawned 2 instances, killed only 1 [`66edcdc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/66edcdc4b649fcde47d07bc4308872746b88c2ed)
- Merge pull request #1806 from abeloin/hotfix-serviceerror [`0111bc8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0111bc8e4e894ac8616011ed71ba34dfaedb0cd9)
- Merge pull request #1806 from abeloin/hotfix-serviceerror [`975c0dd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/975c0dd208c59cac8fd8a77a91da5d1dfc7235df)
- Fix import path on individual tests so they can be ran independantly, from any directory. [`96b2df4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/96b2df465c7f7f6a98891f88cdf138329cfce8d5)
- Blacklist issue_submitter test to avoid fake exception issue spamming, this should be tested manually from time to time. [`228b234`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/228b2347b282f0f515d20d5973cf498b9923fbe9)
- add multi-search [`d20d7c8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d20d7c8b44f1313c0680cc5bcfc095210bf8de22)

#### [v4.0.17](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.16...v4.0.17)

> 19 April 2015

- Update changes.md for 4.0.17 [`#1800`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1800)
- Update IPTorrents search URL 2 [`#1799`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1799)
- Update IPTorrents search URL [`#1798`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1798)
- FR#1015 light.css fix for Season header [`#1797`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1797)
- Column Selection for displayShow FR#1015 [`#1754`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1754)
- Show subtitle service unavailable as info [`#1796`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1796)
- Fix code description error [`#1795`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1795)
- Revert "Change Opensubtitles 503 error to warning" [`#1794`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1794)
- Change Opensubtitles 503 error to warning [`#1782`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1782)
- Fix url error code description [`#1793`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1793)
- Added qbittorrent support [`#1769`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1769)
- Check if url error code is mapped [`#1788`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1788)
- Manage Rolling Download on unpause from submenu button [`#1789`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1789)
- Fix NameError: global name 'ShowObj' is not defined [`#1790`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1790)
- Fix NoneType object has no attribute getOverview [`#1787`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1787)
- FR# 774: Stay on Show Page after "Update Kodie" [`#1786`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1786)
- Fix Title of None for Errors submitted through UI [`#1785`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1785)
- FR#835 Patch 1:  Move pause to submenu [`#1784`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1784)
- Update Plex.py [`#1783`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1783)
- Auto determine indexer when indexer tag not present in nfo [`#1757`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1757)
- SceneTime.com torrent provider [`#1763`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1763)
- ShowUpdater: referenced before assignment curQueueItem [`#1753`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1753)
- Added msg for partial download of multi-episode torrent isn't supported [`#1777`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1777)
- HTML changes of https://eztv.ch [`#1771`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1771)
- Plex Notification fix [`#1764`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1764)
- PNotify Update [`#1743`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1743)
- Fix unknown quality being accepted as a valid quality in PP [`#1775`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1775)
- Adds a log line containing connecting IP on login [`#1781`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1781)
- Fix Case Sensitive associated files check [`#1774`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1774)
- Add logline to show found associated files [`#1779`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1779)
- proper: saveSearch broken for download propers [`#1778`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1778)
- iptorrent: Add missing import [`#1758`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1758)
- Catch all errors from Kodi notify [`#1767`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1767)
- Ignore OSError when obtaining the size of a path. [`#1762`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1762)
- Add user agent to RARBG [`#1768`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1768)
- Catch emailnotify smtp error. [`#1759`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1759)
- rarbg: remove urllib.quote [`#1770`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1770)
- use gir-notify instead of pynotify [`#1705`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1705)
- Add RSS to EZTV provider [`#1689`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1689)
- Fix Episode Thumbnail url when show is in DVD Order [`#1766`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1766)
- Fix for xml_declaration unexpected keyword in python 2.6. [`#1745`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1745)
- FR: Add Pause Button on displayShow page [`#1747`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1747)
- Change timeout errors to WARNING in clients [`#1760`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1760)
- editShow: Select the default indexer language instead of forcing en [`#1756`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1756)
- Fix Case Sensitive associated files check [`#1117`](https://github.com/SiCKRAGETV/sickrage-issues/issues/1117)
- notifiers/libnotify: use gir-notify not pynotify [`bb5020c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bb5020c6e6c84327cdd5f49a6cad8f0a923a027f)
- Followed @abeloin suggestion [`2930460`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2930460d5d212d7a5163e885be61c22fc034752d)
- Use better logging for get_size exceptions [`8db53be`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8db53becbaa8bac2708ae9fb9939d942b071d385)
- Fix issue 1193 [`4d549f6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4d549f6d657b6020562adbae3faea019ea05b52a)

#### [v4.0.16](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.15...v4.0.16)

> 13 April 2015

- NYAA: Switch from cat 1_37 to 1_0 (All Anime) [`#1755`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1755)
- Update changes.md [`#1751`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1751)
- Revert "Add column widget selector to "displayShow"" [`#1752`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1752)
- Add column widget selector to "displayShow" [`#1741`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1741)
- Change Sync to go by episode not by full show [`#1676`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1676)
- Tornado: Ability to switch gzip on/off via config.ini:web_use_gzip [`#1740`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1740)
- OldTPB: Check if the returned results are proper|repack [`#1735`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1735)
- Replace fuzzy images on Add Show ( Add Trending) [`#1742`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1742)
- EZTV: Temporary fix for getURL json [`#1739`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1739)
- Revert "Check getURL response before return" [`#1738`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1738)
- Revert "Added check in manual postprocess to remove hard/sym links in wi... [`#1737`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1737)
- Revert "Remove hardlink and symlink from actions if Win32" [`#1736`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1736)
- Check getURL response before return [`#1727`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1727)
- Scheduler: Various fixes [`#1734`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1734)
- home filter: change to allow to use parsed data for active(yes/no) [`#1732`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1732)
- Show currently running task in show queue [`#1730`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1730)
- Adds option to add a filter row on main show page: [`#1724`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1724)
- Update changes [`#1717`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1717)
- Add TRAKTROLLING to filter in viewlog [`#1719`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1719)
- RarBG: Retry 3 times before failling. [`#1728`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1728)
- Show wanted in displayShow [`#1729`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1729)
- Missing file changes from rebase on the scheduler [`#1725`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1725)
- Revert "PlexNotifier: Fix calling KODI notify instead of pmc" [`#1723`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1723)
- Feature: Scheduler: Redone [`#1722`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1722)
- Bring gzip out into config.ini as "web_use_gzip" for FR #1156 [`a0ba6d1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a0ba6d10c4470a6f5a614b43a9fc35856fc0aeb9)
- Don't display paused show in backlogOverview [`85d36ca`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/85d36ca855de672e5aac4cf2c0a3bc23274189d7)
- Revert commit 728b79f5db6fd6ead56b874c2a030dafc794e320 [`70a88ca`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/70a88ca047846f1367a8d54244a67cb477c5544e)
- Merge pull request #1721 from abeloin/abeloin-patch-pmc_fix [`1a3c28f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1a3c28f8c32dbfb07f3d3eca201a6cdad46be873)
- Merge pull request #1720 from abeloin/abeloin-hotfix-showupdate_fix [`72c403f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/72c403ff6bf3cb36679922a10d9cb03060cac642)
- Merge pull request #1720 from abeloin/abeloin-hotfix-showupdate_fix [`345541e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/345541ef6313f8f5d7ff45ef84647d44a2c29304)
- Fix wrong variable assignation [`0458a2d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0458a2d1461e8bd81d885bdf4cdc7dd68c3d9744)

#### [v4.0.15](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.14...v4.0.15)

> 5 April 2015

- Changed showupdate to datetime.time when updating config [`#1716`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1716)
- Wrong value for change_SHOWUPDATE_HOUR [`#1715`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1715)
- Scheduler: apply the try on the whole run function [`#1714`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1714)
- Fix no title when submitting errors [`#1713`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1713)
- Fix freuqency in start queue [`#1711`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1711)
- EZTV: Fix missing import [`#1712`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1712)
- Added check in manual postprocess to remove hard/sym links in windows [`#1710`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1710)
- Remove white spaces from add show search string [`#1704`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1704)
- Remove access to settings backlog days [`#1709`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1709)
- Relocated coming_eps_missed_range to user interface in UI [`#1708`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1708)
- Providers: Revert _get_title_and_url [`#1707`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1707)
- RarBG: Add new search strings to catch error response [`#1706`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1706)
- Trakt API Changes / Tweaks [`#1678`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1678)
- Add show dir to log message [`#1692`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1692)
- Add Network Logos [`#1702`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1702)
- removeWords: Move into provider generic.py [`#1703`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1703)
- rtorrent: Fix encoding issue in windows [`#1701`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1701)
- KAT: Added removeWordsList to remove ending group [`#1700`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1700)
- RarBG: redone using api. [`#1698`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1698)
- Fix unicode error in verify_freespace [`#1699`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1699)
- submit error: if no title, use default one [`#1697`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1697)
- XEM: Skip invalid entries [`#1696`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1696)
- Redone showupdate in saveGeneral [`#1695`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1695)
- Fix default delete episode in GUI [`#1694`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1694)
- Fix episode description decode error in calendar [`#1682`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1682)
- Patch tntvillage season pack manage [`#1688`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1688)
- add qbittorrent sync file extention to ignore list [`#1687`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1687)
- Use T411 API instead of web scrapping [`#1685`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1685)
- Make removed episodes status configurable [`#1650`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1650)
- tntvillage: Cleanup [`#1677`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1677)
- Fix torrent empty in multi-episode [`#1684`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1684)
- KAT : enclosure season search with " when searching for season number [`#1681`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1681)
- anidb: add log line for editshow [`#1672`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1672)
- rtorrent: Provide traceback in log when torrent failed to send [`#1679`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1679)
- Normalizing Line Endings [`8795d77`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8795d77a9cb1f20a264b1f24765c85a4352364b5)
- Normalizing Line Endings [`e28f73f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e28f73f73048ce2e2a6c8a13aab0aa5ac7915c27)
- merge [`8435123`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/84351236d08146413a887c6d955ab5cfd4258a48)
- Fix freuqency definition in start queue [`cf9d794`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cf9d7945ca38e857807c7ce3d2d992f93138b1a4)

#### [v4.0.14](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.13...v4.0.14)

> 29 March 2015

- Update changes [`#1671`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1671)
- Add DEBUG setting to UI [`#1669`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1669)
- Add note to PP Extra scripts settings [`#1668`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1668)
- Restart showupdater thread when changing update hour [`#1659`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1659)
- Trakt: Catch all internal server error and log a warning [`#1662`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1662)
- Prevent seeing debug and db log in viewlog when debug=0 in config.ini [`#1661`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1661)
- Password encryption switch to v2 [`#1666`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1666)
- Updated network logos. [`#1667`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1667)
- PostProcess: Fix lower quality, bigger sized file overwriting current episode. [`#1663`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1663)
- Normalize all the line endings [`#1665`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1665)
- Fix torrentname with special char [`#1664`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1664)
- Fix inc_top.tmpl loading unnecessary stuff when not logged [`#1658`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1658)
- Fix: cannot find 'PLAY_VIDEOS' [`#1657`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1657)
- Hide proxy_indexers when proxy_settings is empty [`#1656`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1656)
- Remove jwplayer feature [`#1655`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1655)
- Fix gitignore issue with relative folder [`#1654`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1654)
- Add show: fix improperly decoded utf-8 characters [`#1652`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1652)
- Handle Trakt URL error code 500 [`#1653`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1653)
- Added anime regex for 003-004. Show Name - Ep Name.ext [`#1645`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1645)
- fix trending blacklist management [`#1637`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1637)
- Fix don't display prev and next airs if date is invalid [`#1648`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1648)
- PP Airdate: Check without season 0 first [`#1649`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1649)
- Fix active status on home accordingly to manage rolling download enable/disable [`#1640`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1640)
- Fix verify_freespace to check show location and check old file exists [`#1647`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1647)
- tntvillage provider cosmetic fix [`#1646`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1646)
- Added Quality check even if SR itself downloaded the episode [`#1641`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1641)
- Ability to ignore embedded subtitles and layout fixes in config_subtitles.tmpl [`#1617`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1617)
- Change removed episodes status from IGNORED to ARCHIVED [`#1643`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1643)
- Various fixes. [`#1639`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1639)
- Revert "Remove traceback from showupdater" [`#1638`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1638)
- Hounddawgs: Various fixes. [`#1636`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1636)
- EZTV provider [`#1561`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1561)
- Various fixes [`#1634`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1634)
- Added Default Info Language in general settings [`#1633`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1633)
- Manage rolling download [`#1453`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1453)
- home.tmpl: Fix search show name [`#1631`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1631)
- Update CHANGES.md [`#1630`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1630)
- Added Free Space check in PP before deleting files [`#1629`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1629)
- PostProcess: Fix lower quality, bigger sized file overwriting current [`e4348a5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e4348a51c7694d36b8cc0754908471391c0d9e97)
- Defined default_watched_status in order to set it on watched episode [`ae82dfd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ae82dfd36c0a8736b91e4e74bc4e7ede7d606941)
- Managed the Unaired episode according to the rolling download criteria [`6c0543b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6c0543b25c135756bc1fe4615c88914754c7d241)
- blacklist existence check on trakt [`ac105e1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ac105e1ef93bd76fb5f1f86d2d028f9213634443)
- Fix unfriendly log [`179414d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/179414df01fa7025f28a1880980e0b02c27c2a3d)
- Fix small bug [`330f473`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/330f473f3b610bbedd71d38be59746ee48c2f8bf)
- Fix small bug and changed the episode status for which chande to default_watched_status [`78fa1ca`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/78fa1ca997a6279e2c4beb3ad9f6db3dad649463)
- Removed unuseful check [`5f2033e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5f2033ee74a529db705601142ed4b2376304f78b)
- Fix check [`8b278b3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8b278b3b6023c1b47138b69df96260a6570aeb45)
- Fix variable name [`a15325e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a15325ef1aa029baa9b17185de7bd4b180d8ff23)

#### [v4.0.13](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.12...v4.0.13)

> 22 March 2015

- Move encryption_version to the first item read from the config. [`#1627`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1627)
- Add Percent to Footer and Link to Snatched [`#1621`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1621)
- Update Wombles for tv-x264 and tv-dvd [`#1622`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1622)
- properfind: Fix forgotten content [`#1626`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1626)
- Removed Fanzub [`#1624`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1624)
- Fix properfinder not starting or stopping when status changed. [`#1620`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1620)
- GlypeProxy: Fix identation [`#1619`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1619)
- comingEpisodes: Added js logic for forceupdate [`#1618`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1618)
- Proxy: Add a check for theGlypeProxy ssl warning for providers proxies  [`#1616`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1616)
- Remove hardlink and symlink from actions if Win32 [`#1612`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1612)
- DisplayShow: ManualSearch ask if failed and/or download current qual  [`#1613`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1613)
- Fix subliminal not working properly on Windows. [`#1611`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1611)
- home.tmpl: Fix loading show js error. [`#1610`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1610)
- Disable "Find Propers Search" if its disable [`#1609`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1609)
- Fix HDT proper/repack search [`#1608`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1608)
- Re-arrange items so proper settings can be together [`#1607`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1607)
- T411 - Add subcat 639 (tv-show not tv-series) [`#1604`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1604)
- Minor adjustments in editshow [`#1603`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1603)
- Added status column for subtitle. [`#1601`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1601)
- Added the ability to choose displaying columns in home.tmpl. [`#1600`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1600)
- Add workaround for improperly cleaned scgi over unix domain socket URI [`#1599`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1599)
- Revert "Fix "mass edit" subtitle enable action" [`#1598`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1598)
- Allow Shutdown Only when restarting [`#1590`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1590)
- Option to not delete empty folders during Post Processing [`#1591`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1591)
- Fix "mass edit" subtitle enable action [`#1592`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1592)
- Add message about TVRAGE not support banner/posters [`#1593`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1593)
- Fix default new special status [`#1594`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1594)
- Add Log directory to config page [`#1595`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1595)
- Remove newline from Python Version info [`#1596`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1596)
- Fix network sorting with comingEpisodes.tmpl [`#1588`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1588)
- Fix network sorting with small poster, banner in home.tmpl [`#1587`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1587)
- Add note to reminder user to add quality pattern in PP renaming [`#1583`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1583)
- Fix Trakt date and remove bad shows from recommendations [`#1579`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1579)
- Add Provider Animenzb - A Fanzub Clone [`#1580`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1580)
- Safety feature to convert sqlite3.row results to dict  [`#1582`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1582)
- Add coming ep missed range & Fix sab_forced addtion [`#1586`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1586)
- Add option to use force priority in SAB [`#1584`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1584)
- Revert "Support for Foreign Releases based on Show Language" [`#1581`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1581)
- Revert "Add apparmor profile." [`#1577`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1577)
- Add apparmor profile. [`#1405`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1405)
- Support for Foreign Releases based on Show Language [`#1570`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1570)
- Add option to delete files/folders when using manual Post Processing [`#1576`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1576)
- Remove tvcache traceback and change to DEBUG [`#1575`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1575)
- Add upstart init file [`#1556`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1556)
- Added scraper for MoreThan.TV. [`#1493`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1493)
- Possibility to blacklist show in trending [`#1484`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1484)
- Fix restart page [`#1574`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1574)
- Fix HDTorrents [`#1572`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1572)
- Fix providers urllib quote and fixing title in log message [`#1573`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1573)
- Add 'tp' (Beyond TV) to mediaExtensions [`#1571`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1571)
- Show warning message to enable git reset or stash changes [`#1550`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1550)
- Changed failure handling in PostProcessing [`#1548`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1548)
- Revert "Hotfix - Remove BTFailure and add Exception" [`#1566`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1566)
- Hotfix - Remove BTFailure and add Exception [`#1565`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1565)
- Remove bad shows (title is null) [`1214a95`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1214a9537d6b9274db4ba9fcdf16e0d9d038802d)
- check if release is valid for given show language [`d6f8fd8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d6f8fd8d95876493bc4f9b690f3250347da0f4eb)
- additional quality matches for foreign releases [`0cdb0f8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0cdb0f8054aaf1f8b4254cb42cd87b7b05cb2101)
- Re-arrange items so proper settings be in sequence [`5b981ae`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5b981aeb695e2540b12f846e96ac03552a1c7642)
- Fix incorrect indentation [`476c546`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/476c546ed9875dd9d22a19e3932d332e6de66f5f)
- Fix broken sab_force addition [`3c2c874`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3c2c874e7b0b0fa522e2328725c2e28bb201031f)
- remove ignored words [`23ae493`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/23ae493df7dfc31c98b93e7bdf4250a7bc21dd3e)
- fix indentation. [`dd4c7e0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dd4c7e0516c69e9efea649aed921fd83affdf5c2)
- re-order the allowed executables. [`cb120aa`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cb120aad7b7bf36265bb2396a1faa765bc4d96b8)
- Update config_postProcessing.tmpl [`22a559b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/22a559bd638002ab294dcf507222d12592f11c7a)
- Change traceback to repr(e) and DEBUG [`2a1c357`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2a1c357344fe7e3c7bc36e141dc85be93bdc1612)
- Revert "Fix low quality snatch not showing in backlog overview" [`e0ca8c0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e0ca8c00d29baf3c2f4981d24d81e7dc089da323)
- Fixed all episode in season search [`1ba2305`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1ba23051cb601a2e8ee6f4296776e26a9c2a441f)
- Use date preset to show trakt first aired in recommendations [`0a96318`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0a9631819de4dc2c6b36dbf86c8b565efc40a584)
- Replace space with dot. [`ace2907`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ace290763fbb8ed422e0fcc873cca5fe92b7f448)
- Replace space with dot [`a18cd0d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a18cd0d3369e2c0580706a7de61c38b41152570a)
- Replace spate with dot [`7deefea`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7deefeada6847934d3ea01364c7a2b1324be8ed8)
- Fix List_associated_files checking wrong folder [`28c3ea2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/28c3ea21ee3e2cce83b8da24d17539a146755fae)
- Don't show webroot if is not enabled [`1111b2f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1111b2fa97bee482b5ae3b1b77698aaa1bf45f81)
- Remove newline from Python Version [`db8fc5d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/db8fc5dfb05fe26dea6cf88cc47432874ac68c4a)
- Changed unwantedfiles to str(unwantedfiles) in loghelper call [`1725bd4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1725bd4834885e3b7aeeddf6f08a60558997bed3)
- Hide subtitle setting if subtitle feature not enabled [`922d485`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/922d4852221d85b3ffd2b32f29aee826df462e48)
- allow '/bin/cp' execution. [`0252a35`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0252a35d87bd85e9edfe4899137e8588ef5d55fb)
- Fix network sorting with comingEpisodes.tmpl  [`76fcee9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/76fcee9eaadf7a3b42b0203433193d1f7cbb6024)
- allow git-remote-http. [`4eca33c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4eca33c1e1b71575488a9f50c2ccd3b310a9e05c)

#### [v4.0.12](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.11...v4.0.12)

> 15 March 2015

- Update set status description [`#1564`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1564)
- Change tvrage error to warning [`#1563`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1563)
- IPT: Redone findSearchResults forcing search in eponly mode [`#1558`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1558)
- Output more info when unable to parse bencoded data [`#1562`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1562)
- TorrentDay: Improved logging [`#1559`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1559)
- Fix deluge client not working [`#1557`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1557)
- Added some missing network logo's. [`#1554`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1554)
- Add hint to log search field [`#1553`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1553)
- Fix mede8er xml declarations [`#1552`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1552)
- Set release_name to "" when changing downloaded status to wanted [`#1547`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1547)
- Disable legacy import in config.tmpl [`#1551`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1551)
- Remove space from log lines (pre tags) [`#1549`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1549)
- Use consistent behavior in word filtering (global and show settings) [`#1531`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1531)
- Add Note to Post Processing config [`#1538`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1538)
- T411 login captcha [`#1535`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1535)
- Submit: Limit the title to 1024 chars. [`#1543`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1543)
- Fix various providers issue in webui [`#1542`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1542)
- Fix deluge move completed default value [`#1528`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1528)
- Added Kaerizaki-Fansub regex [`#1513`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1513)
- Disable daemon mode in MAC [`#1537`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1537)
- Change Delete_folder to use rmdir when check_empty = True [`#1536`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1536)
- Backup when auto updating [`#1532`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1532)
- Fix re-raising issue to show the real stack trace. [`#1534`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1534)
- Added WebSafe filter to log viewer. [`#1530`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1530)
- Fix submit issue not reading all log files [`#1523`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1523)
- Set amActive to False when return [`#1529`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1529)
- Remove traceback from showupdater [`#1509`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1509)
- Update torrentday url [`#1519`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1519)
- Add SR user and locale to /config page [`#1524`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1524)
- Don't show paused shows in backlog overview [`#1512`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1512)
- Fix error 32: file in use on logrotation on Windows [`#1515`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1515)
- Send user locale when submitting issues [`#1518`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1518)
- history-television [`#1517`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1517)
- unrar: change the error message to be more helpful. [`#1521`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1521)
- Show Syncfiles in log when Postpone PP halts because of them [`#1520`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1520)
- Dont backlog when paused [`#1504`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1504)
- Fix for trying to process hidden sub/sub folders [`#1505`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1505)
- Change update restart page to restart.tmpl instead of restart_bare.tmpl [`#1507`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1507)
- Fix error 32 file in use when rotating logfiles on windows [`#1506`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1506)
- Abort update if remote has new DB version or PP is running or showupdating [`#1491`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1491)
- rarbg: switch to request library [`#1503`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1503)
- Added use of global proxy in tvcache.py/getRSSFeed [`#1502`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1502)
- Try to fix invalid date in coming episodes [`#1501`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1501)
- Remove traceback errors when show is being update [`571e3f2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/571e3f2581484b7852fc0a70aa6d4e90c95973b8)
- Update torrentday new url [`7224719`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7224719a0bd4f359cf6ee744152b399d7d10782f)
- Disbale legacy import in config.tmpl [`1bf632a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1bf632a2681935667c2be234289b6b0b90f2a47f)
- Changed limit to 1024 as per GitHub specs [`703d6c6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/703d6c6dd3c1d9bd1721617c692d3d342c7cb7ee)
- Fix a none type in post process [`a23364f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a23364f6e0e074c9f5b31421bf2a6a7e54cb584c)
- Fix mede8er rating info [`9794254`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/97942542a4d8373e16132cf491a544fa960c850e)
- Fixed a whoopsie in the naming of Wanted [`d796e2a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d796e2a81d4641ca4e44a86b3ef82adb8ea3c4c4)

#### [v4.0.11](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.10...v4.0.11)

> 8 March 2015

- Revert commit 76c8643a6e8c6d0aae6272b2539191916b5c0067 [`#1499`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1499)
- Check if $gh_branch is None [`#1498`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1498)
- Fix for PP always returning "Problem(s) during Processing" [`#1496`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1496)
- Fixed exception on failing to find show in Scene Exceptions [`#1495`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1495)
- Use Scene Exceptions in Post Processing [`#1494`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1494)
- Revert "Added provider for MoreThan.TV" [`#1492`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1492)
- Added provider for MoreThan.TV [`#1477`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1477)
- sync watchlist fix [`#1486`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1486)
- Redo metadata assignments for mede8er [`#1485`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1485)
- Shutil: Catch error in finally when files don't exists [`#1490`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1490)
- Workaround for invalid date(eg 2915) [`#1487`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1487)
- Fix git password not encrypted [`#1483`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1483)
- Possible Fix for Pushbullet update notification [`#1481`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1481)
- Change PostProcessor._delete function to delete ALL associated files [`#1480`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1480)
- Fix brackets in UNRAR log message [`#1482`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1482)
- Fix RSS search element name [`#1479`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1479)
- Fix list branches [`#1474`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1474)
- Revert "Change DIV message when list branches is empty, " [`#1478`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1478)
- Change DIV message when list branches is empty,  [`#1471`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1471)
- Torrentrss custom title tag [`#1335`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1335)
- Sync Watchlist for event that has been lost for traktv site problem [`#1466`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1466)
- Change list_associated_files [`#1476`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1476)
- Change viewLog to use rolled over logfiles [`#1475`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1475)
- Added TRAKT_REMOVE_WATCHLIST Function as was before [`#1467`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1467)
- Add Branch Warning when branch is not master [`#1468`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1468)
- Fix submit issue. [`#1472`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1472)
- Shutil: Fix compatibility with Python 2.6 [`#1469`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1469)
- Don't check SSL certificate when fetching DB version [`#1470`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1470)
- Fix shutil import error [`#1465`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1465)
- Monkeypatch shutil.copyfile [`#1308`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1308)
- Force Show Information Update on snatch [`#1375`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1375)
- Fix coloring episodes as good when "archive first match" selected [`#1460`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1460)
- Add BinSearch to NZB Providers [`#1410`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1410)
- Sync wathclist [`#1400`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1400)
- Fix AR torrent ID [`#1464`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1464)
- Change PostProcessor._delete function to delete ALL associated files [`#842`](https://github.com/SiCKRAGETV/sickrage-issues/issues/842)
- Fix traktv season object merge [`d1997d1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d1997d1597bfac963c189e086c8d201ce1ad7585)
- Faster code to create trakt post data [`3fa97cd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3fa97cd2602c4be5667dc2897981bca9c402eace)
- Replace shutil.filecopy [`1dbf53e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1dbf53e49090c5dcdc090d36f3fdacae1c6f76f2)
- Moved trakt_post_data_merge from helpers.py to notifiers/trakt.py [`3c01d6a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3c01d6a06f4ae2010bfd7aa42c2883c0d342b509)
- Fix some bug [`6425939`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/64259396533af0a73c36038493978bee5cc616ba)
- Removed unnecessary debug log [`b41710e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b41710e1c684b50274d0daae33345d5f7522246b)
- Disable checkout button when list branch is empty [`80d686b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/80d686b0c4d5690a6d60e7e69e7d1d417a55d763)
- Reverted commit a8787bc0d35990d47eee99e21c20689b6676b0b6 [`132f2f6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/132f2f635cdcc68a812fc0df2721a74c77411a7f)
- Manage downloaded status and corrected failed status management [`bcf961f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bcf961fbb50a15369de2352e8f892c579bf76d86)
- Update tv.py [`81adf88`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/81adf882617f94c4fed20ca0fa270569bc943f54)
- Fix to not call list remote twice [`e40c00c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e40c00cc86584a988593ee860aee2964518dfaf4)
- Clean Up [`b17b6e2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b17b6e2928e5a071c5ab47528a53d7e150d31623)
- If checkout list branches is empty, change DIV message [`0c04ed8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0c04ed8621ab6a0ad4094f2fccf7cf0db7105787)
- Fix unable to add torrent rss when nzb search is disable [`08279f2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/08279f2859adcb14e2ed251c5722d8756c247668)
- Update tv.py [`3ef76a1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3ef76a179a3bfab47360a82ad27e9a8f26372720)
- Forget to popilate managed_show and minor fix [`78953cb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/78953cb73cb2b3a04dd208b74f7e2112c9101c9a)
- Forgot to remove comment [`a614e80`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a614e806a0892a9627b4e494222b45a6c94dcb9e)
- Removed one epty line [`a55d084`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a55d0849088cb50f33c51db5ea6a84c9caedf360)

#### [v4.0.10](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.9...v4.0.10)

> 3 March 2015

- IPT: force eponly search since as it isn't supported by the provider. [`#1424`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1424)
- SCC: Fix season search only in sponly [`#1425`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1425)
- Trakt: Catch error when trying to delete library. [`#1463`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1463)
- Email notifiy: Fix msg created witout MIMEext [`#1462`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1462)
- Fix add newznab provider. [`#1461`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1461)
- Compare remote DB versions with local before update [`#1458`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1458)
- Added backup when updating [`#1459`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1459)
- Add "Use failed downloads" to search settings [`#1434`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1434)
- Fix pyUnrar2 on bad archive [`#1451`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1451)
- Remove traceback from generic.py [`#1456`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1456)
- Added some missing network logos. [`#1450`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1450)
- freshontv: Limit number of pages for RSS search [`#1452`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1452)
- Fix missing en_US not working in certain linux system. [`#1447`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1447)
- Update default trakt timeout [`#1449`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1449)
- Fix viewlog JS [`#1455`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1455)
- Redone restart.js [`#1445`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1445)
- Fix viewlog.tmpl [`#1444`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1444)
- Check for UnicodeDecodeError in Cheetah's Filter [`#1442`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1442)
- Fix sickrage UI header when adding 'trending' show [`#1441`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1441)
- Add a warning when gh object is set to None [`#1443`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1443)
- Revert "Don't use sickbeard.SYS_ENCODING for Cheetah's Filter" [`#1439`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1439)
- Fix time display for fuzzy dates with trim zero and 24 hour time style  [`#1433`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1433)
- Don't use sickbeard.SYS_ENCODING for Cheetah's Filter [`#1436`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1436)
- Change File Date: Fix set date/time to local tz when local is chosen [`#1428`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1428)
- Fix Exception generated: Cannot find attribute 'contentrating' [`#1430`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1430)
- Restart: Fix timeout on get error [`#1435`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1435)
- Possible fix for Fix TypeError: object of type 'NoneType' has no len() [`#1419`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1419)
- Fix Show Lookups on Indexer [`#1431`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1431)
- Enhance RARBG [`#1421`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1421)
- Subliminal: Fix ogg subtitles track with und language [`#1427`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1427)
- Updated network logos. [`#1429`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1429)
- smtp: Added missing date field in email body [`#1426`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1426)
- Fix changing episode scene number not updating the show's episode cache. [`#1422`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1422)
- BTN: Fix searching in season mode for episode [`#1423`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1423)
- PP Syncfiles, List_associated_files fix, and Delete RAR contents fix [`#1417`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1417)
- Fix color in displayShow when manually searching. v2 [`#1392`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1392)
- Check actual branch before switch [`#1414`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1414)
- Don't remove logs folder when git reset is enabled in UI [`#1390`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1390)
- Subtitles 3/3: Suppressing subliminal logs on windows [`#1388`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1388)
- Subtitles 2/3: Subtitles: Path always in unicode [`#1387`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1387)
- Subtitles 1/3: Windows UTF-8 console via cp65001 [`#1385`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1385)
- Change the language dropdown in editShow.tmpl [`#1416`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1416)
- Add a missing urllib3.disbale_warning() [`#1409`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1409)
- Replace language selection in add show. [`#1393`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1393)
- New Feature - Log search and log filter by SR thread [`#1347`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1347)
- Add option to delete RAR contents when Process_method != Move [`#1327`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1327)
- Fix PR #1403 extra ) [`#1404`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1404)
- Urllib quote keyerrors issue #708 [`#1403`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1403)
- Handles multi-page results and improved login [`#1395`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1395)
- Added network logos. [`#1402`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1402)
- Revert "Update T411 to its new domain name" [`#1398`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1398)
- Prettier file sizes in DisplayShow [`#1378`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1378)
- Added a specific regex for horriblesubs [`#1386`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1386)
- Provider SCC: Catch exception on getURL [`#1389`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1389)
- Fix for 654 Backlog: failed parsing AlphaRatio Traceback [`#1382`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1382)
- Updated network logos. [`#1381`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1381)
- Added missing network logos [`#1383`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1383)
- Revert "Fix color in displayShow when manually searching." [`#1380`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1380)
- Revert "Possible fix for ValueError: invalid literal for int() with base... [`#1379`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1379)
- Remove trademark from filename [`#1370`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1370)
- Possible fix for kodi notify [`#1371`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1371)
- Update T411 to its new domain name [`#1376`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1376)
- Possible fix for ValueError: invalid literal for int() with base 10: 'un... [`#1377`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1377)
- Add SD search to RARBG provider [`#1368`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1368)
- Provider hounddawgs: Changes to fit new site layout [`#1281`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1281)
- Opensubtitle - show only error message not traceback [`#1348`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1348)
- TPB: Suppressed torrent list not found error message [`#1359`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1359)
- OldPirateBay: Replaced url tv/latest [`#1366`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1366)
- OPB: Fixed season pack searching [`#1360`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1360)
- Trakt remove traceback [`#1363`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1363)
- Added network logos for Canada addikTV and Séries+. [`#1356`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1356)
- AniDB: Fix generating exception on timeout in PP [`#1339`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1339)
- Restore: Replace os.rmdir to shutil.rmtree [`#1364`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1364)
- Remove blue color from 100% progress bar [`#1354`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1354)
- Add value to TNTVillage self.hdtext parameter [`#1352`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1352)
- Fix backup issue with invalid restore folder [`#1358`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1358)
- Fix navbar not collapsing properly [`#1351`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1351)
- Fix color in displayShow when manually searching. [`#1350`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1350)
- Fix self.hdtext declared as list instead of dict [`#1349`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1349)
- Reworked the backup/restore to properly handle the cache directory [`#1345`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1345)
- Added TNTVillage provider [`#1311`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1311)
- Added support for Plex Media Center updates with Auth Token. [`#1340`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1340)
- Hide submit errors button if no git user/pass and auto submit [`#1342`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1342)
- Fix for RARBG provider [`#1343`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1343)
- Disable urllib3 InsecureRequestWarning [`#1341`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1341)
- Add RARBG provider [`#1338`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1338)
- Trakt: Catch all requests exceptions [`#1330`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1330)
- Revert "Added new regex 'itunes'" [`#1333`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1333)
- Updated network logos [`#1332`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1332)
- Fixes shows with double quotes [`#1328`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1328)
- Improved logging to detect CloudFlare blocking [`#1326`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1326)
- Updated network logos. [`#1325`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1325)
- Added Hidden Folder check for Windows Attributes [`#1309`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1309)
- Fix for issue #425: Replace TVTorrents Provider with Shazbat.tv [`#1301`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1301)
- Added new regex 'itunes' [`#1296`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1296)
- Added option to set ShowUpdate time [`#1286`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1286)
- Changed Releasegroup handling in Renamer [`#1223`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1223)
- Rtorrent client improvement [`#1244`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1244)
- Fix if in wrong position [`#1324`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1324)
- Modified sanitizeSceneName() for anime exception. [`#1323`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1323)
-  Fix subtitles display issues. [`#1322`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1322)
- Fix travis build status image in readme [`#1154`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1154)
- Fix typo for locale from us_US to en_US Part 2 [`#1321`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1321)
- Separate providers for oldpiratebay and thepiratebay [`#1270`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1270)
- Revert commit 32da0199f2690b8b04349ebd495c6a7ad5a2b2f4 [`#1318`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1318)
- Updated login param value for torrentBytes provider [`#1317`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1317)
- Fix misc issues [`#1315`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1315)
- Update init.debian to exit instead of return when 'restarted' [`#1312`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1312)
- Fix typo in displayShow.tmpl [`#1307`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1307)
- Fix progress bar vanishing when shows table empty. [`#1306`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1306)
- Fix unknown quality [`#1303`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1303)
- Added default host:port for each torrent clients. [`#1302`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1302)
- Modified touchfile() to detect ENOSYS and EACCES. [`#1295`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1295)
- Fix incorrect operator in dailysearcher.py [`#1293`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1293)
- Partial Revert 1258 [`#1292`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1292)
- Disable ssl checking in synology client [`#1289`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1289)
- Added detection of fs not implemented link creation [`#1287`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1287)
- TVRage, TVdb: Check if show has episodes [`#1285`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1285)
- Set the default Pushbullet target to all devices [`#1284`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1284)
- Fix issues with newznab provider [`#1283`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1283)
- Fix for uTorrent 2.2.1 token order. [`#1282`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1282)
- Corrected aspect ratio of Sky Atlantic network logo [`#1279`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1279)
- Fix verified status of torrents from KAT [`#1278`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1278)
- changed subcategories order [`#1277`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1277)
- Always sort last by asc name in shows table. [`#1276`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1276)
- Improve code check for list comprehensions on subtitle [`#1275`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1275)
- Newznab Categories not beeing saved [`#1274`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1274)
- Trakt 2.0 API fixes [`#1269`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1269)
- Fix case issue for accesstoken [`#1268`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1268)
- Fix IPTorrents url. [`#1267`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1267)
- Use https://kickass.to/ instead of http://kickass.so/ . [`#1264`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1264)
- use subprocess instead of os.system [`#1262`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1262)
- Added IntelliJ IDEA specific gitignores [`#1261`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1261)
- Improve code check for list comprehensions [`#1260`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1260)
- Fix GitHub submit error [`#1233`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1233)
- Fix for issue 358 (filename-thumb.jpg not renaming) [`#1231`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1231)
- Fix if network is None for ical [`#1230`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1230)
- Fix accent issue on system with locale like POSIX. [`#1224`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1224)
- Updated torrentday URL [`#1207`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1207)
- Temporary fix for Python 2.7.9 for SSL [`#1304`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1304)
- Change cookie name to prevent name collision. [`#1290`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1290)
- Generate a cookie instead of using an hardcoded one. [`#1320`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1320)
- Fix 'first_aired' date parsing [`#2`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/2)
- Fix access to webcal without password. [`#1234`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1234)
- Add notice in addShow for special with TVRage [`#1235`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1235)
- Try to fix issue #258 [`#1238`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1238)
- Ignore partially synced files from BTSync 2.0 Alpha [`#1240`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1240)
- Update to Trakt.tv API 2.0 [`#1241`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1241)
- Remove an extra apostrophe from content-type. [`#1242`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1242)
- Added option to display file sizes in Show page [`#1248`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1248)
- Fix moving files across partition [`#1243`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1243)
- FreshonTV now supports HTTPS [`#1245`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1245)
- Change color of 100% progress bar light theme [`#1249`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1249)
- Set UNKNOWN quality as Low Quality [`#1250`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1250)
- Add plot info to mede8er series.xml [`#1255`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1255)
- Added custom rpc url for transmission [`#1256`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1256)
- Added Episode check to PP history check [`#1257`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1257)
- Fix for 'List type has no attribute' on setting failed [`#1258`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1258)
- Updated iptorrents URL [`#1208`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1208)
- Fix 'Sort with "The", "A", "An"' on dropdown in displayShow not working. [`#1217`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1217)
- Update unrar2 from 0.99.3 to 0.99.6 [`#1220`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1220)
- Fix absolute numbering used in notification. [`#1221`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1221)
- Added Select All Checkbox to Preview Rename page [`#1222`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1222)
- Fix issue when location is empty and there's no len() [`#1213`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1213)
- Fix wrong icon used in Growl notification. [`#1214`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1214)
- Fix versionchecker [`#1212`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1212)
- Updated Kodi icons [`#1216`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1216)
- Fix jump to select season dropdown list not working. [`#1215`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1215)
- Patch country flags [`#1210`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1210)
- Fix no attribute while search for proper. [`#1209`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1209)
- Re-download episode when manualsearch and quality is Unknown [`#1206`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1206)
- Check if list_remote_branches is empty before for-loop [`#1203`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1203)
- Added HoundDawgs provider [`#1202`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1202)
- Mass update: Add option for default episode status [`#1201`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1201)
- Fix Safari next show button not working. [`#1200`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1200)
- Update TODO.txt [`#1196`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1196)
- Fix default episode status in display and edit show. [`#1197`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1197)
- Search Providers: Remove Tvtorrents [`#1199`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1199)
- Feature: Add IMDB ID to show webapi [`#1183`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1183)
- Fix low quality snatched episode don't appear at backlog [`#1184`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1184)
- Updated qtip to 2.2.1 to fix tooltip not showing. [`#1187`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1187)
- Adding a download field for the episodes [`#1186`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1186)
- Removed console logging in ajaxEpSearch.js [`#1188`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1188)
- Patch jquery bwlists [`#1189`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1189)
- Added support for Plex Media Center updates with Auth Token. [`#1190`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1190)
- Fix jQuery live not working with 1.9+: [`#1192`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1192)
- use os.system for file copies on posix systems [`#1193`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1193)
- Ignore unrar executable on Windows. [`#1194`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1194)
- SiCKRAGETV/sickrage-issues#360: remove globals in post processing code f... [`#1195`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1195)
- Fix for https://github.com/SiCKRAGETV/sickrage-issues/issues/178 [`#1182`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1182)
- config.clean_url may add trailing /'s in unsuitable circumstances. [`#1180`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1180)
- Fix for SiCKRAGETV/sickrage-issues#360: remove globals in post processin... [`#1179`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1179)
- Fix issue showing 'unknown dir' when adding shows [`#1178`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1178)
- Postpone Processing for incomplete torrents. [`#1176`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1176)
- Fix multipart rars causing the same extracted video to be postprocessed more than once [`#1175`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1175)
- fix for SiCKRAGETV/sickrage-issues#347 [`#1174`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1174)
- Made logging configurable [`#1173`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1173)
- Auto send user and password when open managetorrents page [`#1171`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1171)
- Implementation for sickragetv/sickrage-issues#322 - Add extra progress-bar color for when show is fully downloaded [`#1168`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1168)
- Add Free Mobile SMS Notifier [`#1165`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1165)
- Backup/restore: include cache directory [`#1164`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1164)
- .gitignore - ignore cache folder and not just the contents [`#1163`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1163)
- Don't clean user files when GIT CLEAN [`#1162`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1162)
- correct jquery syntax to select value to fix issue #285 [`#1160`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1160)
- Network logos updated. [`#1159`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1159)
- Don't re-download same quality if we do MANUAL SEARCH [`#1155`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1155)
- Update&add canadian network logos [`#1153`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1153)
- Update kodi.py [`#1149`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1149)
- Added search provider icons. Added network logos. [`#1152`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1152)
- Added Hidden Folder check for Windows Attributes [`#554`](https://github.com/SiCKRAGETV/sickrage-issues/issues/554)
- Fix for issue #358 [`#358`](https://github.com/SiCKRAGETV/sickrage-issues/issues/358)
- Added search provider icons. Added network logos. [`#18`](https://github.com/SiCKRAGETV/sickrage-issues/issues/18) [`#240`](https://github.com/SiCKRAGETV/sickrage-issues/issues/240)
- Replace the language selection in add show. [`d8d4021`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d8d40215f70ac7f94345c4d7fd080d8e7047ffba)
- Fixed issues with newznab custom provider categories. [`0da960f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0da960ff51c4c13441bc6bbda36fd5c8efd75003)
- Updated Requests to 2.5.1 [`fb3cb22`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fb3cb2280863d6dfcd036c2cf2dfdf02ef094740)
- Dropped pastebin and switched to using Gist's for attaching logs to issue reports. [`0b35e9f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0b35e9f2fd7d64b3f770b4b20174d62bf7406fc2)
- Fix path issue with country flags. [`e7f7167`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e7f7167567f468856968df4e055b23ae1c465f11)
- Fix for sickragetv/sickrage-issues#178 [`9fedc24`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9fedc24c556c1b1ac02b7ecdc568a4cf054259d1)
- Updated OldPirateBay file list parsing [`a9ccfd0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a9ccfd0f6d2680865290081da8c3632754708c71)
- Fix subtitles display issues. [`3e1e3e6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3e1e3e61ff482226cdcabc03b4143124bd879585)
- Fix restart timeout on get error [`5835fff`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5835fffa5ede940a140cd5d30019e8ece36da3c5)
- Reverted change torrentday.py, the shouldn't be included [`ccf3a03`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ccf3a03c24736103c962a950c6db06e47acca0cd)
- Fix for sickragetv/sickrage-issues#322 [`2830b9d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2830b9d83ee4dad25c9582e5ac322092b7776391)
- Make the timeout configurable [`7f5d0ff`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7f5d0ff375e17d2d4de4d923995d9929a0084562)
- Removed 'page' parameter [`72826f6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/72826f6dd274c8e53434acadfef221acb190776c)
- Update webserve.py to compareDB on checkout [`384772b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/384772b4cfae58e3d647b536f31713ff2b48531f)
- sickbeard.config.clean_url may add trailing /'s in unsuitable circumstances [`82da317`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/82da3171cdf1e963fd72825aa50a6a97af0e6867)
- Update config.js to compareDB on update [`5eb6937`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5eb693777448cde8092a536bd90823a0fb9b86ed)
- Changes to fit new site layout [`4151cdf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4151cdf9b528d71bbf3471df1e39ffe41f9371be)
- fix for sickragetv/sickrage-issues#347 [`9aa28d1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9aa28d18d2d32819fecb4c0514195f2dd5825b8c)
- Clean up the trakt config section [`6b7a96a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6b7a96a13565ab36d06d3687ade501cea56bb3d0)
- Reverted wrong code commited [`3f2aa42`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3f2aa428c4ee492b50c3a5e1dc70b7d965042cb1)
- Removed some comment [`94853c0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/94853c0f27170e284c1492a3583758887bf5f29e)
- Remove blue color from progress bar [`2b1442b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2b1442bb6eca13498421590fe799a12592cbeb6a)
- Don't show the Download column when the download_url is not set [`53c9418`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/53c9418084a45903718ef48660747bef993b9088)
- Fix for sickragetv/sickrage-issues#303 [`f43bc62`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f43bc62936745f33aafe1b09bf7aed58c6d9d5fa)
- Fix Black and White lists in edit show. [`7796f06`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7796f06b944512d811a2e0929cdf5930e379b2b8)
- Remove traceback from generic.py  [`48cffdd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/48cffdd9a6854a70b1fcb2e74b18d13b3ebffac6)
- Fix set date/time to local tz when local is choosen [`b62c4f4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b62c4f417cab2a387cfd605c30cb12d8771cacf1)
- Fix for sickragetv/sickrage-issues#256 [`68e4aca`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/68e4acaf3730a114ccabc9585d8958676257142d)
- Fix Proper instance has no attribute 'size' [`2985f61`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2985f61cce830a24f70a6f36b904ca30bde628ec)
- Revert "Possible fix for ValueError: invalid literal for int() with base 10: 'un..." [`61d1e6f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/61d1e6ff6e75db198e655bb69ac4174d1fc06862)
- Fixed leading slash. [`b67ef81`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b67ef8133758d1a7565ecea4edbb0f6a51302b87)
- Possible fix for ValueError: invalid literal for int() with base 10: 'undefined' [`a61d8c7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a61d8c7c2e688fe81716d8e7d37bff7b6ec191ad)
- Update readme.md [`ac153cf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ac153cf2320b3b6d0a8aa9a1b1646a51347581d6)
- Make sure we're returning the result of the recursive request [`9cfc3e3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9cfc3e378821e3ba5c8491137fb81dc1d839b8b8)
- Update torrentday.py [`5032826`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/503282694c956ec959bfb8eb97af97dfd2343059)
- Fix if network is None [`cee1566`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cee1566b7bda3da6a90e82954c0e397a6fe258e4)
- Fix for sickragetv/sickrage-issues#274 [`450a09f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/450a09f1a0482d6df6c36c79edbf816d631b88b2)
- Fix for sickragetv/sickrage-issues#263 [`972ee14`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/972ee14216a6146e69fa909355791380d4c4e1bf)
- Replace os.rmdir to shutil.rmtree [`774b5e2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/774b5e2149f179d8ae77417e5318530ad218c963)
- Fix absolute numbering used everywhere if selected even if custom anime [`94732e9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/94732e9568f58b9f89330fec827ebc34671bb1d4)
- Change the name from sickrage to sickrage_user [`6b1a4e2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6b1a4e204a0d77a9f80f15f7a3de88c429519ec4)
- Use hostname rather than IP [`98d9235`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/98d923555ec13ea60eed03a6a1c8afff501a2a3b)
- Use shutil.move instead of os.rename to move file as os.rename doesn't [`2ef08d1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2ef08d1c256d65163290eb843de27b453eb27de3)
- Fix progress bar vanishing when show table empty. [`3917818`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3917818d6fa5a19ec3bc7245383e42f5ec98cd6e)
- Use sbdatetime instead of self [`80ff343`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/80ff343ff255aa43ed0cf6c284d23a11502f1a5c)
- Catch exception if unable to cache the response [`c5cfede`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c5cfede6382a7a29356b3ceaa3f1513cb16f4fe0)
- Fix issue when location is empty [`1856966`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/18569665de7804140a11976f0ba7e10d37f34181)
- Fix .gitignore [`3b29658`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3b29658051707b6bf5808212b68d867249897da1)
- Prevent submitting empty gist. [`17545d9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/17545d93b2bf03fe2becbb89b32e578ab3ec13c6)
- Fix downconverting path from unicode to str [`35c1761`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/35c1761a0159f96fc6667b595a3199c2e0d5d8d6)
- Fix only generating the bwlists for the first item. [`10a199e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/10a199e62fecb44d184e16902e41b4789dd6ec5d)
- Check if we are on windows before query Windows version. [`53e67ca`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/53e67caea520f2b048e2f6a3ebcb38454e31a271)
- Update webserve.py to add delete_failed [`d48772b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d48772baa64f55cfe55c2956ec81ac8a115c5c6f)
- Fix msg created witout MIMEext [`df92cee`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/df92cee84eff9c6d630110f67ebc0df022d4b7a6)
- Re-download episode when manualsearch if quality is Unknown [`8ad5292`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8ad52924a62e0fbf5fbeb04325487a642ff54cfc)
- Fix viewlog [`ebb0c06`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ebb0c06c13a2a84de6cc967d5c5ca9a97c754c08)
- Update traktchecker - remove traceback [`646042d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/646042df8242dd9016c33f2b30b6e7d6665bd3da)
- prevent command injection [`1b3b109`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1b3b10903b8e3fec58941036b0084d9cd8e743dc)
- Catch all requests exceptions [`ad29d18`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ad29d18bc0959d1117a4e024401cfb52d0ca6d67)
- Update helpers.py [`4122029`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4122029df677acc363ebadc51bdc13ea8042b71f)
- Format the rating in whole percentage [`a1871e2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a1871e2d43ece9d85e1be98a5aca6c97b88b2686)
- Fix low quality snatch not showing in backlog overview [`226a714`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/226a7148d267bf4548044b45aef40d444807834c)
- Fix time display for fuzzy dates with trim zero and 24 hour time style enabled [`4ea66cc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4ea66cc713d9c95f8cf12a3add4d8ea7ea3a2688)
- Fix for sickragetv/sickrage-issues#178 [`8b84e4f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8b84e4f4bc6cdebdc605438e9e75d15f1133d65e)
- Partial Revert 1253 [`c0aa41f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c0aa41fefa36782641d9a92a163a40b9031417b7)
- Opensubtitle - show only error not traceback [`90cd0e0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/90cd0e017a70fd99f0531f8874c0801820f50ee0)
- Revert "Fix low quality snatched episode don't appear at backlog" [`7b767c2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7b767c27a90c3ce22c41134afb7c0b3e69d5f15c)
- Fix misplaced or to prevent Nonetype errors [`a3bb636`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a3bb636df27d9363ad4cde5ef0eeae77a5afab77)
- Remove an extra apostrophe. [`bb26790`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bb267905aaf07a5c52e4c2518207f7cf76d481fd)
- Update helpers.py [`2f9362c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2f9362c74cbf4530a6af5341af3fecd8c1f21a1b)
- Fix wrong url handler [`0888942`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0888942820ce1a4131528f545d4ee8702cdf5f5e)
- Fix number of lines submitted. [`c9085a3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c9085a3ac667944301d628636e718a22b097a8eb)
- Updated kickasstorrents URL to kickass.to [`1babd3e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1babd3ec3b5b6e639fa456effb6e4c0d40731290)
- Fix compiling error [`4166099`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4166099c4ad95e96173a40ba9e882c3bf4a67858)
- OldPirateBay Replaced url tv/latest [`3ee18ff`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3ee18ff279ef6832108ccd46dbacd9d58acb17d7)
- Fix rarbg provider searchstring encoding [`2ecf2e7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2ecf2e78ca01b084692c4718dafc9e841ab49410)
- Update traktchecker - remove traceback [`74d49cc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/74d49cc2fd31dedb13b2cad86a20ca3cee95c6d9)
- Forgot $sbRoot. [`9dc7bd1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9dc7bd1938f8e1be6777ff7d5a6492c9fd8be2f6)
- Update kat.py [`3509610`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3509610635f0113d3ecc1ad2571d6586a834b098)
- try ti fix generic modification [`61e201d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/61e201d2010fa94104038652f158d8acee248a99)
- Update manage.tmpl [`639072f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/639072ff3ad94613b6d8de1901fafeb2f3d748b7)
- changed subcategories order  [`d1e5715`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d1e57158d6809f8603a5396f29e6b4d7fec00a27)
- Fix typo in emailnotify.py [`f94f11c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f94f11ccc174ddedccbff2231fb97ff688809386)
- Fix string [`4efb39c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4efb39ce87040bea8d596671598f71bbe306663d)
- z [`7c957a3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7c957a3775575da1d628e2d5f29c543033602088)
- Merge tag 'v4.0.9' into develop [`c71085a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c71085ab3857994b1d9b363863af1134d4d066a4)
- fix oops by not referencing ssl disable property on sickbeard ob [`3e8346a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3e8346a6831d0d20fd913629ff906309e079f89f)
- Use https://kickass.so/ instead of http://kickass.so/ . [`7e7cdb8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7e7cdb846f343a9f652ffd391e8227f3cb03da7e)
- Don't use system.encoding for Cheetah's Filter [`91c35e1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/91c35e1706ff6208e037d692caea3628b4161e6c)
- Fix jquery syntax to fix changing show [`1662e21`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1662e212fe71f34ac08dda7debbbb63f41b9a4bf)
- Fix missing css tag for text color. [`7d3382d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7d3382dc075d441920a55f2fece6315e71b708ea)
- Remove part of the condition to enable utf8 on Windows [`8c846d7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8c846d75b7390067728a8482ea90114682e19639)
- Fix versionchecker  [`728b7bb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/728b7bb1075fd8fd1d3603460aa46ef8aa16c70e)
- Removed print statement [`999767b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/999767b77e9d39c8662b578a1156cd64ee0ab864)
- Replaced adult swim network logo with colored version. [`c35a4f9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c35a4f961178ed52b0f17d178c6c46b5a21a839b)
- Replaced white network logos with colored versions. [`5ed88f3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5ed88f3fb0ac9343a3f6f15abf9a65cafe49121e)
- Renamed network logo of séries+ to series+ [`27ac4ca`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/27ac4cad49b4eaee6f4e46d77d70a7515be26e12)
- Restored back previous Comedy Central logos. [`7f45514`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7f4551468d8dfe21b46b110b30b3a628a025e637)
- Merge tag 'v4.0.8' into develop [`f224e41`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f224e413ff97cf9a248e5f59f49161eda3c30e91)

#### [v4.0.9](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.8...v4.0.9)

> 21 December 2014

- Fix for sickragetv/sickrage-issues#246 - Moved rls required/ignored words to pickBestResults function to occure before we filter the rls name for bad characters plus we now use this function when searching for propers/repacks. [`33e9587`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/33e95870e0c1b241c93f541d4ee27ed6ba3bfcb8)

#### [v4.0.8](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.7...v4.0.8)

> 21 December 2014

- Fix for sickragetv/sickrage-issues#236 [`009da64`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/009da649751e8831afe5f845290487a303c03e60)
- Merge tag 'v4.0.7' into develop [`11e12b9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/11e12b95d1a4e9ff778571b430d4aaa90cb89a75)
- Fix for sickragetv/sickrage-issues#249 [`60e97fb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/60e97fb3cc2192260ff3489be36f19d6b4efecf6)
- Updated flag images. [`b669195`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b6691958827dd9ac0400265f817095d3fad3ecf4)
- Fixed sickragetv/sickrage-issues#117 [`1044808`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/10448086383fc36683fd2eff41f6366890c6fbdf)
- Resized flags to 16x11 to correctly fit in language selector for subtitles. [`f2e3380`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f2e3380cb21d408b42672aae1ac2ea50368d70cc)
- Fixed incorrect flag image files for subtitle languages [`15e6280`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/15e62802ffd801ab5e5bd9a26cb441f6430f11c9)
- Fix for sickragetv/sickrage-issues#236 [`d08d401`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d08d401769aa509a33fc9d758176358cf30e4405)
- Fix for sickragetv/sickrage-issues#237 [`885ef12`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/885ef128fc2aa50b5386143f937b647b435c09d1)
- Fix for sickragetv/sickrage-issues#247 [`b667c72`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b667c722f2ff05975bde8fb1dec9579c3112beab)
- Replaced old poster and banner files with new custom sickrage poster and banner files. [`3829e34`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3829e341b2a49e8541bff7a7f89ffe415bb5b3d4)
- Fixed sickragetv/sickrage-issues#229 - check instance of actor or banner obj to be list and if not we throw it into one. [`bac95b8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bac95b848b7f6e2a7512f1e4d8b1d695cc484331)
- Updated fanart api handler to use new v3 api scheme and re-coded metadata function to properly retrieve images including thumbs. [`46bd851`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/46bd8515c2c2c3d5c92a20712c42186eac347e34)
- Fixed sickragetv/sickrage-issues#117 - CensoredFormatter class func format code corrected. [`785ffdc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/785ffdcf2f58537cc47571e5c18cb954e9d0457e)
- download_file helper function now decodes unicode on the fly [`76062ae`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/76062ae2a7c502dc45ad031242139973f23ecc35)
- Git clean/reset performed before updates now if set from config to avoid update issues [`2d14eef`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2d14eef522739becf994be696b190624692a1d6a)
- Malformed airdates now raises a warning instead of a error so we dont clutter logs. [`482f20b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/482f20b735491337bacf689432412d356e70f78e)
- Fixed issues with issue submitter and pastebin logs. [`3b37dc0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3b37dc054004b00dd2e2c1ada83c7ce7d8cf227e)
- Fixed sickragetv/sickrage-issues#238 [`d5f7a07`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d5f7a0719ef162ba6f8f3b5df78284f6bf1c3724)

#### [v4.0.7](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.6...v4.0.7)

> 20 December 2014

- Fix for issue #216 [`#1148`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1148)
- Fixed sickragetv/sickrage-issues#205 - Getting a proper local lan ip [`2e13186`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2e13186256d31b494025579ea5c2cfe8197c79c1)
- Updated code for get_lan_ip to fix issues with returning local lan ip from network interface. [`8e9f4f4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8e9f4f47cb1a3046f99ec0eaa6d2155d6f542765)
- Fixed issue with issue submitter deleting all errors before submitting them all. [`fb3d485`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fb3d485ced829950812cd764b81608b7927bb5cc)
- Updated code to added referer header for web proxies [`4e0a4c3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4e0a4c3f9998e42923015cf632ad2ba8b37579eb)
- Merge tag 'v4.0.6' into develop [`82f58c7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/82f58c703a51d7c814da3ac467d61291f9baa900)

#### [v4.0.6](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.5...v4.0.6)

> 19 December 2014

- Possible fix for sickragetv/sickrage-issues#180 - redirect loop [`120ea96`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/120ea961f25814b1cb5e176a697eb2e69ab77d8a)
- Improved pastebin logs to search via regex and timestamps for error line then grab 50 lines of data before that. [`477938e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/477938e5f34599ff3c1f4119c90a0ade39425ec5)
- Fixed sickragetv/sickrage-issues#180 - this resolves redirect loops resulting from to many threads being open at once. [`0f4a539`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0f4a53919483b6ce4f206ab1b00306149627e1ba)
- Updated travel yaml file to annouce on new update channel #sickrage-updates [`2f4d3cf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2f4d3cfe3c4d10aa61f80eb6c13eec071161e966)
- Fixed sickragetv/sickrage-issues#210 [`3b42cb6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3b42cb68f91e32c30c776cf0da11f11090fc9ac8)
- Merge tag 'v4.0.5' into develop [`2785abe`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2785abe8a47b1fb45bb4fca6134e37b0a487dfff)

#### [v4.0.5](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.4...v4.0.5)

> 19 December 2014

- Updated piratebay.py with oldpiratebay.org urls [`#1146`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1146)
- Fixed home page issues. [`9927e8a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9927e8ad92401ba7e5f990c1d5f89bef43ed09b4)
- Merge tag 'v4.0.4' into develop [`6151062`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6151062ea45470e6f8793fb20275518490683635)

#### [v4.0.4](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.3...v4.0.4)

> 19 December 2014

- Fixed issues with pastebin attachments for issue submitter. [`476350a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/476350aa7afc279c7d89303479af816ae00baf79)
- Fixed issues with pastebin attachments for issue submitter. [`d881f79`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d881f794debbe192604407e29829e192c138996f)

#### [v4.0.3](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.2...v4.0.3)

> 19 December 2014

- Catches error from set file date and email when they have special charactors in them [`#1140`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1140)
- Fixed sickragetv/sickrage-issues#127 - added requests lib package to autoprocesstv folder then inserted it into path env [`6768741`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6768741cfe3ff43bde96cf395751988197fdb420)
- Fix for duplicate tickets being submitted via app, title variable was being appended to. [`f40d5e1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f40d5e13102b1c1506e2c262f38ade7646eb08d3)
- Catch error when speical charactor crashes email send [`27daf8b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/27daf8b46cb79f6eb4546722e163b7b79abe42de)
- Catch error when setting file date [`ed0e7e4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ed0e7e47168aa297458ead10b9f98d7e893f0aca)
- Fix for sickragetv/sickrage-issues#157 - force redirect to home if 404 http error. [`3060757`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/306075738113767b4623bb32eb36bad5cf05eeb8)
- Catch error when speical charactor crashes email send [`0030c87`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0030c87d044d45dfd36ca7e04249c64429388629)
- Fixed sickragetv/sickrage-issues#170 - checks if key 'language' is present if not discards. [`c65b17d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c65b17d09bf949b9ec348ba25dd866e60cdc3cbe)
- Fixed sickragetv/sickrage-issues#113 [`5e1298f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5e1298f801648204fa62456e86d02bf53f61d1c5)
- Fixed sickragetv/sickrage-issues#162 - will always return list object even when branches do not exist [`ce78735`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ce7873584f26c2a85632bdb13ce14e8c8df59513)
- Fixed sickragetv/sickrage-issues#175 [`88af4c9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/88af4c905a327c0c5d24e8df31459406767c8afd)
- Fixed sickragetv/sickrage-issues#175 [`b27e8e8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b27e8e88a553a6434913b63c2648d6507bfae32e)

#### [v4.0.2](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.1...v4.0.2)

> 17 December 2014

- Fixed sickragetv/sickrage-issues#119 - IOLoop was being loaded before daemonizer code due to improper placement in WebHandler class, moved to init. [`ced8785`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ced8785269908bb6da8b51e8dd3d467de52adaf4)
- ErrorLogs now cleared after submission of issue ticket reports so that the same errors don't keep getting re-submitted with new ones. [`7b219fc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7b219fce8fc257af05d99224f56f2df71de8fa7c)
- Update readme.md [`170d50c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/170d50c2798d122ac2e7f97d54230ecd7b9d993a)
- Fixed sickragetv/sickrage-issues#119 - IOLoop was being loaded before daemonizer code due to improper placement in WebHandler class, moved to init. [`086e7ab`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/086e7abf7009ae486c5e0850670563daf6fae222)

#### [v4.0.1](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v4.0.0...v4.0.1)

> 17 December 2014

- Update .travis.yml [`1b850b3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1b850b3aaa7e62c325230b30517f16ca3350d52b)
- Update readme.md [`8302115`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8302115b6eeeb108494aeccbc6e648e0da277ac1)
- Update readme.md [`c99a8e6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c99a8e6565dc8ad6025d678abec05cb9f4128278)

### [v4.0.0](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v3.9.2...v4.0.0)

> 17 December 2014

- Added network icon for "The Hub" network [`#1143`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1143)
- Fixed Screenshot layout [`#1144`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1144)
- Re-add screenshots [`#1141`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1141)
- mediaToSickbeard.p fix to work with new login system, check for http status 302 [`#1139`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1139)
- Add kat url to the logo at Providers [`#1124`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1124)
- Added Crackle and El Rey Network logos [`#1101`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1101)
- Interface fixes [`#1052`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1052)
- webserve.py has no attribute 'MainHandler' [`#1039`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1039)
- Add removefiles to api show.delete [`#1035`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1035)
- Copy headers set in request handlers to main handler [`#1020`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1020)
- Add screenshots to readme.md [`#1008`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1008)
- Fix error in webapi causing "No Shows" in NZB360 [`#1005`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1005)
- added snatched episodes to shows.stats api command [`#995`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/995)
- Proper fix for EZRSS, issue #984 , previous fix actually totally broke EZRSS [`#998`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/998)
- Fix api/builder if your using a webroot [`#983`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/983)
- Add more info to api command show [`#973`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/973)
- Fix Provider Priorities tab when torrents disabled [`#967`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/967)
- Added features for web api [`#949`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/949)
- Added Smithsonian Channel and Esquire Network Logos [`#960`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/960)
- Add custom nzb category and torrent label for anime [`#961`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/961)
- Improvements made to tv cache code for providers [`589b716`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/589b7167c196ea5ff41315f915ab1ea6b28f3bdb)
- Fixed system path to prepend instead of append for custom libs [`44ae0c2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/44ae0c2933c2f360f6d338c4ee78d15bef72e5cf)
- Fixed issues with WebUI crashing when using a custom web_root setting in the config, also fixed a few other misc WebUI related issues. [`7213fba`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7213fbac1164a826c5cbd9080dc7a30102cc098a)
- Re-coded logger facility for better performance and cleaner code plus has better code for rotation of logs. [`3eb366a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3eb366ac0598eed83d1932b64ac2f74f46a00b72)
- Fixed issues with network timezone downloads crashing on a empty return. [`0209852`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0209852af5c4af2bacfd5759f1bea6325b03e62d)
- Fixed issues with network timezone downloads crashing on a empty return. [`979bf70`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/979bf70f5c1fac506a8c4d8404595f788a2bc4ca)
- Fixed minor issues with provider rss caching code. [`f814de4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f814de4c82fb9778bb89157986aba1aca22ad1c2)
- Fixed more issues with mass editing of shows and episode status editing. [`f302ef3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f302ef3d770a9400ae7b7fd101539136d89e1c84)
- Fixed WebFileBrowser code in WebUI [`9e2c753`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9e2c753d4b711b69acc42255e5c37042bf5158ba)
- Fixes for issues relating to multi-threading, webui, and databases [`9466bdd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9466bddc3ee2679fe476b02d94b6227381536637)
- Fixed a bunch of bugs/issues with tvcache module code flow and added in proper error handling for the threaded cache updates plus resolved some provider issues. [`4254916`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4254916ae917c9652e763bf2c92c3eea91bf504b)
- Fixed issue #1055, adding existing shows with prompt for settings [`de24e52`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/de24e52be6cdf456e7dbdd042e154806ec04c586)
- Fix UI notification issues with auth [`c6c0f96`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c6c0f9600b282b79f6cfc2b8ccc1fd5985496874)
- Possible fix for database threading issues related to async calls from webui [`d2b6145`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d2b6145f8cda8418e5f8a95d455f87f36923bfaf)
- Updated IMDB libs. [`2354c74`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2354c742475c69f50403092a549eb44688121c92)
- Fixed sickragetv/sickrage-issues#109 - resolves logging issues related to new code added in via last updates. [`466ced4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/466ced4c02174f7492a24d5d4817d2c95b9a5fd3)
- Fixed small cosmetic bug with trakt trending shows page. [`a14969f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a14969f4bf53e954ce1d01bf44c1abea30b882a2)
- Fixed manual post-processing issues with WebUI. [`78bfc40`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/78bfc4075760dae8ddbab977df558936454e6c98)
- Fixed issues with newznab/torrent provider searches. [`3d7e460`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3d7e460079825dee69a4ebe1db8034f93eac4ead)
- Improved async threading code for WebUI [`46bd600`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/46bd600da01ee33e8035682d83875752e08d39b0)
- Fixed issues serving static image content for banners/posters and misc other static images, improves overall performance of webui as well. [`efc2aad`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/efc2aad782514666e938b4a3161477b1333b9d45)
- Possible fix for issues #1016, #993, and #1024 - Unicode decode/encode issues [`86e7912`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/86e7912c412b2b8f6e4678d14d575a8553e09ac0)
- Fixed bootstrap @grid-float-breakpoint [`f2bcc72`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f2bcc7217c391ea823f0e0ed99ababaef4b3622d)
- Fixed issues with network timezone downloads crashing on a empty return. [`3f29439`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3f29439ff36980f7e17623dca30b7f045801d501)
- Fixed sqlite code to work better with multithreaded webui code [`64bdd4d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/64bdd4d64a08216a63ecec3db60c5b6cb5018aa7)
- Fixed issues with cached images not loading correctly, major speed improvement! [`785c2d3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/785c2d37db0e5b27485eac2f7231235049148549)
- Fixed unicode issues with sqlite3 database queries [`d716430`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d7164308a5d3b2635244a701147d3472c2eebae0)
- Fixed issues with network timezone downloads crashing on a empty return. [`0b403a4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0b403a419c35505c68ff130145a3da59c83712a7)
- Fixed issues with adding shows via WebUI [`3a2a5f9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3a2a5f9d70565f58f06420e91944a71a6563893c)
- Fixed issues with randomly returned empty show statuses, added tvrage status mapping to ensure it never gets returned incorrectly. [`9000dbd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9000dbd10a42a71979440437303b62bc9d419364)
- Fixed WebUI issue displaying main index home page [`5fa6793`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5fa67936aa381002769e88d24928c976cc6b4d82)
- Fix for issue #1034 - skipping: 'list' object has no attribute 'feed' [`26e82ca`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/26e82caa844cd91dcc834eacdedbf7be3fbad105)
- Logging class now uses a custom censored formatter to filter out sensitive information from being logged. [`9eefc80`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9eefc8034bc77b9c36b50b42bef20ba7f110cc06)
- Merge tag 'v3.9.2' into develop [`fd03e03`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fd03e0394dcfbbd35edd2b60a4309aefdddf9f1d)
- Merge tag 'v3.3.3' into develop [`e02932c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e02932c16a8ef3a8e00e32e8e1f3161416034028)
- Fixed sickrage/sickrage-issues#105 - old code that needed updating that was causing unicode issues. [`f713567`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f713567d60398cf61cf0caa2425cf5199482649c)
- Fixed issue #1092 - auto post-processing scripts re-coded to work with new login system. [`931d5f4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/931d5f41c2914f845d9461631f8330bcd81f1219)
- Fixed issue with login url [`ac70dd3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ac70dd38c258ad527ed20e17a7b70356645281af)
- Updated travis-ci tests [`a70aca6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a70aca6f7c6e5b1cc9d0273394212d5a21043e78)
- Fixed issue #1105 [`467c427`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/467c42747f7ff5b78cec0bbedac9e3a45f8cf408)
- Fixed few misc things related to new logging code and webapi [`949c564`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/949c56439cfb56726ed96b7ac1f3d9b3417ae86d)
- Fixed issues with network timezone downloads crashing on a empty return. [`35af9ac`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/35af9acadb05dd853689372b88f79b0728785408)
- Possible fix for issue #954 [`35c84c9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/35c84c9449df7d0f1a197a8984850fd1c34eea5a)
- Update readme.md [`0dba924`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0dba924eb55c9006108ca4c66cea7733f19581d9)
- Fixed small cosmetic bug with trakt trending shows page. [`2cd72ad`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2cd72ad4e8f5dab9474ca43b54ac1b41d2e19580)
- Fixed issues regarding adding of existing shows. [`d449687`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d44968789f7377f1d5484108e04b1d7d03274508)
- Fixed small cosmetic bug with trakt trending shows page. [`7f0dd9c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7f0dd9cbef7af31cfdcd590fe4aa5dfa9fb33383)
- Update contributing.md [`fa230b1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fa230b132c668bd5e4cb8e60619d0f022bc5314d)
- PEP8 performed on unitests [`76754ff`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/76754ff2baf198904cabe210d1ed005433370266)
- Merge tag 'v3.2.1' into develop [`b71dc36`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b71dc36801820b7a7107c20372fa55989b42c29d)
- Fix for issue #1041, dict has no attrib entries error [`df78fd6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/df78fd6669dafa00587df23d56d4a9dc7796ad17)
- Fix for issue #986 - No RID in search params for NewzNab providers [`e212a09`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e212a09520b88bc20a9090bdfda30e369ea4eb6e)
- Fix 2-row on home [`f4450be`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f4450bec46010fa9af09e4c31c473800496d076b)
- Fixed typo in travis-ci yaml file [`ead2f97`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ead2f97f785408a9ab9050fbeb9ca73ac022d7e4)
- Linked post to get for WebUI [`421e807`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/421e807aa6a6725d488a3ee0af76f2a54156871f)
- Fixed backup and restore - issue was present in javascript file with incorrect url [`1ff906f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1ff906f3ff1372faa45c93d2922cdf410d6f15f5)
- chmod +x all_tests.py to avoid permission issues [`fa7d32e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fa7d32e40373950578081d772fe1d3a2d7a8a0a8)
- fixed yet another typo in travis-cl yaml [`96929e0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/96929e09484b63d4f46d62a22ab3275f391a7442)
- Fixed issues with mass editing of shows and episode status editing. [`98a32c5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/98a32c56654d9f25139916ca19f57f1e540979ce)
- fix to work with new login system, check for http status 302 [`77f70ad`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/77f70ad0df28d23521ecfa5bf889c72f9bfcebc3)
- Fix for unicode issues with image files [`a311b66`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a311b665bab4f32adb00d28910b0a74fd3f2694e)
- Fix for logs being sent to error log viewer when not errors. [`d1341bf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d1341bf7770ea6cd296a8e7bba1d93adbd54b098)
- Updated travis.yml file [`68cca69`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/68cca69b9fc14ba5dc5d5df8723c997fb5e073ce)
- Fix for issue #1111 [`269bf23`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/269bf2333b5dcf6deb67ad0274ba76916a0a6ec3)
- Fix for issue #1004 and issue #989 [`e5af1cb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e5af1cb4ff0898946d660e5e68291869460331e2)
- Fixed issue #990 - was not properly calling lower function [`5f1c16c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5f1c16ca02a3e159386cdde33f08dd21edbef50c)
- Fix for reverseNames missing from new logging code [`9dc03c5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9dc03c5d6aad74acd04ff91bbef720ccd0e9210c)
- Fixed regex issue for naming patterns [`6f5474b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6f5474b999563da8b055f4b67bb0ddec83761866)
- Fix for issue #928 - Regex updated to take into account possible parentheses surrounding the season/episode numbers in searches [`3d45497`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3d454979dbb9eeca517171fb2a11f2bc8b891e83)
- Fix for missing kodi metadata modules [`4bd86b4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4bd86b481e0044891c0c6cd0e4a4d1f985b25549)
- Fix for missing kodi module [`97bb71a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/97bb71a6a5966957219d39cb3cb18401c6876ee0)
- Fix for issues regarding string 'None' being set in config.ini causing issues, this will reset it back to the default setting to avoid further complications. [`22fd308`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/22fd3086aede8844d5519be5415bfa8382eab3a6)
- Fixed error 'No handlers could be found' issue [`33c070a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/33c070ae13e0cbc3e13a762e757208383ef50025)
- Fixed webapi jsonp response code [`71d95b4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/71d95b463e7368c1e4f2671cbf94936e466a93d0)
- Fixed few misc things related to new logging code and webapi [`3214f87`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3214f879ac2ddc40754f7e07c2b8dff31cc6648d)
- Fix for issue #1009 - added show and release_group attributes to properFinder module. [`a946f8a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a946f8aca5059af668b006af1e5e52b9f8e1f8bf)

#### [v3.9.2](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v3.3.3...v3.9.2)

> 26 November 2014

#### [v3.3.3](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v3.2.1...v3.3.3)

> 27 November 2014

- Added features for web api [`#949`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/949)
- Added Smithsonian Channel and Esquire Network Logos [`#960`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/960)
- Add custom nzb category and torrent label for anime [`#961`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/961)
- Fixed webapi jsonp response code [`71d95b4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/71d95b463e7368c1e4f2671cbf94936e466a93d0)
- Merge tag 'v3.9.2' into develop [`fd03e03`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fd03e0394dcfbbd35edd2b60a4309aefdddf9f1d)
- Merge tag 'v3.2.1' into develop [`b71dc36`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b71dc36801820b7a7107c20372fa55989b42c29d)

#### [v3.2.1](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v3.2.0...v3.2.1)

> 25 November 2014

- Merge tag 'v3.2.0' into develop [`0c06c3a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0c06c3a82e6d5995c9b3993aa7f58fff4dcc626f)

#### [v3.2.0](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v3.1.0...v3.2.0)

> 24 November 2014

- Fixed up FreeBSD init file to use rc.subr [`#936`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/936)
- Strip year from show title when adding existing shows, so show is found ... [`#937`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/937)
- Fix for issue #939 - utf8 decoding issues [`f73aee7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f73aee78ccce568989d519454497028f105fc36b)
- Update readme.md [`97d44f9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/97d44f9e01f6251eb80ce89173e03709dac44f82)
- Fixed pnotify issue [`4369802`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4369802ddea49e1130fabc6460fa9fbf20770f6c)
- Fix for issue #942 - Previous code update borked webapi code for show's cmd [`1cd91e6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1cd91e6cc52de6fdf04a884c4c8137202a550ae7)
- Fixed issue with default_ep_status when loading from DB. [`6f83328`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6f833286b7f45833959796b704cd69dfc0a63bcb)
- Fixed startup issue for python 2.6 end-users, had to make some compatibility changes to the ftfy libs [`b67c186`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b67c186ed897e6d6e8abf8fcc0021bb0c7717d64)
- Fixed backlog webapi issue [`47ef5bf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/47ef5bf2b2b225c1a276e173a4342d998b8bfdf3)
- Removed obsolete tvrname reference from tv_tests [`ec62084`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ec6208428e7b552b3b87b9c90e7d004b8f0b7e52)
- Merge tag 'v3.1.0' into develop [`81128f6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/81128f6cf2b7fd2da11b47a9d60c01bc3d86c0aa)

#### [v3.1.0](https://git.sickrage.ca/SiCKRAGE/sickrage/compare/v3.0.0...v3.1.0)

> 22 November 2014

- Add provider name to notifiers [`#909`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/909)
- [New GUI] Prevent Airdate column to wrap [`#931`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/931)
- Add location, filesize, subtitles and releasename [`#932`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/932)
- Fix invalid continuation byte for webapi [`#934`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/934)
- [Provider Options tab] Only configure providers that are enabled [`#924`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/924)
- Instead of checking for NULL when trying to update trakt.tv library or watchlists we now check length [`8320672`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/83206726699b4a3cf94687fb73b5eede3abf4886)
- Fix for issue #933, resolves github comparison errors during update checks [`e0f7860`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e0f78603cb89ef2ab67fd1fafdb421a063d79048)
- Fixed missing system path appends that where causing issues for travis-cl testing [`26ae17d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/26ae17d34996897a34ff1186cde6020ea0b0722a)
- Fix for issue #933, resolves Commit object attribute issues [`de23635`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/de23635e286e3b8a2c287f0597699cca784a2b99)
- Fixed issue with scene exception tests [`ed4c99b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ed4c99b6f08baed55454c83823693c0b26c6bb08)
- Fix for anime processing issues [`04a83ac`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/04a83ac3fb79dce1bc657f869e6de6562a046c51)

#### v3.0.0

> 20 November 2014

- Respect cache. [`#917`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/917)
- UI improvement on Add Show pages [`#907`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/907)
- Fix missing HTML in notifications resulting in incorrect formatting. [`#1`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/1)
- Change how the "local/network" setting is handled to address some issues... [`#150`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/150)
- Update PNotify lib. Make notify close button always visible. Fix issue w... [`#149`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/149)
- Fix missing header and text in poster layout when network is none on com... [`#148`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/148)
- Fix API response header for JSON content type and the return of JSONP data [`#146`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/146)
- Change reporting failed network_timezones.txt updates from an error to a... [`#137`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/137)
- Fix displayShow status and subtitle columns [`#139`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/139)
- Fix typo breaking layout on comingeps [`#141`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/141)
- Add an anonymous redirect builder for external links. [`#124`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/124)
- Fix parsing utf8 data from tvdb and tvrage [`#123`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/123)
- Fix dropdown confirm dialogs [`#132`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/132)
- Fix invalid use of str() in the Send2Trash library for platforms other. [`#131`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/131)
- Fix post processing when using tvrage indexer and mediabrowser metadata ... [`#127`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/127)
- Fix progress sort direction for poster layout view on home page [`#126`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/126)
- Fix missing kat url in config_providers [`#125`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/125)
- Fix growl registration not sending sickrage update notification registration [`#122`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/122)
- Fix SYS_ENCODING - Set System Default if UTF-8 fails [`#117`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/117)
- Change improve Add Show/Add Trending Show page. [`#119`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/119)
- Fixes unicode issues during searches on newznab providers when rid mapping occurs. [`#95`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/95)
- Revert "Fix SYS_ENCODING " [`#118`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/118)
-  Fix invalid responses when using sickbeard.searchtvdb api command [`#114`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/114)
- Make all init scripts executable by default [`#106`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/106)
- Fix SYS_ENCODING  [`#113`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/113)
- Tweak CHANGES.md. [`#108`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/108)
- Fix Coming Episodes/Layout Calender/View Paused and tweak its UI text. [`#107`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/107)
- Add send2trash, General Config/Send to trash, and catch show dir not found exception. [`#101`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/101)
- Fixes changing root dirs on the mass edit page [`#98`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/98)
- Change to suppress reporting of Tornado exception error 1. [`#96`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/96)
- Change API now uses Timezone setting at General Config/Interface/User Interface/ at relevant endpoints [`#82`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/82)
- Fix apply specials fix only to displayShow page to not affect the calend... [`#94`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/94)
- Fix display issue of season tables in displayShow view / Display Special... [`#88`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/88)
- Removed requirement for http login for API when an API key is provided [`#85`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/85)
- Update network logos [`#81`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/81)
- Fix and repositioned show_message on display show [`#78`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/78)
- Fix exception raised when converting 12pm to 24hr format, also handles 1... [`#74`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/74)
- Fixes some unittests [`#67`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/67)
- Change to separate stable and develop only items in CHANGES.md. [`#66`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/66)
- Fix the home page from failing to load due to data_date not being set. [`#65`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/65)
- Fix the home page from failing to load if a show status contains nothing [`#64`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/64)
- Combined 'Delete' and 'Remove' buttons in to one on the individual show ... [`#56`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/56)
- feature/confirmation_dialogs [`#54`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/54)
- Feature/config notification improvements [`#47`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/47)
- Fix theme identification for spinner when restarting. [`#45`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/45)
- Add an in progress spinner that is suitable for the dark theme. [`#44`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/44)
- Fix sorting options on Show List page. [`#43`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/43)
- Implement automatic saving of poster layout sorting options on show list [`#40`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/40)
- Overhaul General Configuration. Tweak top navbar. Fix imdb and other ima... [`#42`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/42)
- Improve UI to display fluidly on different screen sizes. [`#34`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/34)
- Added date formats for d/m/y [`#25`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/25)
- Feature/fix ipt [`#21`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/21)
- Remove building against python 2.5 as travis no longer supports it [`#12`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/12)
- Feature/mass archive on first match [`#20`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/20)
- Fix searching IPTorrentsProvider. [`#17`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/17)
- Add "Archive on first match" to Manage, Mass Update, Edit Selected page. [`#15`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/15)
- Update Calender View on Coming Episodes Page. [`#8`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/8)
- Improve addShows trending page by using less memory and loading quicker. [`#877`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/877)
- Update Tornado webserver to 4.1dev1 and add the certifi lib dependency. [`#876`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/876)
- Various tweaks to UI including additional use of fuzzy dates. [`#875`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/875)
- Fix failed DLs and manage torrents icons [`#874`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/874)
- Change: reduce width on comingEpisodes Calendar view for new page width. [`#873`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/873)
- Change: reduce details width on display show page for new UI width. [`#872`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/872)
- Change: Reduce UI width. Adjust "Limit:" right alignment on history page... [`#871`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/871)
- Change: Reduce UI width. Adjust "Limit:" right alignment on history page... [`#869`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/869)
- Tiny bugfix in searchShowSubtitles [`#868`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/868)
- Subscenter support [`#867`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/867)
- Danish TV 2 with space [`#865`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/865)
- Fix for failed episodes not counted in total [`#863`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/863)
- UI Fixes [`#861`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/861)
- Fixes calendar always being unprotected [`#860`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/860)
- Network logos for Australian ABC, ABC2, ABC3 and Sky Arts [`#859`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/859)
- Fixes SR setting SeedIdleLimit no matter what [`#853`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/853)
- Switchable themes [`#858`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/858)
- styling fixes and clarify what to do after theme selection [`#857`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/857)
- Add theme_name to config and expose THEME_NAME global [`#856`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/856)
- broke the arrows woops [`#855`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/855)
- Setting up for theme changing [`#854`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/854)
- Changing /calendar to add Season and Episode to the description  [`#852`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/852)
- Revert "fix typo on network logo" [`#851`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/851)
- Added a "flip" search order option to new GUI [`#850`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/850)
- Add global required words [`#849`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/849)
- Adjust transmission timeout for slower systems [`#848`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/848)
- Fix git checkout when notifiers are enabled [`#847`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/847)
- Fixes and additions to testRename.tmpl [`#846`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/846)
- fix typo on network logo [`#845`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/845)
- fix for ui-pnotify & fix for fuzzydates on comingepisodes list [`#844`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/844)
- network logo's [`#843`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/843)
- Fix for active and status sorting & Network logo for NRK1 [`#842`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/842)
- Catch airs/network set to None [`#840`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/840)
- add postprocess to api [`#837`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/837)
- fix for date clipping on poster view [`#838`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/838)
- New skin [`#835`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/835)
- First changes for imdb watchlist checker [`#833`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/833)
- Custom naming for anime [`#834`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/834)
- Season pack fix attempt #1 [`#825`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/825)
- This is a check used in webserve.py getManualSearchStatus(), to get the ... [`#827`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/827)
- fix transmission seed time [`#832`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/832)
- Not skipping when self.status = None, but assigning empty string '' [`#830`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/830)
- fixes to make trakt watch list work [`#826`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/826)
- Threads dailysearcher process for each provider. Allows dailysearcher to... [`#824`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/824)
- Revert "Fix for updating queue icon when DailySearchQueueItem is running... [`#823`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/823)
- Dev [`#822`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/822)
- Fix for updating queue icon when DailySearchQueueItem is running. [`#821`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/821)
- Fixes daily search and speed improvements [`#820`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/820)
- Updates to Pushbullet functionality to address rejected keys / connections, provide "All Devices" functionality [`#812`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/812)
- Fixed typo in searchBacklog. Introduced with search from delta functiona... [`#813`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/813)
- Fixed SearchFailedDownload when selecting multiple ep's as failed in dis... [`#814`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/814)
- Dev fix tokyotosho no rows returned [`#815`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/815)
- Fix offset calculation. No more unnecessary (double) searches. [`#816`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/816)
- Fixed the qualityparsing for nyaatorrent search results [`#817`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/817)
- Made improvements for searching for anime on newznab providers, who have... [`#818`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/818)
- Update kat.py [`#819`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/819)
- Update comingEpisodes.tmpl to prevent a 'NotFound' error for... [`#811`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/811)
- Bug in master while doing daily search: https://sickrage.tv/forums/forum/help-support/bug-issue-reports/8358-unsupported-operand-type-s-for-dict-and-dict [`#810`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/810)
- Fix some of the unit tests [`#805`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/805)
- Add first revision of calendar to coming episodes [`#804`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/804)
- Fix RssTorrent where there may be empty values in configuration [`#803`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/803)
- Implemented the queuing functionality also for Failed downloads (Retries). [`#802`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/802)
- Enhancement to Manual searching and Gui queuing of manual searches [`#801`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/801)
- Update .travis.yml, fix imports and tests [`#795`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/795)
- Dev [`#794`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/794)
- Add TokyoToshokanProvider support [`#793`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/793)
- changed technique retrieving of newznab capabilities from sync ajax call... [`#792`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/792)
- Leading zero fix for Anime. [`#790`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/790)
- Fixes backlog for newznab providers [`#789`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/789)
- Dev improvements newznab capabilities [`#788`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/788)
- Fix proper search for t411 [`#787`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/787)
- Add search queue info to ManageSearches page [`#786`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/786)
- Fix default post processing with sync files option [`#785`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/785)
- Added an option in Post Processing options do activated/deactivate postp... [`#784`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/784)
- Dev [`#781`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/781)
- Added the torrent provider for www.t411.me tracker [`#780`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/780)
- Added gui for for choosing newznab (tv) categories [`#769`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/769)
- Do not log ERROR when show isn't in list. Log WARNING instead. [`#762`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/762)
- Fix #3 for daily/backlog checkbox saving [`#779`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/779)
- Fix infinite loop with dognzb [`#778`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/778)
- Test #2 to fix daily/backlog checkboxes with custom newznab server [`#775`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/775)
- Fix for daily/backlog checkbox values not saving correctly on providers [`#774`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/774)
- Testing fix for missing api key on newznab providers [`#773`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/773)
- Fixed missing slash on Kat mirror URL [`#765`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/765)
- Add transmission seed for X hours option [`#764`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/764)
- Update adba libs [`#763`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/763)
- Fix missing fid listing on NotifygetMessageResponse [`#761`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/761)
- Replace tabs with spaces in adba libs / PEP8 [`#760`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/760)
- Dev [`#759`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/759)
- Update bitsoup.py - new table format [`#758`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/758)
- notifiers/libnotify: fix syntax error from #624 [`#756`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/756)
- Added indexerid to CMD_Show(ApiCall) [`#755`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/755)
- Fix for torrentbytes provider where torrentid is &lt;6 characters long [`#752`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/752)
- Fixes rejection of invalid torrent files [`#754`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/754)
- Change minimum backlog frequency to a more acceptable value [`#751`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/751)
- Fix ABD shows manual and backlog searches [`#749`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/749)
- Fix sorting on mass update page [`#746`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/746)
- Fixed result content for Season Pack results [`#743`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/743)
- Dev [`#747`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/747)
- Fix for utorrent label setting [`#745`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/745)
- Should fix some utorrent, rtorrent and deluge [`#744`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/744)
- Fixes anime exceptions being cleared when editing the exceptions on edit... [`#741`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/741)
- Update trakt.py [`#740`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/740)
- Support for newznab offset parameter - https://newznab.readthedocs.org/e... [`#736`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/736)
- Set blank variable [`#738`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/738)
- Fix for torrent rss feeds not validating on add [`#737`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/737)
- Use correct item name [`#735`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/735)
- Fix series remove and add all episodes remove [`#734`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/734)
- Dev [`#732`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/732)
- Fixes speedcd provider issues [`#731`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/731)
- Dev [`#730`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/730)
- Third fix for zip updating and checkouts [`#729`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/729)
- Scene exception list not updated, Double show names in scene excep list after manual scan [`#728`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/728)
- fix for multi ep format setting load [`#727`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/727)
- Second attempt to fix zip updating [`#726`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/726)
- Dev [`#724`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/724)
- Fix for ABD shows [`#723`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/723)
- Update bitsoup.py [`#722`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/722)
- Possible fix for updating when using zips from github [`#721`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/721)
- Dev [`#720`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/720)
- Fix for omgwtfnzb skipping: release error [`#719`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/719)
- Dev [`#718`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/718)
- Fixes issue with search page from PR 713 [`#717`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/717)
- Dev [`#716`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/716)
- Fixes even more daily search issues [`#715`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/715)
- Consolidate more provider code [`#714`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/714)
- Add priority option for daily snatches (inc force) [`#713`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/713)
- Return to linux line feeds [`#712`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/712)
- Fix non-anime propers being skipped for not having a version [`#710`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/710)
- Fixes listing branches for when using source code [`#709`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/709)
- Fixes for trakt settings not saving [`#708`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/708)
- Halt post processing if lftp temporary files are detected [`#707`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/707)
- Fixes resetting of auto postprocessing timer config [`#706`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/706)
- Fixed search pattern for checking ignored and required words in release names [`#703`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/703)
- Fix for HDbits tvcache issue [`#704`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/704)
- Fix for tpb ABD shows [`#705`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/705)
- Sync master&lt;-&gt;dev [`#700`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/700)
- Sync master&lt;-&gt;dev [`#699`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/699)
- Update tvrage_api.py [`#698`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/698)
- Trakt method, error checking, remove series [`#697`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/697)
- Added Danish Public Service channels [`#696`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/696)
- Fixed unbound method editShow() error [`#695`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/695)
- Fixes update issues for source code downloaded versions [`#694`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/694)
- Merge pull requests and changes from DEV branch into MASTER [`#693`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/693)
- Provider image fixes. [`#692`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/692)
- Changes "no_season" regex to support XofX naming [`#691`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/691)
- Halt postprocessing if temporary btsync files are detected [`#690`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/690)
- Tidying provider code [`#689`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/689)
- HDbits fix [`#688`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/688)
- Fixed xbmc notifier failing when it shouldn't [`#687`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/687)
- Fix &lt;a&gt; element so that it doesn't leak to other elements [`#684`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/684)
- Remove unnecessary code from nyaatorrents provider and PEP8 [`#679`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/679)
- Animezb tidy proper code and PEP8 [`#680`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/680)
- Tidy fanzub proper code and PEP8 [`#681`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/681)
- Fixing anime propers due to missed code when rebasing [`#682`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/682)
- Handle case where we don't get back valid data from trakt [`#683`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/683)
- Add network logo [`#669`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/669)
- Completed migration to v2 Pushbullet API. Added extra debug logging. [`#671`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/671)
- Anime proper support [`#667`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/667)
- Remove old Code that caused an exception in the iCal Feed [`#660`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/660)
- fix episode filtering [`#665`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/665)
- Fixed: pushbullet notifications don't work [`#666`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/666)
- Fix for incorrect show snatches [`#662`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/662)
- Added, updated & color corrected network logo's. [`#655`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/655)
- Tidy PP log message [`#653`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/653)
- Fix proper searches with ABD and sports [`#652`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/652)
- Added Support for new append method of NZBGet 13+ [`#649`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/649)
- Fix for symlinking during Post-Processing [`#650`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/650)
- Change SQL in templates. [`#651`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/651)
- Updating provider clear cache log message [`#647`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/647)
- Add Bitsoup and FreshOnTV(TVTorrents.ro) providers [`#648`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/648)
- Add animezb provider [`#638`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/638)
- Add TorrentBytes provider [`#637`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/637)
- Fixes web-dl quality detection for some episode naming patterns [`#632`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/632)
- Minor GUI and console fixes [`#626`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/626)
- Adds custom RSS provider ratio setting. [`#623`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/623)
- Allow the detection of subtitles embedded in mp4 files [`#627`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/627)
- fixed broken images when changing web_root from default (empty) [`#630`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/630)
- Fix for 'add to my list' option defaulting to on upon a restart. [`#631`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/631)
- Fixes downloads column sorting order for shows with all episodes ignored [`#633`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/633)
- Adds network logos for bs11 and niconico [`#634`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/634)
- Fixes blank release group field for animes on history page [`#629`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/629)
- Relocating group labels and required words on show page [`#628`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/628)
- Add support for animes with a different series name per tvdb season [`#625`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/625)
- Notify users on SickRage update via notifiers [`#624`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/624)
- Fixed broken layout for anime black and whitelist [`#618`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/618)
- Fix next backlog date [`#621`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/621)
- Fixrsscookies [`#622`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/622)
- Port:Add safe replace existing file is larger but new file is proper. [`#613`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/613)
- Port:Fix BTN adding same search parameters multiple times. [`#612`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/612)
- Port fix change setting episode status [`#611`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/611)
- Port:Fix omgwtfnzbs findPropers. [`#610`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/610)
- Refactor scheduler and upstream ports. [`#609`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/609)
- Option to NOT rename .nfo to .nfo-orig [`#608`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/608)
- Add moderator to confirmed TPB torrent posters [`#607`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/607)
- Fix for 1080p HDTV anime [`#596`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/596)
- Destination option for the Synology DS [`#593`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/593)
- Fixed setting ratio in Transmission [`#599`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/599)
- Add UI option for users to enter their own Pushover API key [`#604`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/604)
- Update anime-list.xml and animetitles.xml [`#606`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/606)
- Network logo changes [`#594`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/594)
- Renaming network logos files to lowercase as SR requires lowercase [`#601`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/601)
- Fixes searching with usenet-crawler [`#597`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/597)
- Added cookie support to custom torrent provider [`#582`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/582)
- Small fuzzy moments update: Use day numbers instead of lang dependant names [`#590`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/590)
- Fixing "Release" spelling [`#591`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/591)
- Fuzzy Moments Update [`#588`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/588)
- Tweak display show [`#589`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/589)
- Changing filename in Show overview: Complete filename is on hover only, saving valuable space. [`#587`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/587)
- Fixed infinite loop in lib/rtorrent [`#586`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/586)
- More information given on seed ratio/time defaults [`#584`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/584)
- Update webserve.py [`#576`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/576)
- Fix: Searching for propers/repacks at nzbs.org. [`#573`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/573)
- Fixed missing parameter skip_removed_files [`#575`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/575)
- Update pushbullet.py to include episode name [`#574`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/574)
- Display combined SR post processing outcome [`#569`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/569)
- Fix: Clicking on the label "Process backlog on startup" will no longer... [`#570`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/570)
- Add new feature, check propers interval. [`#567`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/567)
- Fix for alterate scene names in theme [`#568`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/568)
- Don't add portnumber when restarting with reverse proxy enabled [`#558`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/558)
- Update boxcar2.py: Title and sound [`#563`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/563)
- Add new feature, set file date to episode aired date. [`#565`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/565)
- PickBestResult x264 over xvid where both exist and quality is equal [`#566`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/566)
- Fix one of the default providers to use SSL. [`#561`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/561)
- Update boxcar2.py [`#557`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/557)
- Fixes Invalid ratio error when ratio is not set for transmission [`#549`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/549)
- Add forgotten 'self' argument to _isSection() [`#559`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/559)
- Fix Renaming issue for not PROPER release generating two dot in filename [`#555`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/555)
- Remove Nl sub Filter [`#554`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/554)
- Fixes Deluge settings appearing in other clients [`#552`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/552)
- Fix nonexistent show [`#553`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/553)
- fix typo in xbmc notifier [`#551`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/551)
- Adding in Mede8er metadata (backport from Midgetspy) [`#534`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/534)
- Adding BETA notification [`#532`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/532)
- Debian style LSB init script [`#522`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/522)
- Deluge bugs: Labels were always lowercase, and SSL certs were always checked. Doesnt work with selfsigned certs [`#519`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/519)
- OpenSubtitle logout issue [`#514`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/514)
- Add version hash to Source installs [`#513`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/513)
- Adds Per Provider Seed Ratio [`#507`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/507)
- Fixing issue #463 [`#506`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/506)
- Datetime fix2, fixes #381 [`#505`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/505)
- Workaround for #336 [`#487`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/487)
- Update search_queue.py [`#484`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/484)
- backport: xbmc always on option - fix #315 [`#471`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/471)
- Adds Manage Torrents button to Home screen [`#469`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/469)
- Add Boxcar2 Notifications [`#450`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/450)
- Fix downloading from foreign section of SceneAccess [`#464`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/464)
- Fix backlog startup setting saving, fixes #434 [`#444`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/444)
- Fix for #390  [`#429`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/429)
- Implement configurable startup [`#427`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/427)
- Fixing Indexer for HDBits [`#424`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/424)
- A fix for #389 [`#409`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/409)
- Torrentday fix [`#418`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/418)
- Added nzbget changes from mr_orange from Prinz23@7282846 [`#410`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/410)
- Remove old obsolete code, that could course an error [`#399`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/399)
- Process showname only if it's present [`#404`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/404)
- Changing repo name to SickRage [`#384`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/384)
- Add proper handling for reverse proxies [`#360`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/360)
- Findproper airdate conditionals [`#369`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/369)
- Fixing more typos [`#368`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/368)
- Expose commit hash on infopage [`#367`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/367)
- Fix for typo [`#365`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/365)
- Fixing typos in prefer_season_download feature [`#362`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/362)
- Prevent TV Download dir from being deleted during postprocessing [`#320`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/320)
- Midgetspy backports [`#323`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/323)
- Update the Plex notifier [`#324`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/324)
- Add option to prefer episode downloading [`#348`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/348)
- Prevent unhashable type errors [`#358`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/358)
- Exposing Deluge username [`#346`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/346)
- Fix typo in db.py [`#341`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/341)
- Code cleanup [`#312`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/312)
- Increase client logging [`#313`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/313)
- Pushbullet Changes [`#299`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/299)
- Update SQL to match TVRage edition [`#308`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/308)
- Changing sorting order for email notification lists, closes enhancement request in #271 [`#283`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/283)
- Increasing generic client timeout [`#276`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/276)
- Small typo in debug logging [`#278`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/278)
- Create an INDEXER_DEFAULT config variable and fix traktWatchListChecker.py [`#106`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/106)
- Fixed 'NoneType' object has no attribute 'status' error [`#267`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/267)
- Fix API history request in dev [`#262`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/262)
- Bugfix for logic error in sql queue for ical (paused shows) [`#247`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/247)
- Update readme.md [`#261`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/261)
- Typo in logging text, closes #251 [`#252`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/252)
- added gentoo linux init script [`#260`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/260)
- Changing IRC channel [`#248`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/248)
- Fix archive search and correct logging for foreign searches [`#216`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/216)
- Fix for API using indexerid instead of tvdbid [`#159`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/159)
- Adds seed time and seed ratio to utorrent client [`#162`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/162)
- ical Bugfix and Change from All-Day Event to Time Event [`#172`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/172)
- Fixing typo [`#176`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/176)
- Fixing reference to alpha release [`#138`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/138)
- Centering the header, by popular demand [`#118`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/118)
- Typo in PROXY_SETTING variable [`#98`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/98)
- Changing release name from alpha to TVRage [`#109`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/109)
- Speedcd mrorange [`#88`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/88)
- HomePage sort by active show first. [`#86`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/86)
- Made space for config menu in top bar of gui on small screens [`#85`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/85)
- Fixed issue #49 [`#69`](https://git.sickrage.ca/SiCKRAGE/sickrage/pull/69)
- Respect cache. [`#903`](https://github.com/SiCKRAGETV/SickRage/issues/903)
- Fix #6 for github module not found issue [`#6`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/6)
- Fix #5 for github module not found issue [`#5`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/5)
- Fix #4 for github module not found issue [`#4`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/4)
- Fix #3 for github module not found issue [`#3`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/3)
- Fix #2 for github module not found issue [`#2`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/2)
- Merge pull request #779 from adam111316/checkbox_fix [`#3`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/3)
- Fix #3 for daily/backlog checkbox saving [`#3`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/3)
- Testing fix #1 for "TypeError: argument of type 'NoneType' is not iterable" 500 error [`#1`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/1)
- Test fix #5 for blank pages [`#5`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/5)
- FreeNAS test fix #4 [`#4`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/4)
- Test fix #3 for freenas [`#3`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/3)
- Test fix #2 for FreeNAS running as a daemon [`#2`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/2)
- db locking issues fix #2 [`#2`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/2)
- Merge pull request #505 from Prinz23/datetime_fix2 [`#381`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/381)
- Merge pull request #471 from pmaciocia/xbmc_always_on_315 [`#315`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/315)
- Merge pull request #444 from WebSpider/dev-fix_backlog_save [`#434`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/434)
- Test fix #3 [`#3`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/3)
- Test fix #1 [`#1`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/1)
- Merge pull request #252 from WebSpider/dev-cache_typo [`#251`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/251)
- Typo in PROXY_SETTING variable [`#91`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/91)
- Making frequency of version update checker (CHECKVERSION) configurable [`#54`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/54)
- Adding SpeedCD provider [`#47`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/47)
- Adding SpeedCD provider [`#47`](https://git.sickrage.ca/SiCKRAGE/sickrage/issues/47)
- Fixed issues with editing/saving custom scene exceptions. [`d02c0bd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d02c0bd6ebcf1cbfe43708b1093aace586f28481)
- Further improved memory handling of bs4 for torrent providers. [`403c267`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/403c2679538cc724a0107551168ee826010d4ed6)
- Replaced cherrypy with tornado which helped resolve our memory leak issue. [`d73cc1c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d73cc1cbbd22c706d5fc77862dedafc1c0b04133)
- Reverted new regex changes, not compatible with enough platforms to warrent keeping. [`893574b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/893574b2edd855e6387d76efe956bd834f75bbbd)
- Upgraded CherryPy libs to 3.3.0 [`cec4ed5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cec4ed573d5edcdfd27853f97bea1510b7a526a1)
- Fix for missing github modules, forgot to add folder to git repo [`d96597b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d96597bf2798daea949cc495d7ba2d04f1b97c4c)
- Playing videos from display show page has now been made opt-in, you can enable/disable via general config menu. [`4246744`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/424674464f50e09afa2848abdcad18aa9ebdb108)
- Update imdbpy libs to v5.0 [`2dcd26e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2dcd26e69c94daa4b23cdc8497c1876f5d799a27)
- Updated tornado to latest stable code, fixes issues with auto-reload [`327df66`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/327df6682e516317c9affce4254ddd6975872fdb)
- Code Clean up and regex fix for "no repeats" error (reverted from commit 8ecd5a196db7c4ef235a87c6110e91596bf5ca34) [`10637f8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/10637f8f2948a5aa3dfab119b7b6111db86340e4)
- Code cleanup and regex fix for "no repeats" error [`8ecd5a1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8ecd5a196db7c4ef235a87c6110e91596bf5ca34)
- Database now closes connection after each query and reconnects if closed to ensure no more connection and locked database problems. [`7e0bb65`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7e0bb651b270361625b5850bd32b2247b3abc782)
- Modified DB code to close its connection if right after its finished with it, helps performance-wise and should resolve locked db issues as well. [`d00d55f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d00d55fdfcda0890c3fccca21cb29f7790ab97fa)
- Updated sumbliminal. [`8d9d62c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8d9d62caf5d05f999f51ce13990b3784617a265f)
- config_notifications improvements [`12dd9ab`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/12dd9abd5fad9ac70d74984dad4ee29dd4fdaed7)
- Updated unrar2 lib [`5b23d83`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5b23d8370476126fe82520449f744e93e1472b11)
- Complete re-code of season/episode search code. [`5772de9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5772de9eecdf6eee4204e323e8faf11f5c1c7229)
- Fix for unrar2 [`b547226`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b5472263533c59f3e917407da316bf81b228370c)
- Replaced our cache handler 'CacheControl' with 'httpcache' as we found the previous was not stable enough and was causing more issues then good. [`ce193ff`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ce193ffcdb7d1cb8fb858fec586d548f83a3d49c)
- Changed to new cache handler that stores its cached data in sqlite db files for persistance [`ff1e6e6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ff1e6e6dbcf0d6782478407729f3b014b46d9f1c)
- Re-coded the Indexer cache, cache lookups are only performed for existing shows and we don't add any cache entries unless we are Indexing the show in our database so we don't waste cpu cycles and memory. [`87b752b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/87b752b4e5eb4f62038566f475cd227589c00b3e)
- Feature/config_provider_improvements [`6489905`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6489905690c86293eb03acb81fe275b38c6fc0af)
- Updated tornado source code. [`0c57676`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0c57676aedac848fc518ac1111fb25521b617a51)
- Major changes made to search code, tvcache code, and name parser [`d5f183c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d5f183c171c4b8ed1939f5aac3e8b18508ffe420)
- Fixed subliminal issues. [`c945726`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c945726f05ab2021dadeb60a48137e6ac1c75ef5)
- Fix for manual and backlog download/search issues. [`1398c38`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1398c38275f25f168c9961edb439f808bdabd44c)
- Fixed issues with multi-threading. [`2a4f878`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2a4f8780e2398e945967557c73fea38c08899e24)
- Removed snatch queues to reduce memory footprint. [`aafe9ad`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/aafe9ad522504b8a92b6235f552396e176855b53)
- Fixed start/restart/shutdown issues including any issues with daemonizing. [`1fc9092`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1fc909299d80d8dbfb54cbcaeffd5d1df240ec8f)
- Lowered CPU usage even further, re-wrote daemonizer code for startups, removed misc unrequired functions from providers. [`f0146f7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f0146f728e69282dc22b6d32b53cd0fb2960cca8)
- Fixed issues with searching for air by date shows and sports. [`9384881`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9384881241b05bd2f11e349ff1c38a464d5d0179)
- Updated our cache code. [`94670f7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/94670f7f95201415f480950bc8a631b74a4f52fe)
- Fixes season pack and episode only searches [`816a3d9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/816a3d95720c0cc9d932dbe121ce615cdc2daa7a)
- Lightning fast indexer searches now! [`f8ec897`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f8ec8970102bfacdd2689649add2c685f123aaab)
- Fixes for post-processing issues. [`9d191f6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9d191f69996b1ba383479a3d97c66a8d28437b06)
- Fixes backlog and manual searches. [`fc94243`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fc942435469d9901372033e4b2c90bd908c5197d)
- Removed a extra space that may have caused issues in future [`12b8fc9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/12b8fc9990705968c07f288fa1d771f67e8da5c0)
- Re-wrote daily searcher to search for unaired and wanted episodes going back as far as 1 week, also moved it so it queue's its items now. [`c65573a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c65573a8d73d9fe8caf06e059bc6f1bb1c05d087)
- Fixed regex pattern for sports events that were preventing searches from working. [`1f17868`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1f178686cc8d5fdb4e6b152417a5865d9353dcef)
- Fixes more issues that were preventing proper shutdowns, restarts, and upgrades. [`7d52d07`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7d52d079fa00df86674de8bed8ba3ef29306dd84)
- sbRoot missing in some img url's [`419e35f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/419e35f30069d4d0a7272dc71cff02833d06d353)
- Fix for failed download issues. [`b931044`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b9310444e5b5f08e4d62347130433b8b4d4b64c0)
- Fixes issues #333 and problems with converting str to int via prettyName func [`afde3b4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/afde3b4c2889bcd4b257d39ccaf366c38c41c68b)
- Fixed IndexError: list index out of range issue [`1136e5c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1136e5c833694cdf5e47fee4fd497a9da7ac93a6)
- Update PNotify lib. Make notify close button always visible. Fix issue with multiple tabs. [`8514285`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/85142855302bc8fa7c61cce567365b205c0f624f)
- Improved find propers code. [`f01c585`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f01c5852d4f1241b062233ed4f4a7bd7afc7f9b6)
- Complete re-write of backlog search. [`a39c881`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a39c881cb3d4dc1a23df2d0202330311ba729831)
- Provider searches for backlog, manual, and failed have been re-worked to not hammer the providers so much plus perform alot faster. [`ff5107c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ff5107cfe2155d211992537d51f33b815abb6f20)
- Fixed further json issues with speedcd provider. [`f477344`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f47734446d1546fd013566b71cf67fee94dfae58)
- Bugfixes and improvements to our code that converts regular sickbeard.db to our new indexer scheme [`c97f5b9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c97f5b9c702ed91f55a67e0cf7ab6486e29e0c53)
- Bunch of code upgrades and bugfixes [`ce5053f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ce5053f25d54cd1ee49045cefdf86c04fee2998c)
- Fixed app performance issues from recent upgrades. [`c5f933e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c5f933e4c8f724bf98224a38beae8b4aa1fb41f9)
- Fixes for backlog search. [`b33e2be`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b33e2be0478d06883f4c1f8dc54412050c278321)
- Improved startup/shutdown of tornado. [`abff43f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/abff43f5680865470fd7f0c38354df595e774bae)
- Fixed failed download handling. [`59675f2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/59675f27ac7584746b3138acb3de28314a8602fd)
- Fixed issues with post-processing, we now perform the auto-detection of the indexer in a spot that doesn't require the post-processing to start all the way from the begining allowing for less processing time to take place. [`c330bbb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c330bbb3863dd44adcd08808b039a5f096a3a2c1)
- Fixed issues with post-processing. [`f7b11e1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f7b11e1e98599bfd44fc91700c93a471545aa784)
- Change how the "local/network" setting is handled to address some issues. [`732009f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/732009fd98e6f3d718a8a80913726e8eee561b89)
- Replaced provider backlog only search option with 2 new options that allow you to enable daily searches and backlog searches individually per provider, default is enabled for both. [`bcffc09`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bcffc09589297d6a7ab199dc75febc4ca3783434)
- Fixed issues with webroot settings and reverse proxies. [`07685f4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/07685f4295007a79da81dda33e93829403f3614f)
- Fixes issues with findpropers and airdate. [`a5b72de`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a5b72dea8424420e81392660fd0a04e811015e9e)
- Revamped the failed handler code to fix a few bugs and have everything failed sent directly to backlog [`748ba6b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/748ba6be71cb325985cbfb0ae0e5ca7fd301b500)
- Fix for daily searches and high cpu usage plus increases search speed [`67bd1a9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/67bd1a9e983d174912e378690e359ac1c070c403)
- New event queue system in place, currently handles shutdown and restart calls. [`74f73bc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/74f73bcc34da09e1406d93b8a19438b0075302d6)
- Fixes for thread naming issues where provider names are getting stacked on top each other per loop iteration. [`b16ff81`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b16ff814788afb6e51d4e3da9dbc6562091cc66c)
- Minor bugfixes and improvements [`fb22290`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fb222902c108f60c501a40f5ad1a403876859f02)
- Fixed dupe issues with backlog searches. [`c350c0f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c350c0fdf94bde366484aa7d7c0b14ecabb4017c)
- Cache issue fixes. [`dbe7e01`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dbe7e019f684ed42887d6dbf6a4ab1dbe9ce34f5)
- Fix for air-by-date and sports shows when searching for full seasons. [`415e0df`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/415e0df536f1c449d069aa91e8ba0450dc44acdd)
- Improved tornado async routines and shutdown routines. [`20e2ae2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/20e2ae2f86fd3561123d855921d235c1bce9a631)
- Fixed issues with restarts and updates. [`d835888`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d8358882de75305749269e90e91c8b9529c09605)
- Fix for air-by-date/sports/anime provider searches [`05dcdd7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/05dcdd72d7771775034f22b07c49c660b48db1a1)
- Fixed alot of issues pertaining to season pack searches and backlog searches in regards to returning accurate results or no results at all. [`dea826c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dea826c3ba54b89ed03e1d3b0e7e87d7272bb389)
- Fix for extensions being stripped off by mistake made when adding in -RP fix from few commits ago. [`5ac99b8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5ac99b8c5c1555ae4252f4677ea1afa2617ac899)
- Fixed NameParser to properly parse anime episodes that use normal season and episode naming conventions. [`a697805`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a69780592330493d6d201c7498365939afa295fc)
- Fixes issues with tvdb and tvrage api content attribute not found [`f54a6e2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f54a6e25b258151ab00c1b724069166665f2bf44)
- Fixed main database structure to line up with original sickbeard structure so that migrating users get our database modifications migrated in without issues plus I've updated our main database structure to reflect all our recent changes so that new fresh installs dont have to go through the migration process [`09dd1b6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/09dd1b6db281242dc61d8a19ce210196fb17cb7c)
- Fix for startup issue when using python 2.6 [`3cefc5b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3cefc5be8697828e879785a0314f09ee1ce1e0ba)
- rss cache updates and daily search have been joined into one function. [`55f27c4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/55f27c4f400934c68147e7ea96c8fe4b16c389b8)
- Notify on update for notifiers via email has been disabled for now till we re-write the email notification code better, fixed a few small errors here and there. [`c34442f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c34442f5c19f419654a6fb48b813b37b0c14d26f)
- Improved code for better performance of application memory and cpu usage. [`0947622`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/09476224c58bf49ad1f9a8e1602306633b40f1e4)
- Bugfixes [`90cdf32`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/90cdf326b7eb90173c3dccb243fdcd299f23eab2)
- Maintenance tasks are no longer blocking startup. [`c478d45`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c478d45c3645049acd17a5a83304f41253e15ce8)
- Reverted some changes. [`75f6939`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/75f69396d4ce75681e9f4cfe5e8b368ac539dabc)
- Fixed find propers. [`854de69`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/854de696835076d659ad6b6f5e3b494c7c34a198)
- Fixed show name formatting issues. [`4f049f4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4f049f4e7ec8fd520307080bf6c89fc8743225aa)
- During backlog/manual/failed searches we now cache disgarded/ignored results pre-parsed for usage later on incase we end up setting a episode to wanted that matches said results, allows for maximum performance and helps limit the waste of resources used. [`3a2b673`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3a2b67330c1b2aaff8f383aebacad483ee937b73)
- Fixed issues with scene numbering being overwritten by ep objects. [`70e7f1b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/70e7f1bfce3400ed94a4a806b5024490cde577d0)
- Fix for air-by-date and sports shows issues with parsing results. [`be17ed1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/be17ed122bf39edc84ee2cc87b594d6f864fefa8)
- Fixed issues with per-provider torrent ratio settings, now can be left blank to default to client ratio setting. [`b499e4b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b499e4b6db20d88b38b11bc548bde376d1ad074c)
- Updated libs to include new pyGitHub modules. [`9abe5ea`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9abe5ea859e7e73552f1eb5d6b6fe8c3bf205e88)
- Updated post-process code. [`08159e2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/08159e28722d4836f17c97b6f897103707a14985)
- Fixes for DB issues [`a1da7df`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a1da7df12ee1f5fc84205c6f08861c448596701b)
- Fix for torrent ratio's, switched them from being stored as strings to integers. [`7673cd5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7673cd5cc9d8e797a5b83cf956ede4eaae3deb7e)
- Doesn't start a scheduled task for things not enabled to not waste resources. [`b1de2c7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b1de2c7080185d930e6c37000b77ed432af07ee0)
- Post-processing now auto-detects the correct indexer for the show both on manual processing and script based processing [`22a4a06`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/22a4a066d8c9868e0837317d5f9a13684f220d87)
- Fix for scene name repeat bug when displaying show. [`de01fa1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/de01fa1e37f873d308a1c33a3789ccf4fd4ff292)
- Fix for addCacheEntry [`450d96e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/450d96e0413f095977f3d4bfc534f84b57145ee2)
- Fixed issues with queues. [`ab8d9e6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ab8d9e64050c0bfcf9d2fbaa5999d58ef157b797)
- Fix for debug logging on console. [`99bbd06`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/99bbd0649cb0ec86c688f6c2495c15fae4a1ea01)
- Fixed issues with trakt and root dirs. [`2d0c315`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2d0c31510eb021d4c9df87b142edcf24984c72b4)
- added indexer selectbox and timeout in search [`ac82e32`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ac82e32b98fb25804e335515aa578111589fbb5b)
- Mor bugfixes to code that handles converting sickbeard.db and cache.db files to our new scheme. [`264f852`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/264f852a971dca0f70e4edcbfcb958c31e29384e)
- Removed maintance schedualer and moved the routines from it to happen before a search is started to ensure things are up to date and to stop waking up synology devices, regexes also made less greedy. [`c8d899a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c8d899ad669ea8111bffecd482b5e0f3bde644eb)
- Code cleanup and bugfixes [`bbf9491`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bbf9491943df4af5dc43d46166f0e8591670831e)
- Misc fixes and code cleanups. [`08d8bef`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/08d8beffa431b2f855b1811bedbd508fe7e284cc)
- Fix for root dir location not being saved or set correctly for shows. [`79a1b1c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/79a1b1c31e419d0e6ed584a056f1806b9a21951d)
- Fix for newznab provider settings not saving properly [`3cb1c57`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3cb1c573a3166f747ac1dd0880a12256eebc81da)
- Fixed errors in scene exceptions when retrieving list of exceptions. [`70c2a2d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/70c2a2d130ffbd4d146a491798d02e6b77ed3df1)
- Removed all scene exception memory caches, fetches data from DB now directly. [`adb4715`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/adb4715b3eb2ae8fad5f71aadd9842142afb218a)
- Fixed issues with parsing release names and naming patterns including regex for sports is now more accurate then ever! [`3a60683`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3a60683327bf0561354bab0da8e46a057f90fc38)
- Fixed metadata code to add proper indexer info to the tvshow.nfo files [`bde70f1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bde70f188169e35ad5a7d592a6a4a262e4a6f4c5)
- Improved XEM scene numbering converting. [`43b6b4b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/43b6b4b5949a24ef6982575096cd72bea7f1eac0)
- Fixes issues with possible duplicate downloads. [`93573ab`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/93573abdc4170a3241055212f885d0b72810f379)
- Fix for 401/404 errors now just redirect back to home page. [`fd88c77`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fd88c77d2698826a48d26886e16640a8f3e504b6)
- More memory reductions and cleanups [`5e507b3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5e507b384989b549295f736bc753f26f2e66c3f5)
- Fixed manual episode searches. [`7e800ff`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7e800ff5242cc980e9044f8ccb108bd146ae1322)
- Fixes issues with daily searcher not snatching its results when it has any to snatch. [`66e499a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/66e499ab23e6e06dc8ee4fd91afd99d1c2ddfe70)
- Converted NZB providers to new dynamic config style format. [`5f328eb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5f328eba5f2e04395e2eb813943584ad0676ab18)
- Moved code for cleaning up cache folder to seperate function located in helper.py. [`b13e72e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b13e72e0a35ee67f9f2a0f1ba8c5e9904632cc0e)
- New searches now search only the indexer specified when importing existing shows. [`d0ac293`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d0ac2936b040abec2a995fa61c8453629b06dfab)
- Fixed up code for searching indexers for show id which fixes a bug that was present in our post processing code [`ab12415`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ab124158a4178e471ff9400c888a060b94b1cf5c)
- Fixes for a few provider issues plus passing of search_mode variable. [`af0ccd6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/af0ccd65cffc9c28082451f596336f8bc2c26070)
- Implemented the queuing functionality also for Failed downloads. [`bdac98d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bdac98db4b8d8962fa3d9deea200c42899c01b73)
- Fixed provider ratio issues, not can be set via .1 increments [`fab8329`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fab8329e2363882535a1686f5b150646b7c8d356)
- Fix for no providers found error during searches. [`012baed`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/012baeda0cc9270234ddaa52f56f8e88172198ce)
- Fixed massEdit issues. [`a15258c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a15258c784e5e84fccf441905ea253cd8fc7ad1d)
- Quality is now set during parsing of results. [`24dfbc3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/24dfbc3f15c7a708b77d983f5e3e5ecc4cf3b7dc)
- Improved manual, failed, and backlog searching. [`734de67`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/734de67684f494442e7f4eabf89fb81cf29d09ed)
- Fix for trakt.tv issues when adding/removing/syncing shows. [`b8b5947`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b8b5947ae65a2e673fe775c84b1b7c3d92d8b4a8)
- Re-coded our cache session handler and made vast improvements to it [`381049c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/381049c3739b01071b2db85cd28e7353a3a18c35)
- Disabled sceneConvert renamer for now till we add it in optionally. [`831e9a5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/831e9a537e6632549c0fb080cd193df4cecd2eeb)
- Fixes errors caused by duplicate newznab providers [`d6a9426`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d6a942698aed46aed6a66a63a5b0af0bd123ce03)
- Fix for threading issues with backlogs and whitelist/blacklist issues for anime shows. [`5bc775d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5bc775dfb9ea9c55e4e3cb867ef1c0563a25e909)
- Merging changes from Prinz23, PR#156 [`b177c1a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b177c1ade29d2bf8afbe2acd0792cd241694d871)
- Fixes more issues that were still present for season pack searches and air-by-date shows. [`b349bab`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b349bab56993a4ac94330d3406fcd5f5f3d7e904)
- Fix for date/time display issues. [`f4b71b7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f4b71b720379efd63c234328e2ee8f4c884cc303)
- Fixed backlog issues and improved cache and provider searches, this resolves issue #298 [`1c6b080`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1c6b0807b0a1941703823d6692ddc2b3a742352d)
- Updates/Restarts now use the same process instead of spawning a new one so the PID remains the same. [`386355e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/386355e1302404bfb239efc8324cb41d9a80f3fc)
- Updates to auto post-processing code, additional code added to ensure indexer is always set to the correct value [`6a4adce`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6a4adceb26d06136a931dca0321fae102c270e5a)
- Fix for saving default options when adding shows. [`2ab436b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2ab436b764e1c9a4f65ccf16d204d98462289276)
- Fix for NameParser invalid show errors. [`fefcfa0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fefcfa09529e995e7c0c3852ae5eabffe7038de0)
- Fix for air-by-date and sports shows [`35f70c7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/35f70c79242c45ad8d77c21cb6e91887bc9c8f5d)
- Fix for air-by-date downloads. [`f8035e8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f8035e800e92fb66a63b09cd6330c938c0148c56)
- Fixes for updating/checkout of source installed versions. [`281c5c3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/281c5c333edced4f95c37e8d9f89aa3004d088ad)
- Fixed invalid naming pattern error. [`7cbeef5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7cbeef5ed0c88a319411ad9f2e804acc8c0697f7)
- Fixes for anime regex matching [`99d129b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/99d129bd414f26ec998e824f007c3b0d55edb423)
- Fix for sports naming patterns [`160b4bc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/160b4bc4ccd63cfc0f90e4ffd1d4d2dc4bb688a6)
- Name parser performance fixed, manual searches fixed. [`ac9d78b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ac9d78bc0f8778766b068133b7690e6a354a154f)
- if nothing has changed don't execute the transaction for network table and don't reload the table [`6adbdb5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6adbdb5e8679edd2214b0b9638a3857be166d109)
- Fix anime legend table on post processing options page [`c19d5e1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c19d5e1600b738eec82bf017a3ae14682ad93f47)
- Updated scene exception code for checking when last refreshed. [`c25da85`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c25da850ab9b14706dfdf5918f3b0c084c76cfbc)
- Fix for issues relating to adding existing shows and nothing happens. [`20bc926`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/20bc92650bbf9f00139964511c8f308c4008040a)
- Fixed andidb scene exceptions to be called only on shows that are marked as anime. [`79f923d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/79f923dc9cf6dba3fe0084c0a41c71cb828da44d)
- Fixed issues with web root settings not working. [`032ddf2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/032ddf24259a7e6a4b3d4c3bb49dd48921949e22)
- Updated readme.md [`75b6d2f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/75b6d2f51ad27e7d0558bcabb8c051a70918da97)
- Updated cacheHandler to allow us to force cache and set a max-age on the cached content, vastly improved performance with indexers. [`40c69d6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/40c69d6a0f15f152f0ba77ea13917c1efefe6201)
- Last set of fixes to correct this problem [`33be932`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/33be93288a243a44bf84e640f98bf3890fc337ee)
- Fixes cache issues with lookups resulting in wasted cpu cycles. [`3fbfed7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3fbfed7d93ebe44350f03b58308b1e8e8850ad87)
- Updated readme [`e8556b4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e8556b4c05d2d7607da244eb5b26e77ed7f0c119)
- Fixed issues with popup notifications. [`96fa095`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/96fa0953e39b0523ad47bb3f7b76d6de7f29e441)
- Reverted persistent storage of nameparser cache, testing fix to prevent crashes possibly related to memory usage. [`546f7c0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/546f7c00b4ab6e8eed214b1d7514bfb6f3f384f8)
- Fix for feedcache logging. [`0e962f8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0e962f83cbd2d6c79d3af6bf26024bfcd2c14b00)
- Fixed -RP release issues. [`02c8b86`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/02c8b867c654871fe202b9bb0458e46da93594eb)
- Fixed cache issues. [`dd16da1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dd16da1a5fc65a3efe8efd9eddad2f0371967623)
- Fixes issues found in cache and with season pack searches [`5252cbb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5252cbb72ceb500c3bd53bb12d85d2971380017b)
- Bugfixes for post processing code [`45ba1e8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/45ba1e815b1f8bbd9aaca27b09c5ccabe9d3c578)
- Fixes issues with scene exception updating when editing a show, should resolve problems with it duplicating scene exception name over and over again. [`636bbfa`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/636bbfa2de373e16235e9cf81a22888dd216c449)
- Resolves issue #13 [`aa86671`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/aa8667106f1b16a7d2b2700fe2b23d3faa3d3961)
- Upgraded IMDBpy and improved performance of it. [`cfcc35e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cfcc35ebcc9fbe139e48c9d45d3ac6eecf5ea02e)
- Fix for setting status via episode status manager [`acadce4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/acadce4d963fd902945768ca948ebefee7601a48)
- Fixed whitelist error when editing shows, needs more code changes to fully function correctly. [`7f20f5e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7f20f5e27f2e68bcdeedaab128404c7eef75c30c)
- NameParser now trys to obtain a show object first to use in determining the correct regex set to use when parsing release names [`4ef8896`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4ef88961b558e2bc3dc474a21835f41e854fdcb0)
- Updated readme.md [`ea2ec23`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ea2ec2390a59c086f93bdc5e56396d862622fa89)
- proper settings for proxy [`484dba0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/484dba0de852ce8b055e71e8c20e7d4dec0f432e)
- NameParser now won't bother to proceed parsing release name results untill it finds a valid show object in the DB to confirm its a show in our list, naming patterns automatically bypass this restriction. [`fcc91be`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fcc91bedd928f4f9c37a4e3650e59e694093e555)
- Fix the home page from failing to load if a show status contains nothing. [`59f4f44`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/59f4f44edbe094c3d6fac308f387a80263b9cbf2)
- Fixed issues with search results not being snatched when searching shows with custom quality settings. [`8ac8150`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8ac8150eb39d2e4b16604d0c1298946b31b094ce)
- Improved startup and shutdown for tornado [`6dd78f5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6dd78f58b6f391bb810db3a06156bb7546f0eb35)
- Fixed issue with main database migration numbering [`fe10a45`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fe10a4551e53d1367d17b00d52050475fc90b761)
- Fix for nullhandler issues for py2.6 users, [`98ff924`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/98ff924b1c85ce19773bdf7b279d5110438ce2d0)
- Fixed Name Parser issues, incorrectly matched current regex used to parse results and anime patterns didn't match 1 to 3 digit numbers for absolute. [`3f6084f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3f6084fe4bdb3fa50513c3cf12098b1af6fa8b0d)
- Multiple bugfixes for provider code [`ad339a9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ad339a9b2e25b85a68889def0f7fe94e8ddf90e9)
- We now check if a torrent url links to a valid file before adding as a verified result to get snatched, this helps prevent issues when attempting to add torrent to client later on to find the url returned nothing resulting in a error. [`19a89d4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/19a89d453c790e51d10172b3aaeb3ddefefcd696)
- Fix for issue causing issues loading and saving search providers [`a350be3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a350be339c6e035ff082fb505b1ff974a03de8d9)
- Fix for __exit__ DB errors [`61e1e5d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/61e1e5d2c26b1e396b95b82d088aeed68f15d599)
- Fixes for editshow functions. [`d916958`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d916958abc4bff8ab11c0b8731eed53214ca7674)
- Fixed potential backlog issues. [`a6d30ac`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a6d30ac4258fcf051066e962fa4da2847df45789)
- New show search code changed to optimize for quicker searches [`872389d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/872389d055fee1a82c48ab518472d3514226b886)
- Fix for Next Ep airdates. [`9cd9576`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9cd95762328d5125dc346fb4d1bdfdb966b10304)
- Fixed naming issues for episode naming patterns. [`7047cf0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7047cf020ef9ce8971852d7936428127a88d5922)
- Fix for restart and PID issues. [`42b6211`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/42b621103f5a77abc1fe5823d40a376977f7bc5a)
- Disabled caching for notification tests. [`1145f90`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1145f90208afb4fa8bec731a112826c1239cf11c)
- Fix for post-processing and parsing errors. [`f91569e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f91569ec848ab335944cf424318218f1d8d0cf52)
- Fixed internal indexer scene name cache which resolved issues with searching and snatching. [`4da248e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4da248ef9b0c7a4ccc72fb9fb65d7f02575c7e46)
- Fix for issue #290, Post-processing issues [`85a9a81`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/85a9a81f4e5848a9c274ab3c761854599fe63453)
- More fixes for checkout/updating issues. [`39fe8e8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/39fe8e84778edf67d092a149e3c656d7ebd3179b)
- Fixed issues in mede8er metadata module [`f8a8f4c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f8a8f4c5b4b14447076ceeb4ef0d37c9d93bf0a6)
- Fix for air-by-date issues [`28d39df`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/28d39df816876efda40dc2d9d90495af403d7fe1)
- Fixed bug for returning requests object exceptions [`23348e0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/23348e0bd0d26f6ab258c113de8925733c9b582a)
- Update pp_tests.py [`94f60e7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/94f60e72966e01d2f994895007f3282d79ee3063)
- Fixed issues with added new shows not showing any episodes. [`9084d7d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9084d7de199dd023ab9e712f1bc0a9400a51cc70)
- Fix for migrating to new newznab and torrent provider config formats [`6fd19de`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6fd19de7e23627785b31283c6d3d69c254f80181)
- Fix for coming soon episodes page. [`7e5cc8c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7e5cc8c6736b5d67fd2405de8e970fbad0d1c34f)
- Update pp_tests.py [`81ddee4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/81ddee4760202407886a7f54ae4c140458eaf559)
- Improved newznab offset code [`ba4b408`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ba4b408af315e126bd9bd3403563878d6cd1c7dc)
- Removed some sleep timers to improve overall speed of sickrage. [`fa11b4e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fa11b4ef3ab20ec56d3b49ffbfbff2dee20cccda)
- Fixed regex patterns for both show and release names. [`5c5b6f4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5c5b6f49e1a89090c46cc43bf7b908ceca8da2cd)
- Fixes issues with scene numbering being set to 0x0 after snatch is performed. [`14201c7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/14201c71f3b6c7ad71dddeeeaa59fe22347d8023)
- Fixed failed download handling. [`64b857e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/64b857ee57ee65e5547143ad428186a74632b24a)
- Improved newznab offset code [`ab16430`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ab16430b1ad9affb77cfe6badcfcf8a2e28c4030)
- Fixes issue #326 [`a3bdf60`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a3bdf6038f00fc187dc6cc4c13206f09621fbf62)
- Fixed issue #221 [`f6cf80a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f6cf80aa99e364dccde73bf7d09173919d620ec3)
- More fixes for strftime and findpropers [`77bc5c7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/77bc5c7291b88b962efeb86adc1a0cadd1de38c9)
- Fix for failed downloads and improper storing of release name in db [`f78ed64`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f78ed64878761640be4fef8c3e564cd827cc41ea)
- tvdb_api update, backport from midgetspy [`ab89084`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ab890846889b9f98afb29e1ef648aadf09507c7e)
- Fix for subtitles datetime issue [`56a0a04`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/56a0a04a2cc28787b9477b6a9712d3e0ba140c3e)
- Fixes for air_by_date and sports shows [`eabd0d0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/eabd0d092f2d2d6e3498ab05dd2a366dbb4f5a39)
- Fixed cheetah's template subclass to properly return correct line numbers in tracebacks so that we may properly debug errors. [`ab69e52`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ab69e526159150ea9b3bdaea994c92d42d1a9065)
- Fix for updating issues [`f9ababe`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f9ababe7cbf54dd822f121138a62b3cdfac92c89)
- Fixed shutdown to completely stop and close IOLoop. [`acca01e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/acca01eb90b1162a0ee5b78362c97df14ff60b73)
- Fxi for failed downloads [`a12085c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a12085cbfc7bfc49e17fd47cacbe7e6a30ef76d8)
- Fixed a few bugs. [`b0426ca`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b0426ca12d82091f158abfa89802294ae50ee5d2)
- Newznab providers now search by tvrage ID if available and show name incase tvrage ID doesnt return any results [`ea66c2c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ea66c2c41be7b9e68e1b3a7828b663b635bbdbe7)
- More namechanges [`177dbc0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/177dbc0f222d12371da35f93c86f5fab8edbc232)
- Fixes issues with skip removed files option. [`a4c790e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a4c790eedc59e03943112cc6303deaa9482888ee)
- Moved show season/episode cache to outside of the show class and turned it into a global to avoid circular ref that may memory leak. [`89ad4bc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/89ad4bccc3415190f193e70027c05cade6cb6ff4)
- Moved code out of series_name check for show object creation/checking. [`09a3333`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/09a3333399d0556f621503bd1333c9bc2f473d7c)
- Fix for bug #911, escapes regex for ignored words [`461b1d8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/461b1d89d354e640151cedb71167bb559fab7075)
- Fix for when no best match is found. [`5f80375`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5f8037530a5738af3c9bef3f8a6256de8cb5343a)
- Unable to parse filename errors are now set to show via DEBUG logs only to prevent unicode chars from causing misc beeping sounds ... [`933fad2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/933fad20c7ec25158ea4df6d5cee99823e483e68)
- Fixed issue with reverts to master on startup due to bug in version checker. [`7cb2296`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7cb2296b6a7192f2f2abff6a32cc6cd80a5add2a)
- Fix for missing column 'subtitles' during migration from other forks. [`ee6e55a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ee6e55aa8897a088c380b9d60c6af7561fd2a1b8)
- Fix show name matching, trys main show name pattern then if no show object is retrieved it attempts using the alternative pattern. [`42e1994`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/42e1994cbaf192fc5a9e7a1de035eed4da75929b)
- Combined 'Delete' and 'Remove' buttons in to one on the individual show pages. [`b9b88b1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b9b88b18a67ba96db5db787feda7e5263103e970)
- Fixed issues with torrent blackhole download issues. [`9761c6c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9761c6c6a37228ad2c7935f3f0032d72c93fa636)
- Fix for pushover notifications. [`8dd4585`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8dd4585145b37067d34751198b35de10483b446f)
- Fixed naming issues for sports and air-by-date shows. [`818536f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/818536fcb4587199cc0afaa856afc597fd01da8a)
- Changing names, branches, URLs [`3163bad`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3163badb4cd5247851bb71dad1bcf7958ef8d6a7)
- Fixed bugs in cache control [`2acafcb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2acafcb603af74e4c9a6fc62523136d74fd6f7d5)
- Fix for closing cache connection early when needed. [`1f180a5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1f180a5a05c38491db1589c10a1dae7bb5f72376)
- db lock issues fix test [`26f30ca`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/26f30cacf523de798b74e2dd7a9c5a587aa26770)
- PEP* Cleanups and added timeouts for threads when shutting down or restarting. [`cef53be`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cef53beee02840bfc735523894dd23050d4cd61a)
- Fix for manual and backlog searches to insure maximum results are returned [`b8a499b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b8a499b3d3ceaef16d0dac914a33e7ad03d13a03)
- Fixed high CPU usage during searches, adding conditional check to prevent un-needed name parsing of search results when search result was previously already parsed and checked during filtering of bad releases [`65eda93`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/65eda93b2b7ea4b9629f50cdd12f808a61437ed1)
- Fixed memory leak in scene exceptions. [`0a80d0c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0a80d0c3dd9194a5a98ab44256f861eb2c4c1e42)
- Fixes issue #25 [`f2fb907`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f2fb9076ad585191b9de4b9eb10299d5d7f342a5)
- Fixed another issue in showUpdater. [`fac97e5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fac97e5f5a37339d40c0cb70a66def94e2704719)
- Only process if there is a name present [`21b7aa2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/21b7aa27850038387b8ac6632d5283ddd4217509)
- NextEpisode code modified to return the airdate ordinal instead of a ep object, faster. [`dbe22b5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dbe22b570b87d2c1408a7b0622b77786e55fbe5a)
- Fix exception for when no results returned. [`8b67844`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8b678445cc45638d3c2ab15afe6901fbe7e0ec89)
- Fixed a couple of bugs related to deluge [`d0105a2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d0105a2f6a5d8b95de4d3d33bb6e435602886751)
- Fix to insure pre-release downloads/snatches don't get reset back to unaired. [`3517952`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/35179525363b2bd2bef628f6fca8d57c595cdc9a)
- Fix for findpropers and newznab providers [`cfa5d99`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cfa5d99066958701274c36daaf72acad1513cd47)
- Revert "Fix for findpropers and newznab providers" [`95adb13`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/95adb131e13d8e60fbf1f30a7304d8daeec529de)
- Fix for trakt connection issues. [`4094e2e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4094e2ed3c678ea0c59de894e8994319075af757)
- Forgot to add check if naming pattern was calling nameparser for previous commit. [`2fec443`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2fec443c37f65a8372d8d32e82ce8811a75c3d49)
- Fix for db locking issues [`d30060b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d30060bf9119994b55c9fae86f60839674dcf530)
- Fix for sports naming pattern issues, finally this is resolved! [`a97dcad`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a97dcad291db66fc3e3fe66758b898d4eeb4e378)
- Fix for subtitle processing. [`1b84c6d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1b84c6d28102dd525168a893ee5ac977539987be)
- Updated nextepisode function to only perform db calls when nextaired date has been reached. [`5237e70`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5237e70fb3cc46a8dafdb5e3afa181d509f5ec89)
- Improved caching results code, helps with daily searches. [`1fcfa4c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1fcfa4c70a86bfd51b123017bdfb5591c4bc3fdb)
- Fix for error code checking for Newznab providers. [`71ec47a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/71ec47ae6b7e8d817e45b90ec9845f5fe5f99e01)
- Fix for pyGitHub module not found issue. [`4d41d88`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4d41d881eb1a2cfbb5414366a981148990749e2b)
- Final fixes for proper shutdown of tornado [`149d7b2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/149d7b29dfaebd81a61e2cef755e63c650436ac5)
-  Option to prefer single episode releases over season releases: [`84120ee`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/84120ee00e09e20acc1b88ba2bb5e9c1d4e71eac)
- Reverted episode cache changes [`44358ef`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/44358ef60187ea4f390ec80e31dff42c9140b53c)
- Fixes issues with backlog overview page failing to load [`8dd822c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8dd822cef010960ad8588815abc9801120cc3a87)
- Fixed forced updates to wait for auto-reload instead of performing a restart. [`2ac1c5f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2ac1c5fdd5813d9e8797b5733958f105d5c2aabd)
- Fixes issue #25 [`896805e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/896805ecb20d22e00e33618462dd2eba253d27ec)
- Fixes issues with searches and importing existing shows [`a71ed25`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a71ed25b198d4ef76cb254c720dd1cc334d187e2)
- Fixed issue with new show searches not returning any data. [`e19e0e8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e19e0e8d1cb57ed1ddae0d42a248f08b20f23296)
- Disabled logging of tornado.access [`53e7c53`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/53e7c53b8afd9c1cdc00b58667b5556892f511d9)
- Fix for mass updating not actually changing any show options when editing [`272ecd0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/272ecd0ab8241a6f37e2936f5cdfc742c225cd90)
- Fix for backlog and manual searches not being executed [`7c9e4b2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7c9e4b24d51929f021affcefaaa4ccdec3d938fc)
- Fix for possible infinitie loop in searches [`905d2b4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/905d2b4eafe7c16d396e54e04ea7a2e3781476aa)
- Fixes other temp tables that may have been left behind from a bad migration of the db [`5dbfc81`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5dbfc81bb2f55c8c8ff5f510d7565b8e9c420210)
- Removed tornado's auto-reload function and reverted back to using our original method of performing auto-updates, this should also correct 500 internal server issues for those that got them after updates where performed automatically. [`b6e7635`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b6e7635a32d79216ec7350d7629b1523d66a1629)
- Fix for bug #903, Fixes issues relating to proper and repack provider searches [`238df07`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/238df07c1dc767f82143bbe6ef7911536d48df22)
- Removed global seed ratio's [`83d7e9f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/83d7e9fb694d66413fe14b5253953166252eab42)
- Fix for anidb errors [`a16bf8c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a16bf8ca2cf0adbb1ef60d3a521c332ce8db7521)
- Fixed some git conflicts [`8b4bb3a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8b4bb3a5a5f50c89aec1003cbe56b71795e06b0b)
- Fix for XBMC notifier when XBMC has no shows in library. [`bea999b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bea999b6399aa20db2494ee0f6bb632186539c99)
- Move some code around in our cache handler for better parsing and accuracy of caching [`1bb9413`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1bb9413b19bc91406778f5fe79a8d7d7a72a4080)
- Fixed adding of trending shows. [`1c46813`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1c46813e89e569c2e56ec5e6ca10bb30bd5c6f03)
- Fix for thread name [`e3bf972`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e3bf97285c14762691615090e7e68cc7059e54a9)
- Update changes file [`0bb60c6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0bb60c6d1c1acff7fea6a98ac95492da8d23b78e)
- Removed tornado async features, testing to see if this resolves blank page and other related possible issues. [`2f73ab1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2f73ab1e41d9d713fafeb8fed9237ec4690f8b60)
- Fix the Plex notifier [`0077a8e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0077a8e5182892183845f18ead1c95ef40c60404)
- Fixed DB issues related to displaying plot details for show episodes. [`f6c40d4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f6c40d4b251706a84df34886f8de10f0d9b3b711)
- Fix for config page issues. [`ecad67b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ecad67be06cc899a5e10eeef91817b5ddeda55a9)
- Fix for missing indexes [`a7ae6a1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a7ae6a19771fbd5d0fda3caab67bbbfb4fd0ac4b)
- Fix for files being deleted from show folder during post-processing runs [`27189d0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/27189d0406ba768126f1d618e778b62fca19c264)
- fix for ui-pnotify [`f97507f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f97507ffc7b0f706c9f2489dcad00df83d887213)
- PEP8 changes for rss feed cache code [`45fc163`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/45fc16343448c79b787104a81197e8a2b52ae4f6)
- Fixed issue with extractZip function. [`5f7b846`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5f7b8465d05279a5a9dab01f28d9fc02e104ba81)
- Fix for scene exceptions error. [`0e665cb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0e665cbbb204f08f4fd952e4c206e2e55b9d48a0)
- Fix for #315, backport xbmc always on option [`77e9988`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/77e9988980fbc3249f9b61726d3ff0a6829a8d54)
- Fix for string issues [`308add5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/308add5a1126fc7459a15a304e9c1da45609336d)
- Fix for formatting pattern issues [`f9cd37c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f9cd37c2436e929a7d313d127eed038246708188)
- Fix for index out of range issues [`2893b33`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2893b3331e64720913d42620e01690ed3f968c58)
- Filter out possible torrent links that would return a 404 http error [`11150ef`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/11150efab05db66348cc40333599591ea68ae17c)
- Fixed language and subtitle issue for new shows. [`9e4ee04`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9e4ee04f577a91283b9af4898e9a66ca07e38c8e)
- Conditional check bugfixes [`e171aa1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e171aa1c1098e45a89ecf15ed84b15b79ca5af68)
- Regex order of placement in list now taken into account when scoring matches. [`20456fd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/20456fde6be3cb1215a8e149f1b375bd672dfd32)
- Fix for newznab provider searches [`f65262e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f65262e0e9e3207ad90886c95f487273068748d3)
- Fixes missing indexes for tv_shows and tv_episodes tables [`fdfc8eb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fdfc8eb2199d0b9450333862a9c3a5b322807aed)
- Delete files after it performs copy/movie/link instead [`872dd2b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/872dd2b9fc9f90dfb35ea4d92904b5d68c735bbf)
- IOLoop tasks are now started and stopped via regular start and halt sickrage functions allowing us to gracefully exit on shutdown or restart. [`fa01711`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fa0171119248547dc6eddce233d330b00db73f5a)
- Fixed more unrequired search strings from being created and wasting our time doing duplicate searches [`e309aa2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e309aa2cbfce4540ee16f6c2f45d14723d267cb0)
- Fix for failed downloads [`c761f32`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c761f32c85e6cae14454c900700b91e09f95cd68)
- Backlog frequency determined by algo that takes into account daily search frequency to prevent overlap of searches, automatically calculates allowed minimum value that is user-settable [`e78392f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e78392f04ab8b3ae9367f70eb176218c0d055586)
- Fixed issues with finding propers to many keywords. [`7f44a2c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7f44a2cfadd17d0b6a968aa946b0c9891585684c)
- Fixed bug #895, automatic post-processing not being enabled when setting enabled from config. [`b1d7cdc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b1d7cdc1ad2ff9206044370f6621069359277cce)
- Fix for adding new and existing shows not showing up in show list [`f742f8a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f742f8a51a31c1e174dfce40b5c78a27392e701d)
- Fixed trakt library update issues. [`cdd190e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cdd190e1e7b98f9781b9fd3160fb72b0134a8979)
- Implemention option to start/stop full backlog thread [`d76c9d1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d76c9d1c3b5bb026f06b4d252be8732385a19d4e)
- Fixed dailysearcher to only update the cache results for each provider once at start of the dailysearch routine instead of per-show which was wasting cycles and time. [`301f124`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/301f124cbbb9cf3d94e480ab07022e9a151a6fab)
- Fix for bug in comingEpisodes template not properly displaying [`3534574`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/353457474119d3f8aa5915e987370a2a97b15d73)
- Bugfix for scene numbering and kickass searches [`e3a843a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e3a843a82391719d321bb7e021b505320ddbdaaa)
- Fixes issues with provider settings being loaded and unicode data when it should of been stripped off. [`22ec1a4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/22ec1a441872f9d46edbd8b3054f514432e5b1f9)
- Fixed issue with scene exception updating for custom names. [`78c4211`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/78c42119253cf8239d2b7e553bce888c5fd00e29)
- Fix downloading from foreign section [`27fa146`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/27fa146724076f343df7032c7d2a15c2d2abe334)
- Fix for search provider config page errors. [`2d87de0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2d87de0fd8ddbd013fddd3c9ef5d98df764dbfbf)
- Fixed backup/restore issues, uses correct data directory variable now. [`10bea52`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/10bea520a7ecddde9f1326da81e82b07e9909ee5)
- Filtering of torrents with 0 seeders is no longer forced, filtering now is done strictly by min seed and min leech user settins which can be set from search provider config settings. [`09f53d3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/09f53d3537238dea86c25937840c20f0d0ef6957)
- Fix for sql mass add issues. [`fb0339a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fb0339a274154deb3fb41c7dcf3d8a39f88d8303)
- Fix for Error cannot find 'cur_ep_enddate' [`a3449db`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a3449db3d36f4880299edc087adc5a58e659e569)
- Fix for sports air-by-date shows [`d2b4ad5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d2b4ad526d6a7aa10f0d3f262f6429be35157afe)
- Fix for issues downloading season packs and episodes and multiples of the same episode. [`a2a608e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a2a608ed856cc42fa0e380463bf6276f27c9ef36)
- Fixed for failed downloads issue list index out of range [`98e1d67`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/98e1d67cf9dd7720887527d4d872559f5ccf5285)
- Fixes issue #376 [`faeb11a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/faeb11a9ac65402d2f654dd18b4b916b338d97f3)
- Update Config info [`b38bf52`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b38bf52c4d94ff7b15bd1d10413daf1a46bd914c)
- Fix for indexerid issues with cache. [`19cf543`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/19cf543693215f8a2197ed88eafa8956e7850969)
- Fix for newznab provider searches unicode issues [`4b66027`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4b6602797fe71c7396c30fc0e980c2fe09da67f0)
- Fixes to metadata parser [`b435fc9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b435fc9d71ac7aaada7ddce84ffd95e8c3d968f3)
- Fixes issues with indexer_id never being added into tv_shows table when at a db version of 15 or higher [`c373844`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c373844d87b06b5461a4fe85cb2eb6f33919f5d2)
- add checkbox to control proxying indexers [`5aae8d7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5aae8d7b4872cff67646fc67d7a9a50cec295404)
- Fixes issue with update frequency. [`b0ec12e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b0ec12e4217097a65d7622560005a18e0e23d968)
- Fixed post-processing issues with shows being rejected and saying they didn't exist when infact they did. [`05cca0d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/05cca0dfe02e6415e1349ba4b30a44be1f630ea0)
- Fixed to use tvdb_id from trakt api instead of indexer_id which is not given [`1f03d1c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1f03d1c2525482081da9625602ba845108c35d92)
- Cleanup leftover fd sockets on restart [`33a28d2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/33a28d20a301ffece608e950a485b32f662f39d4)
- New show searches now try and return exact matches first then next best, search speed vastly improved as well. [`3af9e2c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3af9e2ce6596bcb870e789c4a3aedb8bc4743bbe)
- Logging for tornado.access is now sent to NullHandler so it doesnt complain that it has no handler, still disables logging for tornado.access [`38edbc8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/38edbc8b8b2360f4733b77c0a2420071e6e0b55b)
- Quality sorting fixed for provider results. [`6f817c0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6f817c0c5cc63a1a2ec538ecbacf6433425fc44f)
- Fix for complete season snatches. [`448a45c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/448a45cf4076218f8744cbf095b22e4a7d2d0df8)
- Fix for managing searches [`f7ded2a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f7ded2a4ed1bbad6330a6fa2dbd88170fd2b3515)
- Improved and faster nextepisode function, speeds up home page load times. [`a085f0f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a085f0f5382a2947e28058e1e22f21dc31a99146)
- Fix for updating/checkouts when using source files instead. [`650862f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/650862fafce9964f259d7937dc958379f633365f)
- Moved changes to dev [`06f5f3a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/06f5f3a9aee6d58bc6a020c4debfeae65cd22946)
- Fixes corner case where cookie could not be found [`23b991e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/23b991e9c9c5df3fd3414248699f13d49bf12db8)
- Merge commit '5e95c5bc0294d324ae494e88ad708648b912588b' [`82abad6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/82abad6f19aaf81cbfd4a14880f844d76ee04812)
- Fix for country codes not being properly accessed from imdb causing no icon to display when looking at show info [`0cc5ba4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0cc5ba4eb75f209ed7b53393c3a18a3276098c21)
- Fixed issues with scene converting [`277d630`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/277d630a6fc0892f1e8ee4450cdb49dd69afef13)
- NameParser now gets episode/season numbers for anime shows using absolute numbers. [`c3f6417`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c3f6417f5f08235557ce53118f7476d6154f67d8)
- Updated next episode airdate function to be run once at startup and then each time after that with show update schedualer [`d6225dd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d6225dd8d395599533b3a157ab8e0342e5cdd5cc)
- Removed some re-dundant code from daily search. [`a15db17`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a15db1719d48f031cbfc293f499e3c3e092bddde)
- Merge commit '8c449e2' into dev [`3a08af6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3a08af6661cf79ef765305251888a9d41ae05c0d)
- Fixes a few more issues with backlog searches, relates to issue #298 [`5a1823a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5a1823a15a1f279a45aad477a37c7a430103788c)
- Fixed basic auth issues. [`04681b3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/04681b329766858d9170b99dd2f5d1eb2a313d09)
- Made improvements for searching for anime on newznab providers, who haven't straitened out there anime episode parsing. [`d0dac45`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d0dac45315f717efbbc9e7fa657e6f01ef3b29d7)
- Fixed duplicate tv cache issue. [`cfbb767`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cfbb7678a9bd0bbec8c9d28eeaf0717c13b9434b)
- Updated code to perform indexer id comparisons to confirm show is correctly choosen if we passed in a show object to test against. [`bf40e6b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bf40e6bd98c64ee26eba2741eee3cd13900ebd86)
- Patches the enzyme lib to allow the detection of subtitles embedded into mp4/m4v files [`2c94f9d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2c94f9dd82bd243ab3e6e3d2b7df9d9a2cf8e080)
- Fixed global name season error during searches [`20c0b4e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/20c0b4ea720ab2c3ff3e721020a95bad297183f8)
- Fixed "show must be added to list", regexes now check if numbers following after the series name is a date or part of the series name to properly parse and return correct show object. [`2c98a5a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2c98a5a448932ce40df6b78292c2364c58c69d68)
- Building of name cache executed now at start of searches to prevent building cache for show more then once when not needed [`627debc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/627debcf88632dc90e660ed28024a69b53a2ac46)
- Fix for reguired and prefered ignore words. [`07cee09`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/07cee09c83ddb50350d2d2057715fbf8552b3750)
- auto update test #1 [`52fca3e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/52fca3e29abbc37d138581ade9a0a3fd1d65b682)
- Fixed failed and manual snatches that where causing WebUI lock-ups. [`c423d34`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c423d349e880ab1e473e55654f1282ed1b331d01)
- Fixed bug in backlog search for wanted and failed statuses, was improperly loading our segment lists and dicts. [`08f67e0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/08f67e09de5aa56a8eb44c762b1aa5a86b18b528)
- Updated sports regex pattern for more accurate matches and to filter out pre-event episodes [`dbb3b75`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dbb3b75d6e52b84cadcb6733a6af4fd99d9fcccd)
- Couple small code fixes [`2550b8c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2550b8c831fd7b5d2040ac3a87bfb657c8cc1936)
- Fixed issue with threads not exiting on shutdown properly. [`b484192`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b484192390ff5b088732dfcf9cb70356bfd5706a)
- Fix for scene numbering during post-processing [`dfd6f38`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dfd6f38cfe916705e54c0f7e8c0e021dbcbd97df)
- Reset on every call of Datetime print function the format to default [`f137144`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f137144bc787058b9d096935df2913bb372374dd)
- Improved code for searching existing shows to find there indexerID and Indexer that they belong to for speed and accuracy [`b8048a7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b8048a7e5748d5f27e8cf6627de5ce2d8012cef6)
- Fix for incorrectly displayed remote branch list when in advanced settings. [`a8bcbc6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a8bcbc66c37fe4b0020bc6aab364bb6f3795b66d)
- Fix for scene numbering manually when show has incomplete xem mapping. [`2318e43`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2318e43e899c0f5b26ae6359e35a55b67f54a87e)
- Resolves problem for display country icons if show has more then one country listed for it. [`0766dfe`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0766dfe3108b0769487d0d6934a7f1eff599c5b9)
- Fix name parser issues for unitests [`60c0399`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/60c03996a626ad022f49b92c3e820d70bb42ae9c)
- Fix for manual anime searches [`2c37523`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2c37523ab7a88d719fba0a4c0ad4b7630f0f401e)
- Fix for writing new NFO files for updating Indexer info, prevents constant writing on refreshes of shows [`51ff041`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/51ff0413892d7b1841668128d8edb59776098419)
- Fix for missing code in Name Parser [`688263b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/688263bd62063250a7f8dd3b88a4571961ff06e7)
- use proxies [`aae27f3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/aae27f36f65c795106bf0f6bc984c1dbdc2419c4)
- Fixed nextaired not found issues and fixed kat provider issues. [`e891e9d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e891e9d637e4c1e1375d2e12d36f08d915828911)
- Fix for issue #546 [`1d01d2b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1d01d2bc52f22edf2f17af5714882e97a93efdc1)
- Moved code for marking failed download successful out of loop. [`7b54611`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7b54611361c269793d12661e1ab256d0d6220b72)
- Fix for scene_names table does not exist errors. [`7e91d3a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7e91d3a600515c261bbdd559e3462ecf1060761b)
- Changed to mass action for db indexer convert code [`e255e44`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e255e44462b8f052d0bc5befe317c0ed5eba7679)
- - Removed annoying alert message when failed to retrieve newsnab capabilities (categories) [`3366108`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/33661082553cd344d9da2e5aa0d4973fdca81c87)
- Fix for new show searches, now checks alias names as well as series names to get results. [`7a56afe`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7a56afe512f001509ca9d61f0ccedb230980dee7)
- Fix for hdtorrents uid issues. [`36e12a5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/36e12a5d4d0f5645cd0ff4db34c03a4709f0693b)
- Fixed displaying of currently running searches [`c54e70e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c54e70e99b741d62cc36df1a9ec0e249a2fe983d)
- Fix for invalid scene release issues due to no ignore words being set causing a match on spaces, issue resolved. [`3d43c6b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3d43c6b5bf87178fe4483d2f0c6dd10aa9680e74)
- Fixed issue with tvcache filling with duplicate data. [`9f8c49c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9f8c49ce881e452e8bb43b1b726f8a804aafed07)
- Fix for importing existing shows being set to anime when there not anime shows causing parsing errors when trying to parse episode files from disk. Please perform a mass reset of shows marking the ones that are not anime so that this issue is fixed for when it does its next show refresh. [`9e4ec2c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9e4ec2cfb856b947b1707f283abdd88397a282c3)
- Fix for no status attribute error [`8d4d1a2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8d4d1a21cd30ad612b64659c83f6fef856530459)
- Fixed issue with columns not being unique for xem_numbering table. [`b30ef51`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b30ef51b22f38d1daa44b441f6eec6fedd3a1966)
- Fix for torrentday uid issues. [`ddd9376`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ddd9376faf8706869fb088ff6e235b477643e1c6)
- Fixes issues with scene converting [`96a2c04`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/96a2c047a053652a5fc2e5f441702eccbd317744)
- Fix for missing indexer_id during migration from other forks [`886753b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/886753b76618e84019f6e33df81c80776df217d8)
- Fixed small bug in the getUrl function for helpers. [`4b1dc8a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4b1dc8a63e3bd7f1d7bef84a48f6f5beee0804f8)
- More unicode to int issues resolved [`57fabba`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/57fabbad8b94c49a0eccc3220e206ba4a140e21d)
- Fixes for scene conversion and regexs [`071d51f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/071d51fcda7513744928cbc05453ce89dd4442fd)
- Fixes for db scene numbering fix [`233667c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/233667c6d14c31e583bb8b1031a9f379a5843bc2)
- Complete Backlog searches can now be forced from manage search menu. [`1aff31e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1aff31eaec29c2c4d7f2551d526d2c3edd2d5476)
- Fixed sorting provider results by quality code, was causing a error. [`bf41ba5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bf41ba59be87bb9385bc67ece53bf51f25127a2e)
- Fixes interval setting for auto updates and check version, will set the interval in realtime and take effect right away. [`864af29`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/864af297c644533e219e286a56e806f8c4b9718a)
- Improved name parser scoring [`e0e10dd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e0e10dd289516bf00811d7893fec222e392c3127)
- Fix for validating episode data during provider result gathering. [`39054d7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/39054d781034494aa55bd4b14a940a4bbde6feb8)
- Bugfix in failed handler [`31a63d4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/31a63d41aaadce944e5cc57e8a3bd70faf4689ee)
- Fix for threading schedualers and subtitles. [`0cdd1cf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0cdd1cf8137bbe670384f5c3b50ba2bf96ea2769)
- Fixed issue with facicon.ico file and static link being incorrect causing 404 errors. [`18a1681`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/18a1681a61577b3ee4c36d3b4c80069ccc39c53e)
- Fixed issue #472 [`466eba7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/466eba7fa08a10510fe9bcf301c48fc43d755015)
- Fixes and more fixes [`48462f4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/48462f4baa8a3bf89fae47454b0a2bd15a1b9c70)
- Fix missing header and text in poster layout when network is none on coming episodes page. [`69a0e85`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/69a0e859abd73f6ce628a55e822943490d25ac10)
- Fixes Invalid ratio error when ratio is not set [`e42cdb5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e42cdb5b4a5a92726e6b5ead1b8374390e564865)
- Fixed issue with auto-indexer detection in post-processing code [`381f2e9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/381f2e9e1ab3c16e2b64aad34edc2b4087932afc)
- Checks if trakt is enabled before attempting to start schedualed thread tasks. [`830a4c8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/830a4c840e504a8c0be36de155b5069108af6842)
- Fix invalid responses when using sickbeard.searchtvdb api command [`16b1462`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/16b146284d7bcfc2eb923119c2464508ada01ef6)
- Forgot to commit these [`9fe6b66`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9fe6b664753d173a546a581d31d1e96ff7f414ae)
- Fix for migrating to new newznab provider config format [`ae5644b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ae5644ba91c36b475d46bb24f4b6368b137f4f04)
- Improve display of progress bars. [`7dd545e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7dd545ecae4508740b63a24d27a5b94cbf7ecb12)
- Fixed scene exceptions issue when editing shows. [`b5e0282`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b5e02829425ae73fecaf2e11e68e21334f574fd0)
- Fixed issues with post-processing including the web 500 error. [`fc58a44`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fc58a44ba23ef03eb740b247212fdc09b388d1d0)
- More logo changes [`b31b054`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b31b054e0c759fc14db2f29e53deefcbd47d2789)
- Fixes issue #327 [`b4627af`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b4627af3d2e6fe4b9286d57314db1a88d6658693)
- Possible fix for failed to send torrent errors [`54afca0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/54afca04725be05a73b4ab009e60cb5b146768cb)
- Fixes issues when using system default for Date format, it will now properly display it in your locale. [`9a23bfd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9a23bfd0f58d6e444011732b577ecba1d73d33fd)
- Fix for new feature "first match" [`fc24efb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fc24efb957cc6995598ad5d6a1f333e19b5c414b)
- Fix for failed downloads [`72278cf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/72278cfcb26f89f80c3fcbc5b7c011e535108991)
- Better detection when to show the button [`514d477`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/514d477a326bf317fbaa4ee74f37d23f238035c9)
- Fix for scene numbering not being set properly during a mass edit [`d09f2a2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d09f2a22765ceb37be563d1c8dc6703baa7c805f)
- Fixed issues for unicode problems for encrypted passwords. [`be001c4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/be001c47aefb4750363441c52739dbac77549394)
- Fix where there may be empty values (such as cookies) in older configurations [`93f06af`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/93f06af3008d53896a2839aab7d525b7bd8576d6)
- Fixed startup issue due to import module issues. [`efe115f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/efe115f909818420311ba5e37fc282ed05e1b892)
- Fix for attribute error when no newznab responses are available [`c1a199d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c1a199d6981b7399c29bdb72c33bca9eb17c06e0)
- Fix for #390, add flag to use proxy settings [`36359b1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/36359b1547f5d3d94fc46e187310ad59dc1629f9)
- Fix for air-by-date shows [`896295b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/896295b090c1fdf548158f2ca5afae207d906189)
- Fixed urls [`c9abdfb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c9abdfbac23d3ff2b3804b48083f25f9962d5d0d)
- Fixed indent [`803d560`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/803d5601cd3fead4133b23d0be83247ca63efe57)
- Fixed indent properly [`0afdb79`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0afdb799e61f0f4b31f5919f92b39dd005392ece)
- Fixes issue with daily searcher constantly showing it's in progress when in fact it is not from manage searches page. [`347f595`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/347f595dfe4c52799f3e6bc02232ba5abcbfaa2a)
- layout fixes in for home and displayshow [`0790346`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/07903463e39ca13e7a12ad3f66ce4793dadf2d01)
- Fix for alterate scene names [`cded5db`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cded5db5a2f0f28e2cde47c5ffdf23ab37db512f)
- Fixed naming issues and parsing issues. [`4e83cbe`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4e83cbe6d13fd222e399bcdbd87152c241ec028e)
- Reverted changes to default.css, was just to widescreen for my liking. [`4a0acde`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4a0acde729a5c95e77ce6e76be7c3116c040d597)
- bugfix in tv.py [`ff548a7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ff548a7f6bdf655fd55740bf740b24c26f805ee3)
- Fixed scene numbering, was not being converted to a int before. [`5b69783`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5b69783e86cced47d40829ae8caa381138da3417)
- Failed processing backwards compatibility for original param name "dirName" that has been relabled to "dir" [`a165b89`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a165b891e998a31672caa9335885bcfa1a1aad59)
- Fix for web passing variables in a format that is other then expected [`49027d6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/49027d6185ed40b49ab8f5fa20218bb81bef57a8)
- Fixes issues with inital setting of branch version on startup first run [`326d020`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/326d0204c0c437cce66c815f92ef9722ad716d81)
- Improvements to PublicHD provider code [`049282c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/049282ccb9b73ae9b0f83ee09ff62724427030f7)
- Fix for sports shows. [`f340f9b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f340f9b073c701b52eabcdd86b8f1f07b35a1f90)
- Change code for returning highest scoring match to use generator to avoid overhead of sorting the list [`2da18e6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2da18e65ca6faed2ded235922a81a60e8f6d516d)
- use tor for generic providers:w [`65e0dd9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/65e0dd9ff7c73f8fee0c0ee08b708635a4585064)
- Fix for issues with fallback search option. [`0b9b622`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0b9b6228ae162c1d54ffa1fbf7399868b5ae533c)
- Fixed bug with air dates being malformed [`b3662cf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b3662cfb7b79668b906ca918cc5adf27b9564223)
- Fixed name parsing result issues with improper regex patterns being used. [`c4a0f31`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c4a0f314fdfe5b750c0d8314cf9912b8688e43ef)
- Update .travis.yml [`90bf7b8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/90bf7b8f3b2dc9a19f3cbef94dd87c35b0c75a47)
- Fix for No episode number found error for air-by-date/sports shows [`0fddbac`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0fddbac1c4da642a016000a4a312ea00ecab2ec9)
- Fix for restart issues [`4a4eec0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4a4eec0a9e1ad81aa01238cca36c7a994773866d)
- Update .travis.yml [`ca42757`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ca42757ed450c47b7ace11e78489a21c12b13efb)
- Change process title for more clarity when running multiple python progs [`764cf6e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/764cf6e62e6054f81e7b0b30294d8f6a82ed3efa)
- Fix for restarting issues and slow loading of shows [`4164f00`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4164f00fc8541e2d7f5d88aa46c45d875ed2f88a)
- fix for recent sql errors around connection object [`8fbd915`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8fbd9155d37acf1b449a0769967b98306d57ce66)
- Moved scene conversion routine in Name Parser to end so that it only converts the best result match and not every single one wasting time and cycles. [`7defffb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7defffb4f11253b0c7131dedc810d8437eabf1c3)
- Fix for images in cache folder being deleted by cleaner routine. [`4801990`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/480199085e980413c7eb1302df802ed7ea3f6275)
- Possible fix for failed to send torrent errors [`6c15943`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6c15943363fc6eec5593166af4550bbdd04e5ebf)
- Possible fix for failed to send torrent errors [`8415b32`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8415b32fc6f3f2679989485dd19ea929ce2fffe3)
- PEP8 Cleanups [`c3a1381`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c3a13814f19b89c52446936e9677c72340c10654)
- Update scene_helpers_tests.py [`6270f25`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6270f25176768fbc8512aea59df30baa4d526e8e)
- Fix for custom scene numbering, now able to correct numbering or remove it. [`4c9da4f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4c9da4f44807b32ef059bef91c16e55c13bcbd1d)
- Fixed redirect issues which should now resolve reverse proxy web_root issues as well. [`9e36531`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9e365310b68a8de3a4095ed4c75e3adac2a5298a)
- Update scene_helpers_tests.py [`b7381b3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b7381b3d0a44039f1bbd562b533a8db63b33eeb4)
- Fixes issues in tvcache [`75c7fbf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/75c7fbf137f32e2a3d12943baa436a0b5354fe6d)
- Fix in indexer conversion code for mainDB [`5709c88`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5709c8843c7f0b5e2cb24209839a82d813a3f5f8)
- Possible fix for stacked provider names during backlog search. [`6957bd0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6957bd0656813a7d0fd3534a908223962d446d1e)
- Fixes issue with version update not appearing at top of page [`f5cb9ab`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f5cb9ab84d7dec650d8bd59d56836d0e3bc066ca)
- Fix for backlog overview errors [`e05344d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e05344d571758609cb271fe79914b2e346e46721)
- Fix for migration issues [`7d6e73f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7d6e73f0268e9ab9bce32a4fae6c2ddc5bdd9ef5)
- Fixed for Backlog startup feature. [`a77d8c1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a77d8c1fcbb2c85326e19910ce68a287f6b6de0a)
- Fixes issue #30 [`8c78b55`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8c78b558b52a8abe8490225949abffce98a871aa)
- Fix for published_parsed errors [`dfd8ead`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dfd8ead9f858b29627f4c5c7dff861e12c785e11)
- Further corrections for torrent download issues related to content being empty and not properly checked in advance. [`6e6ae5b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6e6ae5bb8737ada062abf726311862be9dd0bccf)
- Reverting previous changes [`18d7884`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/18d7884c2d007ce14d5663fb21f42d44181b6470)
- Fix for invalid literal for int [`6295d6b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6295d6be94e56fd7816e7e8617b1a9ebb6f2577e)
- Removed internal cache update checks, cache updates will now perform at the interval setting time you set for daily searches. [`e09c497`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e09c4976a55f217621805e6825a92070a3fbfd7d)
- Changed IRC channel details [`dad2c16`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dad2c1623c255a458fd041354ca4c77f8674a881)
- Fixes more non-sense issues [`580afec`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/580afec2a791e1edd72b9ee959490ea63133be17)
- Fix saving rootDirs (refresh before save) [`b63dffa`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b63dffa3a0878a00f0ad43d33400e63fba569c0e)
- Fix for force update. [`c9f8001`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c9f800128ef8e22c840b6c131b075d9c4cc63376)
- Fix for failed releases not properly converting scene numbered to indexer numbering plus small typo fix. [`5154099`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/51540993be74e42ec72d31bf9bb7b70249771bbd)
- Indent fixes [`dad75ae`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dad75ae09b5f913dcea8dbc89dcd13b2c93464fc)
- HDBits fixed! DOn't question just say ... thankyou ;) [`3918917`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3918917f7a33af399289840660bdf516f7d45f96)
- Reverted backlog search nextrun changes [`9eec99c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9eec99cd14e4dceb59df2e1338b4b7a33db6a38d)
- Fix for no attr success [`b0d550b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b0d550b3fbb58ecdee6ae3733d4ab593de13ca96)
- Fix for find propers and newznab providers [`7e711c0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7e711c0665a230da1bb28a2eec6aaaa41e98951a)
- Fixes issue with proxy setting and config not saving. [`6d3f66a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6d3f66aa4d8e807f7c4b5c1647944e1fd6422eb0)
- Fixed couple bugs in cache control [`9124c52`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9124c528a8972468ee39ada0ea1520c081b53cb2)
- PEP8 Fix for backlog searches [`8b5559b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8b5559bdef73e31ce0e34f3c884e1ae69f54b5fa)
- Update utorrent.py [`6c84fed`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6c84fed53674344f8e1220adee58b4a898b017ad)
- Fix for showObj attribute error in cache [`1f74488`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1f74488a38d016f4cdd5a0a1270426d6bda214f0)
- PEP8 cleanups [`7bf1246`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7bf12460bef6cf6964d0fca19c9d57696a6fc57f)
- Fixed a issue that was causing multiple search strings to be created for the same season or episode during a search, this would of caused unrequired searches to be performed. [`4576ade`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4576ade4ce37c3d984ec6a3051bbcf1551ad2ff1)
- Fix for version attribute error [`4fdbb24`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4fdbb245878b86ce3144a9920eea2aa172ab5a28)
- Fixed unicode issues [`1c56876`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1c56876ecc976f25c82b8ecc3f210065381c3cb0)
- Provider results get sorted by quality before filtering occures. [`d6442e0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d6442e06850ba03b4c506eece893dd0a4cda6ce2)
- Fix for DB issues on new installs relating to database version checks. [`0599a89`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0599a89565dcfc3ef433fea6e0f836456db36f4f)
- Fix for active and status sorting [`f4e351a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f4e351a1603fb151d74983f7c0801c14686b49ff)
- Fixes date timezone issues [`b0f1f2c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b0f1f2c91e28706f1983a661c44979882eeae8be)
- Fixed scene naming tests [`1a37238`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1a37238ba649cafd512443f407cc0c117e67d9b3)
- Fixes crash on general settings page when git output is none [`d5daa14`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d5daa14dc0463e53964461e16a8bcd60f12e5a50)
- Update .travis.yml [`d424920`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d42492017ed8762b4de0b0aa6e6b6ed3548daa52)
- Fixed bug "Unknown process method" in postProcessor [`bd84656`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bd84656517c34a215f40e016aa7be29f9c7e2c95)
- Update .travis.yml [`93f56ad`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/93f56adc7eaddba5898832c515502ddeb8c7c168)
- More fixes for source code updating [`1bf4790`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1bf47900dfbcd2f626b346892118c322a3d6de77)
- Possible fix for failed to send torrent errors [`f307317`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f3073174eda66863daf7d467ef4621a3728ffb81)
- Only walk lists if they are populated. [`e475d2a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e475d2a22d94a97576bf3743f324c7c2bc771cc2)
- Provider DB connections remain open instead of constantly open/close for misc db calls. [`423c09f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/423c09fd9edb9c64a0fc572bc4d781b2c00a8449)
- Fix for nameparser error during PP [`14fd0da`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/14fd0daa6c6c1249fbb3299be2203fa43a8437ec)
- Fix for post-processing issue of not being enough info [`b6f7753`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b6f7753ec746137ff94a425d2c165c77b37b200c)
- Fix for search iteration issue [`eeb632f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/eeb632fd0fd3363ed5854a800d4e06e11d0a2ece)
- Regex fixes to resolve issue #10 [`9ba772b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9ba772ba44348623486369a8128688f94ad826a8)
- Now returns both tvdbid and indexerid for 'future', 'history', 'sb.searchtvdb' and 'shows' [`5abd9b2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5abd9b2f97996774756883a64ce344c1c5f93f14)
- Memory cleanup in sql db routines for mass actions. [`b19aafb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b19aafb807703db24f20ca35357bba562cf8fc00)
- Update generic.py [`11f9a89`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/11f9a891f0d1dbf7fa5f444e1a67a80f2c65636b)
- Fixed up regex patterns for better matching of sports events [`8ee4770`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8ee477085eb282cc1936037ff1460bcd29015da1)
- remove duplicate variable [`09b106e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/09b106ec6b5a9f312dba215aa53c0736ccd09c57)
- Revert "Fixed up regex patterns for better matching of sports events" [`67b7eac`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/67b7eac21b929ad4e00310c09a0c06961c50f64c)
- Fix for basicauth and no user/pass set [`4513525`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4513525cc406b0f46e25708db6856e93146c0a26)
- Updated regex patterns to accommodate sports shows with dates in them. [`e30ed48`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e30ed48fcfbb32427a4427f54c6a88e2b276b42b)
- Fix for import issue with episodeCache [`3d062b3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3d062b35105ef32dcb471105e9fc9791f72ea53d)
- Fixes issue with daily searcher setting episodes past todays date to wanted. [`1f55b11`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1f55b11b7d53ea43408f566fa816dc63dca0b50b)
- Fixed issues with daily searcher [`6709ebd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6709ebdf129aed59a00c2879c5dea9e92f69d2f3)
- Update network_timezones.py [`4c5425f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4c5425f4d1e444ede262503896916d652989260c)
- Fix for issue #255, metadata saving for xbmc12+ [`880e923`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/880e9237149e46fe5a6bbe56b1f4efdf3544c1f8)
- Changed js code for checkout button to perform a windows.location.href to redirect on click event. [`27c4b66`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/27c4b66bf6015a8cded769de0abc67f668f0a834)
- fix for issues #321 and 258 [`16441c0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/16441c05824ebc4319b349127c5d14f931d82de3)
- Reverted episode cache changes [`c2ba2d6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c2ba2d6550df58e8008de634a0f96f7ab2eb249a)
- Fixed robots.txt method. [`508c094`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/508c094f484011517fdc8adaeffe04a5c9d123fb)
- remove default proxy setting, fix indent [`ddaa5bb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ddaa5bb5e671f18aaa9bc403275106c507eb4bf9)
- Update pushbullet.py [`f667e8a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f667e8a17ff2819be01fb31a27a5ac74452135c0)
- Fix for startup issues [`1b045d2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1b045d21948cce661db283f12c0facb860da98c2)
- Fixes issues with newznab providers [`905b41c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/905b41c46a22d52701615a06fcf68c4f021d9a55)
- Existing shows no longer display when adding new trending shows. [`a5c0fe1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a5c0fe1d3c76be3cadae56e0a933bdbfefc79d17)
- Fixes displayshow error for series with special characters [`d8e52f2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d8e52f209884703f4c4ef04280f97b69679d6f67)
- Fix for release results x264 issue [`cec0140`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cec01405d84ec196a942a1039923653c3c95d7d3)
- Using unicode for name keys now in NameParser cache, resolves 8-byte error. [`89c8ed4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/89c8ed437286fa48437e5751f60979ef5dfc3151)
- Updated readme again [`bcbdf77`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bcbdf77bcba4855d30c2644e1a5a9ea1ac97466e)
- Fix for transmission torrent client and ratio's [`43219e3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/43219e34e33751af0b33cbf8889b4507bd55b473)
- Use day numbers instead of text for language independent day name fuzzyness. [`02ecb18`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/02ecb18effddc15f2f90652f8778f8bb32bddcf4)
- Fix to have thread name include type of search [`dc56e77`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dc56e774b682f8c91012582b3095bb77148e5ec2)
- Fix for curRegex called before assignment issue that was pointed out to us. [`a65e688`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a65e68837c3ac58138611c88a29725da282a25e4)
- Fix for version branch issues. [`ad39ac8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ad39ac87728d9b03a07564741c60f2a02fcb2f52)
- More testing for auto-updater code [`3c215d8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3c215d8cdedd3b4ec7b76664453750a52bdb3fcb)
- Fix for new shows [`12ca73b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/12ca73bb0e851a98bf5fdfc2a08ed5eac60b7af8)
- Fixed cannot find 'capitalize' while searching for 'capitalize' error. [`7b187c3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7b187c3add63e47a8fea4b488b08116e37e7058f)
- Fixed inital scene numbering database check to look for a value of -1 before updating to insure this record gets done at startup once and once only [`c2e79bf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c2e79bf0319d055a7b4d65c31a40b34114237fc5)
- Fix for issues getting indexerID during cache updates [`dbee4b6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/dbee4b6dbf58862925be9fe55640702b75130b2f)
- Fixed air-by-date issues with downloading a show that results in downloading the incorrect show afterwards. [`ed8de59`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ed8de59e91b5516b2ce85b2c016d0a090045ec90)
- Fix for invalid literal for int() with base 10: 'NULL' [`4784b46`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4784b4619f18c38a630b6c65a549e95553319f33)
- Fix for renaming non-anime shows and absolute numberings being applied by mistake. [`39d9fc6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/39d9fc64346b4e0781c5070d8bd3af7309fb73ab)
- Fixed scene naming tests [`be0e3ab`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/be0e3ab83666c86f29eb22fc22e1919f117084b7)
- Fixes sql issues [`72828e1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/72828e1a8dd76537bf81a02022a965650946176b)
- Fixes issue #53, ignore words not working correctly [`9171a28`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9171a28f68e2bc635d50fa3e6f889483004740f9)
- Update changelog [`3ffb561`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3ffb561282f6478f9321aa0e127dc207297dd826)
- Fix for nonetype issues during parsing [`a9f1421`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a9f142184abdbef0c3b75efb15e00b9660f0b14c)
- Possible fix for failed to send torrent errors [`4752e07`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4752e07733b7969b3a3563d68ab1e2c82b980d6d)
- Bugfix - fix issue with Pushover test notifications, false-positive if api/user keys removed in UI but not yet saved [`e50ce50`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e50ce507e50126086aa229ef762efa1fcf52e838)
- Reverted previous changes made to regexes as no longer needed and started to cause false matches for h264 as a season and episode number result. [`9d8f695`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9d8f695e5ab7a88fad7d971a9493749b53db3075)
- Fix for tornado redirect function, was not properly returning. [`3c370fc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3c370fc5c9d348c7b37cf9f83c3b3562c62caa71)
- Fix post processing when using tvrage indexer and mediabrowser metadata generation [`687d2b9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/687d2b96abe2016a910d04decb4934ba8150b940)
- Correcting typos in prefer_season_download feature [`fde5ce4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fde5ce4c58576be22ea9727efe84a4ba04fab67c)
- PEP8 correction for search web html template [`640b840`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/640b840cdefeb0ff7672acf8cbf2f75b68ccd17f)
- Fixed ajax calls to update function. [`1908f76`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1908f76eaf198c52c85e8b0db04b77e03f971d76)
- Naming pattern issues resolved. [`ac7198a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ac7198a852894130f655e3a4a56f8d09ed9975bb)
- Make hardlink debug error more verbose [`560ffca`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/560ffca7dd46a6799c05d438fb6c1d6ae1324d28)
- Fixes issue #27 [`ea38289`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ea38289dd83b77c596d3dbeb26075075abdefb19)
- Fix for searches of anime shows with absolute numbering [`ba2a44b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ba2a44b1d1e74b0584719964a12e3539f5ce63fa)
- Removes primary keys and unique keys from xem_numbering table in cache.db [`e7cf923`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e7cf923cc03c42a982f09cd75c337ea4068dcb3c)
- Fixes issue with previous db migrations that failed and left behind tables that should have been dropped. [`bc79c93`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bc79c930185ebfe5a7a3b55f98bd20eaa41f0a32)
- Fixed ImportError: cannot import name OrderedDict [`7d2f7c8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7d2f7c82330f57e1da00006d7bda06f1e23b4473)
- Fix for mass add and existing shows adding [`775730c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/775730c3adb5e9597704dabd3b28802e9b27724b)
- Updated regex for show series name matching, faster matching. [`f16ee09`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f16ee09501b650b6ed04f30da594baa45ee927db)
- Resolves issues with saving notification settings and http(s) setting [`2b57fce`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2b57fce5e6bd4dd460009b0349e9e6fc1a51a637)
- Fix for adding new shows and issue with indexer_timeout [`e3da060`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e3da06000038608154b9a5b93e2c398b5f6500e3)
- Fixed backlog frequency calculator code for realtime changes [`47eb4fd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/47eb4fd21a0902402fb56042a2747b90e8ed3299)
- More XEM scene tests [`5d16eda`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5d16eda62026afa23532269fe38aeaa7aeedb94b)
- Fix for issue of downloading multiples of the same episode [`7ca19b8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7ca19b88d69b0362af862a2825035daa1c14945c)
- Fixes issues with settings and newznab providers. [`2a5598b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2a5598ba0fc367f80e5c82cae7ace6454fe66165)
- Fix for showobj none type [`e379d57`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e379d57376bf297690d2fe801be059aaf141b042)
- Fixes issue #325 [`6ee60d2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6ee60d213a663918b0ec7f2981407f108e309796)
- Fix for displayshows error: ValueError: invalid literal for int() with base 10: '' [`8063ac5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8063ac5d7a374f305e57c15c78948884df384462)
- Fixed bug that was causing issues with saving config. [`04213be`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/04213bebf2a6d94d0874a51b8804ca2c28f93150)
- Fix for show parsing errors to be displayed via debug logs now instead as a warning. [`0e3495d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0e3495d30f031e99da7b22994b217a6a12e761c8)
- Output success if *all* the many post processing actions are successful, otherwise indicate a problem occurred if one fails. [`d04937c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d04937cb8bd09a2ca31ed29a5353eabfdd02dba6)
- Fix for absolute numbering issue during renaming of files for non-anime shows. [`5fb3fe6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5fb3fe67974c8394384700de7b4e780c5e1fd3be)
- Revert "Minor change to subtitle code" [`93471b1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/93471b15e647adf24a6dbf5c0757709741e3d654)
- Fixed searching for new anime shows, unicode issues resolved and Naruto does indeed work! [`d07976f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d07976f05721fc1d27aaa6bd66caa817cb70a6b3)
- Fix for regex pattern to match Month's using more then 3 for there abbrv [`02ef367`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/02ef36758377d8b914e3422e731da3435cc8d7c9)
- Fixed issue of forbidden error [`29c5c4d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/29c5c4de4d9be73f64320d0c1447574c7f83038d)
- Fix for showPoster() api calls [`bd582d1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bd582d18d0d7ddb174e1f20aee765bb5315bab09)
- Fix for anime showObj regex matching. [`9dd679e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9dd679e30f886465644e6b91275c7c2e253f449b)
- Fixes missing uid and hash vars [`67073d0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/67073d007ed077561f5dc0a8b27580e6969ee45f)
- MainDB is backed up before being restored now to .r* versioned backup backups [`34009bb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/34009bb9b877ada1e057095d111a98733dce30d0)
- Fix for rls words [`cf99eb9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cf99eb962559cd52cb06f00449c402f3c29eae08)
- couple small bugfixes in code when it was expecting a string but got a integer instead well trying to create a search string for providers to use. [`146d9ba`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/146d9ba23b11fa0aa98841245f7aa6d813d18892)
- Fix for metadata mede8er provider for error: tvdb_attributenotfound: Cannot find attribute '_actors' [`561a12a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/561a12a735fb3623c37f8bc030f05160c0a2f1a0)
- Fix for adding existing shows. [`e6056c5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e6056c57450722f4a326790da4f5c8f0b0f528a1)
- Finally thanks to the new error handlers we have resolved the dredded issue 500 errors, enjoy! [`2b0b0dd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2b0b0dd885a751a8780a821f57735730c77c1592)
- fixed broken images when changing  from default (empty) [`c5949b4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c5949b4672334c4981d4b337d2d7d8c63a23858b)
- Fix for sql rowcount error [`f052848`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f052848e52c19b8384c56aec2a9b2ebe04df967d)
- fixed post-processing uncaught exception [`4cd67aa`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4cd67aa6ec53262c612abd0fc5ba849f594c7869)
- Updated readme [`5eaa84f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5eaa84f42922fb5e84a17b635b0f2fab756ce0e3)
- Corrected a sqlite syntax error [`0830de8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0830de89cd4eaf1c14e4e1dd38c0977157dca6ac)
- Fixed timezones (reversed) [`b842185`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b842185bad73b769e84d6f45fd5a07c3a6911add)
- Fix for edit shows and add shows. [`93e2e93`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/93e2e93b630fa977f32272c07382ec1ea44489b5)
- Making the links to submit issues actually work :) [`d4ad2e7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d4ad2e7fb75af73305f85c2ef746f36a6f7b147f)
- Fix for PID file: /tmp/sickbeard.pid already exists during auto updates [`95e928b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/95e928bfcbdc39ac6695d36a8fcfecee54194945)
- Fixed missing code. [`0871435`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/08714357ddee1c51712ef5a313df5192318c6d6e)
- Fixed small typo causing scene numbering to indexer numbering issues [`c6b064d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c6b064de23e4b50c5bf3242f0d99ecb9033d040e)
- Fixed search issues regarding error about result attribute being referenced early [`2193a4b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2193a4bfd1e5ad9826f4c6ddffae0fcf2f9df46d)
- Regex fixes [`50b792d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/50b792d6df92cda9cbc3eabae3e848093b4a3484)
- Bugfix in parser [`a4b11a0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a4b11a0c95472ae7948936fe413d3eed3ff6502b)
- Fixed issues with cache results being used during searches [`8f6d014`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8f6d0148307d1ba1b0bfcda43c55156725a28566)
- Fix for None type in cache [`e10a725`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e10a725d276c1bb85cf759f5ffb83813919c186b)
- Fixing typo in last commit [`981d661`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/981d6612b8cf527c11dc31b27132a762110767ee)
- Fix for looping issue during backlog searches [`1d339b9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1d339b97f6bb0a295951103f8430e1c467795993)
- Update growl.py with missing registration of update notification [`e58f3fd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e58f3fd9cd11c9537be0328ea334bdf2f890d6c0)
- Fixing more newznab issues sigh [`b43248a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b43248a6446269e1baf0ff62e1a7b570e6bb2b59)
- removed sleep timers from db code all together, overall speed increased. [`6e61314`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6e613145b32e3eb0a21df7e01f431990b0e380b6)
- Boxcar2 Notifications now working [`704281a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/704281ab589cc60972f2c0f4a4468c3a696f1c44)
- Fix for anime regex's 'anime_and_normal' pattern, resolves issues with show-queue refreshes [`a2a44ea`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a2a44eae85fe5729549ee5e9f4ad5fe2ea41b55a)
- Code fix [`3ae4c13`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3ae4c13104e489a0d68bdffa38de1be917a732c0)
- Code fix typo [`8c2c319`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8c2c319c7fdda040d3104467c65595c53ef0f2ba)
- Fixes originally aired dates and times issues. Please perform a mass update of all shows after updating to this new commit to have changes take affect. [`8ac0b79`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8ac0b799862ec323d96fd427434b8f01d4886f76)
- Fixed issue #20 [`fb85c6e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fb85c6e50e3e53bcd891bafbf0f9851b5d36d012)
- Fixed a typo issue [`4caf244`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4caf2441d616a8b48d3013c70c8d2747b20cf33d)
- Fix backlog nextrun to return datetime instead of just date [`41dbbba`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/41dbbbaa9bdf08fe42c45a2772a0ab1628f97be1)
- Fix for update frequency ... again! [`1cfe91e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1cfe91eb805e18f76e93631dc85bb8abdf26e9cc)
- Fix for shows that are air-by-date [`0ae27fa`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0ae27fa6e6dd9b2162919c7c4fabdb4151c6cce9)
- Fix for UnboundLocalError: local variable 'rating_text' referenced before assignment [`d42b864`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d42b864ecc254d0f5ff30ad0cad42ff1ac2d67b5)
- Update __init__.py [`5d9c84a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5d9c84a15ed996c9e92c5ce594e3dcacb30b038a)
- Fixed a typo [`331be09`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/331be097cb3a84a4bef65b38fa332256d14a9791)
- Minor change to subtitle code [`70c5a02`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/70c5a025807c537bd20ae2c09e64b4d2dc141dd9)
- Fixed missing ui notification for snatched episodes. [`5c43787`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5c4378756053a474e20c06ca237a69cd64a35738)
- Fix for rss torrent feeds, resolves issue #32 [`77696ca`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/77696cad66c91982d238965858228cfb4028f3ec)
- Fix for imdbinfo key error year [`15815c4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/15815c41ab3d9c6ba8769ba035fabdbe683746a3)
- More bugfixes for post processing code [`d282f76`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d282f76052516f4c18995d60e58963d0f3dbcea3)
- Fix for brnch checkouts from webui. [`4ff4ebb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4ff4ebb0d6bad8f2beeb86e46085b0b91f77d778)
- Fix anime naming patterns being stored as sports naming patterns [`b83b872`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b83b8721a03a416120f57f63b26aaf7bac6482f3)
- Update scc.py [`90620e4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/90620e47b88ef52aaa6a64dae21588c54de03bee)
- Post processing bug fixed, forgot to set out indexer api parms after correctly setting the indexer based on values from DB when performing automatic post processing lookups [`fddee6d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fddee6d687785252c451b887c12f42786d0c696c)
- Fix for new show searches [`00f38a7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/00f38a7157f95babeb40224d95fae69c777c6e04)
- fix_checkdates_in_the_future (itofzo) [`3e3e6d9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3e3e6d961d3d8415c484c22d1f2d4695ba0b9f46)
- Fix another unittest error [`5a5b2af`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5a5b2af676eb4eb4e99cd1a9882779a144561494)
- Fixed minor regex mistake in code. [`fcd54c9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fcd54c93d6a6482f0e0f8daeea964ee4f7b45f1b)
- Fix for scene exception and scene numbering updates when editing a show. [`9b78e3d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9b78e3dc5e4f54c12b37f58c784da157168a690b)
- Fixed bug #897, switched message to be classified as a warning instead of a error [`b829502`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b8295024befcc605c0e95e8977dea63eb7c8010d)
- Update .travis.yml [`47c7420`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/47c7420581a7e639da10933956af283a6a646748)
- Fixes show folder not deleting if files remain in folder [`4adad57`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4adad577c8133fd636912b83146b0121da142559)
- Fix for post-processing and adding anime shows to your anidb mylist [`6ca979d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6ca979d51bf1b4440334376cda098cc56411b792)
- Fixing error in findpropers when air-by-date search is attempted, but show is not air-by-date [`d1d9025`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d1d902597158e7c39149573615845e97e70aadf5)
- Fix for manual updates when auto-upate option is enabled. [`12ee35a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/12ee35a5e6c3f216b2334db5f1046145da76d1d3)
- Fixed issue with searches that contain special characters such as () [`aa94711`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/aa94711788f3a74ea39aeb89b8d9d37cc63c9deb)
- Update config_search.tmpl [`2d64af4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2d64af4b93d898ce50bee07315d66d22f66ce48d)
- Update config_providers.tmpl [`5b9471b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5b9471b2cdecc6179adc2736148735dcd687c7d7)
- Fixed backlog searches [`85019f0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/85019f07e4694d9d939113982b83edbe702985a7)
- Deletes duplicates found in tv provider cache before creating unique index for provider table or just performs cleanup of any duplicate record period. [`13cbffb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/13cbffb6d485828e73359df9def28a79176faa04)
- Fixed code to set branch version at startup [`bd2748d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bd2748d33aba2137848c99e8ef184e59341a9200)
- Fix for autoreload issues [`09297b8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/09297b853b4c18fff1dc4f451e26047de71d0744)
- Limiting search to English-translated only (for now) [`0e989fe`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0e989fe90fa7d00863e84297eed72da14ea140e0)
- Update .travis.yml [`4d96b01`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4d96b01f028d4db63662f74ef02d5f16433acc64)
- Clarify description for backlog searches option on provider settings page [`195277f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/195277f708a4272ff39cc3094f82e387be4adb1c)
- Fix for mediabrowser absolute_number issue [`b9fa92e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b9fa92e439bad6eae65b7206f36a948cdc0c929f)
- Fix for failed download handling and sql issues [`2eec706`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2eec706197c5482e6204df236f4ace9b7a177233)
- Bugfix for sports regex matching [`e62250d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e62250d63b3d0f6d590b0796f484382bef7c39ea)
- Fixes unicode issues during searches on newznab providers when rid mapping occurs [`e63ffd3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e63ffd363cc4e566313c441088b4d36a285258c0)
- Fixes issue #337 [`bb4ef18`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bb4ef18fe3921bf1414174f95d7675506bb3533f)
- Fix for rss feeds clearcache [`7bff5a2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7bff5a246f6823aaf01c63e9215928c925c9d022)
- Fixed saving general settings rootDir error [`610d1af`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/610d1af4f0e08e3b9a68419dcaa98b7670f72bbf)
- Fixed saving general settings rootDir error [`a0ef748`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a0ef748f3b2d00342ed5759cb2d9a9db6ed1bdc1)
- Possible fix for error 500 in web gui when trying to get a show poster and showList is not yet been init'd [`8045976`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8045976c1519a2e54e898d737cdcc2b9d6568db4)
- Changed log message to be less confusing for torrents [`0a936ea`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0a936ea1ef6932b5301505c8fe3ea1a573e6e00a)
- Change reporting failed network_timezones.txt updates from an error to a warning. [`afce91f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/afce91f79de9bc09a97e3ca3520e2819efcc8cca)
- Fixed up sports regex matching pattern [`42b11cd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/42b11cd00015be6ab228d2b4ba8d74d571d14936)
- PublicHD removed till further notice. [`4df31bc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4df31bcceeff034f151fe3160ba2b740d04a75bd)
- Fix for startup issues after last commit [`03c3c96`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/03c3c9666be4341eba391478931e8c2c84308332)
- PickBestResult x264 over xvid where both exist. [`6988ffb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/6988ffb82bda62ab1fffa5ab629a99f566041fbf)
- Disabled purging of feed-cache items for providers. [`cc07bdb`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cc07bdb12f0ebfc7904a4a51e88c12de0c09cce1)
- Fix for thread locking issues [`bf31077`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bf31077cc295f8ed39feb3187642311718a6971a)
- Fixes issue #161 [`a5836af`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a5836afa4f225d87202260671c8e31b1eb7467d1)
- rawhd update [`76e8c73`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/76e8c73c4b78b82d98d0fa2d1736e8f9b98b2d45)
- Fixed indent properly [`9fd3414`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9fd3414d3cadf4a60a565a2e8a6256e20262f6c6)
- Fix for uncaught exception error for 404 errors [`06e99ce`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/06e99ce4a76bfe046abb2877469d6f9eb9113235)
- Fixed indent [`c37e291`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c37e2911eab85248d580f45e525f615b5ba63764)
- Corrected self.finish to self.write [`145433e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/145433e19a994a617cf379ba4f48600c717153a6)
- Fixed issue with appending UNNOWN qualities to provider results after being sorted. [`899d03b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/899d03b5feb3184c6e58ad7173126166a76f6cbf)
- Fix for sports naming issues [`ba660a1`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ba660a194206374ff5016e9fb7dff3fe2d24e204)
- Fixed for adding new shows [`a742c27`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a742c27f09ce487cabba85ad0c5bad1f0eced563)
- Fix for strftime and thread locking issues [`826a9aa`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/826a9aab6a942cf20b92a6d0a00e8ed18b9b5021)
- Logo change [`43f66f6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/43f66f63cf9fa3d4364cdb398615d5005683509b)
- don't use proxy by default [`348c0ed`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/348c0edf261c1120a0504c3b0a294c18c587f257)
- Fixed improper line indentation [`1790653`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/17906539ae037c04b9840114ed07669f6201791d)
- Fixed code that was preventing branch checkouts from working. [`ef8b4e5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ef8b4e587dd63c7568d8d0938b27aa90ef19d248)
- Renamed filename for donate button [`e3db9b8`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e3db9b8c93ef75d3b58cca66b73c4e87db9e7a00)
- Deluge likes a username as well. Updating UI to show it. [`33751b2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/33751b2c6182b689c8d552896fec9144ff17821f)
- Only log deletion when we're really deleting [`a843303`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a843303812e940ded5788d4cd99e5a89b16af053)
- Fix for adding and importing shows [`94f688a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/94f688a1bc4ca530198907a957e9b0d4ee7a9eb7)
- Fix for XBMC notifier [`c7e58ca`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c7e58cadb547593a3bebd0591cb4107a3e39b6e7)
- Bottom of page backlog nextrun shows time as well as date now [`4a03885`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4a03885956551cd62f1f9c5d711674670e7a6a5b)
- Bugfix in the metadata code [`c9ddd63`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c9ddd633eed8a16e52105a4639935bdf35b3134e)
- Bugfix for XBMC 12+ metadata parser [`3bdebb4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3bdebb4e6d7e61503cf825a833023184927a498a)
- Fix for airdate issues during proper search [`b59c8fd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b59c8fd1ec13bd6a53a498eaf240177b23f46580)
- Fixes issue of missing ui notification to let you know that there was no update needed when forcing a version check. [`753be64`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/753be6409031002b7f0eca289461836a6ca0950b)
- Fixed unicode error [`f5a6d45`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f5a6d45d8f8cecb3ee5884e8eba5bdb0a38961e8)
- Fix for backlog searches [`d8171ac`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d8171acc9718cf61b7d02aae4c72f203c3bd282e)
- NextEpisode sets episodes that dont return a next air date to todays date to help improve load times for home page. [`23239e0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/23239e0a5d7b112c939f781d15f65c7a3f3b679a)
- Fixed video root issues for video player [`3eab864`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3eab86478a1d22df34a72d11fcec9c23ac324338)
- Fix for rssfeed [`99da474`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/99da47464dcb85d26125a6a861de3b8c3eea29cb)
- Can't += dicts. Need to dict.copy() [`4bfb271`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4bfb271e8d447c2aad5b42cdbcbb37c3dc95f62f)
- Fixed typo in searchBacklog. Introduced with search from delta functionality. [`47cd8b5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/47cd8b53f0d83ae72c0b4996c9a1eb76d5243d64)
- Fix for ignore_words [`f10dd31`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f10dd3131fff3dc8dc123ba6f8e154c4bab1e607)
- Fixed typo causing addexisting shows page to not function correctly [`deb355e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/deb355ef88c7f62b472210790e5fa4d983ee1e91)
- When no absolute episode number retrieved, fall backto the scene_episode. Else search will be done for episode: 00 [`4b1b3c6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4b1b3c6488d68cb73b4d535a561bace7447ee847)
- varable [`e02490e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e02490ee26afcbca8f195a0dca85dabefbebed19)
- Minor code correction. [`f5725f4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f5725f44022d87d17d1a2c15434d8855d444127c)
- Update fuzzyMoment.js [`144a05f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/144a05ff2054d1fe5bbcffc9c72b7a5c82c9741d)
- Fix for issue #291 [`74c6bec`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/74c6bec150190cb92b479e58602797ed9500a550)
- Fix for Newznab providers [`26e259c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/26e259c03606c6cc03ff06c15a8abd295a2ced00)
- Changing sorting order for email notification lists to alphabetical, ascending [`71cd579`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/71cd57927fd7670f9e6d99bc2c11c40b1fa6c802)
- Fixed backlog search details [`cd04d79`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cd04d79af5b9bb69670c516501f9ca60e7a25217)
- Fixes typo in previous commit [`ba5e547`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ba5e5478e02b83045348ca5a83a495c4d8a00c70)
- Increasing generic client timeout to 20s to work around busy hosts [`812e844`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/812e8443bd83d31d6e363fd8d4a634f8bc2116fa)
- Fix for restarts/updates issues when running as a daemon. [`39f32b3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/39f32b3b7cd9edb09d9597571c34c8f66434b456)
- Fixed error when saving blank ratio's [`32cf17c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/32cf17c638dd6a5cddba951762e5238c1151e255)
- Fixed issue with daily search progress monitoring. [`840f7c7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/840f7c7bdfa9999a0fcda4ca1c8da72d8edad842)
- Update db.py [`2079863`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/20798639ae86b580c27e0b95fbc5a93d59e5778b)
- Fixed issue with backup/resotre config file variable [`696a1a9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/696a1a9f4af2e6c82afa6e12f2ca377e6b16bc82)
- Path detection for icons was still in midgetspy format. [`da8e2e3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/da8e2e3d1918399e7c2ffe280577f7f14c489663)
- fix indent [`5007b80`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5007b806a55a95162fc4cf1305dfd27bab856143)
- Fix typo [`cea8fd3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cea8fd3216146409de52e6e4c9dd64733accbc69)
- Update tv.py [`3384e2c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3384e2c51d2f7ec8caeb715eb37da1e814ff10ba)
- Possible fix for incorrect show matches [`b03ffa2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b03ffa231d26990af685acd6c20dac80631e84aa)
- Code typo fixed [`f1c45a5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f1c45a596dd22878ef06b5f5f0698ed0f160a9cf)
- Fixes issue #423 [`a0bd46c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a0bd46c18a6000c188dca55194361433c7265536)
- Fixes shows not being added from tvrage [`3c9f1d7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3c9f1d754d52673434278b46eba5287f493cbdd3)
- Fix so that scene converting does not happening when performing naming pattern routines. [`b0149cc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b0149cc65df8a8091f9f51d1729c2e875a2f9747)
- Fix for default sports naming pattern issue #269 [`bb3e609`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bb3e6095654c583166aa4755639485d21b90aacb)
- Code correction [`50b91f9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/50b91f9d7ceae7b3ba0b7b8cdd609235e54ccc1d)
- Misc code cleanup [`b3246b0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b3246b00496b0f8697ec41be3f95e32160b5db5e)
- PEP8 Cleanups [`fcded3c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fcded3c3cf474b7e28371cf84aa748e77ee3358a)
- fix for fuzzydates on comingepisodes list [`060fa65`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/060fa6562d35e867c7d0b96624444a7da10f5e66)
- Code fix for attribute error [`9714fc3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9714fc3299774e013fec3c74c12b701d653ecd61)
- forgot to remove print [`2af5b95`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2af5b95a9d77db87eebbaf0c95c3bf67f3bb7352)
- Fixed post-processing issues for anime shows. [`72b4155`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/72b4155b0b66f9e0879ba70070d0372a05899a65)
- Fixed issue #473 [`bc05a9f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bc05a9f6fad2ab77f38c7877879c992260566c56)
- Update scc.py [`5b713f0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5b713f0262644023ebbd335ea1172d9ffcd20a84)
- Fixed issue #37, ignore words [`4c84351`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4c8435130680fd089b4bcb0bddc87946af1d5634)
- Had a few requests for this so here it is. [`88f7ef2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/88f7ef2c93c1da4b777c99489d0cf8fb2d759d71)
- Update testRename.tmpl [`ea8d109`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ea8d10902907e61cd3f3727ce1447c7ec7d2d7c0)
- Fix omgwtfnzb provider retention = 1 bug [`a72779d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a72779d5d31147f1d31e51f5819a11efd28d5ca2)
- Removed unneeded code from theme_name tests yesterday [`db6eb33`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/db6eb33db4770da6cff641560ea08f75c5569c8f)
- Forgot and int() [`c62e34c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c62e34c601b4a5052a101481bc247a9f089af788)
- Fix for custom newznab providers with leading integer in name [`c26eb39`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c26eb396957ec09be592ce4ea86d9cd5f4ef0fda)
- Fixed typo [`cd91e24`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cd91e2430f1c7744667ce0cda8d2c0bb1dfa3213)
- Fix for show_queue errors when loading a show [`5ec5dde`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5ec5dde9bab216e8168dda89b6b394c9b39be035)
- We're moving! [`215942f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/215942f445f7202aa3ec3387dbfae01f13c228ff)
- Fix for show opt not in __init__ issues [`0ddcc3b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/0ddcc3b58a65c302d30fde8d0abd754d54bb0986)
- Fixed a small typo in versionChecker [`b4efb2d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b4efb2d641b0649618176c30b3dcd792849221cb)
- No need to convert from absolute numbers to season/episode numbers twice, fixed! [`4f32ed2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4f32ed262c4c9f955408f5deb7b8b05c4174a2a9)
- Make failed torrent log message more verbose [`16a54e6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/16a54e62d6ee2fce6883ae8ab4bddaa79fece6c0)
- Code correction for scene conversion in Parsing cache [`a912140`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a912140ec582d9ea7484563b785fbe0df5c9e9f4)
- Change: reduce details width on display show page for new page width. [`7bff816`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7bff81694729435b49f074e50ac9e74875b51b88)
- Fix for naming pattern issues. [`5802fc3`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5802fc372cf42782a163ed3aab020dc306a66bbe)
- Fixes classification issues for determining if a show is air-by-date or sports or regular [`d14581b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d14581b8ccd7d6ed38838b64655694d7f0c0e79c)
- fix for tornado error handler [`bbbc746`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bbbc7469fbaba6942b075c544967c11759c6441f)
- Fixed issue with saving show info to DB [`a47136e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/a47136e551a3df4366a7794f797e27e8d793bcfe)
- Fix for bug #898, fixes issues with show image overlay when using small poster layout [`aa76734`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/aa76734f56c1b0f2f23cfd0f0432a5aac3969b52)
- Fixed newznab to search no more then 1000 results [`991a939`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/991a93991e515630e75d82b723aa711e98f1bd43)
- fix not loading proxy_indexers config [`ea3a165`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ea3a16598794f7031eac8aea8524486eb22efc64)
- Fixed bug in cache controller [`c309e8a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c309e8afc91426ec8c4150e78cfe40c73af821d0)
- Fix for scene numbering issues [`7ce27b7`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/7ce27b72f5944f1115b37f713ba72b44f63cfa1e)
- Fixed version string [`faa6ca5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/faa6ca5103d279710f03e76392260addd826c372)
- Fixed IntegrityError caused by primary key not being unique [`97db8fd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/97db8fd408380721325a7cda8a428415546806be)
- Fix for issue #17 [`69691f9`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/69691f9d417f3cdf418dd9d1b0c9fd6062ba8c4f)
- add subtitle to cmd show and shows [`f185c1f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f185c1fee0e96b70667a635af041248ca21f3a5b)
- Fix exception raised when converting 12pm to 24hr format, also handles 12am. [`d6950bc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/d6950bc6f140884335dfcd5d92ea0b076d978d7a)
- Fix for scene exception update error, please delete cache.db file for this to fix tow take affect. [`067438b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/067438b5d91a6a99eb818da227795ee8527c9176)
- Removed a sleep timer [`3fd5f75`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3fd5f75180ddf4f9d14d563852cbe2713ab47ade)
- Removed unrequired extra sql transaction append line. [`37fceb2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/37fceb2704629c5c6355d0d50a53414bd57c2613)
- Fixes issue #374 [`afdbc44`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/afdbc44a4790fcda0af881071b2a886b94dc76f2)
- More fixes for webui branch checkout feature. [`e9eca83`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e9eca837a899d79859712a5c30c2310950adfb4c)
- More cache fixes [`cc02967`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cc0296783b264250974a2b8824da58d8858946a8)
- Fixed notifier failing when it shouldn't [`ff9c8ae`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ff9c8ae82cf797cc0887de266b841d79f8472703)
- Fix typo in last commit [`8f3469c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/8f3469cce7d610022453b88846cdea9c164be91b)
- Missed coverting scene_numbering table, fixed! [`999b1ba`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/999b1bafe000e52e098a598442275c5e0734c858)
- Changing default auto-update to disabled, while we're pushing many updates [`48b4abf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/48b4abffa51ec6e7d2653af4f022f9539cb38942)
- Fix for season pack searches [`e2d1178`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e2d11785150f65b30855971ba69a76f49d3684d4)
- Previous fix to air dates did not take but this fix does correct the issue once causing malformed air dates or no air dates at all. [`f3c3327`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f3c33279b5162aa27bf18c3e084f57f282202398)
- Fix for mass edit [`4443a5a`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4443a5a6497af9f8edf4b08a18d577ee6e00e138)
- Fixed issue for season searches using episode only mode but fallback to season only mode, was small typo correction [`71604b5`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/71604b576994c0987623830c2e82086515479cbc)
- Missed one :P [`ac65eab`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/ac65eab3c062c902553d9b46cc81b7549be4558f)
- Fix for issue #182 [`51f691e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/51f691eeb221411ff6a847a256284148dc2bb92b)
- Fixed branch version to reflect proper branch [`1eb5fe4`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1eb5fe4fafb05c082c95c97c672ec9bbf4209a2e)
- Fixed regex issue [`3e958ca`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/3e958ca0e1a517f542b130709a0859956811e737)
- Fix to stop removal message of cache items from occuring when untrue [`628fe23`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/628fe23f8d5ed548bfe30030ca61e612b969f5b7)
- Fixed regex issue [`297e690`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/297e69094aa3e1c0e236b446f6d53d1ec86d5555)
- Fixed issue of unknown attribute keyword 'show' [`872056c`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/872056cc5dbe6db2582e41f33dd4188202d5daf7)
- Update show_name_helpers.py [`c0dedd0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c0dedd080f42b89505bf7dc42b512f2f925aecd9)
- Fixed basic auth realm issue, needed to be quoted. [`e202cbc`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e202cbc0ac18aea37f74b17369aee5f90c840439)
- Revert: Fixed regex issue (3e958ca0e1a517f542b130709a0859956811e737) [`9257a5f`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9257a5f2febe5f5298dbc2b738e69ce615fd72bc)
- Fix for api builder. [`2e8c8a2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/2e8c8a262fab094108459b152b9180b88b6fa658)
- Fix for indexer being sent as unicode when its supposed to me integer [`cecd35b`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cecd35bb5d9a6029ef63b265a9d6122578f6d291)
- Possible fix for high CPU usage when doing NZB searches [`4fe3a96`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/4fe3a9605165addf4b6602712991a1836081a883)
- Fix for H.264 issues related to regexes and matching for parsing release names. [`858951d`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/858951d31c511b02636e670e5d8b0107515c8289)
- Reverse proxy support fixed [`5124771`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/51247710bbdd647ab16aba00d4de050c6763b690)
- Made all init scripts executable [`1845bdd`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1845bdd5a9655e4bcce30eaf0f8c421907e95a7f)
- Fixing UnboundLocalError when attempting to process nonexisting dir [`44d45ca`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/44d45ca760acf9305db15ad82e62f0d7823eaa53)
- Removed unrequired version file. [`bfe0a00`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/bfe0a00cc7466559e547f0effeb7d91ab9500b97)
- Fix for missing indexerid number when performing naming pattern tests. [`267affa`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/267affa5e99120df7ef39854201f80719003aacb)
- Fix for force update and autoreload [`9790b30`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9790b30b904d5fbccbcd0ef9be49ce9d7b3f65ad)
- Fixed post-processing loop issue. [`5f0265e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5f0265e769901f438b68ac4b18d2c9a320974dcb)
- Update comingEpisodes.tmpl to prevent a 'NotFound' error for cur_ep_enddate [`f3c1fa6`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/f3c1fa6b61102b041595023b6018d5336c11eb18)
- Possible fix for failed to send torrent errors [`88d68cf`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/88d68cfe11e8f5ef80c87a8935121901d4460bc7)
- Reverted episode cache changes [`013f9a2`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/013f9a2134390abf75e5120bebdbf06ca1e4f993)
- Fix for startup issue due to dependant that was missing. [`1dc9138`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/1dc913824a0e91994cca88463cc6001914382276)
- Fix for issue #274, ebObj ref'd before assignment [`5ba99db`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/5ba99db64ef9f43c9f531560711931772196244b)
- Fixed typo. [`b3bfe99`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/b3bfe99faddc2ea0b9f2595901bcf9fec835bee0)
- Fixed anime button in settings [`500f387`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/500f387bad43090bbc9e2c9d3ab5393f2f7fb0dc)
- Renamed filename for wgn america network logo [`fc23454`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/fc23454a1e24df1c9005d519ca31a07da20d00ed)
- New logo design idea [`9bf38c0`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/9bf38c07aec2e9a00998192f7f420a33b1ee20a9)
- Updated logo design and removed old one [`72a1e4e`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/72a1e4e580bfd06acb66b641f438d7a6c4a3c8e6)
- Fix for missing regex module for python2.7 users [`90d0119`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/90d011990c755f96a8041f92962e5d05d01b5d2c)
- Fix, update and add some network specific logos as seen on the home page in "poster" view mode. [`e99d779`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/e99d779f7d9436758d4fa9f38bd0ccdb1a46f6e5)
- Fix for missing regex module for python2.6 users [`c581179`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/c5811791d0ce5975b3679aab4eb336d31c0d502b)
- Updated network logo's to their current logo & made BBC logo's display nicer. [`cf1a3aa`](https://git.sickrage.ca/SiCKRAGE/sickrage/commit/cf1a3aa5d82544e39ea6021b322fa5b9072d3493)
